-- Agregar campos para entidades de gobierno
If Not Exists (Select SysColumns.Name
               From SysColumns 
               Left Join SysObjects ON SysColumns.id = SysObjects.id
               Where Upper(SysColumns.Name) = 'CLAVESAT' And Upper(SysObjects.Name) = 'NOMINA1_ANUAL')
  Begin
    Alter Table Nomina1_Anual Add ClaveSAT     VarChar(3)    DEFAULT ''
    Alter Table Nomina1_Anual Add PorcientoSAT Numeric(12,4) DEFAULT 0
  End
Go

If Not Exists (Select SysColumns.Name
               From SysColumns 
               Left Join SysObjects ON SysColumns.id = SysObjects.id
               Where Upper(SysColumns.Name) = 'OTROSPAGOS' And Upper(SysObjects.Name) = 'NOMINA1_ANUAL')
  Alter Table Nomina1_Anual Add OtrosPagos Numeric(12,2) DEFAULT 0
Go

-- Estos campos son para los CFDIs 2017
IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE UPPER(syscolumns.name) = 'SINDICATO' AND UPPER(sysobjects.name) = 'NOMINA1_ANUAL')
  BEGIN
    ALTER TABLE Nomina1_Anual ADD Sindicato    CHAR(1)    NULL
    ALTER TABLE Nomina1_Anual ADD ClaveEstado  VARCHAR(3) NULL
    ALTER TABLE Nomina1_Anual ADD Clase        VARCHAR(2) NULL
    ALTER TABLE Nomina1_Anual ADD TipoContrato INTEGER    NULL
    ALTER TABLE Nomina1_Anual ADD TipoRegimen  INTEGER    NULL
  END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'PeriodicidadPagoSAT'
                        AND sysobjects.name = 'Nominas' ) 
    ALTER TABLE dbo.Nominas ADD PeriodicidadPagoSAT CHAR(02) NULL
GO

UPDATE  dbo.Nominas
SET     PeriodicidadPagoSAT = CASE WHEN frecuencia = 07 THEN '02'
                                   WHEN frecuencia = 14 THEN '03'
                                   WHEN frecuencia = 15 THEN '04'
                                   WHEN frecuencia = 30 THEN '05'
                                   WHEN frecuencia = 10 THEN '10'
                              END
WHERE   tiponom > 0
        AND PeriodicidadPagoSAT IS NULL                                                    
GO

IF OBJECT_ID('dbo.Fun_R_LeeDsVacaciones') IS NOT NULL
  DROP FUNCTION dbo.Fun_R_LeeDsVacaciones
GO


--print dbo.fun_r_leedsvacaciones(1074,2,'20110301','20110315',0,1,'DS')


CREATE FUNCTION dbo.Fun_R_LeeDsVacaciones
(
  @nCodigo         INTEGER, 
  @nEmpresa        INTEGER,
  @dInicio         DATETIME,
  @dTermino        DATETIME,
  @nDiasVacaciones INTEGER,
  @nHorario        INTEGER,
  @cValor          CHAR(2),
  @cFuncion        CHAR(1)
)

RETURNS NUMERIC(8,4)

AS

BEGIN

  /*
  Declare @nCodigo  Integer
  Declare @dInicio  DateTime
  Declare @dTermino DateTime
  Declare @nEmpresa Integer
  Declare @nDiasVacaciones Integer
  Declare @nHorario Integer
  Declare @cValor   Char(2)
  
  Set @nCodigo  = 1074
  Set @dInicio  = '20110301'
  Set @dTermino = '20110315'
  Set @nEmpresa = 2
  Set @nDiasVacaciones = 0
  Set @nHorario = 0
  Set @cValor   = 'DS'
  */
  
  DECLARE @nRegresaValor NUMERIC(8,4)
  
  IF @cValor = 'DS'
    BEGIN
      IF @cFuncion = 'R'
        SET @nRegresaValor = ISNULL( (SELECT SUM( DATEDIFF(DD,CASE WHEN Tmp_KardexVac.Fch_Inicio < @dInicio
                                                                   THEN @dInicio
                                                                   ELSE Tmp_KardexVac.Fch_Inicio
                                                              END,
                                                              CASE WHEN Tmp_KardexVac.Fch_Cierre > @dTermino
                                                                   THEN @dTermino
                                                                   ELSE Tmp_KardexVac.Fch_Cierre
                                                              END)+1 )
                                      FROM Tmp_KardexVac
                                      WHERE Tmp_KardexVac.Codigo = @nCodigo AND
                                            Tmp_KardexVac.Num_Conc = 30 AND
                                            Tmp_KardexVac.Nomina IN ('ORD','VAC') AND
                                            ((Tmp_KardexVac.Fch_Inicio BETWEEN @dInicio AND @dTermino) OR
                                             (Tmp_KardexVac.Fch_Cierre BETWEEN @dInicio AND @dTermino) OR
                                             (@dInicio BETWEEN Tmp_KardexVac.Fch_Inicio AND Tmp_KardexVac.Fch_Cierre) OR
                                             (@dTermino BETWEEN Tmp_KardexVac.Fch_Inicio AND Tmp_KardexVac.Fch_Cierre)) AND
                                            Tmp_KardexVac.Empresa = @nEmpresa),0)
      ELSE
        SET @nRegresaValor = ISNULL( (SELECT SUM( DATEDIFF(DD,CASE WHEN Kardex.Fch_Inicio < @dInicio
                                                                   THEN @dInicio
                                                                   ELSE Kardex.Fch_Inicio
                                                              END,
                                                              CASE WHEN Kardex.Fch_Cierre > @dTermino
                                                                   THEN @dTermino
                                                                   ELSE Kardex.Fch_Cierre
                                                              END)+1 )
                                      FROM Kardex
                                      WHERE Kardex.Codigo = @nCodigo AND
                                            Kardex.Num_Conc = 30 AND
                                            Kardex.Nomina = 'VAC' AND
                                            ((Kardex.Fch_Inicio BETWEEN @dInicio AND @dTermino) OR
                                             (Kardex.Fch_Cierre BETWEEN @dInicio AND @dTermino) OR
                                             (@dInicio BETWEEN Kardex.Fch_Inicio AND Kardex.Fch_Cierre) OR
                                             (@dTermino BETWEEN Kardex.Fch_Inicio AND Kardex.Fch_Cierre)) AND
                                            Kardex.Empresa = @nEmpresa),0) +
                             ISNULL( (SELECT SUM( DATEDIFF(DD,CASE WHEN Kardex_Anual.Fch_Inicio < @dInicio
                                                                   THEN @dInicio
                                                                   ELSE Kardex_Anual.Fch_Inicio
                                                              END,
                                                              CASE WHEN Kardex_Anual.Fch_Cierre > @dTermino
                                                                   THEN @dTermino
                                                                   ELSE Kardex_Anual.Fch_Cierre
                                                              END)+1 )
                                      FROM Kardex_Anual
                                      WHERE Kardex_Anual.Codigo = @nCodigo AND
                                            Kardex_Anual.Num_Conc = 30 AND
                                            Kardex_Anual.Nomina In ('ORD','VAC') AND
                                            ISNULL(Kardex_Anual.Tipo_Mov,'') <> 'FIN' AND
                                            ((Kardex_Anual.Fch_Inicio BETWEEN @dInicio AND @dTermino) OR
                                             (Kardex_Anual.Fch_Cierre BETWEEN @dInicio AND @dTermino) OR
                                             (@dInicio BETWEEN Kardex_Anual.Fch_Inicio AND Kardex_Anual.Fch_Cierre) OR
                                             (@dTermino BETWEEN Kardex_Anual.Fch_Inicio AND Kardex_Anual.Fch_Cierre)) AND
                                            Kardex_Anual.Empresa = @nEmpresa),0)

    END

  ELSE
    BEGIN
      IF @cFuncion = 'R'
        SET @nRegresaValor = ISNULL( (SELECT SUM( CONVERT(NUMERIC(8,4), dbo.Fun_R_FactorSeptimoDia(CASE WHEN Tmp_KardexVac.Fch_Inicio < @dInicio
                                                                                                        THEN @dInicio
                                                                                                        ELSE Tmp_KardexVac.Fch_Inicio
                                                                                                   END,
                                                                                                   CASE WHEN Tmp_KardexVac.Fch_Cierre > @dTermino
                                                                                                        THEN @dTermino
                                                                                                        ELSE Tmp_KardexVac.Fch_Cierre
                                                                                                   END,
                                                                                                   @nDiasVacaciones,
                                                                                                   @nHorario,
                                                                                                   @nEmpresa,
                                                                                                   'DS') ) )
                                      FROM Tmp_KardexVac
                                      WHERE Tmp_KardexVac.Codigo = @nCodigo AND
                                            Tmp_KardexVac.Num_Conc = 30 AND
                                            Tmp_KardexVac.Nomina IN ('ORD','VAC') AND
                                            ((Tmp_KardexVac.Fch_Inicio BETWEEN @dInicio AND @dTermino) OR
                                             (Tmp_KardexVac.Fch_Cierre BETWEEN @dInicio AND @dTermino) OR
                                             (@dInicio BETWEEN Tmp_KardexVac.Fch_Inicio AND Tmp_KardexVac.Fch_Cierre) OR
                                             (@dTermino BETWEEN Tmp_KardexVac.Fch_Inicio AND Tmp_KardexVac.Fch_Cierre)) AND
                                            Tmp_KardexVac.Empresa = @nEmpresa),0) 
      ELSE
        SET @nRegresaValor = ISNULL( (SELECT SUM( CONVERT(NUMERIC(8,4), dbo.Fun_R_FactorSeptimoDia(CASE WHEN Kardex.Fch_Inicio < @dInicio
                                                                                                        THEN @dInicio
                                                                                                        ELSE Kardex.Fch_Inicio
                                                                                                   END,
                                                                                                   CASE WHEN Kardex.Fch_Cierre > @dTermino
                                                                                                        THEN @dTermino
                                                                                                        ELSE Kardex.Fch_Cierre
                                                                                                   END,
                                                                                                   @nDiasVacaciones,
                                                                                                   @nHorario,
                                                                                                   @nEmpresa,
                                                                                                   'DS') ) )
                                      FROM Kardex
                                      WHERE Kardex.Codigo = @nCodigo AND
                                            Kardex.Num_Conc = 30 AND
                                            Kardex.Nomina = 'VAC' AND
                                            ((Kardex.Fch_Inicio BETWEEN @dInicio AND @dTermino) OR
                                             (Kardex.Fch_Cierre BETWEEN @dInicio AND @dTermino) OR
                                             (@dInicio BETWEEN Kardex.Fch_Inicio AND Kardex.Fch_Cierre) OR
                                             (@dTermino BETWEEN Kardex.Fch_Inicio AND Kardex.Fch_Cierre)) AND
                                            Kardex.Empresa = @nEmpresa),0) + 
                             ISNULL( (SELECT SUM( CONVERT(NUMERIC(8,4), dbo.Fun_R_FactorSeptimoDia(CASE WHEN Kardex_Anual.Fch_Inicio < @dInicio
                                                                                                        THEN @dInicio
                                                                                                        ELSE Kardex_Anual.Fch_Inicio
                                                                                                   END,
                                                                                                   CASE WHEN Kardex_Anual.Fch_Cierre > @dTermino
                                                                                                        THEN @dTermino
                                                                                                      ELSE Kardex_Anual.Fch_Cierre
                                                                                                   END,
                                                                                                   @nDiasVacaciones,
                                                                                                   @nHorario,
                                                                                                   @nEmpresa,
                                                                                                   'DS') ) )
                                      FROM Kardex_Anual
                                      WHERE Kardex_Anual.Codigo = @nCodigo AND
                                            Kardex_Anual.Num_Conc = 30 AND
                                            Kardex_Anual.Nomina IN ('ORD','VAC') AND
                                            ISNULL(Kardex_Anual.Tipo_Mov,'') <> 'FIN' AND
                                            ((Kardex_Anual.Fch_Inicio BETWEEN @dInicio AND @dTermino) OR
                                             (Kardex_Anual.Fch_Cierre BETWEEN @dInicio AND @dTermino) OR
                                             (@dInicio BETWEEN Kardex_Anual.Fch_Inicio AND Kardex_Anual.Fch_Cierre) OR
                                             (@dTermino BETWEEN Kardex_Anual.Fch_Inicio AND Kardex_Anual.Fch_Cierre)) AND
                                            Kardex_Anual.Empresa = @nEmpresa),0)

    END
  
  SET @nRegresaValor = ISNULL(@nRegresaValor,0)
      
  RETURN (@nRegresaValor)

END
GO
