IF OBJECT_ID('dbo.ObtieneRangoFecha') IS NOT NULL
   DROP  FUNCTION [dbo].[ObtieneRangoFecha]
GO
CREATE FUNCTION [dbo].[ObtieneRangoFecha]
    (
      @fecha DATETIME,
      @periodo INT
    )
RETURNS @rangoFecha TABLE
    (
      fechaInicio DATETIME,
      fechaFin DATETIME
    )
AS 
    BEGIN
      DECLARE @fechaInicio DATETIME
      DECLARE @fechaFin DATETIME
     
      -- 1. Para obtener el da de hoy.
      IF @periodo = 1
         BEGIN
           SET @fechaInicio = @fecha 
           SET @fechaFin = @fecha
         END

      -- 2. Inicio y fin del da actual.
      ELSE IF @periodo = 2
         BEGIN
           SET @fechaInicio = DATEADD(dd,DATEDIFF(dd,0,@fecha),0)
           SET @fechaFin = DATEADD(ms,-3,DATEADD(dd,DATEDIFF(dd,0,@fecha),1))
        END

      -- 3. Para obtener el da de ayer.
      ELSE IF @periodo = 3
         BEGIN
           SET @fechaInicio = DATEADD(d,-1,@fecha)
           SET @fechaFin = DATEADD(d,-1,@fecha)
        END
        
      -- 4. Para obtener inicio y fin del da de ayer.
      ELSE IF @periodo = 4
         BEGIN
           SET @fechaInicio = DATEADD(dd,DATEDIFF(dd,0,@fecha),-1)
           SET @fechaFin = DATEADD(ms,-3,DATEADD(dd,DATEDIFF(dd,0,@fecha),0))
        END

      -- 5. Primer da y ultimo de la semana actual.
      ELSE IF @periodo = 5
         BEGIN
           SET @fechaInicio = DATEADD(wk,DATEDIFF(wk,0,@fecha),0)
           SET @fechaFin = DATEADD(wk,DATEDIFF(wk,0,@fecha),6)
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      -- 6. Primer da y ultimo de la semana pasada.
      ELSE IF @periodo = 6
         BEGIN
           SET @fechaInicio = DATEADD(wk,DATEDIFF(wk,7,@fecha),0)
           SET @fechaFin = DATEADD(wk,DATEDIFF(wk,7,@fecha),6)
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      -- 7. Primer da y ultimo del mes actual.
      ELSE IF @periodo = 7
         BEGIN
           SET @fechaInicio = DATEADD(mm,DATEDIFF(mm,0,@fecha),0)
           SET @fechaFin = DATEADD(ms,-3,DATEADD(mm,0,DATEADD(mm,DATEDIFF(mm,0,@fecha)+1,0)))
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      -- 8. Primer da y ultimo del mes pasado.
      ELSE IF @periodo = 8
         BEGIN
           SET @fechaInicio = DATEADD(mm,-1,DATEADD(mm,DATEDIFF(mm,0,@fecha),0))
           SET @fechaFin = DATEADD(ms,-3,DATEADD(mm,0,DATEADD(mm,DATEDIFF(mm,0,@fecha),0)))
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      -- 9. Primer da y ultimo del mes ante pasado.
      ELSE IF @periodo = 9
         BEGIN
           SET @fechaInicio = DATEADD(mm,-2,DATEADD(mm,DATEDIFF(mm,0,@fecha),0))
           SET @fechaFin = DATEADD(ms,-3,DATEADD(mm,0,DATEADD(mm,DATEDIFF(mm,0,@fecha)-1,0)))
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      -- 10. Primer da y ultimo del prximo mes.
      ELSE IF @periodo = 10
         BEGIN
           SET @fechaInicio = DATEADD(mm,1,DATEADD(mm,DATEDIFF(mm,0,@fecha),0))
           SET @fechaFin = DATEADD(ms,-3,DATEADD(mm,0,DATEADD(mm,DATEDIFF(mm,0,@fecha)+2,0)))
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      -- 11. Primer da y ultimo de este ao.
      ELSE IF @periodo = 11
         BEGIN
           SET @fechaInicio = DATEADD(yy,DATEDIFF(yy,0,@fecha),0)
           SET @fechaFin = DATEADD(ms,-3,DATEADD(yy,0,DATEADD(yy,DATEDIFF(yy,0,@fecha)+1,0)))
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      -- 12. Primer da y ultimo del ao pasado.
      ELSE IF @periodo = 12
         BEGIN
           SET @fechaInicio = DATEADD(yy,-1,DATEADD(yy,DATEDIFF(yy,0,@fecha),0))
           SET @fechaFin = DATEADD(ms,-3,DATEADD(yy,0,DATEADD(yy,DATEDIFF(yy,0,@fecha),0)))
           SET @fechaFin = CONVERT(DATETIME, CONVERT (CHAR(10), @fechaFin, 112))
        END

      INSERT @rangoFecha (fechaInicio, fechaFin) VALUES (@fechaInicio, @fechaFin)
      RETURN
    END
GO

IF OBJECT_ID('dbo.datosemps') IS NOT NULL 
   BEGIN
     IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'domicilio'
                        AND sysobjects.name = 'datosemps' ) 
        ALTER TABLE dbo.datosemps ALTER COLUMN domicilio VARCHAR(100)
   
     IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'colonia'
                        AND sysobjects.name = 'datosemps' ) 
        ALTER TABLE dbo.datosemps ALTER COLUMN colonia VARCHAR(100)
        
     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'numeroExterior'
                        AND sysobjects.name = 'datosemps' ) 
        ALTER TABLE dbo.datosemps ADD numeroExterior VARCHAR(25)

     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'numeroInterior'
                        AND sysobjects.name = 'datosemps' ) 
        ALTER TABLE dbo.datosemps ADD numeroInterior VARCHAR(25)

     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'municipio'
                        AND sysobjects.name = 'datosemps' ) 
        ALTER TABLE dbo.datosemps ADD municipio VARCHAR(100)
        
     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'localidad'
                        AND sysobjects.name = 'datosemps' ) 
        ALTER TABLE dbo.datosemps ADD localidad VARCHAR(100)
        
     IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'email'
                        AND sysobjects.name = 'datosemps' ) 
        ALTER TABLE dbo.datosemps ALTER COLUMN email VARCHAR(100)
   END
GO

IF OBJECT_ID('dbo.EmpleadoAdicional') IS NULL 
    BEGIN
        CREATE TABLE dbo.EmpleadoAdicional
            (
              empresa NUMERIC(3, 0) DEFAULT 0
                                    NOT NULL ,
              codigo NUMERIC(8, 0) DEFAULT 0
                                   NOT NULL ,
              discapacitado CHAR(1) NULL ,
              CONSTRAINT PK185 PRIMARY KEY NONCLUSTERED ( empresa, codigo )
            )
        ALTER TABLE EmpleadoAdicional ADD CONSTRAINT Refempleados211 
        FOREIGN KEY (empresa, codigo)
        REFERENCES empleados(empresa, codigo)
    END
GO
IF OBJECT_ID('dbo.EmpleadoAdicional') IS NOT NULL 
   BEGIN
     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'tipoRegimen'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD tipoRegimen INT
   
     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'tipoContrato'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD tipoContrato INT

     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'clabe'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD clabe VARCHAR(20)

     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'fonacot'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD fonacot NUMERIC(10,0) NULL

     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'claveSat'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD claveSat VARCHAR(3) NULL

     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'porcientoSat'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD porcientoSat NUMERIC(7,3) NULL
        
     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'claveEstado'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD claveEstado CHAR(3) NULL
        
     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'nss'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD nss VARCHAR(15) NULL

     IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'enviarApsiReloj'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional DROP COLUMN enviarApsiReloj

     IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'enviosApsiReloj'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional DROP COLUMN enviosApsiReloj

     IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'ultimaFechaEnvioApsiReloj'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional DROP COLUMN ultimaFechaEnvioApsiReloj

     IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'ultimoMovimientoEnvioApsiReloj'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional DROP COLUMN ultimoMovimientoEnvioApsiReloj

     IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'regimenFiscal'
                        AND sysobjects.name = 'EmpleadoAdicional' ) 
        ALTER TABLE dbo.EmpleadoAdicional ADD regimenFiscal INT
   END
GO

IF OBJECT_ID('dbo.Tbl_EmpresasSeleccionadasV4') IS NULL 
    BEGIN
        CREATE TABLE [dbo].[Tbl_EmpresasSeleccionadasV4]
            (
              usuarioApsi VARCHAR(100) NOT NULL DEFAULT '',
              empresa INT,
			  seleccionada INT
              
              CONSTRAINT PKCatalogoAccesoUsuarioApsiUnique PRIMARY KEY CLUSTERED (usuarioApsi, empresa) ,
              CONSTRAINT PKCatalogoAccesoUsuarioApsiUniqueNonClustered UNIQUE NONCLUSTERED ( usuarioApsi, empresa, seleccionada )
              ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO

IF OBJECT_ID('dbo.ObtienePrimasImssFuncion') IS NOT NULL 
    DROP FUNCTION dbo.ObtienePrimasImssFuncion
GO
CREATE FUNCTION dbo.ObtienePrimasImssFuncion
    (
      @empresa INT ,
      @ayoProceso INT ,
      @simularReforma INT
    )
RETURNS @primasImss TABLE
    (
      eymArt25 FLOAT ,
      eymPat25 FLOAT ,
      eymTra25 FLOAT ,
      eymArt106I FLOAT ,
      eymArt1062 FLOAT ,
      eymPat1062 FLOAT ,
      eymTra1062 FLOAT ,
      eymArt107 FLOAT ,
      eymPat107 FLOAT ,
      eymTra107 FLOAT ,
      ivArt147 FLOAT ,
      ivPat147 FLOAT ,
      ivTra147 FLOAT ,
      cvArt168II FLOAT ,
      cvPat168II FLOAT ,
      cvTra168II FLOAT ,
      cvArt168I FLOAT ,
      infonavitPorciento FLOAT ,
      art211 FLOAT ,
      seguroDesempleoPorciento FLOAT,
      infonavit FLOAT
    )
AS 
    BEGIN
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT

        SELECT  @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa

        IF @simularReforma = 0 
            BEGIN
                INSERT  @primasImss
                        ( eymArt25 ,
                          eymPat25 ,
                          eymTra25 ,
                          eymArt106I ,
                          eymArt1062 ,
                          eymPat1062 ,
                          eymTra1062 ,
                          eymArt107 ,
                          eymPat107 ,
                          eymTra107 ,
                          ivArt147 ,
                          ivPat147 ,
                          ivTra147 ,
                          cvArt168II, 
                          cvPat168II ,
                          cvTra168II ,
                          cvArt168I ,
                          infonavitPorciento ,
                          art211 ,
                          seguroDesempleoPorciento,
                          infonavit
                        )
                        SELECT  primasImss.eymart25 AS eymArt25 ,
                                primasImss.eympat25 + CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra25 ELSE 0 END AS eymPat25 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra25 END AS eymTra25 ,
                                primasImss.eymart106I AS eymArt106I ,
                                primasImss.eymart1062 AS eymArt1062 ,
                                primasImss.eympat1062 + CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra1062 ELSE 0 END AS eymPat1062 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra1062 END AS eymTra1062 ,
                                primasImss.eymart107 AS eymArt107 ,
                                primasImss.eympat107 + CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra107 ELSE 0 END AS eymPat107 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra107 END AS eymTra107 ,
                                primasImss.ivart147 AS ivArt147 , 
                                primasImss.ivpat147 + CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.ivtra147 ELSE 0 END AS ivPat147 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.ivtra147 END AS ivTra147 ,
                                primasImss.cvart168II AS cvArt168II ,
                                primasImss.cvpat168II + CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END AS cvPat168II ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END AS cvTra168II ,
                                primasImss.retiro AS cvArt168I ,
                                primasImss.infonavit AS infonavitPorciento ,
                                primasImss.art211 AS art211 ,
                                seguroDesempleo AS seguroDesempleoPorciento,
                                primasImss.infonavit
                        FROM    dbo.primas_imss AS primasImss
                        WHERE   YEAR(primasImss.periodo) = CASE
                                                              WHEN @ayoProceso > @ayoEmpresa
                                                              THEN @ayoEmpresa
                                                              ELSE @ayoProceso
                                                           END
            END
        ELSE 
            BEGIN
                /*
                INSERT  @primasImss
                        ( eymArt25 ,
                          eymPat25 ,
                          eymTra25 ,
                          eymArt106I ,
                          eymArt1062 ,
                          eymPat1062 ,
                          eymTra1062 ,
                          eymArt107 ,
                          eymPat107 ,
                          eymTra107 ,
                          ivArt147 ,
                          ivPat147 ,
                          ivTra147 ,
                          cvArt168II, 
                          cvPat168II ,
                          cvTra168II ,
                          cvArt168I ,
                          infonavitPorciento ,
                          art211 ,
                          seguroDesempleoPorciento 
                        )
                        SELECT  1.425 AS eymArt25 ,
                                1.05 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.37500 ELSE 0 END AS eymPat25 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.37500 END AS eymTra25 ,
                                20.4 AS eymArt106I ,
                                1.5000 AS eymArt1062 ,
                                1.10000 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.40000 ELSE 0 END AS eymPat1062 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.40000 END AS eymTra1062 ,
                                0.95 AS eymArt107 ,
                                0.70 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.25000 ELSE 0 END AS eymPat107 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.25000 END AS eymTra107 ,
                                2.37500 AS ivArt147 ,
                                1.75000 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.62500 ELSE 0 END AS ivPat147 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.62500 END AS ivTra147 ,
                                4.27500 AS cvArt168II ,
                                3.15000 + CASE WHEN @patronPagaIMSS = 'S' THEN 1.12500 ELSE 0 END AS cvPat168II ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 1.12500 END AS cvTra168II ,
                                2.00000 AS cvArt168I ,
                                5 AS infonavitPorciento ,
                                1 AS art211 ,
                                0 AS seguroDesempleoPorciento
                */
                                
                INSERT  @primasImss
                        ( eymArt25 ,
                          eymPat25 ,
                          eymTra25 ,
                          eymArt106I ,
                          eymArt1062 ,
                          eymPat1062 ,
                          eymTra1062 ,
                          eymArt107 ,
                          eymPat107 ,
                          eymTra107 ,
                          ivArt147 ,
                          ivPat147 ,
                          ivTra147 ,
                          cvArt168II, 
                          cvPat168II ,
                          cvTra168II ,
                          cvArt168I ,
                          infonavitPorciento ,
                          art211 ,
                          seguroDesempleoPorciento,
                          infonavit
                        )
                        SELECT  3.17500 AS eymArt25 ,
                                2.80000 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.37500 ELSE 0 END AS eymPat25 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.37500 END AS eymTra25 ,
                                10.0000 AS eymArt106I ,
                                1.5000 AS eymArt1062 ,
                                1.10000 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.40000 ELSE 0 END AS eymPat1062 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.40000 END AS eymTra1062 ,
                                2.05000 AS eymArt107 ,
                                1.80000 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.25000 ELSE 0 END AS eymPat107 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.25000 END AS eymTra107 ,
                                2.37500 AS ivArt147 ,
                                1.75000 + CASE WHEN @patronPagaIMSS = 'S' THEN 0.62500 ELSE 0 END AS ivPat147 ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 0.62500 END AS ivTra147 ,
                                4.27500 AS cvArt168II ,
                                3.15000 + CASE WHEN @patronPagaIMSS = 'S' THEN 1.12500 ELSE 0 END AS cvPat168II ,
                                CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE 1.12500 END AS cvTra168II ,
                                2.00000 AS cvArt168I ,
                                2 AS infonavitPorciento ,
                                1 AS art211 ,
                                3 AS seguroDesempleoPorciento,
                                5 AS infonavit
            END
        RETURN
    END
GO

IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'empleadosconcta' AND sysobjects.name='polizas')
  BEGIN
    ALTER TABLE polizas ADD empleadosconcta    INTEGER NULL
    ALTER TABLE polizas ADD empleadossincta    INTEGER NULL
    ALTER TABLE polizas ADD percepcionesconcta NUMERIC(15,2) NULL
    ALTER TABLE polizas ADD percepcionessincta NUMERIC(15,2) NULL
    ALTER TABLE polizas ADD deduccionesconcta  NUMERIC(15,2) NULL
    ALTER TABLE polizas ADD deduccionessincta  NUMERIC(15,2) NULL
  END
GO

-- Tipo Rgimen
IF OBJECT_ID('dbo.CatalogoRegimenContratacionTrabajador') IS NULL 
    BEGIN
      CREATE TABLE dbo.CatalogoRegimenContratacionTrabajador
            (
              idClave INT ,
              descripcion VARCHAR(250)
            )
    END
GO
IF OBJECT_ID('dbo.CatalogoRegimenContratacionTrabajador') IS NOT NULL 
    BEGIN
      DELETE catalogo FROM dbo.CatalogoRegimenContratacionTrabajador AS catalogo WHERE catalogo.idClave = 1
        
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Sueldos' WHERE idClave = 2
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Jubilados' WHERE idClave = 3
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Pensionados' WHERE idClave = 4
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Asimilados Miembros Sociedades Cooperativas Produccion' WHERE idClave = 5
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Asimilados Integrantes Sociedades Asociaciones Civiles' WHERE idClave = 6
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Asimilados Miembros consejos' WHERE idClave = 7
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Asimilados comisionistas' WHERE idClave = 8
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Asimilados Honorarios' WHERE idClave = 9
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Asimilados acciones' WHERE idClave = 10
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Asimilados otros' WHERE idClave = 11
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Jubilados o Pensionados' WHERE idClave = 12
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Indemnizacin o Separacin' WHERE idClave = 13
      UPDATE dbo.CatalogoRegimenContratacionTrabajador SET descripcion = 'Otro Regimen' WHERE idClave = 99

      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  2, 'Sueldos' WHERE  NOT EXISTS (SELECT 2 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 2)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  3, 'Jubilados' WHERE NOT EXISTS (SELECT 3 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 3)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  4, 'Pensionados' WHERE NOT EXISTS (SELECT 4 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 4)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  5, 'Asimilados Miembros Sociedades Cooperativas Produccion' WHERE NOT EXISTS (SELECT 5 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 5)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  6, 'Asimilados Integrantes Sociedades Asociaciones Civiles' WHERE NOT EXISTS (SELECT 6 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 6)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  7, 'Asimilados Miembros consejos' WHERE NOT EXISTS (SELECT 7 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 7)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  8, 'Asimilados comisionistas' WHERE NOT EXISTS (SELECT 8 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 8)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT  9, 'Asimilados Honorarios' WHERE NOT EXISTS (SELECT 9 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 9)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT 10, 'Asimilados acciones' WHERE NOT EXISTS (SELECT 10 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 10)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT 11, 'Asimilados otros' WHERE NOT EXISTS (SELECT 11 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 11)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT 12, 'Jubilados o Pensionados' WHERE NOT EXISTS (SELECT 12 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 12)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT 13, 'Indemnizacin o Separacin' WHERE NOT EXISTS (SELECT 13 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 13)
      INSERT dbo.CatalogoRegimenContratacionTrabajador (idClave, descripcion) SELECT 99, 'Otro Regimen' WHERE NOT EXISTS (SELECT 99 FROM dbo.CatalogoRegimenContratacionTrabajador WHERE idClave = 99)
    END
GO

-- Tipo Contrato
IF OBJECT_ID('dbo.CatalogoTipoContrato') IS NULL 
    BEGIN
      CREATE TABLE dbo.CatalogoTipoContrato
            (
              idClave INT ,
              descripcion VARCHAR(250)
            )
    END
IF OBJECT_ID('dbo.CatalogoTipoContrato') IS NOT NULL 
    BEGIN
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Contrato de trabajo por tiempo indeterminado' WHERE idClave = 1
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Contrato de trabajo para obra determinada' WHERE idClave = 2
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Contrato de trabajo por tiempo determinado' WHERE idClave = 3
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Contrato de trabajo por temporada' WHERE idClave = 4
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Contrato de trabajo sujeto a prueba' WHERE idClave = 5
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Contrato de trabajo con capacitacin inicial' WHERE idClave = 6
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Modalidad de contratacin por pago de hora laborada' WHERE idClave = 7
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Modalidad de trabajo por comisin laboral' WHERE idClave = 8
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Modalidades de contratacin donde no existe relacin de trabajo' WHERE idClave = 9
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Jubilacin, pensin, retiro.' WHERE idClave = 10
      UPDATE dbo.CatalogoTipoContrato SET descripcion = 'Otro contrato' WHERE idClave = 99
    
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  1, 'Contrato de trabajo por tiempo indeterminado' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoTipoContrato WHERE idClave = 1)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  2, 'Contrato de trabajo para obra determinada' WHERE NOT EXISTS (SELECT 2 FROM dbo.CatalogoTipoContrato WHERE idClave = 2)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  3, 'Contrato de trabajo por tiempo determinado' WHERE NOT EXISTS (SELECT 3 FROM dbo.CatalogoTipoContrato WHERE idClave = 3)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  4, 'Contrato de trabajo por temporada' WHERE NOT EXISTS (SELECT 4 FROM dbo.CatalogoTipoContrato WHERE idClave = 4)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  5, 'Contrato de trabajo sujeto a prueba' WHERE NOT EXISTS (SELECT 5 FROM dbo.CatalogoTipoContrato WHERE idClave = 5)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  6, 'Contrato de trabajo con capacitacin inicial' WHERE NOT EXISTS (SELECT 6 FROM dbo.CatalogoTipoContrato WHERE idClave = 6)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  7, 'Modalidad de contratacin por pago de hora laborada' WHERE NOT EXISTS (SELECT 7 FROM dbo.CatalogoTipoContrato WHERE idClave = 7)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  8, 'Modalidad de trabajo por comisin laboral' WHERE NOT EXISTS (SELECT 8 FROM dbo.CatalogoTipoContrato WHERE idClave = 8)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT  9, 'Modalidades de contratacin donde no existe relacin de trabajo' WHERE NOT EXISTS (SELECT 9 FROM dbo.CatalogoTipoContrato WHERE idClave = 9)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT 10, 'Jubilacin, pensin, retiro.' WHERE NOT EXISTS (SELECT 10 FROM dbo.CatalogoTipoContrato WHERE idClave = 10)
      INSERT dbo.CatalogoTipoContrato (idClave, descripcion) SELECT 99, 'Otro contrato' WHERE NOT EXISTS (SELECT 99 FROM dbo.CatalogoTipoContrato WHERE idClave = 99)
      
    END
GO

-- Regimen fiscal trabajador
IF OBJECT_ID('dbo.CatalogoRegimenFiscalEmpleado') IS NULL 
    BEGIN
      CREATE TABLE dbo.CatalogoRegimenFiscalEmpleado
            (
              idClave INT ,
              descripcion VARCHAR(250)
            )
    END
IF OBJECT_ID('dbo.CatalogoRegimenFiscalEmpleado') IS NOT NULL 
    BEGIN
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Sueldos y Salarios e Ingresos Asimilados a Salarios' WHERE idClave = 605
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Arrendamiento' WHERE idClave = 606
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Dems ingresos' WHERE idClave = 608
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Residentes en el Extranjero sin Establecimiento Permanente en Mxico' WHERE idClave = 610
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Ingresos por Dividendos (socios y accionistas)' WHERE idClave = 611
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Personas Fsicas con Actividades Empresariales y Profesionales' WHERE idClave = 612
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Ingresos por intereses' WHERE idClave = 614
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Sin obligaciones fiscales' WHERE idClave = 616
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Incorporacin Fiscal' WHERE idClave = 621
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Actividades Agrcolas, Ganaderas, Silvcolas y Pesqueras' WHERE idClave = 622
      UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'De los Regmenes Fiscales Preferentes y de las Empresas Multinacionales' WHERE idClave = 629
	  UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Enajenacin de acciones en bolsa de valores' WHERE idClave = 630
	  UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Rgimen de los ingresos por obtencin de premios' WHERE idClave = 615
	  UPDATE dbo.CatalogoRegimenFiscalEmpleado SET descripcion = 'Rgimen de las Actividades Empresariales con ingresos a travs de Plataformas Tecnolgicas' WHERE idClave = 625

      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 605, 'Sueldos y Salarios e Ingresos Asimilados a Salarios' WHERE NOT EXISTS (SELECT 605 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 605)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 606, 'Arrendamiento' WHERE NOT EXISTS (SELECT 606 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 606)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 608, 'Dems ingresos' WHERE NOT EXISTS (SELECT 608 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 608)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 610, 'Residentes en el Extranjero sin Establecimiento Permanente en Mxico' WHERE NOT EXISTS (SELECT 610 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 610)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 611, 'Ingresos por Dividendos (socios y accionistas)' WHERE NOT EXISTS (SELECT 611 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 611)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 612, 'Personas Fsicas con Actividades Empresariales y Profesionales' WHERE NOT EXISTS (SELECT 612 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 612)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 614, 'Ingresos por intereses' WHERE NOT EXISTS (SELECT 614 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 614)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 616, 'Sin obligaciones fiscales' WHERE NOT EXISTS (SELECT 616 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 616)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 621, 'Incorporacin Fiscal' WHERE NOT EXISTS (SELECT 621 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 621)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 622, 'Actividades Agrcolas, Ganaderas, Silvcolas y Pesqueras' WHERE NOT EXISTS (SELECT 622 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 622)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 629, 'De los Regmenes Fiscales Preferentes y de las Empresas Multinacionales' WHERE NOT EXISTS (SELECT 629 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 629)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 630, 'Enajenacin de acciones en bolsa de valores' WHERE NOT EXISTS (SELECT 630 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 630)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 615, 'Rgimen de los ingresos por obtencin de premios' WHERE NOT EXISTS (SELECT 615 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 615)
      INSERT dbo.CatalogoRegimenFiscalEmpleado (idClave, descripcion) SELECT 625, 'Rgimen de las Actividades Empresariales con ingresos a travs de Plataformas Tecnolgicas' WHERE NOT EXISTS (SELECT 625 FROM dbo.CatalogoRegimenFiscalEmpleado WHERE idClave = 625)
    END
GO

IF OBJECT_ID('dbo.CatalogoRegimenContratacionTrabajador') IS NOT NULL
    AND OBJECT_ID('dbo.CatalogoTipoContrato') IS NOT NULL 
    BEGIN
        INSERT  dbo.EmpleadoAdicional
                ( empresa ,
                  codigo ,
                  discapacitado ,
                  fonacot ,
                  tipoRegimen ,
                  tipoContrato ,
                  clabe
                )
                SELECT  dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        'N' AS discapacitado ,
                        0 AS fonacot ,
                        2 AS tipoRegimen ,
                        1 AS tipoContrato ,
                        '' AS clabe
                FROM    dbo.empleados
                WHERE   NOT EXISTS ( SELECT dbo.EmpleadoAdicional.codigo
                                     FROM   dbo.EmpleadoAdicional
                                     WHERE  dbo.EmpleadoAdicional.codigo = dbo.empleados.codigo
                                            AND dbo.EmpleadoAdicional.empresa = dbo.empleados.empresa )
    END
GO
UPDATE  dbo.EmpleadoAdicional
SET     dbo.EmpleadoAdicional.fonacot = 0
WHERE   dbo.EmpleadoAdicional.fonacot IS NULL
GO
UPDATE  dbo.EmpleadoAdicional
SET     dbo.EmpleadoAdicional.clabe = ''
WHERE   dbo.EmpleadoAdicional.clabe IS NULL
GO
IF OBJECT_ID('dbo.CatalogoRegimenContratacionTrabajador') IS NOT NULL 
    BEGIN
        UPDATE  dbo.EmpleadoAdicional
        SET     dbo.EmpleadoAdicional.tipoRegimen = 2
        WHERE   dbo.EmpleadoAdicional.tipoRegimen IS NULL
    END
GO
IF OBJECT_ID('dbo.CatalogoTipoContrato') IS NOT NULL 
    BEGIN
        UPDATE  dbo.EmpleadoAdicional
        SET     dbo.EmpleadoAdicional.tipoContrato = 1
        WHERE   dbo.EmpleadoAdicional.tipoContrato IS NULL
    END
GO
IF OBJECT_ID('dbo.CatalogoRegimenFiscalEmpleado') IS NOT NULL 
    BEGIN
        UPDATE  dbo.EmpleadoAdicional
        SET     dbo.EmpleadoAdicional.regimenFiscal = 605
        WHERE   dbo.EmpleadoAdicional.regimenFiscal IS NULL
    END
GO

/**************************************************************************************************
 * Name          : ChecaDecimales
 * Project       : APSI Nomina
 * Description   : Regresa entero si no tiene decimales
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Julio 1, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'FN'
                    AND name = 'ChecaDecimales' ) 
    BEGIN
        DROP  FUNCTION [dbo].[ChecaDecimales]
    END
GO

CREATE FUNCTION [dbo].[ChecaDecimales]
    (
      @importe FLOAT
    )
RETURNS FLOAT

AS 
    BEGIN
    
    DECLARE @regresaValor FLOAT
    
    IF @importe - FLOOR(@importe) > 0
       SET @regresaValor = @importe
    ELSE
       SET @regresaValor = FLOOR(@importe)
       
    RETURN @regresaValor
    
    END
GO

ALTER TABLE dbo.datosemps ALTER COLUMN poblacion VARCHAR(150)
GO

IF EXISTS ( SELECT  sysobjects.name
            FROM    sysobjects
            WHERE   sysobjects.name = 'empleadosDelTrig' )
    DROP TRIGGER empleadosDelTrig
GO
IF EXISTS ( SELECT  sysobjects.name
            FROM    sysobjects
            WHERE   sysobjects.name = 'empleadosUpdTrig' )
    DROP TRIGGER empleadosUpdTrig
GO
IF EXISTS ( SELECT  sysobjects.name
            FROM    sysobjects
            WHERE   sysobjects.name = 'clasificacion_empleadosInsTrig' )
    DROP TRIGGER clasificacion_empleadosInsTrig
GO
IF EXISTS ( SELECT  sysobjects.name
            FROM    sysobjects
            WHERE   sysobjects.name = 'clasificacion_empleadosUpdTrig' )
    DROP TRIGGER clasificacion_empleadosUpdTrig
GO

IF OBJECT_ID('dbo.EsRpuEspecial') IS NOT NULL
  DROP FUNCTION dbo.EsRpuEspecial
GO
CREATE FUNCTION dbo.EsRpuEspecial (@Empresa INT)
RETURNS INT

AS

  BEGIN
    DECLARE @EsRpuEspecial INT 

    SET @EsRpuEspecial = ISNULL((SELECT CASE WHEN empresa.Rpu = 'S'
                                                 AND ((empresa.rfc_empresa = ' XPE980408QJ4' OR empresa.rfc_empresa = ' XPE140206DF2') --Verity
												      OR (empresa.rfc_empresa = ' BSH9104107Y9' OR empresa.rfc_empresa = ' LLC890327GD6' OR empresa.rfc_empresa = ' LLR980402351')) -- Aries
                                            THEN 1
                                            ELSE 0	   
                                       END AS EsRpuEspecial
                                 FROM dbo.empresas AS empresa 
                                 WHERE empresa.empresa = @Empresa),0)
      RETURN (@EsRpuEspecial)
END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'idNomTblEquipo'
                        AND sysobjects.name = 'accesos' ) 
    BEGIN
	    ALTER TABLE dbo.accesos ADD idNomTblEquipo BIGINT NOT NULL DEFAULT 0
    END
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'sesion'
                        AND sysobjects.name = 'accesos' ) 
    BEGIN
	    ALTER TABLE dbo.accesos ADD sesion CHAR(14) NOT NULL DEFAULT ''
    END
GO

if not EXISTS(select syscolumns.name  from syscolumns
 left join sysobjects on syscolumns.id=sysobjects.id
 where syscolumns.name = 'nombreClase' and sysobjects.name='auditoria')
 alter table dbo.auditoria add nombreClase char(20)
go

if not EXISTS(select syscolumns.name  from syscolumns
 left join sysobjects on syscolumns.id=sysobjects.id
 where syscolumns.name = 'multiple' and sysobjects.name='auditoria')
 alter table dbo.auditoria add multiple char(1)
go

if not EXISTS(select syscolumns.name  from syscolumns
 left join sysobjects on syscolumns.id=sysobjects.id
 where syscolumns.name = 'ocupacion' and sysobjects.name='auditoria')
 alter table dbo.auditoria add ocupacion int
go

if not EXISTS(select syscolumns.name  from syscolumns
 left join sysobjects on syscolumns.id=sysobjects.id
 where syscolumns.name = 'centro' and sysobjects.name='auditoria')
 alter table dbo.auditoria add centro CHAR(15)
go

if not EXISTS(select syscolumns.name  from syscolumns
 left join sysobjects on syscolumns.id=sysobjects.id
 where syscolumns.name = 'jornada' and sysobjects.name='auditoria')
 alter table dbo.auditoria add jornada INT
go

if not EXISTS(select syscolumns.name  from syscolumns
 left join sysobjects on syscolumns.id=sysobjects.id
 where syscolumns.name = 'salDf' and sysobjects.name='auditoria')
 alter table dbo.auditoria add salDf FLOAT
go

if not EXISTS(select syscolumns.name  from syscolumns
 left join sysobjects on syscolumns.id=sysobjects.id
 where syscolumns.name = 'salMin' and sysobjects.name='auditoria')
 alter table dbo.auditoria add salMin FLOAT
go

alter table dbo.auditoria alter column clase char(2) not null
alter table dbo.auditoria alter column nombre varchar(90) 
alter table dbo.auditoria alter column sueldo numeric(12,2) 
alter table dbo.auditoria alter column sdi_fijo numeric(12,2) 
alter table dbo.auditoria alter column sdi_reportado numeric(12,2) 
alter table dbo.auditoria alter column sdi_ok numeric(12,2) 
alter table dbo.auditoria alter column parte_variable numeric(12,2) 
alter table dbo.auditoria alter column usuario varchar(30) not null
alter table dbo.auditoria alter column obs_auto varchar(50)
go

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'umaDiario' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD umaDiario NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'tiponom' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD tiponom INT
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'excedenteDespensa' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD excedenteDespensa NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'importesFijos' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD importesFijos NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'diastr' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD diastr NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'ausen' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD ausen NUMERIC(12,2)
GO


IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'incap' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD incap INT
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'percepcionVariable'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD percepcionVariable NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'DivisorPercepcionesVariables'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD DivisorPercepcionesVariables VARCHAR(30)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'ip'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD ip VARCHAR(15) NOT NULL DEFAULT ''
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'mac'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD mac VARCHAR(17) NOT NULL DEFAULT ''
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'nombreEquipo'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD nombreEquipo VARCHAR(50) NOT NULL DEFAULT ''
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'id'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD id BIGINT IDENTITY NOT NULL
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'origen'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD origen VARCHAR(2) NOT NULL DEFAULT ''
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'topaDespensa'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD topaDespensa VARCHAR(15)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'fondoAhorroPatron'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD fondoAhorroPatron NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'fondoAhorroEmpleado'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD fondoAhorroEmpleado NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'accion'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD accion INT
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'topeDespensa'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD topeDespensa NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'ultimoAvisoMov'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD ultimoAvisoMov VARCHAR(2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'ultimoAvisoFch_Mov'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD ultimoAvisoFch_Mov DATETIME
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'topeUltimoAviso' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD topeUltimoAviso NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'minimoUltimoAviso' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD minimoUltimoAviso NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'topeAuditoria' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD topeAuditoria NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'minimoAuditoria' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD minimoAuditoria NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'minimoAuditoriaIntegrado' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD minimoAuditoriaIntegrado NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'existeCodigo' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD existeCodigo BIT
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'despensa' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD despensa NUMERIC(12,4)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'despensaim' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD despensaim NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'fechaUMA' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD fechaUMA DATETIME
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'factorLaboral' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD factorLaboral NUMERIC(7,4)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'sdiLaboral' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD sdiLaboral NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'importeFijoLaboral' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD importeFijoLaboral NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'DespensaLaboral' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD despensaLaboral NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'sdiCalculado' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD sdiCalculado NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'tieneAvisoAnterior' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD tieneAvisoAnterior BIT
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'serial' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD serial INT
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'diasLaboral' 
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD diasLaboral NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'percepcionVariableLaboraL'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD percepcionVariableLaboral NUMERIC(12,2)
GO

IF NOT EXISTS(SELECT syscolumns.name 
              FROM syscolumns
                   LEFT JOIN sysobjects on syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'parteVariableLaboral'
                    AND sysobjects.name='auditoria')
   ALTER TABLE dbo.auditoria ADD parteVariableLaboral NUMERIC(12,2)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'rpu'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD rpu VARCHAR(3)
GO

IF NOT EXISTS (SELECT TOP 1 1
               FROM dbo.avisos_imss AS a
               WHERE a.rpu IS NULL)
   BEGIN
     UPDATE  avisos_imss
     SET     avisos_imss.rpu = dbo.empleados.rpu
     FROM    dbo.avisos_imss AS avisos_imss
             INNER JOIN empleados ON empleados.empresa = avisos_imss.empresa
                                AND empleados.codigo = avisos_imss.codigo
     WHERE   avisos_imss.rpu IS NULL 
   END
GO
IF NOT EXISTS (SELECT TOP 1 1
               FROM dbo.empleados AS e
               WHERE e.rpu IS NULL)
   BEGIN           
     UPDATE dbo.empleados
     SET dbo.empleados.rpu = SUBSTRING(dbo.empresas.registro_patronal,1,3)
     FROM dbo.empleados
          INNER JOIN dbo.empresas ON dbo.empleados.empresa = dbo.empresas.empresa
     WHERE dbo.empleados.rpu IS NULL
   END
GO
IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'enviarApsiReloj'
                        AND sysobjects.name = 'avisos_imss' ) 
   ALTER TABLE dbo.avisos_imss DROP COLUMN enviarApsiReloj
GO
IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'enviosApsiReloj'
                        AND sysobjects.name = 'avisos_imss' ) 
   ALTER TABLE dbo.avisos_imss DROP COLUMN enviosApsiReloj
GO
IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'ultimaFechaEnvioApsiReloj'
                        AND sysobjects.name = 'avisos_imss' ) 
   ALTER TABLE dbo.avisos_imss DROP COLUMN ultimaFechaEnvioApsiReloj
GO
IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'ultimoMovimientoEnvioApsiReloj'
                        AND sysobjects.name = 'avisos_imss' ) 
   ALTER TABLE dbo.avisos_imss DROP COLUMN ultimoMovimientoEnvioApsiReloj
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'Enviar'
                        AND sysobjects.name = 'avisos_imss' ) 
   ALTER TABLE dbo.avisos_imss ADD Enviar BIT
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'Enviado'
                        AND sysobjects.name = 'avisos_imss' ) 
   ALTER TABLE dbo.avisos_imss ADD Enviado BIT
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'consecutivo'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD consecutivo INT 
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'fechaEnvio'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD fechaEnvio DATETIME 
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'lote'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD lote VARCHAR(25)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'estatus'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD estatus VARCHAR(25)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'fechaConfirmacion'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD fechaConfirmacion DATETIME
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'lic'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD lic INT
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'consecutivo'
                        AND sysobjects.name = 'rpu_trabajador' ) 
    ALTER TABLE dbo.rpu_trabajador ADD consecutivo INT 
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'fechaEnvio'
                        AND sysobjects.name = 'rpu_trabajador' ) 
    ALTER TABLE dbo.rpu_trabajador ADD fechaEnvio DATETIME 
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'lote'
                        AND sysobjects.name = 'rpu_trabajador' ) 
    ALTER TABLE dbo.rpu_trabajador ADD lote VARCHAR(25)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'estatus'
                        AND sysobjects.name = 'rpu_trabajador' ) 
    ALTER TABLE dbo.rpu_trabajador ADD estatus VARCHAR(25)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'fechaConfirmacion'
                        AND sysobjects.name = 'rpu_trabajador' ) 
    ALTER TABLE dbo.rpu_trabajador ADD fechaConfirmacion DATETIME
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'origen'
                        AND sysobjects.name = 'avisos_imss' ) 
    ALTER TABLE dbo.avisos_imss ADD origen VARCHAR(2)
ELSE
    ALTER TABLE dbo.avisos_imss ALTER COLUMN origen VARCHAR(2)
GO

IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'apellidoPaterno' AND sysobjects.name='casos_rt_importado')
  BEGIN
    ALTER TABLE dbo.casos_rt_importado ADD apellidoPaterno VARCHAR(40)
  END
GO
IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'apellidoMaterno' AND sysobjects.name='casos_rt_importado')
  BEGIN
    ALTER TABLE dbo.casos_rt_importado ADD apellidoMaterno VARCHAR(40)
  END
GO
IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'nombreEmpleado' AND sysobjects.name='casos_rt_importado')
  BEGIN
    ALTER TABLE dbo.casos_rt_importado ADD nombreEmpleado VARCHAR(40)
  END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'campo__09'
                        AND sysobjects.name = 'clasificacion_empleados' ) 
    ALTER TABLE dbo.clasificacion_empleados ADD campo__09 VARCHAR(100)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'campo__10'
                        AND sysobjects.name = 'clasificacion_empleados' ) 
    ALTER TABLE dbo.clasificacion_empleados ADD campo__10 VARCHAR(100)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'campo__11'
                        AND sysobjects.name = 'clasificacion_empleados' ) 
    ALTER TABLE dbo.clasificacion_empleados ADD campo__11 VARCHAR(100)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'campo__12'
                        AND sysobjects.name = 'clasificacion_empleados' ) 
    ALTER TABLE dbo.clasificacion_empleados ADD campo__12 VARCHAR(100)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'campo__13'
                        AND sysobjects.name = 'clasificacion_empleados' ) 
    ALTER TABLE dbo.clasificacion_empleados ADD campo__13 VARCHAR(100)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'campo__14'
                        AND sysobjects.name = 'clasificacion_empleados' ) 
    ALTER TABLE dbo.clasificacion_empleados ADD campo__14 VARCHAR(100)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'campo__15'
                        AND sysobjects.name = 'clasificacion_empleados' ) 
    ALTER TABLE dbo.clasificacion_empleados ADD campo__15 VARCHAR(100)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'usarSalarioMinimo'
                        AND sysobjects.name = 'empresas' ) 
    ALTER TABLE dbo.empresas ADD usarSalarioMinimo CHAR(1)
GO

ALTER TABLE dbo.Historico ALTER COLUMN campo VARCHAR(25)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'origen'
                        AND sysobjects.name = 'historico' ) 
    ALTER TABLE dbo.Historico ADD origen VARCHAR(25)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'fechaSuspension'
                        AND sysobjects.name = 'infonavit' ) 
    ALTER TABLE dbo.infonavit ADD fechaSuspension DATETIME
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'excedente'
                        AND sysobjects.name = 'Partes_variables' ) 
    ALTER TABLE dbo.Partes_variables ADD excedente DECIMAL (12,2)
GO
IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'excedente'
                        AND sysobjects.name = 'Partes_variables' ) 
    ALTER TABLE dbo.Partes_variables ALTER COLUMN diastr NUMERIC(6,2)
GO

IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'iCedula' AND sysobjects.name='resumen_rt')
  BEGIN
    ALTER TABLE dbo.resumen_rt ADD iCedula VARCHAR(25)
  END
GO
IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'sCedula' AND sysobjects.name='resumen_rt')
  BEGIN
    ALTER TABLE dbo.resumen_rt ADD sCedula VARCHAR(25)
  END
GO
IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'dCedula' AND sysobjects.name='resumen_rt')
  BEGIN
    ALTER TABLE dbo.resumen_rt ADD dCedula VARCHAR(25)
  END
GO
IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'nCedula' AND sysobjects.name='resumen_rt')
  BEGIN
    ALTER TABLE dbo.resumen_rt ADD nCedula VARCHAR(25)
  END
GO
IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE syscolumns.name = 'mCedula' AND sysobjects.name='resumen_rt')
  BEGIN
    ALTER TABLE dbo.resumen_rt ADD mCedula VARCHAR(25)
  END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'FechaAprobacion'
                        AND sysobjects.name = 'solicitud_VPA' ) 
    ALTER TABLE solicitud_VPA ADD FechaAprobacion Datetime null
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'Usuario'
                        AND sysobjects.name = 'solicitud_VPA' ) 
    ALTER TABLE solicitud_VPA ADD Usuario Varchar(100) null
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'CategoriaActual'
                        AND sysobjects.name = 'Solicitud_VPA' ) 
    ALTER TABLE Solicitud_VPA ADD CategoriaActual VARCHAR(100) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'CategoriaSiguiente'
                        AND sysobjects.name = 'Solicitud_VPA' ) 
    ALTER TABLE Solicitud_VPA ADD CategoriaSiguiente VARCHAR(100) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'SueldoNetoNuevo'
                        AND sysobjects.name = 'Solicitud_VPA' ) 
    ALTER TABLE Solicitud_VPA ADD SueldoNetoNuevo decimal(10,2) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'SueldoNetoActual'
                        AND sysobjects.name = 'Solicitud_VPA' ) 
    ALTER TABLE Solicitud_VPA ADD SueldoNetoActual decimal(10,2) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'FchUltMov'
                        AND sysobjects.name = 'Solicitud_VPA' ) 
    ALTER TABLE Solicitud_VPA ADD FchUltMov datetime NULL 
GO

IF OBJECT_ID('dbo.NOM_FUN_AjustaFechaPrimerDiaMes') IS NOT NULL
   DROP  FUNCTION [dbo].[NOM_FUN_AjustaFechaPrimerDiaMes]
GO
CREATE FUNCTION [dbo].[NOM_FUN_AjustaFechaPrimerDiaMes]
    (
      @Fi DATETIME,
      @Fch_Mov DATETIME,
	  @DiasTr INT
    )

RETURNS DATETIME

AS 
    BEGIN
	  DECLARE @Fecha DATETIME
	  DECLARE @FechaPrimerDiaMes DATETIME

	  SET @Fecha = @Fch_Mov + @DiasTr - 1 

	  IF @Fch_Mov < @Fi AND @Fch_Mov + @DiasTr > @Fi
	     SET @FechaPrimerDiaMes = @Fi
      ELSE
         SET @FechaPrimerDiaMes =  @Fch_Mov

      RETURN @FechaPrimerDiaMes
    END
GO

IF OBJECT_ID('dbo.NOM_FUN_AjustaFechaUltimoDiaMes') IS NOT NULL
   DROP  FUNCTION [dbo].[NOM_FUN_AjustaFechaUltimoDiaMes]
GO
CREATE FUNCTION [dbo].[NOM_FUN_AjustaFechaUltimoDiaMes]
    (
      @Ff DATETIME,
      @Fch_Mov DATETIME,
	  @DiasTr INT
    )

RETURNS DATETIME

AS 
    BEGIN
	  DECLARE @Fecha DATETIME
	  DECLARE @FechaUltimoDiaMes DATETIME

	  SET @Fecha = @Fch_Mov + @DiasTr - CASE WHEN @DiasTr > 0 THEN 1 ELSE 0 END
	  
	  IF @Fecha > @Ff
	     SET @FechaUltimoDiaMes = @Ff
      ELSE
	     SET @FechaUltimoDiaMes = @Fecha

      RETURN @FechaUltimoDiaMes
    END
GO

IF OBJECT_ID('dbo.NOM_TBL_Equipo') IS NULL 
   CREATE TABLE dbo.NOM_TBL_Equipo
          (
            ip VARCHAR(15) NOT NULL DEFAULT ('')
	        ,direccionMac VARCHAR(17) NOT NULL DEFAULT ('')
	        ,nombreEquipo VARCHAR(50) NOT NULL DEFAULT ('')
	        ,idNomTblEquipo BIGINT IDENTITY

            CONSTRAINT [NOM_TBL_Equipo_PK] PRIMARY KEY CLUSTERED (ip ASC, direccionMac ASC, nombreEquipo, idNomTblEquipo)
                       WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                              IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                              ALLOW_PAGE_LOCKS = ON )
            ON [PRIMARY]
          )
   ON  [PRIMARY]
GO

IF OBJECT_ID('dbo.NOM_TBL_PrimaCVPatron') IS NULL 
   CREATE TABLE dbo.NOM_TBL_PrimaCVPatron
          (
            id INT NOT NULL IDENTITY
			, rango INT
	        , limiteInferior NUMERIC(6,2)
			, claveInferior VARCHAR(3)
	        , limiteSuperior NUMERIC(6,2)
			, claveSuperior VARCHAR(3)
	        , ayo INT
			, primaCVPatron NUMERIC(8,4)
            CONSTRAINT [CL_NOM_TBL_PrimaCVPatron] PRIMARY KEY CLUSTERED (id, limiteInferior, limiteSuperior, ayo)
                       WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                              IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                              ALLOW_PAGE_LOCKS = ON )
            ON [PRIMARY]
          )
   ON  [PRIMARY]
GO

IF OBJECT_ID('dbo.NOM_TBL_PrimaCVPatron') IS NOT NULL 
   BEGIN
     --Sbc                 2023    2024    2025    2026    2027    2028    2029    2030
     --0.00 SM  1.00 SM    3.150%  3.150%  3.150%  3.150%  3.150%  3.150%  3.150%  3.150%
     --1.01 SM  1.50 UMA   3.281%  3.413%  3.544%  3.676%  3.807%  3.939%  4.070%  4.202%
     --1.51 UMA 2.00 UMA   3.575%  4.000%  4.426%  4.851%  5.276%  5.701%  6.126%  6.552%
     --2.01 UMA 2.50 UMA   3.751%  4.353%  4.954%  5.556%  6.157%  6.759%  7.360%  7.962%
     --2.51 UMA 3.00 UMA   3.869%  4.588%  5.307%  6.026%  6.745%  7.464%  8.183%  8.902%
     --3.01 UMA 3.50 UMA   3.953%  4.756%  5.559%  6.361%  7.164%  7.967%  8.770%  9.573%
     --3.51 UMA 4.00 UMA   4.016%  4.882%  5.747%  6.613%  7.479%  8.345%  9.211% 10.077%
     --4.01 UMA 999.99 UMA 4.241%  5.331%  6.422%  7.513%  8.603%  9.694% 10.784% 11.875%

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2023, 3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2023)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2023, 3.281 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2023)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2023, 3.575 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2023)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2023, 3.751 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2023)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2023, 3.869 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2023)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2023, 3.953 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2023)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2023, 4.016 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2023)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2023, 4.241 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2023)

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2024, 3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2024)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2024, 3.413 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2024)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2024, 4.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2024)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2024, 4.353 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2024)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2024, 4.588 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2024)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2024, 4.756 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2024)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2024, 4.882 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2024)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2024, 5.331 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2024)

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2025, 3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2025)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2025, 3.544 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2025)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2025, 4.426 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2025)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2025, 4.954 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2025)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2025, 5.307 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2025)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2025, 5.559 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2025)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2025, 5.747 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2025)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2025, 6.422 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2025)

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2026, 3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2026)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2026, 3.676 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2026)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2026, 4.851 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2026)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2026, 5.556 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2026)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2026, 6.026 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2026)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2026, 6.361 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2026)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2026, 6.613 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2026)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2026, 7.513 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2026)

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2027, 3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2027)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2027, 3.807 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2027)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2027, 5.276 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2027)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2027, 6.157 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2027)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2027, 6.745 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2027)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2027, 7.164 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2027)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2027, 7.479 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2027)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2027, 8.603 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2027)

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2028, 3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2028)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2028, 3.939 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2028)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2028, 5.701 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2028)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2028, 6.759 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2028)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2028, 7.464 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2028)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2028, 7.967 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2028)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2028, 8.345 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2028)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2028, 9.694 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2028)

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2029,  3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2029)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2029,  4.070 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2029)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2029,  6.126 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2029)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2029,  7.360 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2029)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2029,  8.183 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2029)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2029,  8.770 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2029)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2029,  9.211 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2029)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2029, 10.784 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2029)

     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 1, 0.00, 'SM' , 1.00  , 'SM' , 2030,  3.150 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 00.00 AND limiteSuperior = 001.00 AND ayo = 2030)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 2, 1.01, 'SM' , 1.50  , 'UMA', 2030,  4.202 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.01 AND limiteSuperior = 001.50 AND ayo = 2030)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 3, 1.51, 'UMA', 2.00  , 'UMA', 2030,  6.552 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 01.51 AND limiteSuperior = 002.00 AND ayo = 2030)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 4, 2.01, 'UMA', 2.50  , 'UMA', 2030,  7.962 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.01 AND limiteSuperior = 002.50 AND ayo = 2030)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 5, 2.51, 'UMA', 3.00  , 'UMA', 2030,  8.902 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 02.51 AND limiteSuperior = 003.00 AND ayo = 2030)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 6, 3.01, 'UMA', 3.50  , 'UMA', 2030,  9.573 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.01 AND limiteSuperior = 003.50 AND ayo = 2030)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 7, 3.51, 'UMA', 4.00  , 'UMA', 2030, 10.077 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 03.51 AND limiteSuperior = 004.00 AND ayo = 2030)
     INSERT dbo.NOM_TBL_PrimaCVPatron (rango, limiteInferior, claveInferior, limiteSuperior, claveSuperior, ayo, primaCVPatron) 
            SELECT 8, 4.01, 'UMA', 999.99, 'UMA', 2030, 11.875 WHERE NOT EXISTS (SELECT 1 FROM dbo.NOM_TBL_PrimaCVPatron WHERE limiteInferior = 04.01 AND limiteSuperior = 999.99 AND ayo = 2030)
   END
GO

IF OBJECT_ID('dbo.NOM_TBL_Tmp_Listado') IS NULL 
    BEGIN
        CREATE TABLE dbo.NOM_TBL_Tmp_Listado
            (
              empresa INT
              ,codigo INT
              ,idNomTblEquipo BIGINT
			  ,idNomTblTmpListado BIGINT IDENTITY
              CONSTRAINT [NOM_TBL_Tmp_Listado_PK] PRIMARY KEY CLUSTERED (empresa ASC, codigo ASC, idNomTblEquipo ASC, idNomTblTmpListado ASC)
                         WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                                IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                                ALLOW_PAGE_LOCKS = ON )
              ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO

/**************************************************************************************************
 * Name          : ResumenPorCentroNomina
 * Project       : APSI Nomina
 * Description   : Genera el resumen de la tabla 
 * Table name    : Kardex, Centros
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Julio 14, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.ResumenPorCentroNomina') IS NOT NULL 
    DROP FUNCTION [dbo].[ResumenPorCentroNomina]
GO

CREATE FUNCTION [dbo].[ResumenPorCentroNomina]
    (
      @empresa INT ,
      @nomina VARCHAR(15) ,
      @incluirProvisiones CHAR(1) ,
      @porDetalle CHAR(1) ,
      @tipoNomina INT ,
      @queConcepto CHAR(1) ,
      @ordenadoPor INT ,
      @salarioDF FLOAT ,
      @salarioRegion FLOAT ,
      @eymArt25 FLOAT ,
      @eymArt1062 FLOAT ,
      @eymArt107 FLOAT ,
      @ivArt147 FLOAT ,
      @cvArt168II FLOAT ,
      @desglosadoPor INT ,
      @porCentro INT
    )
RETURNS @resumenPorCentro TABLE
    (
	  id INT IDENTITY,
      centro VARCHAR(50) ,
      supervisor INT ,
      codigo INT ,
      numeroConcepto INT ,
      nombreConcepto VARCHAR(50) ,
      importe FLOAT ,
      gravable FLOAT ,
      exento FLOAT ,
      centroGrupo VARCHAR(50) ,
      conceptoGrupo INT ,
      renglon INT ,
      tipoPago INT ,
      saldoPercepcion FLOAT ,
      anexoConceptoPercepcion VARCHAR(150) ,
      anexoConceptoDeduccion VARCHAR(150) ,
      empleados INT ,
      provisionIMSS FLOAT ,
      provisionRCV FLOAT ,
      provisionINFONAVIT FLOAT ,
      retencionIMSS FLOAT ,
      retencionRCV FLOAT ,
      retencionINFONAVIT FLOAT ,
      empleadosConCuentaBancaria INT ,
      empleadosSinCuentaBancaria INT ,
      percepcionesConCuentaBancaria FLOAT ,
      deduccionesConCuentaBancaria FLOAT ,
      percepcionesSinCuentaBancaria FLOAT ,
      deduccionesSinCuentaBancaria FLOAT ,
      basePorcientoSobreNomina FLOAT ,
      porcientoSobreNomina FLOAT ,
      fondoAhorroAportacionEmpleado FLOAT ,
      fondoAhorroAportacionPatron FLOAT ,
      sueldoNetoGeneral FLOAT ,
      ejercicio INT ,
      diarioOficialDia INT ,
      diarioOficialMes INT ,
      diarioOficialAyo INT ,
      salarioMinimoDF FLOAT ,
      salarioMinimoRegion FLOAT ,
      eymArt25 FLOAT ,
      eymArt106ii FLOAT ,
      eymArt107 FLOAT ,
      ivArt147 FLOAT ,
      cvArt168ii FLOAT ,
      baseCalculo INT ,
      grupo VARCHAR(500) ,
      supervisorGrupo INT,
      
      baseISN1      FLOAT,
      porcientoISN1 FLOAT,
      importeISN1   FLOAT,
      empleadosISN1 INT,

      baseISN2      FLOAT,
      porcientoISN2 FLOAT,
      importeISN2   FLOAT,
      empleadosISN2 INT
    )
AS 
    BEGIN
        DECLARE @nombreEmpresa VARCHAR(250)
        DECLARE @centroAnterior VARCHAR(50)
        DECLARE @supervisorAnterior INT
        DECLARE @tipoPagoAnterior VARCHAR(50)
        DECLARE @renglon INT
        DECLARE @numeroConceptoPercepcionInicio INT
        DECLARE @numeroConceptoPercepcionTermino INT
        DECLARE @numeroConceptoContraPercepcionInicio INT
        DECLARE @numeroConceptoContraPercepcionTermino INT
        DECLARE @numeroConceptoDeduccionInicio INT
        DECLARE @numeroConceptoDeduccionTermino INT
        DECLARE @numeroConceptoContraDeduccionInicio INT
        DECLARE @numeroConceptoContraDeduccionTermino INT
        DECLARE @numeroConceptoProvisionInicio INT
        DECLARE @numeroConceptoProvisionTermino INT
        DECLARE @conceptosBaseImpuestoSobreNomina VARCHAR(2000)
        DECLARE @importeBaseImpuestoSobreNomina FLOAT
        DECLARE @contador INT
        DECLARE @caracter CHAR(1)
        DECLARE @cadena VARCHAR(15)
        DECLARE @resumenPorCentroTemporal TABLE
            (
              centro VARCHAR(50) ,
              supervisor INT ,
              codigo INT ,
              numeroConcepto INT ,
              nombreConcepto VARCHAR(50) ,
              importe FLOAT ,
              gravable FLOAT ,
              exento FLOAT ,
              centroGrupo VARCHAR(50) ,
              conceptoGrupo INT ,
              renglon INT ,
              tipoPago CHAR(1) ,
              saldoPercepcion FLOAT ,
              anexoConceptoPercepcion VARCHAR(150) ,
              anexoConceptoDeduccion VARCHAR(150) ,
              empleados INT ,
              provisionIMSS FLOAT ,
              provisionRCV FLOAT ,
              provisionINFONAVIT FLOAT ,
              retencionIMSS FLOAT ,
              retencionRCV FLOAT ,
              retencionINFONAVIT FLOAT ,
              empleadosConCuentaBancaria INT ,
              empleadosSinCuentaBancaria INT ,
              percepcionesConCuentaBancaria FLOAT ,
              deduccionesConCuentaBancaria FLOAT ,
              percepcionesSinCuentaBancaria FLOAT ,
              deduccionesSinCuentaBancaria FLOAT ,
              basePorcientoSobreNomina FLOAT ,
              porcientoSobreNomina FLOAT ,
              fondoAhorroAportacionEmpleado FLOAT ,
              fondoAhorroAportacionPatron FLOAT ,
              sueldoNetoGeneral FLOAT ,
              ejercicio INT ,
              diarioOficialDia INT ,
              diarioOficialMes INT ,
              diarioOficialAyo INT ,
              salarioMinimoDF FLOAT ,
              salarioMinimoRegion FLOAT ,
              eymArt25 FLOAT ,
              eymArt106ii FLOAT ,
              eymArt107 FLOAT ,
              ivArt147 FLOAT ,
              cvArt168ii FLOAT ,
              baseCalculo INT ,
              grupo VARCHAR(500) ,
              supervisorGrupo INT ,
              horas FLOAT
            )    
        DECLARE @tablaConceptoBaseImpuestoSobreNomina TABLE ( numeroConcepto
                                                              INT )
        DECLARE @ejercicio INT
        DECLARE @diarioOficial DATETIME
        DECLARE @baseCalculo VARCHAR(25)
        DECLARE @porSupervisor INT
        DECLARE @empleados INT
        DECLARE @provisionIMSS FLOAT
        DECLARE @provisionRCV FLOAT
        DECLARE @provisionINFONAVIT FLOAT
        DECLARE @retencionIMSS FLOAT
        DECLARE @retencionRCV FLOAT
        DECLARE @retencionINFONAVIT FLOAT
        DECLARE @empleadosConCuentaBancaria INT
        DECLARE @empleadosSinCuentaBancaria INT
        DECLARE @percepcionesConCuentaBancaria FLOAT
        DECLARE @deduccionesConCuentaBancaria FLOAT
        DECLARE @percepcionesSinCuentaBancaria FLOAT
        DECLARE @deduccionesSinCuentaBancaria FLOAT
        DECLARE @porcientoSobreNomina FLOAT
        DECLARE @fondoAhorroAportacionEmpleado FLOAT
        DECLARE @fondoAhorroAportacionPatron FLOAT
        DECLARE @sueldoNetoGeneral FLOAT

        DECLARE @empleadosCentro INT
        DECLARE @provisionIMSSCentro FLOAT
        DECLARE @provisionRCVCentro FLOAT
        DECLARE @provisionINFONAVITCentro FLOAT
        DECLARE @retencionIMSSCentro FLOAT
        DECLARE @retencionRCVCentro FLOAT
        DECLARE @retencionINFONAVITCentro FLOAT
        DECLARE @empleadosConCuentaBancariaCentro INT
        DECLARE @empleadosSinCuentaBancariaCentro INT
        DECLARE @percepcionesConCuentaBancariaCentro FLOAT
        DECLARE @deduccionesConCuentaBancariaCentro FLOAT
        DECLARE @percepcionesSinCuentaBancariaCentro FLOAT
        DECLARE @deduccionesSinCuentaBancariaCentro FLOAT
        DECLARE @porcientoSobreNominaCentro FLOAT
        DECLARE @fondoAhorroAportacionEmpleadoCentro FLOAT
        DECLARE @fondoAhorroAportacionPatronCentro FLOAT
        DECLARE @sueldoNetoGeneralCentro FLOAT
        DECLARE @regimenSeguridadSocial INT
        
        DECLARE @tEstatal TABLE (Centro     VARCHAR(14),
                                 Base1      FLOAT,
                                 Porciento1 FLOAT,
                                 Importe1   FLOAT,
                                 Empleados1 INT,
                                 Base2      FLOAT,
                                 Porciento2 FLOAT,
                                 Importe2   FLOAT,
                                 Empleados2 INT)
        
        SET @numeroConceptoPercepcionInicio = 1
        SET @numeroConceptoPercepcionTermino = 99
        SET @numeroConceptoContraPercepcionInicio = 1101
        SET @numeroConceptoContraPercepcionTermino = 1199
        SET @numeroConceptoDeduccionInicio = 101
        SET @numeroConceptoDeduccionTermino = 199
        SET @numeroConceptoContraDeduccionInicio = 1001
        SET @numeroConceptoContraDeduccionTermino = 1099
        SET @numeroConceptoProvisionInicio = CASE WHEN @incluirProvisiones = 'S'
                                                  THEN 201
                                                  ELSE 0
                                             END
        SET @numeroConceptoProvisionTermino = CASE WHEN @incluirProvisiones = 'S'
                                                   THEN 299
                                                   ELSE 0
                                              END
    
        SET @nombreEmpresa = ISNULL(( SELECT    dbo.empresas.nombre_empresa
                                      FROM      dbo.empresas
                                      WHERE     dbo.empresas.empresa = @empresa
                                    ), 'SIN RAZON SOCIAL REGISTRADA')
        
        SET @regimenSeguridadSocial = ISNULL((SELECT dbo.empresas.Regimen_Seguridad_Social
                                              FROM dbo.empresas
                                              WHERE dbo.empresas.empresa = @empresa),1)
                                              
        IF @ordenadoPor & 16 > 0
            OR @ordenadoPor & 32 > 0 
            SET @porSupervisor = 1
                                    
        -- Cuando el reporte es General el order de hace cero
        IF @desglosadoPor & 4 > 0 
            SET @ordenadopor = 0


        -- @porDetalle = 'S' agrega los valores de kardex
        IF @porDetalle = 'S' 
            BEGIN
            
                -- si el orden es 1 o 2 y el desglose es 1 
                -- quiere decir que se van a incluir los empleados           
                IF ( ( @ordenadoPor & 1 > 0
                       OR @ordenadoPor & 2 > 0
                     )
                     AND @desglosadoPor & 1 > 0
                   ) 
                    BEGIN
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  --supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  importe ,
                                  gravable ,
                                  exento ,
                                  tipoPago ,
                                  saldoPercepcion
                                )
                                SELECT  '99999999999997' AS centro ,
                                        --NULL, --999999995 AS supervisor ,
                                        999999995 AS codigo ,
                                        dbo.kardex.num_conc AS numeroConcepto ,
                                        dbo.kardex.concepto AS nombreConcepto ,
                                        SUM(dbo.kardex.importe) AS importePercepciones ,
                                        SUM(dbo.kardex.igravable) AS gravablePercepciones ,
                                        SUM(dbo.kardex.iexento) AS exentoPercepciones ,
                                        CASE WHEN dbo.kardex.num_conc >= 1
                                                  AND dbo.kardex.num_conc <= 99
                                             THEN 1
                                             WHEN dbo.kardex.num_conc >= 1101
                                                  AND dbo.kardex.num_conc <= 1199
                                             THEN 1
                                             WHEN dbo.kardex.num_conc >= 101
                                                  AND dbo.kardex.num_conc <= 199
                                             THEN 2
                                             WHEN dbo.kardex.num_conc >= 1001
                                                  AND dbo.kardex.num_conc <= 1099
                                             THEN 2
                                             WHEN dbo.kardex.num_conc >= 201
                                                  AND dbo.kardex.num_conc <= 299
                                             THEN 3
                                             ELSE 0
                                        END ,
                                        SUM(CASE WHEN ( ( dbo.kardex.num_conc >= 1
                                                          AND dbo.kardex.num_conc <= 99
                                                        )
                                                        OR ( dbo.kardex.num_conc >= 1101
                                                             AND dbo.kardex.num_conc <= 1199
                                                           )
                                                      )
                                                      AND dbo.kardex.saldo > 0
                                                 THEN CASE WHEN dbo.kardex.saldo IS NULL
                                                           THEN 0
                                                           ELSE dbo.kardex.saldo
                                                      END
                                                 ELSE 0
                                            END) AS saldoPercepcion
                                FROM    dbo.kardex
                                WHERE   dbo.kardex.empresa = @empresa
                                        AND dbo.kardex.nomina = @nomina
                                        AND ( ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                  AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                )
                                                OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                              )
                                              OR ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                                   OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                        AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                      )
                                                 )
                                              OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                   AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                 )
                                            )
                                GROUP BY dbo.kardex.num_conc ,
                                        dbo.kardex.concepto
                    END
                    
                
                -- Si el orden es 4 u 8 o el desglose es 2
                -- Quiere decir que solo se va a incluir 
                -- los centros de costos sin empleados
                IF ( ( @ordenadoPor & 4 > 0
                       OR @ordenadoPor & 8 > 0
                     )
                     OR ( ( @ordenadoPor & 1 > 0
                            OR @ordenadoPor & 2 > 0
                          )
                          AND @desglosadoPor & 2 > 0
                        )
                   ) 
                    BEGIN
                        -- Si quiere totales por departamento tomar la tabla
                        -- polizas porque considera los registros de nivei
                        -- superior del centro de costos
                        IF @desglosadoPor & 1 > 0 OR  @desglosadoPor & 2 > 0 
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          importe ,
                                          gravable ,
                                          exento ,
                                          centroGrupo ,
                                          conceptoGrupo ,
                                          tipoPago ,
                                          saldoPercepcion ,
                                          horas
                                        )
                                        SELECT  dbo.polizas.centro AS centroGrupo ,
                                                999999995 AS codigo ,
                                                dbo.polizas.num_conc AS numeroConcepto ,
                                                dbo.polizas.concepto AS nombreConcepto ,
                                                dbo.polizas.importe AS importePercepciones ,
                                                dbo.polizas.gravable AS gravablePercepciones ,
                                                dbo.polizas.exento AS exentoPercepciones ,
                                                dbo.polizas.centro AS centroGrupo ,
                                                999999995 AS ConceptoGrupo ,
                                                CASE WHEN dbo.polizas.num_conc >= 1
                                                          AND dbo.polizas.num_conc <= 99
                                                     THEN 1
                                                     WHEN dbo.polizas.num_conc >= 1101
                                                          AND dbo.polizas.num_conc <= 1199
                                                     THEN 1
                                                     WHEN dbo.polizas.num_conc >= 101
                                                          AND dbo.polizas.num_conc <= 199
                                                     THEN 2
                                                     WHEN dbo.polizas.num_conc >= 1001
                                                          AND dbo.polizas.num_conc <= 1099
                                                     THEN 2
                                                     WHEN dbo.polizas.num_conc >= 201
                                                          AND dbo.polizas.num_conc <= 299
                                                     THEN 3
                                                     ELSE 0
                                                END ,
                                                0 AS saldoPercepcion ,
                                                dbo.polizas.horas
                                        FROM    dbo.polizas
                                        WHERE   dbo.polizas.empresa = @empresa
                                                AND dbo.polizas.tiponom = @tipoNomina
                                                AND ( ( ( dbo.polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                          AND dbo.polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                        )
                                                        OR ( dbo.polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                      )
                                                      OR ( ( dbo.polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                           OR ( dbo.polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                              AND dbo.polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                              )
                                                         )
                                                      OR ( dbo.polizas.num_conc >= @numeroConceptoProvisionInicio
                                                           AND dbo.polizas.num_conc <= @numeroConceptoProvisionTermino
                                                         )
                                                    )
                                        --GROUP BY dbo.polizas.centro ,
                                        --        dbo.polizas.num_conc ,
                                        --        dbo.polizas.concepto
                                                --WITH CUBE
                                                
                              /*
                                        SELECT  CASE WHEN polizas.centro IS NULL
                                                     THEN '99999999999997'
                                                     ELSE polizas.centro
                                                END AS centroGrupo ,
                                                --dbo.polizas.centro AS centroGrupo ,
                                        --NULL, --999999995 AS supervisor ,
                                                999999995 AS codigo ,
                                                CASE WHEN polizas.num_conc IS NULL
                                                     THEN 9995
                                                     ELSE polizas.num_conc
                                                END AS numeroConcepto ,
                                                CASE WHEN polizas.concepto IS NULL
                                                     THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                     ELSE polizas.concepto
                                                END AS nombreConcepto ,
                                                SUM(polizas.importe) AS importePercepciones ,
                                                SUM(polizas.gravable) AS gravablePercepciones ,
                                                SUM(polizas.exento) AS exentoPercepciones ,
                                                CASE WHEN GROUPING(polizas.centro) = 1
                                                     THEN '99999999999997'
                                                     ELSE ''
                                                END AS centroGrupo ,
                                                CASE WHEN GROUPING(polizas.num_conc) = 1
                                                     THEN 999999995
                                                     ELSE 0
                                                END AS ConceptoGrupo ,
                                                CASE WHEN polizas.num_conc >= 1
                                                          AND polizas.num_conc <= 99
                                                     THEN 1
                                                     WHEN polizas.num_conc >= 1101
                                                          AND polizas.num_conc <= 1199
                                                     THEN 1
                                                     WHEN polizas.num_conc >= 101
                                                          AND polizas.num_conc <= 199
                                                     THEN 2
                                                     WHEN polizas.num_conc >= 1001
                                                          AND polizas.num_conc <= 1099
                                                     THEN 2
                                                     WHEN polizas.num_conc >= 201
                                                          AND polizas.num_conc <= 299
                                                     THEN 3
                                                     ELSE 0
                                                END ,
                                                --SUM(CASE WHEN ( ( dbo.polizas.num_conc >= 1
                                                --              AND dbo.polizas.num_conc <= 99
                                                --              )
                                                --              OR ( dbo.polizas.num_conc >= 1101
                                                --              AND dbo.polizas.num_conc <= 1199
                                                --              )
                                                --              )
                                                --              AND dbo.kardex.saldo > 0
                                                --         THEN CASE
                                                --              WHEN dbo.kardex.saldo IS NULL
                                                --              THEN 0
                                                --              ELSE dbo.kardex.saldo
                                                --              END
                                                --         ELSE 0
                                                --    END) 
                                                0 AS saldoPercepcion ,
                                                SUM(polizas.horas)
                                        FROM    @polizas AS polizas
                                                --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                --              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                        WHERE   polizas.empresa = @empresa
                                                AND polizas.tiponom = @tipoNomina
                                                AND ( ( ( polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                          AND polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                        )
                                                        OR ( polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                             AND polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                      )
                                                      OR ( ( polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                             AND polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                           OR ( polizas.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                              AND polizas.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                              )
                                                         )
                                                      OR ( polizas.num_conc >= @numeroConceptoProvisionInicio
                                                           AND polizas.num_conc <= @numeroConceptoProvisionTermino
                                                         )
                                                    )
                                        GROUP BY polizas.centro ,
                                                polizas.num_conc ,
                                                polizas.concepto
                                                WITH CUBE
                              */
                            END
                        ELSE 
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                  --supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          importe ,
                                          gravable ,
                                          exento ,
                                          centroGrupo ,
                                          conceptoGrupo ,
                                          tipoPago ,
                                          saldoPercepcion
                                        )
                                        SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                                     THEN '99999999999997'
                                                     ELSE dbo.Llaves.centro
                                                END AS centroGrupo ,
                                        --NULL, --999999995 AS supervisor ,
                                                999999995 AS codigo ,
                                                CASE WHEN dbo.kardex.num_conc IS NULL
                                                     THEN 9995
                                                     ELSE dbo.kardex.num_conc
                                                END AS numeroConcepto ,
                                                CASE WHEN dbo.kardex.concepto IS NULL
                                                     THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                     ELSE dbo.kardex.concepto
                                                END AS nombreConcepto ,
                                                SUM(dbo.kardex.importe) AS importePercepciones ,
                                                SUM(dbo.kardex.igravable) AS gravablePercepciones ,
                                                SUM(dbo.kardex.iexento) AS exentoPercepciones ,
                                                CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                                     THEN '99999999999997'
                                                     ELSE ''
                                                END AS centroGrupo ,
                                                CASE WHEN GROUPING(dbo.kardex.num_conc) = 1
                                                     THEN 999999995
                                                     ELSE 0
                                                END AS ConceptoGrupo ,
                                                CASE WHEN dbo.kardex.num_conc >= 1
                                                          AND dbo.kardex.num_conc <= 99
                                                     THEN 1
                                                     WHEN dbo.kardex.num_conc >= 1101
                                                          AND dbo.kardex.num_conc <= 1199
                                                     THEN 1
                                                     WHEN dbo.kardex.num_conc >= 101
                                                          AND dbo.kardex.num_conc <= 199
                                                     THEN 2
                                                     WHEN dbo.kardex.num_conc >= 1001
                                                          AND dbo.kardex.num_conc <= 1099
                                                     THEN 2
                                                     WHEN dbo.kardex.num_conc >= 201
                                                          AND dbo.kardex.num_conc <= 299
                                                     THEN 3
                                                     ELSE 0
                                                END ,
                                                SUM(CASE WHEN ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.kardex.saldo > 0
                                                         THEN CASE
                                                              WHEN dbo.kardex.saldo IS NULL
                                                              THEN 0
                                                              ELSE dbo.kardex.saldo
                                                              END
                                                         ELSE 0
                                                    END) AS saldoPercepcion
                                        FROM    dbo.kardex
                                                INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                        WHERE   dbo.kardex.empresa = @empresa
                                                AND dbo.kardex.nomina = @nomina
                                                AND ( ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                          AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                        )
                                                        OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                      )
                                                      OR ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                           OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                              AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                              )
                                                         )
                                                      OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                           AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                         )
                                                    )
                                        GROUP BY dbo.Llaves.centro ,
                                                dbo.kardex.num_conc ,
                                                dbo.kardex.concepto
                                                WITH CUBE
                            END
                                     
                        IF @porCentro = 1 
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                  --supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          importe ,
                                          gravable ,
                                          exento ,
                                          tipoPago ,
                                          saldoPercepcion
                                        )
                                        SELECT  '99999999999996' AS centro ,
                                        --NULL, --999999995 AS supervisor ,
                                                999999995 AS codigo ,
                                                dbo.kardex.num_conc AS numeroConcepto ,
                                                CASE WHEN dbo.kardex.concepto IS NULL
                                                     THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                     ELSE dbo.kardex.concepto
                                                END AS nombreConcepto ,
                                                SUM(dbo.kardex.importe) AS importePercepciones ,
                                                SUM(dbo.kardex.igravable) AS gravablePercepciones ,
                                                SUM(dbo.kardex.iexento) AS exentoPercepciones ,
                                                CASE WHEN dbo.kardex.num_conc >= 1
                                                          AND dbo.kardex.num_conc <= 99
                                                     THEN 1
                                                     WHEN dbo.kardex.num_conc >= 1101
                                                          AND dbo.kardex.num_conc <= 1199
                                                     THEN 1
                                                     WHEN dbo.kardex.num_conc >= 101
                                                          AND dbo.kardex.num_conc <= 199
                                                     THEN 2
                                                     WHEN dbo.kardex.num_conc >= 1001
                                                          AND dbo.kardex.num_conc <= 1099
                                                     THEN 2
                                                     WHEN dbo.kardex.num_conc >= 201
                                                          AND dbo.kardex.num_conc <= 299
                                                     THEN 3
                                                     ELSE 0
                                                END ,
                                                SUM(CASE WHEN ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.kardex.saldo > 0
                                                         THEN CASE
                                                              WHEN dbo.kardex.saldo IS NULL
                                                              THEN 0
                                                              ELSE dbo.kardex.saldo
                                                              END
                                                         ELSE 0
                                                    END) AS saldoPercepcion
                                        FROM    dbo.kardex
                                                INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                        WHERE   dbo.kardex.empresa = @empresa
                                                AND dbo.kardex.nomina = @nomina
                                                AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                AND dbo.SeleccionElementos.nomina = @nomina
                                                AND ( ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                          AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                        )
                                                        OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                      )
                                                      OR ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                           OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                              AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                              )
                                                         )
                                                      OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                           AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                         )
                                                    )
                                        GROUP BY --dbo.Llaves.centro ,
                                                dbo.kardex.num_conc ,
                                                dbo.kardex.concepto
                            END
                           
                    END
                    
                -- Ordenado por Centro, Supervisor y Nombre o Codigo
                IF ( ( @ordenadoPor & 16 > 0
                       OR @ordenadoPor & 32 > 0
                     )
                     AND ( @desglosadoPor & 1 > 0
                           OR @desglosadoPor & 2 > 0
                         )
                   ) 
                    BEGIN
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  importe ,
                                  gravable ,
                                  exento ,
                                  centroGrupo ,
                                  conceptoGrupo ,
                                  tipoPago ,
                                  supervisorGrupo ,
                                  saldoPercepcion
                                    
                                )
                                SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                             THEN '99999999999997'
                                             ELSE dbo.Llaves.centro
                                        END AS centro ,
                                        CASE WHEN dbo.Llaves.supervisor IS NULL
                                             THEN 999999995
                                             ELSE dbo.Llaves.supervisor
                                        END ,
                                        999999995 AS codigo ,
                                        CASE WHEN dbo.kardex.num_conc IS NULL
                                             THEN 9995
                                             ELSE dbo.kardex.num_conc
                                        END AS numeroConcepto ,
                                        CASE WHEN dbo.kardex.concepto IS NULL
                                             THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                             ELSE dbo.kardex.concepto
                                        END AS nombreConcepto ,
                                        SUM(dbo.kardex.importe) AS importePercepciones ,
                                        SUM(dbo.kardex.igravable) AS gravablePercepciones ,
                                        SUM(dbo.kardex.iexento) AS exentoPercepciones ,
                                        CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                             THEN '99999999999997'
                                             ELSE ''
                                        END AS centroGrupo ,
                                        CASE WHEN GROUPING(dbo.kardex.num_conc) = 1
                                             THEN 999999995
                                             ELSE 0
                                        END AS ConceptoGrupo ,
                                        CASE WHEN dbo.kardex.num_conc >= 1
                                                  AND dbo.kardex.num_conc <= 99
                                             THEN 1
                                             WHEN dbo.kardex.num_conc >= 1101
                                                  AND dbo.kardex.num_conc <= 1199
                                             THEN 1
                                             WHEN dbo.kardex.num_conc >= 101
                                                  AND dbo.kardex.num_conc <= 199
                                             THEN 2
                                             WHEN dbo.kardex.num_conc >= 1001
                                                  AND dbo.kardex.num_conc <= 1099
                                             THEN 2
                                             WHEN dbo.kardex.num_conc >= 201
                                                  AND dbo.kardex.num_conc <= 299
                                             THEN 3
                                             ELSE 0
                                        END AS tipoPago ,
                                        CASE WHEN GROUPING(dbo.Llaves.supervisor) = 1
                                             THEN 99995
                                             ELSE 0
                                        END AS supervisorGrupo ,
                                        SUM(CASE WHEN ( ( dbo.kardex.num_conc >= 1
                                                          AND dbo.kardex.num_conc <= 99
                                                        )
                                                        OR ( dbo.kardex.num_conc >= 1101
                                                             AND dbo.kardex.num_conc <= 1199
                                                           )
                                                      )
                                                      AND dbo.kardex.saldo > 0
                                                 THEN CASE WHEN dbo.kardex.saldo IS NULL
                                                           THEN 0
                                                           ELSE dbo.kardex.saldo
                                                      END
                                                 ELSE 0
                                            END) AS saldoPercepcion
                                FROM    dbo.kardex
                                        INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                WHERE   dbo.kardex.empresa = @empresa
                                        AND dbo.kardex.nomina = @nomina
                                        AND ( ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                  AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                )
                                                OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                              )
                                              OR ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                                   OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                        AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                      )
                                                 )
                                              OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                   AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                 )
                                            )
                                GROUP BY dbo.Llaves.centro ,
                                        dbo.Llaves.supervisor ,
                                        dbo.kardex.num_conc ,
                                        dbo.kardex.concepto
                                        WITH CUBE
                                ORDER BY dbo.Llaves.centro ,
                                        dbo.Llaves.supervisor ,
                                        dbo.kardex.num_conc ASC
                    
                        IF @porCentro = 1 
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          importe ,
                                          gravable ,
                                          exento ,
                                          tipoPago ,
                                          saldoPercepcion
                                        )
                                        SELECT  '99999999999996' AS centro ,
                                                999999995 AS supervisor ,
                                                999999995 AS codigo ,
                                                dbo.kardex.num_conc AS numeroConcepto ,
                                                dbo.kardex.concepto AS nombreConcepto ,
                                                SUM(dbo.kardex.importe) AS importePercepciones ,
                                                SUM(dbo.kardex.igravable) AS gravablePercepciones ,
                                                SUM(dbo.kardex.iexento) AS exentoPercepciones ,
                                                CASE WHEN dbo.kardex.num_conc >= 1
                                                          AND dbo.kardex.num_conc <= 99
                                                     THEN 1
                                                     WHEN dbo.kardex.num_conc >= 1101
                                                          AND dbo.kardex.num_conc <= 1199
                                                     THEN 1
                                                     WHEN dbo.kardex.num_conc >= 101
                                                          AND dbo.kardex.num_conc <= 199
                                                     THEN 2
                                                     WHEN dbo.kardex.num_conc >= 1001
                                                          AND dbo.kardex.num_conc <= 1099
                                                     THEN 2
                                                     WHEN dbo.kardex.num_conc >= 201
                                                          AND dbo.kardex.num_conc <= 299
                                                     THEN 3
                                                     ELSE 0
                                                END AS tipoPago ,
                                                SUM(CASE WHEN ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.kardex.saldo > 0
                                                         THEN CASE
                                                              WHEN dbo.kardex.saldo IS NULL
                                                              THEN 0
                                                              ELSE dbo.kardex.saldo
                                                              END
                                                         ELSE 0
                                                    END) AS saldoPercepcion
                                        FROM    dbo.kardex
                                                INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                        WHERE   dbo.kardex.empresa = @empresa
                                                AND dbo.kardex.nomina = @nomina
                                                AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                AND dbo.SeleccionElementos.nomina = @nomina
                                                AND ( ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                          AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                        )
                                                        OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                      )
                                                      OR ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                           OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                              AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                              )
                                                         )
                                                      OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                           AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                         )
                                                    )
                                        GROUP BY --dbo.Llaves.centro ,
                                        --dbo.Llaves.supervisor ,
                                                dbo.kardex.num_conc ,
                                                dbo.kardex.concepto
                                        --WITH CUBE
                                        ORDER BY --dbo.Llaves.centro ,
                                        --dbo.Llaves.supervisor ,
                                                dbo.kardex.num_conc ASC
                            END
                        
                    END


                -- desglosadoPor = 4 
                -- quiere decir que solo se va imprimir el total general
                IF @ordenadoPor = 0
                    AND @desglosadoPor & 4 > 0 
                    BEGIN
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  --supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  importe ,
                                  gravable ,
                                  exento ,
                                  tipoPago ,
                                  saldoPercepcion
                                )
                                SELECT  '99999999999997' AS centro ,
                                        --NULL, --999999995 AS supervisor ,
                                        999999995 AS codigo ,
                                        dbo.kardex.num_conc AS numeroConcepto ,
                                        dbo.kardex.concepto AS nombreConcepto ,
                                        SUM(dbo.kardex.importe) AS importePercepciones ,
                                        SUM(dbo.kardex.igravable) AS gravablePercepciones ,
                                        SUM(dbo.kardex.iexento) AS exentoPercepciones ,
                                        CASE WHEN dbo.kardex.num_conc >= 1
                                                  AND dbo.kardex.num_conc <= 99
                                             THEN 1
                                             WHEN dbo.kardex.num_conc >= 1101
                                                  AND dbo.kardex.num_conc <= 1199
                                             THEN 1
                                             WHEN dbo.kardex.num_conc >= 101
                                                  AND dbo.kardex.num_conc <= 199
                                             THEN 2
                                             WHEN dbo.kardex.num_conc >= 1001
                                                  AND dbo.kardex.num_conc <= 1099
                                             THEN 2
                                             WHEN dbo.kardex.num_conc >= 201
                                                  AND dbo.kardex.num_conc <= 299
                                             THEN 3
                                             ELSE 0
                                        END ,
                                        SUM(CASE WHEN ( ( dbo.kardex.num_conc >= 1
                                                          AND dbo.kardex.num_conc <= 99
                                                        )
                                                        OR ( dbo.kardex.num_conc >= 1101
                                                             AND dbo.kardex.num_conc <= 1199
                                                           )
                                                      )
                                                      AND dbo.kardex.saldo > 0
                                                 THEN CASE WHEN dbo.kardex.saldo IS NULL
                                                           THEN 0
                                                           ELSE dbo.kardex.saldo
                                                      END
                                                 ELSE 0
                                            END) AS saldoPercepcion
                                FROM    dbo.kardex
                                WHERE   dbo.kardex.empresa = @empresa
                                        AND dbo.kardex.nomina = @nomina
                                        AND ( ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                  AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                )
                                                OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                              )
                                              OR ( ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                                   OR ( dbo.kardex.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                        AND dbo.kardex.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                      )
                                                 )
                                              OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                   AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                 )
                                            )
                                GROUP BY dbo.kardex.num_conc ,
                                        dbo.kardex.concepto
                    END                    
                    

                -- Anexo Concepto Percepcion por Centro
                -- Llena el campo anexoConceptoPercepcion 
                -- con desglose por departamento
                IF @queConcepto = 'P' 
                    BEGIN
                        IF ( ( @ordenadoPor & 4 > 0
                               OR @ordenadoPor & 8 > 0
                             )
                             OR ( ( @ordenadoPor & 1 > 0
                                    OR @ordenadoPor & 2 > 0
                                  )
                                  AND @desglosadoPor & 2 > 0
                                )
                           ) 
                            BEGIN
                                -- Si quiere totales por departamento tomar la tabla
                                -- polizas porque considera los registros de nivei 
                                -- superior del centro de costos
                                IF @desglosadoPor & 2 > 0 
                                    BEGIN
                                        UPDATE  [@resumenPorCentroTemporal]
                                        SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              ISNULL(SUM(dbo.polizas.empleados),
                                                              0)
                                                              FROM
                                                              dbo.polizas
                                                              --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              --AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.polizas.empresa = @empresa
                                                              AND dbo.polizas.tiponom = @tipoNomina
                                                              AND dbo.polizas.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.polizas.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.polizas.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.polizas.horas)
                                                              FROM
                                                              dbo.polizas
                                                              --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              --AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.polizas.empresa = @empresa
                                                              AND dbo.polizas.tiponom = @tipoNomina
                                                              AND dbo.polizas.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.polizas.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.polizas.centro = [@resumenPorCentroTemporal].centro
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              ISNULL(SUM(dbo.polizas.empleados),
                                                              0)
                                                              FROM
                                                              dbo.polizas
                                                              --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              --AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.polizas.empresa = @empresa
                                                              AND dbo.polizas.tiponom = @tipoNomina
                                                              AND dbo.polizas.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.polizas.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.polizas.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                        FROM    @resumenPorCentroTemporal
                                        WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                      )
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                                    )
                                    END
                                ELSE 
                                    BEGIN
                                        UPDATE  [@resumenPorCentroTemporal]
                                        SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( dbo.kardex.codigo ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.horas)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                        FROM    @resumenPorCentroTemporal
                                        WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                      )
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                                    )
                                    END
                            END
                            
                            
                        IF ( ( @ordenadoPor & 16 > 0
                               OR @ordenadoPor & 32 > 0
                             )
                             AND ( @desglosadoPor & 1 > 0
                                   OR @desglosadoPor & 2 > 0
                                 )
                           ) 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( dbo.kardex.codigo ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.horas)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )                           
                            END                             
                            
-- Anexo Concepto Percepcion Total Centro
                        -- Llena el campo anexoConceptoPercepcion 
                        -- solo el total General
                        UPDATE  [@resumenPorCentroTemporal]
                        SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( dbo.kardex.codigo ))
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.horas)
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                        FROM    @resumenPorCentroTemporal
                        WHERE   [@resumenPorCentroTemporal].centro = '99999999999997'
                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                      )
                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                         )
                                      OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                    )
                                    
                                    
                        IF @porCentro = 1 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( dbo.kardex.codigo ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.horas)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro = '99999999999996'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                            )
                            END            
                    END
                                                              
                                                              

-- Anexo Concepto Deduccion por Centro
                -- Llena el campo anexoConceptoDeduccion
                -- con desglose por departamento
                IF @queConcepto = 'D' 
                    BEGIN
                        IF ( ( @ordenadoPor & 4 > 0
                               OR @ordenadoPor & 8 > 0
                             )
                             OR ( ( @ordenadoPor & 1 > 0
                                    OR @ordenadoPor & 2 > 0
                                  )
                                  AND @desglosadoPor & 2 > 0
                                )
                           ) 
                            BEGIN
                                -- Si quiere totales por departamento tomar la tabla
                                -- polizas porque considera los registros de nivei 
                                -- superior del centro de costos
                                IF @desglosadoPor & 2 > 0 
                                    BEGIN
                                        UPDATE  [@resumenPorCentroTemporal]
                                        SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.polizas.dias)
                                                              FROM
                                                              dbo.polizas
                                                              --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              --AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.polizas.empresa = @empresa
                                                              AND dbo.polizas.tiponom = @tipoNomina
                                                              AND dbo.polizas.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.polizas.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.polizas.centro = [@resumenPorCentroTemporal].centro
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              ISNULL(SUM(dbo.polizas.empleados),
                                                              0)
                                                              FROM
                                                              dbo.polizas
                                                              --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              --AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.polizas.empresa = @empresa
                                                              AND dbo.polizas.tiponom = @tipoNomina
                                                              AND dbo.polizas.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.polizas.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.polizas.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              ISNULL(SUM(dbo.polizas.empleados),
                                                              0)
                                                              FROM
                                                              dbo.polizas
                                                              --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              --AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.polizas.empresa = @empresa
                                                              AND dbo.polizas.tiponom = @tipoNomina
                                                              AND dbo.polizas.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.polizas.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.polizas.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                        FROM    @resumenPorCentroTemporal
                                        WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                      )
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                                    )                                    
                                    END
                                ELSE 
                                    BEGIN
                                        UPDATE  [@resumenPorCentroTemporal]
                                        SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.dias)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                        FROM    @resumenPorCentroTemporal
                                        WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                      )
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                         )
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                                      OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                                    )
                                    END
                            END


                        IF ( ( @ordenadoPor & 16 > 0
                               OR @ordenadoPor & 32 > 0
                             )
                             AND ( @desglosadoPor & 1 > 0
                                   OR @desglosadoPor & 2 > 0
                                 )
                           ) 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.dias)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )                           
                            END

                            

-- Anexo Concepto Deduccion Total Centro
                        -- Llena el campo anexoConceptoDeduccion
                        -- solo el total General
                        UPDATE  [@resumenPorCentroTemporal]
                        SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.dias)
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                        FROM    @resumenPorCentroTemporal
                        WHERE   [@resumenPorCentroTemporal].centro = '99999999999997'
                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                      )
                                      OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                      OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                    )
                                    
                        IF @porCentro = 1 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.kardex.dias)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.kardex.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro = '99999999999996'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                              )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )
                            END           
                    END
            END
        ELSE 
            IF @porDetalle = 'N' 
                BEGIN
                    -- Genera un registro por trabajador y renglon
                    IF ( @ordenadoPor & 1 > 0
                         OR @ordenadoPor & 2 > 0
                       )
                        AND @desglosadoPor & 1 > 0 
                        BEGIN
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      --supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      nombreConcepto ,
                                      tipoPago
                                    )
                                    SELECT  '99999999999997' ,
                                            --NULL, --999999995 AS supervisor ,
                                            999999995 AS codigo ,
                                            dbo.kardex.num_conc AS numeroConcepto ,
                                            dbo.kardex.concepto ,
                                            CASE WHEN dbo.kardex.num_conc >= 1
                                                      AND dbo.kardex.num_conc <= 99
                                                 THEN 1
                                                 WHEN dbo.kardex.num_conc >= 1101
                                                      AND dbo.kardex.num_conc <= 1199
                                                 THEN 1
                                                 WHEN dbo.kardex.num_conc >= 101
                                                      AND dbo.kardex.num_conc <= 199
                                                 THEN 2
                                                 WHEN dbo.kardex.num_conc >= 1001
                                                      AND dbo.kardex.num_conc <= 1099
                                                 THEN 2
                                                 WHEN dbo.kardex.num_conc >= 201
                                                      AND dbo.kardex.num_conc <= 299
                                                 THEN 3
                                                 ELSE 0
                                            END AS tipoPago
                                    FROM    dbo.kardex
                                    WHERE   dbo.kardex.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                                    GROUP BY dbo.kardex.num_conc ,
                                            dbo.kardex.concepto
                        END             
            
             
                    IF ( ( @ordenadoPor & 4 > 0
                           OR @ordenadoPor & 8 > 0
                         )
                         OR ( ( @ordenadoPor & 1 > 0
                                OR @ordenadoPor & 2 > 0
                              )
                              AND @desglosadoPor & 2 > 0
                            )
                       ) 
                        -- Gernera un registro por centro y renglon
                        BEGIN
                            -- Si quiere totales por departamento tomar la tabla
                            -- polizas porque considera los registros de nivei 
                            -- superior del centro de costos
                            IF @desglosadoPor & 2 > 0 
                                BEGIN
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                              codigo ,
                                              numeroConcepto ,
                                              nombreConcepto ,
                                              centroGrupo ,
                                              conceptoGrupo ,
                                              tipoPago
                                            )
                                            SELECT  dbo.polizas.centro AS centroGrupo ,
                                                    999999995 AS codigo ,
                                                    dbo.polizas.num_conc AS numeroConcepto ,
                                                    dbo.polizas.concepto AS nombreConcepto ,
                                                    dbo.polizas.centro AS centroGrupo ,
                                                    999999995 AS ConceptoGrupo ,
                                                    CASE WHEN dbo.polizas.num_conc >= 1
                                                              AND dbo.polizas.num_conc <= 99
                                                         THEN 1
                                                         WHEN dbo.polizas.num_conc >= 1101
                                                              AND dbo.polizas.num_conc <= 1199
                                                         THEN 1
                                                         WHEN dbo.polizas.num_conc >= 101
                                                              AND dbo.polizas.num_conc <= 199
                                                         THEN 2
                                                         WHEN dbo.polizas.num_conc >= 1001
                                                              AND dbo.polizas.num_conc <= 1099
                                                         THEN 2
                                                         WHEN dbo.polizas.num_conc >= 201
                                                              AND dbo.polizas.num_conc <= 299
                                                         THEN 3
                                                         ELSE 0
                                                    END
                                            FROM    dbo.polizas
                                                    INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.polizas.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.polizas.centro
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                            WHERE   dbo.polizas.empresa = @empresa
                                                    AND dbo.polizas.tiponom = @tipoNomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.polizas.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.polizas.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.polizas.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.polizas.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.polizas.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                            --GROUP BY dbo.polizas.centro ,
                                            --        dbo.polizas.num_conc ,
                                            --        dbo.polizas.concepto
                                            --        WITH CUBE
                                                    
                                  /*
                                            SELECT  CASE WHEN dbo.polizas.centro IS NULL
                                                         THEN '99999999999997'
                                                         ELSE dbo.polizas.centro
                                                    END AS centroGrupo ,
                                                    --dbo.polizas.centro AS centroGrupo ,
                                            --NULL, --999999995 AS supervisor ,
                                                    999999995 AS codigo ,
                                                    CASE WHEN dbo.polizas.num_conc IS NULL
                                                         THEN 9995
                                                         ELSE dbo.polizas.num_conc
                                                    END AS numeroConcepto ,
                                                    CASE WHEN dbo.polizas.concepto IS NULL
                                                         THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                         ELSE dbo.polizas.concepto
                                                    END AS nombreConcepto ,
                                                    CASE WHEN GROUPING(dbo.polizas.centro) = 1
                                                         THEN '99999999999997'
                                                         ELSE ''
                                                    END AS centroGrupo ,
                                                    CASE WHEN GROUPING(dbo.polizas.num_conc) = 1
                                                         THEN 999999995
                                                         ELSE 0
                                                    END AS ConceptoGrupo ,
                                                    CASE WHEN dbo.polizas.num_conc >= 1
                                                              AND dbo.polizas.num_conc <= 99
                                                         THEN 1
                                                         WHEN dbo.polizas.num_conc >= 1101
                                                              AND dbo.polizas.num_conc <= 1199
                                                         THEN 1
                                                         WHEN dbo.polizas.num_conc >= 101
                                                              AND dbo.polizas.num_conc <= 199
                                                         THEN 2
                                                         WHEN dbo.polizas.num_conc >= 1001
                                                              AND dbo.polizas.num_conc <= 1099
                                                         THEN 2
                                                         WHEN dbo.polizas.num_conc >= 201
                                                              AND dbo.polizas.num_conc <= 299
                                                         THEN 3
                                                         ELSE 0
                                                    END
                                            FROM    dbo.polizas --INNER JOIN dbo.Llaves ON dbo.polizas.empresa = dbo.Llaves.empresa
                                            --                  AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.polizas.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.polizas.centro
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                            WHERE   dbo.polizas.empresa = @empresa
                                                    AND dbo.polizas.tiponom = @tipoNomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.polizas.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.polizas.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.polizas.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.polizas.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.polizas.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                            GROUP BY dbo.polizas.centro ,
                                                    dbo.polizas.num_conc ,
                                                    dbo.polizas.concepto
                                                    WITH CUBE
                                  */
                                END
                            ELSE 
                                BEGIN
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                      --supervisor ,
                                              codigo ,
                                              numeroConcepto ,
                                              nombreConcepto ,
                                              centroGrupo ,
                                              conceptoGrupo ,
                                              tipoPago
                                            )
                                            SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                                         THEN '99999999999997'
                                                         ELSE dbo.Llaves.centro
                                                    END AS centroGrupo ,
                                            --NULL, --999999995 AS supervisor ,
                                                    999999995 AS codigo ,
                                                    CASE WHEN dbo.kardex.num_conc IS NULL
                                                         THEN 9995
                                                         ELSE dbo.kardex.num_conc
                                                    END AS numeroConcepto ,
                                                    CASE WHEN dbo.kardex.concepto IS NULL
                                                         THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                         ELSE dbo.kardex.concepto
                                                    END AS nombreConcepto ,
                                                    CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                                         THEN '99999999999997'
                                                         ELSE ''
                                                    END AS centroGrupo ,
                                                    CASE WHEN GROUPING(dbo.kardex.num_conc) = 1
                                                         THEN 999999995
                                                         ELSE 0
                                                    END AS ConceptoGrupo ,
                                                    CASE WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                         THEN 1
                                                         WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                         THEN 1
                                                         WHEN dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                         THEN 2
                                                         WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                         THEN 2
                                                         WHEN dbo.kardex.num_conc >= 201
                                                              AND dbo.kardex.num_conc <= 299
                                                         THEN 3
                                                         ELSE 0
                                                    END
                                            FROM    dbo.kardex
                                                    INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.centro
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                            WHERE   dbo.kardex.empresa = @empresa
                                                    AND dbo.kardex.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                            GROUP BY dbo.Llaves.centro ,
                                                    dbo.kardex.num_conc ,
                                                    dbo.kardex.concepto
                                                    WITH CUBE
                                END                
                            
                        
                            -- Si quiere totales por departamento tomar la tabla
                            -- polizas porque considera los registros de nivei 
                            -- superior del centro de costos
                            IF @desglosadoPor & 2 > 0 
                                BEGIN
                            -- Agrega el registro de total por cada centro
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                      --supervisor ,
                                              codigo ,
                                              tipoPago ,
                                              renglon
                                            )
                                            SELECT  DISTINCT
                                                    dbo.polizas.centro ,
                                            --NULL, --999999996 AS supervisor ,
                                                    999999996 AS codigo ,
                                                    4 ,
                                                    1
                                            FROM    dbo.polizas --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                    --          AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.polizas.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.polizas.centro
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                            WHERE   dbo.polizas.empresa = @empresa
                                                    AND dbo.polizas.tiponom = @tipoNomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.polizas.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.polizas.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.polizas.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.polizas.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.polizas.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.polizas.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                END
                            ELSE 
                                BEGIN
                            -- Agrega el registro de total por cada centro
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                      --supervisor ,
                                              codigo ,
                                              tipoPago ,
                                              renglon
                                            )
                                            SELECT  DISTINCT
                                                    dbo.Llaves.centro ,
                                            --NULL, --999999996 AS supervisor ,
                                                    999999996 AS codigo ,
                                                    4 ,
                                                    1
                                            FROM    dbo.kardex
                                                    INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.centro
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                            WHERE   dbo.kardex.empresa = @empresa
                                                    AND dbo.kardex.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                END

                                                
                            -- Para cuando solo quiere imprimir algunos centro de costos
                            IF @porCentro = 1 
                                BEGIN
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                      --supervisor ,
                                              codigo ,
                                              numeroConcepto ,
                                              nombreConcepto ,
                                              tipoPago
                                            )
                                            SELECT  DISTINCT
                                                    '99999999999996' AS centro ,
                                            --NULL, --999999995 AS supervisor ,
                                                    999999995 AS codigo ,
                                                    dbo.kardex.num_conc ,
                                                    RTRIM(LTRIM(dbo.kardex.concepto)) ,
                                                    CASE WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                         THEN 1
                                                         WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                         THEN 1
                                                         WHEN dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                         THEN 2
                                                         WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                         THEN 2
                                                         WHEN dbo.kardex.num_conc >= 201
                                                              AND dbo.kardex.num_conc <= 299
                                                         THEN 3
                                                         ELSE 0
                                                    END
                                            FROM    dbo.kardex
                                                    INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.kardex.empresa = @empresa
                                                    AND dbo.kardex.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                            GROUP BY dbo.kardex.num_conc ,
                                                    RTRIM(LTRIM(dbo.kardex.concepto))
                                END
                              
                        END   
                        
                        
                    -- Por centro, supervisor y nombre o codigo
                    IF ( ( @ordenadoPor & 16 > 0
                           OR @ordenadoPor & 32 > 0
                         )
                         AND ( @desglosadoPor & 1 > 0
                               OR @desglosadoPor & 2 > 0
                             )
                       ) 
                        BEGIN
                        
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      nombreConcepto ,
                                      centroGrupo ,
                                      conceptoGrupo ,
                                      tipoPago ,
                                      supervisorGrupo
                                    )
                                    SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                                 THEN '99999999999997'
                                                 ELSE dbo.Llaves.centro
                                            END AS centro ,
                                            CASE WHEN dbo.Llaves.supervisor IS NULL
                                                 THEN 999999995
                                                 ELSE dbo.Llaves.supervisor
                                            END ,
                                            999999995 AS codigo ,
                                            CASE WHEN dbo.kardex.num_conc IS NULL
                                                 THEN 9995
                                                 ELSE dbo.kardex.num_conc
                                            END AS numeroConcepto ,
                                            CASE WHEN dbo.kardex.concepto IS NULL
                                                 THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                 ELSE dbo.kardex.concepto
                                            END AS nombreConcepto ,
                                            CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                                 THEN '99999999999997'
                                                 ELSE ''
                                            END AS centroGrupo ,
                                            CASE WHEN GROUPING(dbo.kardex.num_conc) = 1
                                                 THEN 999999995
                                                 ELSE 0
                                            END AS ConceptoGrupo ,
                                            CASE WHEN dbo.kardex.num_conc >= 1
                                                      AND dbo.kardex.num_conc <= 99
                                                 THEN 1
                                                 WHEN dbo.kardex.num_conc >= 1101
                                                      AND dbo.kardex.num_conc <= 1199
                                                 THEN 1
                                                 WHEN dbo.kardex.num_conc >= 101
                                                      AND dbo.kardex.num_conc <= 199
                                                 THEN 2
                                                 WHEN dbo.kardex.num_conc >= 1001
                                                      AND dbo.kardex.num_conc <= 1099
                                                 THEN 2
                                                 WHEN dbo.kardex.num_conc >= 201
                                                      AND dbo.kardex.num_conc <= 299
                                                 THEN 3
                                                 ELSE 0
                                            END AS tipoPago ,
                                            CASE WHEN GROUPING(dbo.Llaves.supervisor) = 1
                                                 THEN 99995
                                                 ELSE 0
                                            END AS supervisorGrupo
                                    FROM    dbo.kardex
                                            INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                    WHERE   dbo.kardex.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                                    GROUP BY dbo.Llaves.centro ,
                                            dbo.Llaves.supervisor ,
                                            dbo.kardex.num_conc ,
                                            dbo.kardex.concepto
                                            WITH CUBE
                                    ORDER BY dbo.Llaves.centro ,
                                            dbo.Llaves.supervisor ,
                                            dbo.kardex.num_conc ASC
                                            
                            
                                            
                            -- Agrega el registro de total por cada centro
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      tipoPago ,
                                      renglon
                                    )
                                    SELECT  DISTINCT
                                            dbo.Llaves.centro ,
                                            dbo.Llaves.supervisor ,
                                            999999996 AS codigo ,
                                            4 ,
                                            1
                                    FROM    dbo.kardex
                                            INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                    WHERE   dbo.kardex.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
--- ********************                                                
-- rutina para totales por total supervisor
                                    UNION
                                    SELECT  DISTINCT
                                            dbo.Llaves.centro ,
                                            999999996 , --dbo.Llaves.supervisor ,
                                            999999996 AS codigo ,
                                            4 ,
                                            1
                                    FROM    dbo.kardex
                                            INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                    WHERE   dbo.kardex.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
--- ********************                                                
                         
                                                
                            IF @porCentro = 1 --AND (@desglosadoPor & 2 > 0 OR @desglosadoPor & 4 > 0)
                                BEGIN
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                              supervisor ,
                                              codigo ,
                                              numeroConcepto ,
                                              nombreConcepto ,
                                              tipoPago ,
                                              supervisorGrupo
                                            )
                                            SELECT  DISTINCT
                                                    '99999999999996' AS centro ,
                                                    999999995 AS supervisor ,
                                                    999999995 AS codigo ,
                                                    dbo.kardex.num_conc ,
                                                    dbo.kardex.concepto ,
                                                    CASE WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                         THEN 1
                                                         WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                         THEN 1
                                                         WHEN dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                         THEN 2
                                                         WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                         THEN 2
                                                         WHEN dbo.kardex.num_conc >= 201
                                                              AND dbo.kardex.num_conc <= 299
                                                         THEN 3
                                                         ELSE 0
                                                    END ,
                                                    99995
                                            FROM    dbo.kardex
                                                    INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.kardex.empresa = @empresa
                                                    AND dbo.kardex.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                            GROUP BY dbo.kardex.num_conc ,
                                                    dbo.kardex.concepto
                                END                                                
                            
                        END
                        
                       
                        
                    IF @ordenadoPor = 0
                        AND @desglosadoPor & 4 > 0 
                        -- Agrega un registro por cada renglon 
                        -- solo total general
                        BEGIN
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      nombreConcepto ,
                                      tipoPago
                                    )
                                    SELECT  '99999999999997' AS centro ,
                                            CASE WHEN @porSupervisor = 1
                                                 THEN 999999996
                                                 ELSE NULL
                                            END , --NULL, --999999995 AS supervisor ,
                                            999999995 AS codigo ,
                                            dbo.kardex.num_conc ,
                                            dbo.kardex.concepto ,
                                            CASE WHEN dbo.kardex.num_conc >= 1
                                                      AND dbo.kardex.num_conc <= 99
                                                 THEN 1
                                                 WHEN dbo.kardex.num_conc >= 1101
                                                      AND dbo.kardex.num_conc <= 1199
                                                 THEN 1
                                                 WHEN dbo.kardex.num_conc >= 101
                                                      AND dbo.kardex.num_conc <= 199
                                                 THEN 2
                                                 WHEN dbo.kardex.num_conc >= 1001
                                                      AND dbo.kardex.num_conc <= 1099
                                                 THEN 2
                                                 WHEN dbo.kardex.num_conc >= 201
                                                      AND dbo.kardex.num_conc <= 299
                                                 THEN 3
                                                 ELSE 0
                                            END
                                    FROM    dbo.kardex
                                    WHERE   dbo.kardex.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.kardex.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                                    GROUP BY dbo.kardex.num_conc ,
                                            dbo.kardex.concepto
                        END


                    IF @porCentro = 1
                        AND ( @desglosadoPor & 1 > 0
                              OR @desglosadoPor & 2 > 0
                            ) 
                        BEGIN
                         -- Agrega registro de Total General para los centros seleccionados
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      tipoPago ,
                                      renglon
                                    )
                            VALUES  ( '99999999999996' ,
                                      CASE WHEN @porSupervisor = 1
                                           THEN 999999996
                                           ELSE NULL
                                      END ,
                                      999999996 ,
                                      9996 ,
                                      4 ,
                                      1
                                    )
                        END
                      

                    -- Agrega registro de Total General
                    INSERT  @resumenPorCentroTemporal
                            ( centro ,
                              supervisor ,
                              codigo ,
                              numeroConcepto ,
                              tipoPago ,
                              renglon
                            )
                    VALUES  ( '99999999999997 ' ,
                              CASE WHEN @porSupervisor = 1 THEN 999999996
                                   ELSE NULL
                              END ,
                              999999996 ,
                              9996 ,
                              4 ,
                              1
                            )
                                  
                END
            
            ELSE 
                IF @porDetalle = 'T' 
                    BEGIN
                    
                        SET @conceptosBaseImpuestoSobreNomina = ISNULL(( SELECT
                                                              dbo.conceptos.totales
                                                              FROM
                                                              dbo.conceptos
                                                              WHERE
                                                              dbo.conceptos.empresa = @empresa
                                                              AND dbo.conceptos.centro = ''
                                                              AND dbo.conceptos.clase = ''
                                                              AND num_conc = 216
                                                              ), '')
                                                              
                                                              
                        SET @conceptosBaseImpuestoSobreNomina = CASE
                                                              WHEN LEN(@conceptosBaseImpuestoSobreNomina) > 0
                                                              THEN LTRIM(RTRIM(SUBSTRING(@conceptosBaseImpuestoSobreNomina,
                                                              2,
                                                              LEN(@conceptosBaseImpuestoSobreNomina)
                                                              - 4)))
                                                              ELSE ''
                                                              END
                        SET @conceptosBaseImpuestoSobreNomina = @conceptosBaseImpuestoSobreNomina
                            + CASE WHEN SUBSTRING(@conceptosBaseImpuestoSobreNomina,
                                                  LEN(@conceptosBaseImpuestoSobreNomina),
                                                  1) <> ',' THEN ','
                                   ELSE ''
                              END
                                        
                        SET @contador = 1
                        SET @cadena = ''

                        WHILE @contador <= LEN(@conceptosBaseImpuestoSobreNomina) 
                            BEGIN
                                SET @caracter = SUBSTRING(@conceptosBaseImpuestoSobreNomina,
                                                          @contador, 1)
        
                                IF @caracter IN ( '1', '2', '3', '4', '5', '6',
                                                  '7', '8', '9', '0' ) 
                                    SET @cadena = @cadena + @caracter
                                ELSE 
                                    IF @caracter = ',' 
                                        BEGIN
                                            INSERT  @tablaConceptoBaseImpuestoSobreNomina
                                                    ( numeroConcepto )
                                            VALUES  ( CONVERT(INT, @cadena)  -- codigo - int
                                                      )
                                            SET @cadena = ''
                                        END
                                SET @contador = @contador + 1
                            END
                        
                        SET @importeBaseImpuestoSobreNomina = ISNULL(( SELECT
                                                              SUM(CASE
                                                              WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              THEN 1
                                                              WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              THEN 1
                                                              WHEN dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              THEN -1
                                                              WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              THEN -1
                                                              ELSE 1
                                                              END * importe)
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc IN (
                                                              SELECT
                                                              [@tablaConceptoBaseImpuestoSobreNomina].numeroConcepto
                                                              FROM
                                                              @tablaConceptoBaseImpuestoSobreNomina )
                                                              ), 0)
                                                              
                                                              
                        SELECT TOP 1
                                @ejercicio = SUBSTRING(CONVERT(VARCHAR(15), dbo.apsiispt.trimestre),
                                                       1, 4) ,
                                @diarioOficial = dbo.apsiispt.diario_of ,
                                @baseCalculo = CASE WHEN dbo.apsiispt.base_calc = 'P'
                                                    THEN 1
                                                    WHEN dbo.apsiispt.base_calc = 'M'
                                                    THEN 2
                                                    ELSE 0
                                               END
                        FROM    dbo.apsiispt
                        WHERE   dbo.apsiispt.empresa = @empresa
                                AND dbo.apsiispt.mca_ultimo = 'U'
                                
                                
                        SET @empleados = ISNULL(( SELECT    COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                  FROM      dbo.kardex
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND dbo.kardex.num_conc = @tipoNomina
                                                ), 0)
                                                              
                        SET @provisionIMSS = CASE WHEN @regimenSeguridadSocial = 1
                                                  THEN ISNULL(( SELECT  SUM(dbo.kardex.importe)
                                                                FROM    dbo.kardex
                                                                WHERE   dbo.kardex.empresa = @empresa
                                                                        AND dbo.kardex.nomina = @nomina
                                                                        AND ( dbo.kardex.num_conc = 201
                                                                              OR dbo.kardex.num_conc = 202
                                                                              OR dbo.kardex.num_conc = 203
                                                                              OR dbo.kardex.num_conc = 204
                                                                              OR dbo.kardex.num_conc = 205
                                                                              OR dbo.kardex.num_conc = 208
                                                                              OR dbo.kardex.num_conc = 209
                                                                            )
                                                              ), 0)
                                                  ELSE ISNULL(( SELECT  SUM(dbo.kardex.importe)
                                                                FROM    dbo.kardex
                                                                WHERE   dbo.kardex.empresa = @empresa
                                                                        AND dbo.kardex.nomina = @nomina
                                                                        AND ( dbo.kardex.num_conc = 201
                                                                              OR dbo.kardex.num_conc = 202
                                                                              OR dbo.kardex.num_conc = 203
                                                                              OR dbo.kardex.num_conc = 204
                                                                              OR dbo.kardex.num_conc = 205
                                                                              OR dbo.kardex.num_conc = 206
                                                                            )
                                                              ), 0)
                                             END
                    
                        SET @provisionRCV = CASE WHEN @regimenSeguridadSocial = 1
                                                 THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                               FROM   dbo.kardex
                                                               WHERE  dbo.kardex.empresa = @empresa
                                                                      AND dbo.kardex.nomina = @nomina
                                                                      AND ( dbo.kardex.num_conc = 206
                                                                            OR dbo.kardex.num_conc = 207
                                                                          )
                                                             ), 0)
                                                 ELSE 0
                                            END
                                  
                        SET @provisionINFONAVIT = CASE WHEN @regimenSeguridadSocial = 1
                                                       THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                     FROM dbo.kardex
                                                                     WHERE dbo.kardex.empresa = @empresa
                                                                           AND dbo.kardex.nomina = @nomina
                                                                           AND dbo.kardex.num_conc = 210
                                                                   ), 0)
                                                       ELSE ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                     FROM dbo.kardex
                                                                     WHERE dbo.kardex.empresa = @empresa
                                                                           AND dbo.kardex.nomina = @nomina
                                                                           AND dbo.kardex.num_conc = 207
                                                                   ), 0)
                                                  END
                                  
                        SET @retencionIMSS = CASE WHEN @regimenSeguridadSocial = 1
                                                  THEN ISNULL(( SELECT  ISNULL(SUM(dbo.kardex.importe),0)
                                                                FROM    dbo.kardex
                                                                WHERE   dbo.kardex.empresa = @empresa
                                                                        AND dbo.kardex.nomina = @nomina
                                                                        AND ( dbo.kardex.num_conc = 101
                                                                              OR dbo.kardex.num_conc = 102
                                                                              OR dbo.kardex.num_conc = 103
                                                                              OR dbo.kardex.num_conc = 104
                                                                              OR dbo.kardex.num_conc = 106
                                                                            )
                                                              ), 0)
                                                  ELSE 0
                                             END
                                  
                        SET @retencionRCV = CASE WHEN @regimenSeguridadSocial = 1
                                                 THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                               FROM   dbo.kardex
                                                               WHERE  dbo.kardex.empresa = @empresa
                                                                      AND dbo.kardex.nomina = @nomina
                                                                      AND dbo.kardex.num_conc = 105
                                                             ), 0)
                                                 ELSE 0
                                            END
                                  
                        SET @retencionINFONAVIT = CASE WHEN @regimenSeguridadSocial = 1
                                                       THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                     FROM dbo.kardex
                                                                     WHERE dbo.kardex.empresa = @empresa
                                                                           AND dbo.kardex.nomina = @nomina
                                                                           AND ( dbo.kardex.num_conc = 112
                                                                                 OR dbo.kardex.num_conc = 113
                                                                               )
                                                                   ), 0)
                                                       ELSE 0
                                                  END
                                  
                        SET @empleadosConCuentaBancaria = ISNULL(( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.empleados
                                                              WHERE
                                                              dbo.empleados.empresa = @empresa
                                                              AND dbo.empleados.cta_bco_no <> ''
                                                              AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.kardex.codigo
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              )
                                                              ), 0)
                                  
                        SET @empleadosSinCuentaBancaria = ISNULL(( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.empleados
                                                              WHERE
                                                              dbo.empleados.empresa = @empresa
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.kardex.codigo
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              )
                                                              ), 0)
                                  
                        SET @percepcionesConCuentaBancaria = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no <> ''
                                                              ), 0)
                                  
                        SET @deduccionesConCuentaBancaria = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no <> ''
                                                              ), 0)
                                  
                        SET @percepcionesSinCuentaBancaria = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              ), 0)
                                  
                        SET @deduccionesSinCuentaBancaria = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              ), 0)
                                  
                        SET @porcientoSobreNomina = ISNULL(( SELECT TOP 1
                                                              ISNULL(dbo.kardex.unidades,
                                                              0)
                                                             FROM
                                                              dbo.kardex
                                                             WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 216
                                                              AND dbo.kardex.unidades > 0
                                                           ), 0)
                                  
                        SET @fondoAhorroAportacionEmpleado = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 126
                                                              ), 0)
                                  
                        SET @fondoAhorroAportacionPatron = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 127
                                                              ), 0)
                                  
                        SET @sueldoNetoGeneral = ISNULL(( SELECT
                                                              ISNULL(SUM(CASE
                                                              WHEN ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN dbo.kardex.num_conc = 30
                                                              THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 1108
                                                              AND dbo.kardex.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 108
                                                              AND dbo.kardex.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 120
                                                              THEN -1
                                                              WHEN dbo.kardex.num_conc = 1120
                                                              THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                        ), 0)

                                  
                    
              -- Agrega Registro de Totales
                        -- Llena el registro de total General
                        -- un solo registro
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  empleados ,
                                  provisionIMSS ,
                                  provisionRCV ,
                                  provisionINFONAVIT ,
                                  retencionIMSS ,
                                  retencionRCV ,
                                  retencionINFONAVIT ,
                                  empleadosConCuentaBancaria ,
                                  empleadosSinCuentaBancaria ,
                                  percepcionesConCuentaBancaria ,
                                  deduccionesConCuentaBancaria ,
                                  percepcionesSinCuentaBancaria ,
                                  deduccionesSinCuentaBancaria ,
                                  basePorcientoSobreNomina ,
                                  porcientoSobreNomina ,
                                  fondoAhorroAportacionEmpleado ,
                                  fondoAhorroAportacionPatron ,
                                  sueldoNetoGeneral ,
                                  renglon ,
                                  tipoPago ,
                                  ejercicio ,
                                  diarioOficialDia ,
                                  diarioOficialMes ,
                                  diarioOficialAyo ,
                                  salarioMinimoDF ,
                                  salarioMinimoRegion ,
                                  eymArt25 ,
                                  eymArt106ii ,
                                  eymArt107 ,
                                  ivArt147 ,
                                  cvArt168ii ,
                                  baseCalculo 
                                    
                                )
                        VALUES  ( '99999999999997' ,
                                  CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                OR @ordenadoPor & 32 > 0
                                              )
                                              AND ( @desglosadoPor & 1 > 0
                                                    OR @desglosadoPor & 2 > 0
                                                  )
                                            ) THEN 999999996
                                       ELSE NULL
                                  END ,
                                  999999996 ,
                                  9996 ,
                                  'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                  @empleados , --empleados ,
                                  @provisionIMSS ,   --provisionIMSS ,
                                  @provisionRCV ,  --provisionRCV ,
                                  @provisionINFONAVIT ,
                                  @retencionIMSS ,
                                  @retencionRCV ,
                                  @retencionINFONAVIT ,
                                  @empleadosConCuentaBancaria ,
                                  @empleadosSinCuentaBancaria ,
                                  @percepcionesConCuentaBancaria ,
                                  @deduccionesConCuentaBancaria ,
                                  @percepcionesSinCuentaBancaria ,
                                  @deduccionesSinCuentaBancaria ,
                                  @importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                  @porcientoSobreNomina ,
                                  @fondoAhorroAportacionEmpleado ,
                                  @fondoAhorroAportacionPatron ,
                                  @sueldoNetoGeneral ,
                                  1 , -- AS renglon ,
                                  4 ,--AS tipoPago
                                  @ejercicio ,
                                  DAY(@diarioOficial) ,
                                  MONTH(@diarioOficial) ,
                                  YEAR(@diarioOficial) ,
                                  @salarioDF ,
                                  @salarioRegion ,
                                  @eymArt25 ,
                                  @eymArt1062 ,
                                  @eymArt107 ,
                                  @ivArt147 ,
                                  @cvArt168II ,
                                  @baseCalculo
                                )
                                
                        IF @porCentro = 1 
                            BEGIN
                                SET @empleadosCentro = ISNULL(( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = @tipoNomina
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ), 0)
                                          
                                SET @provisionIMSSCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                                THEN ISNULL((SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                             FROM dbo.kardex
                                                                                  INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                           AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                  INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                       AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                             WHERE dbo.kardex.empresa = @empresa
                                                                                   AND dbo.kardex.nomina = @nomina
                                                                                   AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                   AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                   AND dbo.SeleccionElementos.nomina = @nomina
                                                                                   AND ( dbo.kardex.num_conc = 201
                                                                                         OR dbo.kardex.num_conc = 202
                                                                                         OR dbo.kardex.num_conc = 203
                                                                                         OR dbo.kardex.num_conc = 204
                                                                                         OR dbo.kardex.num_conc = 205
                                                                                         OR dbo.kardex.num_conc = 208
                                                                                         OR dbo.kardex.num_conc = 209
                                                                                       )
                                                                            ), 0)
                                                                ELSE ISNULL((SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                             FROM dbo.kardex
                                                                                  INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                           AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                  INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                       AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                             WHERE dbo.kardex.empresa = @empresa
                                                                                   AND dbo.kardex.nomina = @nomina
                                                                                   AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                   AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                   AND dbo.SeleccionElementos.nomina = @nomina
                                                                                   AND ( dbo.kardex.num_conc = 201
                                                                                         OR dbo.kardex.num_conc = 202
                                                                                         OR dbo.kardex.num_conc = 203
                                                                                         OR dbo.kardex.num_conc = 204
                                                                                         OR dbo.kardex.num_conc = 205
                                                                                         OR dbo.kardex.num_conc = 206
                                                                                       )
                                                                            ), 0)
                                                           END
                              
                                SET @provisionRCVCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                               THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                             FROM dbo.kardex
                                                                                  INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                           AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                  INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                       AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                             WHERE dbo.kardex.empresa = @empresa
                                                                                   AND dbo.kardex.nomina = @nomina
                                                                                   AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                   AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                   AND dbo.SeleccionElementos.nomina = @nomina
                                                                                   AND ( dbo.kardex.num_conc = 206
                                                                                         OR dbo.kardex.num_conc = 207
                                                                                       )
                                                                           ), 0)
                                                               ELSE 0
                                                          END
                              
                                SET @provisionINFONAVITCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                                     THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                                   FROM dbo.kardex
                                                                                        INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                                 AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                        INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                   AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                                         AND dbo.kardex.nomina = @nomina
                                                                                         AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                         AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                         AND dbo.SeleccionElementos.nomina = @nomina
                                                                                         AND dbo.kardex.num_conc = 210
                                                                                 ), 0)
                                                                     ELSE ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                                   FROM dbo.kardex
                                                                                        INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                                 AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                        INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                   AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                                         AND dbo.kardex.nomina = @nomina
                                                                                         AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                         AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                         AND dbo.SeleccionElementos.nomina = @nomina
                                                                                         AND dbo.kardex.num_conc = 207
                                                                                 ), 0)
                                                                END
                              
                                SET @retencionIMSSCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                                THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                              FROM dbo.kardex
                                                                                   INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                            AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                   INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                        AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                              WHERE dbo.kardex.empresa = @empresa
                                                                                    AND dbo.kardex.nomina = @nomina
                                                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                                                    AND ( dbo.kardex.num_conc = 101
                                                                                          OR dbo.kardex.num_conc = 102
                                                                                          OR dbo.kardex.num_conc = 103
                                                                                          OR dbo.kardex.num_conc = 104
                                                                                          OR dbo.kardex.num_conc = 106
                                                                                        )
                                                                            ), 0)
                                                                ELSE 0
                                                           END
                              
                                SET @retencionRCVCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                               THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                             FROM dbo.kardex
                                                                                  INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                           AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                  INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                       AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                             WHERE dbo.kardex.empresa = @empresa
                                                                                   AND dbo.kardex.nomina = @nomina
                                                                                   AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                   AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                   AND dbo.SeleccionElementos.nomina = @nomina
                                                                                   AND dbo.kardex.num_conc = 105
                                                                           ), 0)
                                                               ELSE 0
                                                          END
                              
                                SET @retencionINFONAVITCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                                     THEN ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                                   FROM dbo.kardex
                                                                                        INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                                 AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                        INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                             AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                                         AND dbo.kardex.nomina = @nomina
                                                                                         AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                         AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                         AND dbo.SeleccionElementos.nomina = @nomina
                                                                                         AND ( dbo.kardex.num_conc = 112
                                                                                               OR dbo.kardex.num_conc = 113
                                                                                             )
                                                                                 ), 0)
                                                                     ELSE 0
                                                                END
                              
                                SET @empleadosConCuentaBancariaCentro = ISNULL(( SELECT COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,0) ))
                                                                                 FROM dbo.empleados
                                                                                      INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                                                                               AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                                                      INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                           AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                 WHERE dbo.empleados.empresa = @empresa
                                                                                       AND dbo.empleados.cta_bco_no <> ''
                                                                                       AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                       AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                       AND dbo.SeleccionElementos.nomina = @nomina
                                                                                       AND dbo.empleados.codigo = ( SELECT DISTINCT dbo.kardex.codigo
                                                                                                                    FROM dbo.kardex
                                                                                                                         INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                                                                  AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                                                         INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                                                  AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                                                    WHERE dbo.kardex.empresa = @empresa
                                                                                                                          AND dbo.kardex.nomina = @nomina
                                                                                                                          AND dbo.kardex.codigo = dbo.empleados.codigo
                                                                                                                          AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                                                          AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                                                          AND dbo.SeleccionElementos.nomina = @nomina
                                                                                                                  )
                                                                               ), 0)
                              
                                SET @empleadosSinCuentaBancariaCentro = ISNULL(( SELECT COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,0) ))
                                                                                 FROM dbo.empleados
                                                                                      INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                                                                               AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                                                      INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                           AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                 WHERE dbo.empleados.empresa = @empresa
                                                                                       AND dbo.empleados.cta_bco_no = ''
                                                                                       AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                       AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                       AND dbo.SeleccionElementos.nomina = @nomina
                                                                                       AND dbo.empleados.codigo = ( SELECT DISTINCT dbo.kardex.codigo
                                                                                                                    FROM dbo.kardex
                                                                                                                         INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                                                                                                                  AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                                                                                         INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                                                    WHERE dbo.kardex.empresa = @empresa
                                                                                                                          AND dbo.kardex.nomina = @nomina
                                                                                                                          AND dbo.kardex.codigo = dbo.empleados.codigo
                                                                                                                          AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                                                          AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                                                          AND dbo.SeleccionElementos.nomina = @nomina
                                                                                                                  )
                                                                               ), 0)
                              
                                SET @percepcionesConCuentaBancariaCentro = ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                                    FROM dbo.kardex
                                                                                         INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                                                                                     AND dbo.kardex.codigo = dbo.empleados.codigo
                                                                                         INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                                                                                  AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                                                         INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                    WHERE dbo.kardex.empresa = @empresa
                                                                                          AND dbo.kardex.nomina = @nomina
                                                                                          AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                          AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                          AND dbo.SeleccionElementos.nomina = @nomina
                                                                                          AND ( ( dbo.kardex.num_conc >= 1
                                                                                                  AND dbo.kardex.num_conc <= 99
                                                                                                )
                                                                                                OR ( dbo.kardex.num_conc >= 1101
                                                                                                     AND dbo.kardex.num_conc <= 1199
                                                                                                   )
                                                                                              )
                                                                                          AND dbo.empleados.cta_bco_no <> ''
                                                                                  ), 0)
                              
                                SET @deduccionesConCuentaBancariaCentro = ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                                   FROM dbo.kardex
                                                                                        INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                                                                                    AND dbo.kardex.codigo = dbo.empleados.codigo
                                                                                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                                                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                                                        INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                             AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                                         AND dbo.kardex.nomina = @nomina
                                                                                         AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                         AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                         AND dbo.SeleccionElementos.nomina = @nomina
                                                                                         AND ( ( dbo.kardex.num_conc >= 101
                                                                                                 AND dbo.kardex.num_conc <= 199
                                                                                               )
                                                                                               OR ( dbo.kardex.num_conc >= 1001
                                                                                                    AND dbo.kardex.num_conc <= 1099
                                                                                                  )
                                                                                             )
                                                                                         AND dbo.empleados.cta_bco_no <> ''
                                                                                 ), 0)
                              
                                SET @percepcionesSinCuentaBancariaCentro = ISNULL(( SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                                    FROM dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              ), 0)
                              
                                SET @deduccionesSinCuentaBancariaCentro = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              ), 0)
                              
                                SET @porcientoSobreNominaCentro = ISNULL(( SELECT TOP 1
                                                              ISNULL(dbo.kardex.unidades,
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 216
                                                              AND dbo.kardex.unidades > 0
                                                              ), 0)
                              
                                SET @fondoAhorroAportacionEmpleadoCentro = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 126
                                                              ), 0)
                              
                                SET @fondoAhorroAportacionPatronCentro = ISNULL(( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 127
                                                              ), 0)
                              
                                SET @sueldoNetoGeneralCentro = ISNULL(( SELECT
                                                              ISNULL(SUM(CASE
                                                              WHEN ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN dbo.kardex.num_conc = 30
                                                              THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 1108
                                                              AND dbo.kardex.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 108
                                                              AND dbo.kardex.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 120
                                                              THEN -1
                                                              WHEN dbo.kardex.num_conc = 1120
                                                              THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * dbo.kardex.importe),
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ), 0)
                              
                            
                            
                            
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          empleados ,
                                          provisionIMSS ,
                                          provisionRCV ,
                                          provisionINFONAVIT ,
                                          retencionIMSS ,
                                          retencionRCV ,
                                          retencionINFONAVIT ,
                                          empleadosConCuentaBancaria ,
                                          empleadosSinCuentaBancaria ,
                                          percepcionesConCuentaBancaria ,
                                          deduccionesConCuentaBancaria ,
                                          percepcionesSinCuentaBancaria ,
                                          deduccionesSinCuentaBancaria ,
                                          basePorcientoSobreNomina ,
                                          porcientoSobreNomina ,
                                          fondoAhorroAportacionEmpleado ,
                                          fondoAhorroAportacionPatron ,
                                          sueldoNetoGeneral ,
                                          renglon ,
                                          tipoPago ,
                                          ejercicio ,
                                          diarioOficialDia ,
                                          diarioOficialMes ,
                                          diarioOficialAyo ,
                                          salarioMinimoDF ,
                                          salarioMinimoRegion ,
                                          eymArt25 ,
                                          eymArt106ii ,
                                          eymArt107 ,
                                          ivArt147 ,
                                          cvArt168ii ,
                                          baseCalculo 
                                        )
                                VALUES  ( '99999999999996' ,
                                          CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                        OR @ordenadoPor & 32 > 0
                                                      )
                                                      AND ( @desglosadoPor & 1 > 0
                                                            OR @desglosadoPor
                                                            & 2 > 0
                                                          )
                                                    ) THEN 999999996
                                               ELSE NULL
                                          END ,
                                          999999996 ,
                                          9996 ,
                                          'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                          @empleadosCentro ,
                                          @provisionIMSSCentro ,
                                          @provisionRCVCentro ,
                                          @provisionINFONAVITCentro ,
                                          @retencionIMSSCentro ,
                                          @retencionRCVCentro ,
                                          @retencionINFONAVITCentro ,
                                          @empleadosConCuentaBancariaCentro ,
                                          @empleadosSinCuentaBancariaCentro ,
                                          @percepcionesConCuentaBancariaCentro ,
                                          @deduccionesConCuentaBancariaCentro ,
                                          @percepcionesSinCuentaBancariaCentro ,
                                          @deduccionesSinCuentaBancariaCentro ,
                                          @importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                          @porcientoSobreNominaCentro ,
                                          @fondoAhorroAportacionEmpleadoCentro ,
                                          @fondoAhorroAportacionPatronCentro ,
                                          @sueldoNetoGeneral ,
                                          1 , -- AS renglon ,
                                          4 ,--AS tipoPago
                                          @ejercicio ,
                                          DAY(@diarioOficial) ,
                                          MONTH(@diarioOficial) ,
                                          YEAR(@diarioOficial) ,
                                          @salarioDF ,
                                          @salarioRegion ,
                                          @eymArt25 ,
                                          @eymArt1062 ,
                                          @eymArt107 ,
                                          @ivArt147 ,
                                          @cvArt168II ,
                                          @baseCalculo
                                        )
                            END

                                
                        IF ( ( @ordenadoPor & 4 > 0
                               OR @ordenadoPor & 8 > 0
                             )
                             OR ( ( @ordenadoPor & 1 > 0
                                    OR @ordenadoPor & 2 > 0
                                  )
                                  AND @desglosadoPor & 2 > 0
                                )
                             OR ( ( @ordenadoPor & 16 > 0
                                    OR @ordenadoPor & 32 > 0
                                  )
                                  AND ( @desglosadoPor & 1 > 0
                                        OR @desglosadoPor & 2 > 0
                                      )
                                )
                           )
                            
                            -- Llena el registro de total
                            -- uno por cada centro de costos
                            BEGIN
                            -- Si quiere totales por departamento tomar la tabla
                            -- polizas porque considera los registros de nivel
                            -- superior del centro de costos
                                IF @desglosadoPor & 2 > 0 
                                    BEGIN
                                        SET @porcientoSobreNomina = ISNULL(( SELECT TOP 1
                                                              ISNULL(dbo.kardex.unidades,
                                                              0)
                                                              FROM
                                                              dbo.kardex
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 216
                                                              AND dbo.kardex.unidades > 0
                                                              ), 0)

                                        INSERT  @resumenPorCentroTemporal
                                                ( centro ,
                                                  supervisor ,
                                                  codigo ,
                                                  numeroConcepto ,
                                                  nombreConcepto ,
                                                  renglon ,
                                                  empleados ,
                                                  provisionIMSS ,
                                                  provisionRCV ,
                                                  provisionINFONAVIT ,
                                                  retencionIMSS ,
                                                  retencionRCV ,
                                                  retencionINFONAVIT ,
                                                  empleadosConCuentaBancaria ,
                                                  empleadosSinCuentaBancaria ,
                                                  percepcionesConCuentaBancaria ,
                                                  deduccionesConCuentaBancaria ,
                                                  percepcionesSinCuentaBancaria ,
                                                  deduccionesSinCuentaBancaria ,
                                                  basePorcientoSobreNomina ,
                                                  porcientoSobreNomina ,
                                                  fondoAhorroAportacionEmpleado ,
                                                  fondoAhorroAportacionPatron ,
                                                  sueldoNetoGeneral ,
                                                  tipoPago ,
                                                  ejercicio ,
                                                  diarioOficialDia ,
                                                  diarioOficialMes ,
                                                  diarioOficialAyo ,
                                                  salarioMinimoDF ,
                                                  salarioMinimoRegion ,
                                                  eymArt25 ,
                                                  eymArt106ii ,
                                                  eymArt107 ,
                                                  ivArt147 ,
                                                  cvArt168ii ,
                                                  baseCalculo
                                            
                                                )
                                                SELECT DISTINCT
                                                        dbo.polizas.centro ,
                                                        CASE WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND ( @desglosadoPor
                                                              & 1 > 0
                                                              OR @desglosadoPor
                                                              & 2 > 0
                                                              )
                                                              ) THEN 999999996
                                                             ELSE NULL
                                                        END ,
                                                        999999996 ,
                                                        9996 ,
                                                        'XZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                                        1 ,
                                                        ( SELECT
                                                              ISNULL(SUM(poliza.empleados),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) , -- empleados ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tipoNomina
                                                                         AND ( poliza.num_conc = 201
                                                                               OR poliza.num_conc = 202
                                                                               OR poliza.num_conc = 203
                                                                               OR poliza.num_conc = 204
                                                                               OR poliza.num_conc = 205
                                                                               OR poliza.num_conc = 208
                                                                               OR poliza.num_conc = 209
                                                                             )
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                             ELSE (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tipoNomina
                                                                         AND ( poliza.num_conc = 201
                                                                               OR poliza.num_conc = 202
                                                                               OR poliza.num_conc = 203
                                                                               OR poliza.num_conc = 204
                                                                               OR poliza.num_conc = 205
                                                                               OR poliza.num_conc = 206
                                                                             )
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                        END
                                                         , --provisionIMSS ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                        --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                        --AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tiponomina
                                                                         AND ( poliza.num_conc = 206
                                                                               OR poliza.num_conc = 207
                                                                             )
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --provisionRCV ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                        --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                        --AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tipoNomina
                                                                         AND poliza.num_conc = 210
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                             ELSE (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                        --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                        --AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tipoNomina
                                                                         AND poliza.num_conc = 207
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                        END
                                                         ,  --provisionINFONAVIT ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                        --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                        --AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tipoNomina
                                                                         AND ( poliza.num_conc = 101
                                                                               OR poliza.num_conc = 102
                                                                               OR poliza.num_conc = 103
                                                                               OR poliza.num_conc = 104
                                                                               OR poliza.num_conc = 106
                                                                             )
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --retencionIMSS ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                        --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                        --AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tipoNomina
                                                                         AND poliza.num_conc = 105
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --retencionRCV ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(poliza.importe),0)
                                                                   FROM dbo.polizas AS poliza
                                                                        --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                        --AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE poliza.empresa = @empresa
                                                                         AND poliza.tiponom = @tipoNomina
                                                                         AND (poliza.num_conc = 112
                                                                              OR poliza.num_conc = 113)
                                                                         AND poliza.centro = dbo.polizas.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --retencionINFONAVIT ,
                                                        ( SELECT
                                                              ISNULL(poliza.empleadosconcta,
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --empleadosConCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(poliza.empleadossincta,
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --empleadosSinCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(poliza.percepcionesconcta),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --percepcionesConCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(poliza.deduccionesconcta),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --deduccionesConCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(poliza.percepcionessincta),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --percepcionesSinCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(poliza.deduccionessincta),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) , --deduccionesSinCuentaBancaria ,
                                                        ( SELECT
                                                              SUM(CASE
                                                              WHEN poliza.num_conc >= 1
                                                              AND poliza.num_conc <= 99
                                                              THEN 1
                                                              WHEN poliza.num_conc >= 1101
                                                              AND poliza.num_conc <= 1199
                                                              THEN 1
                                                              WHEN poliza.num_conc >= 101
                                                              AND poliza.num_conc <= 199
                                                              THEN -1
                                                              WHEN poliza.num_conc >= 1001
                                                              AND poliza.num_conc <= 1099
                                                              THEN -1
                                                              ELSE 1
                                                              END
                                                              * poliza.importe)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                              AND poliza.num_conc IN (
                                                              SELECT
                                                              [@tablaConceptoBaseImpuestoSobreNomina].numeroConcepto
                                                              FROM
                                                              @tablaConceptoBaseImpuestoSobreNomina )
                                                        ) , --@importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                                        @porcientoSobreNomina ,  --porcientoSobreNomina ,
                                                        ( SELECT
                                                              ISNULL(SUM(poliza.importe),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = 126
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --fondoAhorroAportacionEmpleado ,
                                                        ( SELECT
                                                              ISNULL(SUM(poliza.importe),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.num_conc = 127
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --fondoAhorroAportacionPatron ,
                                                        ( SELECT
                                                              ISNULL(SUM(CASE
                                                              WHEN ( poliza.num_conc >= 1
                                                              AND poliza.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN poliza.num_conc = 30
                                                              THEN 1
                                                              WHEN ( poliza.num_conc >= 1108
                                                              AND poliza.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( poliza.num_conc >= 108
                                                              AND poliza.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN poliza.num_conc = 120
                                                              THEN -1
                                                              WHEN ( poliza.num_conc >= 1001
                                                              AND poliza.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN poliza.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * poliza.importe),
                                                              0)
                                                          FROM
                                                              dbo.polizas AS poliza
                                                              --INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              --AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              poliza.empresa = @empresa
                                                              AND poliza.tiponom = @tipoNomina
                                                              AND poliza.centro = dbo.polizas.centro
                                                        ) ,  --sueldoNetoGeneral
                                                        4 ,--AS tipoPago
                                                        @ejercicio ,
                                                        DAY(@diarioOficial) ,
                                                        MONTH(@diarioOficial) ,
                                                        YEAR(@diarioOficial) ,
                                                        @salarioDF ,
                                                        @salarioRegion ,
                                                        @eymArt25 ,
                                                        @eymArt1062 ,
                                                        @eymArt107 ,
                                                        @ivArt147 ,
                                                        @cvArt168II ,
                                                        @baseCalculo
                                                FROM    dbo.polizas
                                                        --INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                        --      AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                WHERE   dbo.polizas.empresa = @empresa
                                                        AND dbo.polizas.tiponom = @tipoNomina
                                                GROUP BY dbo.polizas.centro
                                    END
                                ELSE 
                                    BEGIN
                                        INSERT  @resumenPorCentroTemporal
                                                ( centro ,
                                                  supervisor ,
                                                  codigo ,
                                                  numeroConcepto ,
                                                  nombreConcepto ,
                                                  renglon ,
                                                  empleados ,
                                                  provisionIMSS ,
                                                  provisionRCV ,
                                                  provisionINFONAVIT ,
                                                  retencionIMSS ,
                                                  retencionRCV ,
                                                  retencionINFONAVIT ,
                                                  empleadosConCuentaBancaria ,
                                                  empleadosSinCuentaBancaria ,
                                                  percepcionesConCuentaBancaria ,
                                                  deduccionesConCuentaBancaria ,
                                                  percepcionesSinCuentaBancaria ,
                                                  deduccionesSinCuentaBancaria ,
                                                  basePorcientoSobreNomina ,
                                                  porcientoSobreNomina ,
                                                  fondoAhorroAportacionEmpleado ,
                                                  fondoAhorroAportacionPatron ,
                                                  sueldoNetoGeneral ,
                                                  tipoPago ,
                                                  ejercicio ,
                                                  diarioOficialDia ,
                                                  diarioOficialMes ,
                                                  diarioOficialAyo ,
                                                  salarioMinimoDF ,
                                                  salarioMinimoRegion ,
                                                  eymArt25 ,
                                                  eymArt106ii ,
                                                  eymArt107 ,
                                                  ivArt147 ,
                                                  cvArt168ii ,
                                                  baseCalculo
                                            
                                                )
                                                SELECT DISTINCT
                                                        dbo.Llaves.centro ,
                                                        CASE WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND ( @desglosadoPor
                                                              & 1 > 0
                                                              OR @desglosadoPor
                                                              & 2 > 0
                                                              )
                                                              ) THEN 999999996
                                                             ELSE NULL
                                                        END ,
                                                        999999996 ,
                                                        9996 ,
                                                        'XZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                                        1 ,
                                                        ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = @tipoNomina
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) , -- empleados ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                 AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND ( dbo.kardex.num_conc = 201
                                                                               OR dbo.kardex.num_conc = 202
                                                                               OR dbo.kardex.num_conc = 203
                                                                               OR dbo.kardex.num_conc = 204
                                                                               OR dbo.kardex.num_conc = 205
                                                                               OR dbo.kardex.num_conc = 208
                                                                               OR dbo.kardex.num_conc = 209
                                                                             )
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                             ELSE (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                 AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND ( dbo.kardex.num_conc = 201
                                                                               OR dbo.kardex.num_conc = 202
                                                                               OR dbo.kardex.num_conc = 203
                                                                               OR dbo.kardex.num_conc = 204
                                                                               OR dbo.kardex.num_conc = 205
                                                                               OR dbo.kardex.num_conc = 206
                                                                             )
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                        END
                                                         , --provisionIMSS ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                                AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND ( dbo.kardex.num_conc = 206
                                                                               OR dbo.kardex.num_conc = 207
                                                                             )
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --provisionRCV ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                                AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND dbo.kardex.num_conc = 210
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                             ELSE (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                                AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND dbo.kardex.num_conc = 207
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                        END
                                                         ,  --provisionINFONAVIT ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                                AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND ( dbo.kardex.num_conc = 101
                                                                               OR dbo.kardex.num_conc = 102
                                                                               OR dbo.kardex.num_conc = 103
                                                                               OR dbo.kardex.num_conc = 104
                                                                               OR dbo.kardex.num_conc = 106
                                                                             )
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --retencionIMSS ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                                AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND dbo.kardex.num_conc = 105
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --retencionRCV ,
                                                        CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                                   FROM dbo.kardex
                                                                        INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                                AND dbo.kardex.codigo = llaveCentro.codigo
                                                                   WHERE dbo.kardex.empresa = @empresa
                                                                         AND dbo.kardex.nomina = @nomina
                                                                         AND (dbo.kardex.num_conc = 112
                                                                              OR dbo.kardex.num_conc = 113)
                                                                         AND llaveCentro.centro = dbo.Llaves.centro)
                                                             ELSE 0
                                                        END
                                                         ,  --retencionINFONAVIT ,
                                                        ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,
                                                              0) ))
                                                          FROM
                                                              dbo.empleados
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.empleados.empresa = @empresa
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                              AND dbo.empleados.cta_bco_no <> ''
                                                              AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.kardex.codigo
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                              )
                                                        ) ,  --empleadosConCuentaBancaria ,
                                                        ( SELECT
                                                              COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,
                                                              0) ))
                                                          FROM
                                                              dbo.empleados
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.empleados.empresa = @empresa
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.kardex.codigo
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                              )
                                                        ) ,  --empleadosSinCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no <> ''
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --percepcionesConCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no <> ''
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --deduccionesConCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --percepcionesSinCuentaBancaria ,
                                                        ( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND ( ( dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              )
                                                              )
                                                              AND dbo.empleados.cta_bco_no = ''
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --deduccionesSinCuentaBancaria ,
                                                        ( SELECT
                                                              SUM(CASE
                                                              WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              THEN 1
                                                              WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              THEN 1
                                                              WHEN dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              THEN -1
                                                              WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              THEN -1
                                                              ELSE 1
                                                              END * importe)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                              AND dbo.kardex.num_conc IN (
                                                              SELECT
                                                              [@tablaConceptoBaseImpuestoSobreNomina].numeroConcepto
                                                              FROM
                                                              @tablaConceptoBaseImpuestoSobreNomina )
                                                        ) , --@importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                                        ( SELECT TOP 1
                                                              ISNULL(dbo.kardex.unidades,
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 216
                                                              AND dbo.kardex.unidades > 0
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --porcientoSobreNomina ,
                                                        ( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 126
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --fondoAhorroAportacionEmpleado ,
                                                        ( SELECT
                                                              ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.num_conc = 127
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --fondoAhorroAportacionPatron ,
                                                        ( SELECT
                                                              ISNULL(SUM(CASE
                                                              WHEN ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN dbo.kardex.num_conc = 30
                                                              THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 1108
                                                              AND dbo.kardex.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 108
                                                              AND dbo.kardex.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 120
                                                              THEN -1
                                                              WHEN ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * dbo.kardex.importe),
                                                              0)
                                                          FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                          WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                        ) ,  --sueldoNetoGeneral
                                                        4 ,--AS tipoPago
                                                        @ejercicio ,
                                                        DAY(@diarioOficial) ,
                                                        MONTH(@diarioOficial) ,
                                                        YEAR(@diarioOficial) ,
                                                        @salarioDF ,
                                                        @salarioRegion ,
                                                        @eymArt25 ,
                                                        @eymArt1062 ,
                                                        @eymArt107 ,
                                                        @ivArt147 ,
                                                        @cvArt168II ,
                                                        @baseCalculo
                                                FROM    dbo.kardex
                                                        INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                                WHERE   dbo.kardex.empresa = @empresa
                                                        AND dbo.kardex.nomina = @nomina
                                                GROUP BY dbo.Llaves.centro
                                    END
                            END
                            
                        IF ( ( @ordenadoPor & 16 > 0
                               OR @ordenadoPor & 32 > 0
                             )
                             AND ( @desglosadoPor & 1 > 0
                                   OR @desglosadoPor & 2 > 0
                                 )
                           ) 
                            -- Llena el registro de total
                            -- uno por cada centro de costos y supervisor
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          renglon ,
                                          empleados ,
                                          provisionIMSS ,
                                          provisionRCV ,
                                          provisionINFONAVIT ,
                                          retencionIMSS ,
                                          retencionRCV ,
                                          retencionINFONAVIT ,
                                          empleadosConCuentaBancaria ,
                                          empleadosSinCuentaBancaria ,
                                          percepcionesConCuentaBancaria ,
                                          deduccionesConCuentaBancaria ,
                                          percepcionesSinCuentaBancaria ,
                                          deduccionesSinCuentaBancaria ,
                                          basePorcientoSobreNomina ,
                                          porcientoSobreNomina ,
                                          fondoAhorroAportacionEmpleado ,
                                          fondoAhorroAportacionPatron ,
                                          sueldoNetoGeneral ,
                                          tipoPago ,
                                          ejercicio ,
                                          diarioOficialDia ,
                                          diarioOficialMes ,
                                          diarioOficialAyo ,
                                          salarioMinimoDF ,
                                          salarioMinimoRegion ,
                                          eymArt25 ,
                                          eymArt106ii ,
                                          eymArt107 ,
                                          ivArt147 ,
                                          cvArt168ii ,
                                          baseCalculo
                                        )
                                        SELECT DISTINCT
                                                dbo.Llaves.centro ,
                                                dbo.Llaves.supervisor ,
                                                999999996 ,
                                                9996 ,
                                                'XZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                                1 ,
                                                ( SELECT    COUNT(DISTINCT ( ISNULL(dbo.kardex.codigo,
                                                              0) ))
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND dbo.kardex.num_conc = @tipoNomina
                                                ) , -- empleados ,
                                                CASE WHEN @regimenSeguridadSocial = 1
                                                     THEN (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                             AND dbo.kardex.codigo = llaveCentro.codigo
                                                                                                             AND dbo.Llaves.centro = llaveCentro.centro
                                                                                                             AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND ( dbo.kardex.num_conc = 201
                                                                           OR dbo.kardex.num_conc = 202
                                                                           OR dbo.kardex.num_conc = 203
                                                                           OR dbo.kardex.num_conc = 204
                                                                           OR dbo.kardex.num_conc = 205
                                                                           OR dbo.kardex.num_conc = 208
                                                                           OR dbo.kardex.num_conc = 209
                                                                         ))
                                                     ELSE (SELECT ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                             AND dbo.kardex.codigo = llaveCentro.codigo
                                                                                                             AND dbo.Llaves.centro = llaveCentro.centro
                                                                                                             AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND ( dbo.kardex.num_conc = 201
                                                                           OR dbo.kardex.num_conc = 202
                                                                           OR dbo.kardex.num_conc = 203
                                                                           OR dbo.kardex.num_conc = 204
                                                                           OR dbo.kardex.num_conc = 205
                                                                           OR dbo.kardex.num_conc = 206
                                                                         ))
                                                END
                                                 , --provisionIMSS ,
                                                CASE WHEN @regimenSeguridadSocial = 1
                                                     THEN (SELECT    ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                             AND dbo.kardex.codigo = llaveCentro.codigo
                                                                                                             AND dbo.Llaves.centro = llaveCentro.centro
                                                                                                             AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND ( dbo.kardex.num_conc = 206
                                                                           OR dbo.kardex.num_conc = 207
                                                                         ))
                                                     ELSE 0
                                                END    
                                                 ,  --provisionRCV ,
                                                CASE WHEN @regimenSeguridadSocial = 1
                                                     THEN (SELECT    ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                             AND dbo.kardex.codigo = llaveCentro.codigo
                                                                                                             AND dbo.Llaves.centro = llaveCentro.centro
                                                                                                             AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND dbo.kardex.num_conc = 210)
                                                     ELSE (SELECT    ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                             AND dbo.kardex.codigo = llaveCentro.codigo
                                                                                                             AND dbo.Llaves.centro = llaveCentro.centro
                                                                                                             AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND dbo.kardex.num_conc = 207)
                                                END
                                                 ,  --provisionINFONAVIT ,
                                                CASE WHEN @regimenSeguridadSocial = 1
                                                     THEN (SELECT    ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND ( dbo.kardex.num_conc = 101
                                                                           OR dbo.kardex.num_conc = 102
                                                                           OR dbo.kardex.num_conc = 103
                                                                           OR dbo.kardex.num_conc = 104
                                                                           OR dbo.kardex.num_conc = 106
                                                                         ))
                                                     ELSE 0
                                                END
                                                 ,  --retencionIMSS ,
                                                CASE WHEN @regimenSeguridadSocial = 1
                                                     THEN (SELECT    ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                             AND dbo.Llaves.centro = llaveCentro.centro
                                                                                                             AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                                                                             AND dbo.kardex.codigo = llaveCentro.codigo
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND dbo.kardex.num_conc = 105)
                                                     ELSE 0
                                                END
                                                      
                                                 ,  --retencionRCV ,
                                                CASE WHEN @regimenSeguridadSocial = 1
                                                     THEN (SELECT    ISNULL(SUM(dbo.kardex.importe),0)
                                                           FROM      dbo.kardex
                                                                     INNER JOIN dbo.Llaves AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                                                                             AND dbo.kardex.codigo = llaveCentro.codigo
                                                                                                             AND dbo.Llaves.centro = llaveCentro.centro
                                                                                                             AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                           WHERE     dbo.kardex.empresa = @empresa
                                                                     AND dbo.kardex.nomina = @nomina
                                                                     AND (dbo.kardex.num_conc = 112
                                                                          OR dbo.kardex.num_conc = 113))
                                                     ELSE 0
                                                END
                                                 ,  --retencionINFONAVIT ,
                                                ( SELECT    COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,
                                                              0) ))
                                                  FROM      dbo.empleados
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.empleados.empresa = @empresa
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.kardex.codigo
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              )
                                                ) ,  --empleadosConCuentaBancaria ,
                                                ( SELECT    COUNT(DISTINCT ( ISNULL(dbo.empleados.codigo,
                                                              0) ))
                                                  FROM      dbo.empleados
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.empleados.empresa = @empresa
                                                            AND dbo.empleados.cta_bco_no = ''
                                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.kardex.codigo
                                                              FROM
                                                              dbo.kardex
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                              WHERE
                                                              dbo.kardex.empresa = @empresa
                                                              AND dbo.kardex.nomina = @nomina
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                              )
                                                ) ,  --empleadosSinCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                ) ,  --percepcionesConCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND ( ( dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                ) ,  --deduccionesConCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND ( ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no = ''
                                                ) ,  --percepcionesSinCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND ( ( dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              )
                                                              OR ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no = ''
                                                ) ,  --deduccionesSinCuentaBancaria ,
                                                ( SELECT    SUM(CASE
                                                              WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 99
                                                              THEN 1
                                                              WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              THEN 1
                                                              WHEN dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 199
                                                              THEN -1
                                                              WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              THEN -1
                                                              ELSE 1
                                                              END * importe)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND dbo.kardex.num_conc IN (
                                                            SELECT
                                                              [@tablaConceptoBaseImpuestoSobreNomina].numeroConcepto
                                                            FROM
                                                              @tablaConceptoBaseImpuestoSobreNomina )
                                                ) , --@importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                                ( SELECT TOP 1
                                                            ISNULL(dbo.kardex.unidades,
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND dbo.kardex.num_conc = 216
                                                            AND dbo.kardex.unidades > 0
                                                ) ,  --porcientoSobreNomina ,
                                                ( SELECT    ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND dbo.kardex.num_conc = 126
                                                ) ,  --fondoAhorroAportacionEmpleado ,
                                                ( SELECT    ISNULL(SUM(dbo.kardex.importe),
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                            AND dbo.kardex.num_conc = 127
                                                ) ,  --fondoAhorroAportacionPatron ,
                                                ( SELECT    ISNULL(SUM(CASE
                                                              WHEN ( dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN dbo.kardex.num_conc = 30
                                                              THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 1108
                                                              AND dbo.kardex.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( dbo.kardex.num_conc >= 108
                                                              AND dbo.kardex.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 120
                                                              THEN -1
                                                              WHEN ( dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN dbo.kardex.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * dbo.kardex.importe),
                                                              0)
                                                  FROM      dbo.kardex
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.kardex.empresa = llaveCentro.empresa
                                                              AND dbo.kardex.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.kardex.empresa = @empresa
                                                            AND dbo.kardex.nomina = @nomina
                                                ) ,  --sueldoNetoGeneral
                                                4 ,--AS tipoPago
                                                @ejercicio ,
                                                DAY(@diarioOficial) ,
                                                MONTH(@diarioOficial) ,
                                                YEAR(@diarioOficial) ,
                                                @salarioDF ,
                                                @salarioRegion ,
                                                @eymArt25 ,
                                                @eymArt1062 ,
                                                @eymArt107 ,
                                                @ivArt147 ,
                                                @cvArt168II ,
                                                @baseCalculo
                                        FROM    dbo.kardex
                                                INNER JOIN dbo.Llaves ON dbo.kardex.empresa = dbo.Llaves.empresa
                                                              AND dbo.kardex.codigo = dbo.Llaves.codigo
                                        WHERE   dbo.kardex.empresa = @empresa
                                                AND dbo.kardex.nomina = @nomina
                                        GROUP BY dbo.Llaves.centro ,
                                                dbo.Llaves.supervisor
                            END                            
                    END
            
            

        -- Borra los registros que no son necesarios
        -- generados por la funcion Grouping
        DELETE  @resumenPorCentroTemporal
        WHERE   [@resumenPorCentroTemporal].nombreConcepto = 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                OR ( [@resumenPorCentroTemporal].centro = '99999999999997'
                     AND [@resumenPorCentroTemporal].codigo = 999999995
                     AND [@resumenPorCentroTemporal].numeroConcepto = 9995
                     --AND [@resumenPorCentroTemporal].supervisor = 99995
                     
                   )
                OR ( [@resumenPorCentroTemporal].codigo = 999999995
                     AND [@resumenPorCentroTemporal].numeroConcepto = 9995
                     AND [@resumenPorCentroTemporal].centro <> '99999999999996'
                     --AND [@resumenPorCentroTemporal].supervisor = 99995
                     
                   )
                OR ( [@resumenPorCentroTemporal].numeroConcepto = 9995
                     AND [@resumenPorCentroTemporal].conceptoGrupo = 999999995
                     AND [@resumenPorCentroTemporal].supervisorGrupo = 0
                   )
                OR ( [@resumenPorCentroTemporal].centro = '99999999999997'
                     AND [@resumenPorCentroTemporal].codigo = 999999995
                     AND [@resumenPorCentroTemporal].supervisorGrupo = 0
                   )
                   

        -- Pasa de la temporal a la tabla que regresa la funcion
        -- se hace esto para darle la salida en el orden que se 
        -- requiere
        INSERT  @resumenPorCentro
                ( centro ,
                  supervisor ,
                  codigo ,
                  numeroConcepto ,
                  nombreConcepto ,
                  importe ,
                  gravable ,
                  exento ,
                  renglon ,
                  tipoPago ,
                  anexoConceptoPercepcion ,
                  anexoConceptoDeduccion ,
                  empleados ,
                  provisionIMSS ,
                  provisionRCV ,
                  provisionINFONAVIT ,
                  retencionIMSS ,
                  retencionRCV ,
                  retencionINFONAVIT ,
                  empleadosConCuentaBancaria ,
                  empleadosSinCuentaBancaria ,
                  percepcionesConCuentaBancaria ,
                  deduccionesConCuentaBancaria ,
                  percepcionesSinCuentaBancaria ,
                  deduccionesSinCuentaBancaria ,
                  basePorcientoSobreNomina ,
                  porcientoSobreNomina ,
                  fondoAhorroAportacionEmpleado ,
                  fondoAhorroAportacionPatron ,
                  sueldoNetoGeneral ,
                  ejercicio ,
                  diarioOficialDia ,
                  diarioOficialMes ,
                  diarioOficialAyo ,
                  salarioMinimoDF ,
                  salarioMinimoRegion ,
                  eymArt25 ,
                  eymArt106ii ,
                  eymArt107 ,
                  ivArt147 ,
                  cvArt168ii ,
                  baseCalculo 
                )
                SELECT  [@resumenPorCentroTemporal].centro ,
                        [@resumenPorCentroTemporal].supervisor ,
                        [@resumenPorCentroTemporal].codigo ,
                        [@resumenPorCentroTemporal].numeroConcepto ,
                        [@resumenPorCentroTemporal].nombreConcepto ,
                        [@resumenPorCentroTemporal].importe ,
                        [@resumenPorCentroTemporal].gravable ,
                        [@resumenPorCentroTemporal].exento ,
                        [@resumenPorCentroTemporal].renglon ,
                        [@resumenPorCentroTemporal].tipoPago ,
                        [@resumenPorCentroTemporal].anexoConceptoPercepcion ,
                        [@resumenPorCentroTemporal].anexoConceptoDeduccion ,
                        [@resumenPorCentroTemporal].empleados ,
                        [@resumenPorCentroTemporal].provisionIMSS ,
                        [@resumenPorCentroTemporal].provisionRCV ,
                        [@resumenPorCentroTemporal].provisionINFONAVIT ,
                        [@resumenPorCentroTemporal].retencionIMSS ,
                        [@resumenPorCentroTemporal].retencionRCV ,
                        [@resumenPorCentroTemporal].retencionINFONAVIT ,
                        [@resumenPorCentroTemporal].empleadosConCuentaBancaria ,
                        [@resumenPorCentroTemporal].empleadosSinCuentaBancaria ,
                        [@resumenPorCentroTemporal].percepcionesConCuentaBancaria ,
                        [@resumenPorCentroTemporal].deduccionesConCuentaBancaria ,
                        [@resumenPorCentroTemporal].percepcionesSinCuentaBancaria ,
                        [@resumenPorCentroTemporal].deduccionesSinCuentaBancaria ,
                        [@resumenPorCentroTemporal].basePorcientoSobreNomina ,
                        [@resumenPorCentroTemporal].porcientoSobreNomina ,
                        [@resumenPorCentroTemporal].fondoAhorroAportacionEmpleado ,
                        [@resumenPorCentroTemporal].fondoAhorroAportacionPatron ,
                        [@resumenPorCentroTemporal].sueldoNetoGeneral ,
                        [@resumenPorCentroTemporal].ejercicio ,
                        [@resumenPorCentroTemporal].diarioOficialDia ,
                        [@resumenPorCentroTemporal].diarioOficialMes ,
                        [@resumenPorCentroTemporal].diarioOficialAyo ,
                        [@resumenPorCentroTemporal].salarioMinimoDF ,
                        [@resumenPorCentroTemporal].salarioMinimoRegion ,
                        [@resumenPorCentroTemporal].eymArt25 ,
                        [@resumenPorCentroTemporal].eymArt106ii ,
                        [@resumenPorCentroTemporal].eymArt107 ,
                        [@resumenPorCentroTemporal].ivArt147 ,
                        [@resumenPorCentroTemporal].cvArt168ii ,
                        [@resumenPorCentroTemporal].baseCalculo
                FROM    @resumenPorCentroTemporal
                ORDER BY [@resumenPorCentroTemporal].centro ,
                        CASE WHEN @ordenadoPor & 16 > 0
                                  OR @ordenadoPor & 32 > 0
                                  OR @porSupervisor = 1
                             THEN [@resumenPorCentroTemporal].supervisor
                             ELSE ''
                        END ,
                        [@resumenPorCentroTemporal].tipoPago ,
                        [@resumenPorCentroTemporal].numeroConcepto ASC ,
                        [@resumenPorCentroTemporal].nombreConcepto
        
		/*
		--Cancelado el 09 de Enero 2019 Por Jorge Mtz
		--En la version SQL 2014 no generaba bien el numero de renglon
        IF @porDetalle = 'S'
            OR @porDetalle = 'T' 
            -- Renumera los renglones
            BEGIN
                SET @tipoPagoAnterior = ''
                SET @supervisorAnterior = -1
                SET @renglon = 0

                UPDATE  @resumenPorCentro
                SET     @renglon = CASE WHEN @tipoPagoAnterior <> LTRIM([@resumenPorCentro].centro)
                                             + CASE WHEN @ordenadoPor & 16 > 0
                                                         OR @ordenadoPor & 32 > 0
                                                         OR @porSupervisor = 1
                                                    THEN LTRIM(STR([@resumenPorCentro].supervisor))
                                                    ELSE ''
                                               END
                                             + STR([@resumenPorCentro].tipoPago)
                                        THEN 0
                                        ELSE @renglon
                                   END ,
                        @renglon = @renglon + 1 ,
                        [@resumenPorCentro].renglon = @renglon ,
                        @tipoPagoAnterior = LTRIM([@resumenPorCentro].centro)
                        + CASE WHEN @ordenadoPor & 16 > 0
                                    OR @ordenadoPor & 32 > 0
                                    OR @porSupervisor = 1
                               THEN LTRIM(STR([@resumenPorCentro].supervisor))
                               ELSE ''
                          END + STR([@resumenPorCentro].tipoPago)
            END
        ELSE 
            -- Renumera los renglones
            BEGIN
                SET @centroAnterior = ''
                SET @supervisorAnterior = -1
                SET @renglon = 0

                UPDATE  @resumenPorCentro
                SET     @renglon = CASE WHEN @centroAnterior <> LTRIM([@resumenPorCentro].centro)
                                             + CASE WHEN @ordenadoPor & 16 > 0
                                                         OR @ordenadoPor & 32 > 0
                                                         OR @porSupervisor = 1
                                                    THEN LTRIM(STR([@resumenPorCentro].supervisor))
                                                    ELSE ''
                                               END
                                             + LTRIM(STR([@resumenPorCentro].tipoPago))
                                        THEN 0
                                        ELSE @renglon
                                   END ,
                        @renglon = @renglon + 1 ,
                        [@resumenPorCentro].renglon = @renglon ,
                        @centroAnterior = LTRIM([@resumenPorCentro].centro)
                        + CASE WHEN @ordenadoPor & 16 > 0
                                    OR @ordenadoPor & 32 > 0
                                    OR @porSupervisor = 1
                               THEN LTRIM(STR([@resumenPorCentro].supervisor))
                               ELSE ''
                          END + LTRIM(STR([@resumenPorCentro].tipoPago))
            END                  
        */

		--Se cambio al rutina para generar el numero de renglon el 09 de Enero 2019 Por Jorge Mtz
        SET @centroAnterior = ''
        SET @supervisorAnterior = -1
        SET @renglon = 0

        DECLARE @idCursor INT
        DECLARE @centroCursor VARCHAR(15)
        DECLARE @supervisorCursor INT
        DECLARE @tipoPagoCursor INT
        DECLARE NumeraRenglon CURSOR READ_ONLY FORWARD_ONLY FOR 

        SELECT id,
		       centro,
		       supervisor,
			   tipoPago 
		FROM @resumenPorCentro AS rc1
        ORDER BY id

        OPEN NumeraRenglon
             FETCH NEXT FROM NumeraRenglon INTO @idCursor,
		                                        @centroCursor,
												@supervisorCursor,
												@tipoPagoCursor
               WHILE @@fetch_status = 0
                 BEGIN 
                   SET @renglon = CASE WHEN @centroAnterior <> LTRIM(@centroCursor)
                                                               + CASE WHEN @ordenadoPor & 16 > 0 OR @ordenadoPor & 32 > 0 OR @porSupervisor = 1
                                                                      THEN LTRIM(STR(@supervisorCursor))
                                                                      ELSE ''
                                                                 END
                                                                     + LTRIM(STR(@tipoPagoCursor))
                                       THEN 0
                                       ELSE @renglon
                                  END
                   SET @renglon = @renglon + 1

                   UPDATE rc3
                   SET rc3.renglon = @renglon
                   FROM @resumenPorCentro AS rc3
                   WHERE rc3.id = @idCursor

                   SET @centroAnterior = LTRIM(@centroCursor)
                                         + CASE WHEN @ordenadoPor & 16 > 0 OR @ordenadoPor & 32 > 0 OR @porSupervisor = 1
                                                THEN LTRIM(STR(@supervisorCursor))
                                                ELSE ''
                                           END 
					                     + LTRIM(STR(@tipoPagoCursor))

                   FETCH NEXT FROM NumeraRenglon INTO @idCursor,
					                                  @centroCursor,
					                                  @supervisorCursor,
					                                  @tipoPagoCursor
                 END

        CLOSE NumeraRenglon
        DEALLOCATE NumeraRenglon

		    
        -- Generar el resumen para la seccion del impuesto sobre nominas
        INSERT INTO @tEstatal(Centro)
        SELECT DISTINCT Centro
        FROM Estatal

        UPDATE tEstatal
        SET Base1      = Estatal1.Base,
            Porciento1 = Estatal1.Porciento,
            Importe1   = Estatal1.Importe,
            Empleados1 = Estatal1.Registros,
            Base2      = ISNULL(Estatal2.Base,0),
            Porciento2 = ISNULL(Estatal2.Porciento,0),
            Importe2   = ISNULL(Estatal2.Importe,0),
            Empleados2 = ISNULL(Estatal2.Registros,0)
        FROM @tEstatal AS tEstatal
        INNER JOIN Estatal AS Estatal1 ON Estatal1.Centro = tEstatal.Centro AND Estatal1.TipoNom = @tipoNomina AND Estatal1.Empresa = @empresa
        LEFT JOIN Estatal AS Estatal2 ON Estatal2.Porciento <> Estatal1.Porciento AND Estatal2.Centro = tEstatal.Centro AND Estatal2.TipoNom = @tipoNomina AND Estatal2.Empresa = @empresa
        
        
        
        UPDATE tResumenPorCentro
        SET baseISN1      = tEstatal.Base1,
            porcientoISN1 = tEstatal.Porciento1,
            importeISN1   = tEstatal.Importe1,
            empleadosISN1 = tEstatal.Empleados1,
            baseISN2      = tEstatal.Base2,
            porcientoISN2 = tEstatal.Porciento2,
            importeISN2   = tEstatal.Importe2,
            empleadosISN2 = tEstatal.Empleados2
       FROM @resumenPorCentro AS tResumenPorCentro
       INNER JOIN @tEstatal AS tEstatal ON tEstatal.Centro = tResumenPorCentro.Centro
        --  22 Marzo 2012
       
       
/*
        UPDATE tResumenPorCentro
        SET baseISN1      = tEstatal.Base1,
            --porcientoISN1 = tEstatal.Porciento1,
            importeISN1   = tEstatal.Importe1,
            empleadosISN1 = tEstatal.Empleados1
            --baseISN2      = tEstatal.Base2,
            --porcientoISN2 = tEstatal.Porciento2,
            --importeISN2   = tEstatal.Importe2,
            --empleadosISN2 = tEstatal.Empleados2
       FROM @resumenPorCentro AS tResumenPorCentro
       INNER JOIN (SELECT SUM(Base1) AS base1,
                          SUM(Importe1) AS importe1,
                          SUM(Empleados1) AS empleados1
                   FROM  @tEstatal AS tEstatal
                         INNER JOIN (SELECT DISTINCT 
                                            llaves.centro
                                     FROM dbo.kardex AS kardex
                                          INNER JOIN dbo.Llaves AS llaves ON kardex.codigo = llaves.codigo AND kardex.empresa = llaves.empresa
                                     WHERE llaves.tiponom = @tipoNomina
                                           AND llaves.empresa = @empresa
                                           AND kardex.nomina = @nomina
                                           AND kardex.empresa = @empresa
                                           AND kardex.num_conc = 216) AS llaves ON LTRIM(RTRIM(tEstatal.centro)) = LTRIM(RTRIM(llaves.centro))
                   WHERE tEstatal.centro <> '99999999999997') AS tEstatal ON tEstatal.base1 > 0

       WHERE LTRIM(RTRIM(tResumenPorCentro.centro)) = '99999999999997'
             AND tResumenPorCentro.codigo = 999999996
             AND numeroConcepto = 9996
*/

        DECLARE @base1 NUMERIC(12,2)
        DECLARE @importe1 NUMERIC(12,2)
        DECLARE @empleados1 INT
        
        SELECT @base1 = SUM(e.Base),
               @importe1 = SUM(e.Importe),
               @empleados1 = SUM(e.registros)
        FROM  dbo.estatal AS e
              INNER JOIN (SELECT DISTINCT 
                                 ll.centro
                          FROM dbo.llaves AS ll
                               INNER JOIN dbo.kardex AS k ON k.num_conc = 216
                                                             AND ll.codigo = k.codigo
                                                             AND ll.empresa = k.empresa
                          WHERE ll.tiponom = @tipoNomina
                                AND ll.empresa = @empresa) AS ll ON LTRIM(RTRIM(e.centro)) = LTRIM(RTRIM(ll.centro))
        WHERE e.tiponom = @tipoNomina
              AND e.empresa = @empresa


        UPDATE tResumenPorCentro
        SET baseISN1      = @base1,
            importeISN1   = @importe1,
            empleadosISN1 = @empleados1,
            baseISN2      = 0,
            importeISN2   = 0,
            empleadosISN2 = 0
        FROM @resumenPorCentro AS tResumenPorCentro
        WHERE LTRIM(RTRIM(tResumenPorCentro.centro)) = '99999999999997'
              AND tResumenPorCentro.codigo = 999999996
              AND numeroConcepto = 9996

        RETURN
    END
GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[SeleccionElementos]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    CREATE TABLE [dbo].[SeleccionElementos]
        (
          empresa int ,
          procesoId INT,
          procesoName VARCHAR(100),
          codigo int ,
          nomina VARCHAR(15),
          tipoNomina INT,
          centro VARCHAR(15),
          clase VARCHAR(5),
          supvervisor INT
        )
GO

IF OBJECT_ID('dbo.AvisosImssTemporalCalculo') IS NULL 
    BEGIN
        CREATE TABLE [dbo].[AvisosImssTemporalCalculo]
            (
              [proceso] [varchar] (250) ,
              [fechaProceso] [datetime] ,
              [horaProceso] [varchar] (8) ,
              [empresa] [numeric](3, 0) NOT NULL ,
              [codigo] [numeric](8, 0) NOT NULL ,
              [serial] [int] NOT NULL ,
              [mes_operacion] [int] NOT NULL ,
              [ayo_operacion] [int] NOT NULL ,
              [fch_mov] [datetime] NOT NULL ,
              [fch_real] [datetime] NULL ,
              [mov] [varchar](2) NULL ,
              [saldiaint] [decimal](10, 2) NULL ,
              [saldiaiv] [decimal](10, 2) NULL ,
              [sueldo] [decimal](12, 2) NULL ,
              [diastr] [int] NULL ,
              [incap] [int] NULL ,
              [lic] [int] NULL ,
              [ausen] [decimal](5, 2) NULL ,
              [mot_baja] [varchar](30) NULL ,
              [clave_baja] [int] NULL ,
              [campo_01] [varchar](50) NULL ,
              [captura] [varchar](1) NULL ,
              [campo_02] [varchar](50) NULL ,
              [campo_03] [numeric](15, 5) NULL ,
              [campo_04] [numeric](15, 5) NULL ,
              [campo_05] [int] NULL ,
              [campo_06] [int] NULL ,
              [campo_07] [datetime] NULL ,
              [campo_08] [datetime] NULL ,
              [sueldoant] [decimal](12, 2) NULL ,
              [saldiaintant] [decimal](12, 2) NULL ,
              [origen] [varchar](2) NULL ,
              [rpu] [varchar](3) NULL ,
              [consecutivo] [int] NULL ,
              [fechaEnvio] [datetime] NULL ,
              [lote] [varchar](25) NULL ,
              [estatus] [varchar](25) NULL ,
              [fechaConfirmacion] [datetime] NULL ,
              [umaDiario] NUMERIC(12,2),
              [registro] INT NOT NULL,
              [aplicaIMSS] BIT,
              [umaFD] NUMERIC(12,2),
              CONSTRAINT [AvisosImssTemporalCalculo_PK14] PRIMARY KEY CLUSTERED
                ( [proceso] ASC, [fechaProceso] ASC, [horaProceso] ASC, [empresa] ASC, [codigo] ASC, [fch_mov] ASC, [serial] ASC, registro )
                WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                       IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                       ALLOW_PAGE_LOCKS = ON ) ON [PRIMARY]
            )
        ON  [PRIMARY]

        ALTER TABLE [dbo].[AvisosImssTemporalCalculo]  WITH CHECK ADD  CONSTRAINT [AvisosImssTemporalCalculo_Refempleados443] FOREIGN KEY([empresa], [codigo])
        REFERENCES [dbo].[empleados] ([empresa], [codigo])

        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] CHECK CONSTRAINT [AvisosImssTemporalCalculo_Refempleados443]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT ('') FOR [proceso]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT ('') FOR [fechaProceso]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT ('') FOR [horaProceso]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [empresa]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [codigo]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [serial]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [mes_operacion]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [ayo_operacion]
    END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'umaFD'
                        AND sysobjects.name = 'AvisosImssTemporalCalculo' ) 
    ALTER TABLE dbo.AvisosImssTemporalCalculo ADD umaFD NUMERIC(12,2)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'lic'
                        AND sysobjects.name = 'AvisosImssTemporalCalculo' ) 
    ALTER TABLE dbo.AvisosImssTemporalCalculo ADD lic INT
GO

IF OBJECT_ID('dbo.CatalogoALSC') IS NULL 
    BEGIN
        CREATE TABLE [dbo].[CatalogoALSC]
            (
              [id] [integer] IDENTITY ,
              [clave] [char] (2) ,
              [descripcion] [varchar] (50) ,
              CONSTRAINT [CatalogoALSC_PK01] PRIMARY KEY CLUSTERED
                ( [id] ASC )
                WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                       IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                       ALLOW_PAGE_LOCKS = ON ) ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO
IF OBJECT_ID('dbo.CatalogoALSC') IS NOT NULL 
    BEGIN
        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 1)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (1,'CELAYA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 2)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (2,'LEON')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 3)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (3,'MORELIA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 4)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (4,'QUERETARO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 5)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (5,'PACHUCA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 6)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (6,'SAN LUIS POTOSI')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 7)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (7,'IRAPUATO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 8)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (8,'URUAPAN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 11)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (11,'NORTE DEL D.F.')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 12)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (12,'CENTRO DEL D.F.')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 13)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (13,'SUR DEL D.F.')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 14)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (14,'ORIENTE DEL D.F.')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 15)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (15,'NAUCALPAN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 16)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (16,'TOLUCA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 21)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (21,'PUEBLA SUR')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 22)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (22,'TLAXCALA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 23)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (23,'PUEBLA NORTE')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 24)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (24,'JALAPA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 25)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (25,'VERACRUZ')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 26)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (26,'COATZACOALCOS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 27)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (27,'ACAPULCO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 28)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (28,'CUERNAVACA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 29)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (29,'CORDOBA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 30)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (30,'IGUALA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 31)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (31,'GUADALUPE')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 32)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (32,'REYNOSA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 33)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (33,'TAMPICO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 34)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (34,'TUXPAN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 35)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (35,'S. PEDRO GARZA GARCIA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 36)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (36,'MONTERREY')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 37)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (37,'NUEVO LAREDO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 38)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (38,'MATAMOROS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 39)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (39,'CIUDAD VICTORIA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 40)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (40,'LOS CABOS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 41)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (41,'TIJUANA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 42)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (42,'MEXICALI')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 43)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (43,'LA PAZ')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 44)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (44,'CULIACAN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 45)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (45,'CIUDAD OBREGON')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 46)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (46,'HERMOSILLO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 47)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (47,'ENSENADA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 48)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (48,'LOS MOCHIS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 49)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (49,'MAZATLAN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 50)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (50,'NOGALES')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 51)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (51,'TORREON')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 52)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (52,'SALTILLO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 53)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (53,'CIUDAD JUAREZ')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 54)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (54,'CHIHUAHUA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 55)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (55,'DURANGO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 56)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (56,'ZACATECAS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 57)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (57,'PIEDRAS NEGRAS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 61)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (61,'AGUASCALIENTES')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 62)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (62,'COLIMA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 63)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (63,'GUADALAJARA CENTRO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 64)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (64,'TEPIC')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 65)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (65,'CIUDAD GUZMAN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 66)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (66,'GUADALAJARA SUR')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 67)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (67,'ZAPOPAN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 68)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (68,'PUERTO VALLARTA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 71)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (71,'OAXACA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 72)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (72,'CAMPECHE')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 73)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (73,'CANCUN')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 74)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (74,'VILLAHERMOSA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 75)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (75,'MERIDA')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 76)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (76,'TUXTLA GUTIERREZ')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 77)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (77,'CHETUMAL')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoALSC AS catalogo WHERE catalogo.clave = 78)
           INSERT dbo.CatalogoALSC (clave, descripcion) VALUES (78,'TAPACHULA')
    END
GO

IF OBJECT_ID('dbo.CatalogoEstadosCFDI') IS NULL 
    BEGIN
        CREATE TABLE dbo.CatalogoEstadosCFDI
            (
              idClaveEstado BIGINT IDENTITY,
              claveEstado CHAR(3),
              pais CHAR(3),
              nombreEstado VARCHAR(250),
              CONSTRAINT [PK_01_CatalogoEstadosCFDI] PRIMARY KEY CLUSTERED
                ( idClaveEstado ASC, claveEstado ASC, pais ASC, nombreEstado ASC )
                WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                       IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                       ALLOW_PAGE_LOCKS = ON ) ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'AGU','MEX','Aguascalientes' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'AGU' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'BCN','MEX','Baja California' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'BCN' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'BCS','MEX','Baja California Sur' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'BCS' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'CAM','MEX','Campeche' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'CAM' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'CHP','MEX','Chiapas' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'CHP' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'CHH','MEX','Chihuahua' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'CHH' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'COA','MEX','Coahuila' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'COA' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'COL','MEX','Colima' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'COL' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'CMX','MEX','Ciudad de Mxico' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'CMX' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'DUR','MEX','Durango' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'DUR' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'GUA','MEX','Guanajuato' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'GUA' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'GRO','MEX','Guerrero' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'GRO' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'HID','MEX','Hidalgo' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'HID' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'JAL','MEX','Jalisco' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'JAL' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MEX','MEX','Estado de Mxico' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MEX' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MIC','MEX','Michoacn' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MIC' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MOR','MEX','Morelos' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MOR' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NAY','MEX','Nayarit' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NAY' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NLE','MEX','Nuevo Len' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NLE' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'OAX','MEX','Oaxaca' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'OAX' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'PUE','MEX','Puebla' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'PUE' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'QUE','MEX','Quertaro' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'QUE' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'ROO','MEX','Quintana Roo' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'ROO' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'SLP','MEX','San Luis Potos' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'SLP' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'SIN','MEX','Sinaloa' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'SIN' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'SON','MEX','Sonora' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'SON' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'TAB','MEX','Tabasco' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'TAB' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'TAM','MEX','Tamaulipas' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'TAM' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'TLA','MEX','Tlaxcala' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'TLA' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'VER','MEX','Veracruz' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'VER' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'YUC','MEX','Yucatn' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'YUC' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'ZAC','MEX','Zacatecas' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'ZAC' AND pais = 'MEX')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'AL','USA','Alabama' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'AL' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'AK','USA','Alaska' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'AK' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'AZ','USA','Arizona' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'AZ' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'AR','USA','Arkansas' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'AR' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'CA','USA','California' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'CA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NC','USA','Carolina del Norte' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NC' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'SC','USA','Carolina del Sur' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'SC' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'CO','USA','Colorado' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'CO' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'CT','USA','Connecticut' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'CT' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'ND','USA','Dakota del Norte' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'ND' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'SD','USA','Dakota del Sur' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'SD' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'DE','USA','Delaware' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'DE' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'FL','USA','Florida' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'FL' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'GA','USA','Georgia' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'GA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'HI','USA','Hawi' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'HI' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'ID','USA','Idaho' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'ID' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'IL','USA','Illinois' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'IL' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'IN','USA','Indiana' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'IN' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'IA','USA','Iowa' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'IA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'KS','USA','Kansas' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'KS' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'KY','USA','Kentucky' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'KY' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'LA','USA','Luisiana' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'LA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'ME','USA','Maine' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'ME' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MD','USA','Maryland' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MD' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MA','USA','Massachusetts' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MI','USA','Mchigan' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MI' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MN','USA','Minnesota' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MN' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MS','USA','Misisipi' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MS' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MO','USA','Misuri' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MO' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MT','USA','Montana' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MT' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NE','USA','Nebraska' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NE' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NV','USA','Nevada' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NV' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NJ','USA','Nueva Jersey' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NJ' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NY','USA','Nueva York' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NY' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NH','USA','Nuevo Hampshire' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NH' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NM','USA','Nuevo Mxico' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NM' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'OH','USA','Ohio' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'OH' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'OK','USA','Oklahoma' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'OK' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'OR','USA','Oregn' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'OR' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'PA','USA','Pensilvania' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'PA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'RI','USA','Rhode Island' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'RI' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'TN','USA','Tennessee' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'TN' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'TX','USA','Texas' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'TX' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'UT','USA','Utah' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'UT' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'VT','USA','Vermont' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'VT' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'VA','USA','Virginia' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'VA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'WV','USA','Virginia Occidental' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'WV' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'WA','USA','Washington' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'WA' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'WI','USA','Wisconsin' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'WI' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'WY','USA','Wyoming' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'WY' AND pais = 'USA')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'ON','CAN','Ontario' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'ON' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'QC','CAN','Quebec' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'QC' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NS','CAN','Nueva Escocia' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NS' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NB','CAN','Nuevo Brunswick' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NB' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'MB','CAN','Manitoba' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'MB' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'BC','CAN','Columbia Britnica' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'BC' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'PE','CAN','Isla del Prncipe Eduardo' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'PE' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'SK','CAN','Saskatchewan' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'SK' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'AB','CAN','Alberta' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'AB' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NL','CAN','Terranova y Labrador' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NL' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'NT','CAN','Territorios del Noroeste' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'NT' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'YT','CAN','Yukn' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'YT' AND pais = 'CAN')
GO
INSERT INTO dbo.CatalogoEstadosCFDI (claveEstado, pais, nombreEstado) SELECT 'UN','CAN','Nunavut' WHERE NOT EXISTS (SELECT 1 FROM dbo.CatalogoEstadosCFDI WHERE claveEstado = 'UN' AND pais = 'CAN')
GO
IF EXISTS (SELECT 1
           FROM dbo.CatalogoEstadosCFDI  AS cec
		   WHERE cec.claveEstado = 'DIF')
   BEGIN
     UPDATE cec
     SET cec.claveEstado = 'CMX'
     FROM dbo.CatalogoEstadosCFDI  AS cec
     WHERE cec.claveEstado = 'DIF'
   END
GO
IF EXISTS (SELECT 1
           FROM dbo.EmpleadoAdicional AS ea
		   WHERE ea.claveEstado = 'DIF')
   BEGIN
     UPDATE ea
     SET ea.claveEstado = 'CMX'
     FROM dbo.EmpleadoAdicional AS ea
     WHERE ea.claveEstado = 'DIF'
   END
GO
DELETE cec
FROM dbo.CatalogoEstadosCFDI  AS cec
WHERE cec.claveEstado = 'CMX'
AND cec.idClaveEstado > (SELECT MIN(idClaveEstado)
                         FROM dbo.CatalogoEstadosCFDI  AS cec
                         WHERE claveEstado = 'CMX')
GO

IF OBJECT_ID('dbo.CatalogoOrigen') IS NULL 
    BEGIN
        CREATE TABLE [dbo].[CatalogoOrigen]
            (
              [id] [integer] IDENTITY ,
              [clave] [char] (2) ,
              [descripcion] [varchar] (50) ,
              CONSTRAINT [CatalogoOrigen_PK01] PRIMARY KEY CLUSTERED
                ( [id] ASC )
                WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                       IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                       ALLOW_PAGE_LOCKS = ON ) ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO
IF OBJECT_ID('dbo.CatalogoOrigen') IS NOT NULL 
    BEGIN
        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 1)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (1,'SECTOR PRIMARIO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 2)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (2,'SECTOR RECICLADOR')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 3)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (3,'SECTOR ARRENDADOR')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 4)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (4,'SECTOR PIGNORANTE')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 5)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (5,'SECTOR PEQUEO MINERO')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 6)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (6,'ASALARIADOS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 7)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (7,'POTENCIALES')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 8)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (8,'REPECOS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 9)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (9,'IDE')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 10)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (10,'SOCIOS')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 11)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (11,'INTERESES')

        IF NOT EXISTS (SELECT catalogo.clave FROM dbo.CatalogoOrigen AS catalogo WHERE catalogo.clave = 12)
           INSERT dbo.CatalogoOrigen (clave, descripcion) VALUES (12,'BANCOS')
    END
GO

IF OBJECT_ID('dbo.EmpleadoApsiReloj') IS NOT NULL
   BEGIN
     IF NOT EXISTS (SELECT syscolumns.name  
                    FROM syscolumns
                         LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
                    WHERE syscolumns.name = 'Clave' and sysobjects.name='EmpleadoApsiReloj')
        BEGIN
          DROP TABLE dbo.EmpleadoApsiReloj
        END
   END
GO


IF OBJECT_ID('dbo.EmpleadoApsiReloj') IS NULL
   CREATE TABLE [dbo].[EmpleadoApsiReloj](empresa NUMERIC(3,0), 
                                          Codigo NUMERIC(8,0), 
                                          --accion VARCHAR(3),
                                          --tipoMov VARCHAR(2),
                                          --orden INT,
                                          --IdEmpleado BIGINT, 
                                          --Codigo NUMERIC(8,0), 
                                          --Nombre VARCHAR(50), 
                                          --Paterno VARCHAR(50), 
                                          --Materno VARCHAR(50), 
                                          --RFC VARCHAR(14), 
                                          --CURP VARCHAR(18), 
                                          --Afiliacion VARCHAR(11), 
                                          --Alta DATETIME, 
                                          --CuotaDiaria NUMERIC(10,2), 
                                          --Sexo VARCHAR(1), 
                                          --Baja DATETIME, 
                                          --Nacimiento DATETIME, 
                                          --Estatus VARCHAR(2), 
                                          --email VARCHAR(100), 
                                          --Telefono VARCHAR(30), 
                                          Foto VARBINARY(MAX),
                                          --idLlave BIGINT, 
                                          --empresa NUMERIC(3,0), 
                                          --idPerfil BIGINT, 
                                          --IdClave BIGINT, 
                                          --idHorario BIGINT, 
                                          --idSupervisor BIGINT,
                                          --idPuesto BIGINT, 
                                          --idTipoNom BIGINT,
                                          Clave VARCHAR(200), 
                                          --Expiracion DATETIME, 
                                          --Expira VARCHAR(1),
                                          --supervisorAPSI INT,
                                          --actividadAPSI VARCHAR(40),
                                          --tiponomAPSI INT,
                                          NoChecar VARCHAR(1), 
                                          ChecaLibre VARCHAR(1), 
                                          NoTiempoExtra VARCHAR(1),
                                          NoAusen VARCHAR(1), 
                                          Bloqueado VARCHAR(1), 
                                          NoExportar VARCHAR(1), 
                                          PremioPyA VARCHAR(1), 
                                          Comedor VARCHAR(1), 
                                          ExportaComedor VARCHAR(1), 
                                          FNomina VARCHAR(1), 
                                          Credencial VARCHAR(20),
                                          --idArea BIGINT,
                                          --Area VARCHAR(50),
                                          --fechaImpor DATETIME,
                                          --Origen VARCHAR(2),
                                          --hora VARCHAR(10),
                                          --modulo VARCHAR(50),
                                          --idUsuario BIGINT,
                                          --RegistroPatronal VARCHAR(11),
                                          MailRetardos VARCHAR(2),
                                          MailTE VARCHAR(2),
                                          MailSalidaAntes VARCHAR(2),
                                          MailSupervisor VARCHAR(2),
                                          MailNomina VARCHAR(2),
                                          Enviar BIT,
                                          FechaUltimoEnvio DATETIME,
                                          ultimoMovimientoEnviado VARCHAR(2),
                                          Enviado BIT
                                           
                                          CONSTRAINT PKEmpleadoApsiRelojUnique PRIMARY KEY CLUSTERED (empresa,codigo)
                                          --CONSTRAINT PKEmpleadoApsiRelojUniqueNonClustered UNIQUE NONCLUSTERED ()
                                           
                                          WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
                                         ) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
IF OBJECT_ID('dbo.EmpleadoApsiReloj') IS NOT NULL
   BEGIN
     IF NOT EXISTS (
                    SELECT 1 
                    FROM sys.foreign_keys 
                    WHERE object_id = OBJECT_ID(N'dbo.FKEmpleado')
                          AND parent_object_id = OBJECT_ID(N'dbo.EmpleadoApsiReloj')
                   )
        BEGIN
          ALTER TABLE dbo.EmpleadoApsiReloj ADD CONSTRAINT FKEmpleado FOREIGN KEY (empresa,Codigo) REFERENCES dbo.empleados(empresa,codigo)
        END
   END
GO

--DROP TABLE dbo.EspecialEnviaCorreo
IF OBJECT_ID('dbo.EspecialEnviaCorreo') IS NULL 
    CREATE TABLE [dbo].[EspecialEnviaCorreo]
        (
          serial INT IDENTITY ,
          empresa INT ,
          direccionDeCorreo VARCHAR(1000) ,
          servidorDeCorreo VARCHAR(1000) ,
          puertoDeCorreo INT ,
          usuarioDeCorreo VARCHAR(1000) ,
          passwordDeCorreo NVARCHAR(1000) ,
          AutentificacionCorreo CHAR(1)	,
          TipoAutentificacionCorreo VARCHAR(100) ,
          SSL CHAR(1) ,
          TLS CHAR(1) ,
          MensajeDeCorreo VARCHAR(1000) NULL ,
          correoDestino VARCHAR(1000) ,
          asunto VARCHAR(250),
          correoDestino2 VARCHAR(1000),
          asunto2 VARCHAR(250),
          MensajeDeCorreo2 VARCHAR(1000) NULL
        )
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'asunto'
                        AND sysobjects.name = 'EspecialEnviaCorreo' ) 
    ALTER TABLE dbo.EspecialEnviaCorreo ADD asunto VARCHAR(250) 
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'correoDestino2'
                        AND sysobjects.name = 'EspecialEnviaCorreo' ) 
    ALTER TABLE dbo.EspecialEnviaCorreo ADD correoDestino2 VARCHAR(250) 
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'asunto2'
                        AND sysobjects.name = 'EspecialEnviaCorreo' ) 
    ALTER TABLE dbo.EspecialEnviaCorreo ADD asunto2 VARCHAR(250) 
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'MensajeDeCorreo2'
                        AND sysobjects.name = 'EspecialEnviaCorreo' ) 
    ALTER TABLE dbo.EspecialEnviaCorreo ADD MensajeDeCorreo2 VARCHAR(1000) 
GO

IF OBJECT_ID('dbo.KardexImprimeRecibos') IS NULL 
    BEGIN
        CREATE TABLE dbo.KardexImprimeRecibos
            (
              proceso VARCHAR(250) ,
              fechaProceso DATETIME ,
              horaProceso VARCHAR(8) ,
              empresa INT ,
              codigoId VARCHAR(100) ,
              codigo INT ,
              nombre VARCHAR(100) ,
              fechaAlta DATETIME ,
              numeroSeguridadSocial VARCHAR(10) ,
              digitoVerificador CHAR(1) ,
              curp VARCHAR(18) ,
              centro VARCHAR(16) ,
              nombreCentro VARCHAR(50) ,
              cuentaBanco VARCHAR(30) ,
              nombreBanco VARCHAR(50) ,
              ocupacion INT ,
              categoria VARCHAR(100) ,
              tipoSalario INT ,
              renglon INT ,
              jornada INT ,
              sueldoDiario FLOAT ,
              salarioBaseCotizacion FLOAT ,
              clase VARCHAR(3) ,
              nombreClase VARCHAR(50) ,
              supervisor INT ,
              nombreSupervisor VARCHAR(50) ,
              marcaContraPercepcion CHAR(1) ,
              numeroConceptoPercepcion INT ,
              nombreConceptoPercepcion VARCHAR(50) ,
              importeConceptoPercepcion FLOAT ,
              gravablePercepcion FLOAT ,
              exentoPercepcion FLOAT ,
              saldoPercepcion FLOAT ,
              anexoConceptoPercepcion VARCHAR(150) ,
              marcaContraDeduccion CHAR(1) ,
              numeroConceptoDeduccion INT ,
              nombreConceptoDeduccion VARCHAR(50) ,
              importeConceptoDeduccion FLOAT ,
              gravableDeduccion FLOAT ,
              exentoDeduccion FLOAT ,
              saldoDeduccion FLOAT ,
              anexoConceptoDeduccion VARCHAR(150) ,
              numeroConceptoProvision INT ,
              nombreConceptoProvision VARCHAR(50) ,
              importeConceptoProvision FLOAT ,
              empleados INT ,
              provisionIMSS FLOAT ,
              provisionRCV FLOAT ,
              provisionINFONAVIT FLOAT ,
              retencionIMSS FLOAT ,
              retencionRCV FLOAT ,
              retencionINFONAVIT FLOAT ,
              empleadosConCuentaBancaria INT ,
              empleadosSinCuentaBancaria INT ,
              percepcionesConCuentaBancaria FLOAT ,
              deduccionesConCuentaBancaria FLOAT ,
              percepcionesSinCuentaBancaria FLOAT ,
              deduccionesSinCuentaBancaria FLOAT ,
              basePorcientoSobreNomina FLOAT ,
              porcientoSobreNomina FLOAT ,
              fondoAhorroAportacionEmpleado FLOAT ,
              fondoAhorroAportacionPatron FLOAT ,
              sueldoNetoGeneral FLOAT ,
              ejercicio INT ,
              diarioOficialDia INT ,
              diarioOficialMes INT ,
              diarioOficialAyo INT ,
              salarioMinimoDF FLOAT ,
              salarioMinimoRegion FLOAT ,
              eymArt25 FLOAT ,
              eymArt106ii FLOAT ,
              eymArt107 FLOAT ,
              ivArt147 FLOAT ,
              cvArt168ii FLOAT ,
              baseCalculo INT ,
              grupo VARCHAR(500) ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              percepcionesEmpleado FLOAT ,
              deduccionesEmpleado FLOAT ,
              netoPagarEmpleado FLOAT ,
              grupoRecibo VARCHAR(500) ,
              rfcAlfa VARCHAR(4) ,
              rfcNum VARCHAR(6) ,
              rfcHomo VARCHAR(3) ,
              acumuladoPercepcion FLOAT ,
              acumuladoPercepcionGravable FLOAT ,
              acumuladoIsr FLOAT ,
              acumuladoInfonavit FLOAT ,
              acumuladoSar FLOAT ,
              acumuladoCv FLOAT ,
              email VARCHAR(100) ,
              fechaAntiguedad DATETIME ,
              procesoName VARCHAR(100) ,
              nomina CHAR(3) ,
              saltarPagina CHAR(1) ,
              firma CHAR(1) ,
              mov CHAR(2) ,
              foto VARCHAR(255) ,
              substotal FLOAT ,
              baseISN1 FLOAT ,
              porcientoISN1 FLOAT ,
              importeISN1 FLOAT ,
              empleadosISN1 INT ,
              baseISN2 FLOAT ,
              porcientoISN2 FLOAT ,
              importeISN2 FLOAT ,
              empleadosISN2 INT ,
              imprimirResumen INT ,
              copia INT
                --CONSTRAINT PK_KardexImprimeRecibos_01
                --PRIMARY KEY NONCLUSTERED 
                --( proceso, fechaProceso, horaProceso, empresa, codigo, copia, renglon )
            )
    END    
GO
IF EXISTS ( SELECT  *
            FROM    sys.indexes
            WHERE   object_id = OBJECT_ID('dbo.KardexImprimeRecibos')
                    AND NAME = 'PK_KardexImprimeRecibos_01' ) 
    BEGIN
        ALTER TABLE dbo.KardexImprimeRecibos DROP CONSTRAINT PK_KardexImprimeRecibos_01 
    END
GO
IF EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'categoria'
                        AND sysobjects.name = 'KardexImprimeRecibos' ) 
    ALTER TABLE dbo.KardexImprimeRecibos ALTER COLUMN categoria VARCHAR(100)
GO
--IF NOT EXISTS ( SELECT  *
--                FROM    sys.indexes
--                WHERE   object_id = OBJECT_ID('dbo.KardexImprimeRecibos')
--                        AND NAME = 'PK_KardexImprimeRecibos_02' ) 
--    BEGIN
--        ALTER TABLE [dbo].[KardexImprimeRecibos] ADD  CONSTRAINT [PK_KardexImprimeRecibos_02] PRIMARY KEY NONCLUSTERED 
--        (
--        [proceso] ASC,
--        [fechaProceso] ASC,
--        [horaProceso] ASC,
--        [empresa] ASC,
--        [centro] ASC,
--        [supervisor] ASC,
--        [codigo] ASC,
--        [copia] ASC,
--        [renglon] ASC
--        )WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
--    END
--GO

IF OBJECT_ID('dbo.KardexImprimeResumenISN') IS NULL 
    BEGIN
        CREATE TABLE dbo.KardexImprimeResumenISN
            (
              proceso VARCHAR(250) ,
              fechaProceso DATETIME ,
              horaProceso VARCHAR(8) ,
              empresa INT ,
              codigoId VARCHAR(100) ,
              codigo INT ,
              nombre VARCHAR(100) ,
              fechaAlta DATETIME ,
              numeroSeguridadSocial VARCHAR(10) ,
              digitoVerificador CHAR(1) ,
              curp VARCHAR(18) ,
              centro VARCHAR(16) ,
              nombreCentro VARCHAR(50) ,
              cuentaBanco VARCHAR(30) ,
              nombreBanco VARCHAR(50) ,
              ocupacion INT ,
              categoria VARCHAR(50) ,
              tipoSalario INT ,
              renglon INT ,
              jornada INT ,
              sueldoDiario FLOAT ,
              salarioBaseCotizacion FLOAT ,
              clase VARCHAR(3) ,
              nombreClase VARCHAR(50) ,
              supervisor INT ,
              nombreSupervisor VARCHAR(50) ,
              marcaContraPercepcion CHAR(1) ,
              numeroConceptoPercepcion INT ,
              nombreConceptoPercepcion VARCHAR(50) ,
              importeConceptoPercepcion FLOAT ,
              gravablePercepcion FLOAT ,
              exentoPercepcion FLOAT ,
              saldoPercepcion FLOAT ,
              anexoConceptoPercepcion VARCHAR(150) ,
              marcaContraDeduccion CHAR(1) ,
              numeroConceptoDeduccion INT ,
              nombreConceptoDeduccion VARCHAR(50) ,
              importeConceptoDeduccion FLOAT ,
              gravableDeduccion FLOAT ,
              exentoDeduccion FLOAT ,
              saldoDeduccion FLOAT ,
              anexoConceptoDeduccion VARCHAR(150) ,
              numeroConceptoProvision INT ,
              nombreConceptoProvision VARCHAR(50) ,
              importeConceptoProvision FLOAT ,
              empleados INT ,
              provisionIMSS FLOAT ,
              provisionRCV FLOAT ,
              provisionINFONAVIT FLOAT ,
              retencionIMSS FLOAT ,
              retencionRCV FLOAT ,
              retencionINFONAVIT FLOAT ,
              empleadosConCuentaBancaria INT ,
              empleadosSinCuentaBancaria INT ,
              percepcionesConCuentaBancaria FLOAT ,
              deduccionesConCuentaBancaria FLOAT ,
              percepcionesSinCuentaBancaria FLOAT ,
              deduccionesSinCuentaBancaria FLOAT ,
              basePorcientoSobreNomina FLOAT ,
              porcientoSobreNomina FLOAT ,
              fondoAhorroAportacionEmpleado FLOAT ,
              fondoAhorroAportacionPatron FLOAT ,
              sueldoNetoGeneral FLOAT ,
              ejercicio INT ,
              diarioOficialDia INT ,
              diarioOficialMes INT ,
              diarioOficialAyo INT ,
              salarioMinimoDF FLOAT ,
              salarioMinimoRegion FLOAT ,
              eymArt25 FLOAT ,
              eymArt106ii FLOAT ,
              eymArt107 FLOAT ,
              ivArt147 FLOAT ,
              cvArt168ii FLOAT ,
              baseCalculo INT ,
              grupo VARCHAR(500) ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              percepcionesEmpleado FLOAT ,
              deduccionesEmpleado FLOAT ,
              netoPagarEmpleado FLOAT ,
              grupoRecibo VARCHAR(500) ,
              rfcAlfa VARCHAR(4) ,
              rfcNum VARCHAR(6) ,
              rfcHomo VARCHAR(3) ,
              acumuladoPercepcion FLOAT ,
              acumuladoPercepcionGravable FLOAT ,
              acumuladoIsr FLOAT ,
              acumuladoInfonavit FLOAT ,
              acumuladoSar FLOAT ,
              acumuladoCv FLOAT ,
              email VARCHAR(100) ,
              fechaAntiguedad DATETIME ,
              procesoName VARCHAR(100) ,
              nomina CHAR(3) ,
              saltarPagina CHAR(1) ,
              firma CHAR(1) ,
              mov CHAR(2) ,
              foto VARCHAR(255) ,
              substotal FLOAT ,
              baseISN1 FLOAT ,
              porcientoISN1 FLOAT ,
              importeISN1 FLOAT ,
              empleadosISN1 INT ,
              baseISN2 FLOAT ,
              porcientoISN2 FLOAT ,
              importeISN2 FLOAT ,
              empleadosISN2 INT ,
              imprimirResumen INT ,
              copia INT
            )
    END    
GO
--IF EXISTS ( SELECT  *
--            FROM    sys.indexes
--            WHERE   object_id = OBJECT_ID('dbo.KardexImprimeResumenISN')
--                    AND NAME = 'PK_KardexImprimeResumenISN_01' ) 
--    BEGIN
--        ALTER TABLE dbo.KardexImprimeRecibos DROP CONSTRAINT PK_KardexImprimeRecibos_01 
--    END
--GO

IF OBJECT_ID('dbo.ManoObraInicia') IS NOT NULL 
   DROP PROCEDURE dbo.ManoObraInicia
GO
CREATE PROCEDURE dbo.ManoObraInicia
@empresa INT 

AS
  IF OBJECT_ID('dbo.ManoObra') IS NULL 
     CREATE TABLE dbo.ManoObra
            (
              empresa INT ,
              clave CHAR(1) ,
              descripcion VARCHAR(200)
              CONSTRAINT PK_ManoObra PRIMARY KEY CLUSTERED ( empresa, clave )
            )
            
  /*
  Agregar las claves iniciales para la tabla de mano de obra si no existen
  D.-Directos
  I.-Indirectos
  ' '.-Sin definir
  */
  IF NOT EXISTS ( SELECT  clave
                  FROM    dbo.ManoObra
                  WHERE   clave = ' '
                          AND dbo.ManoObra.empresa = @empresa ) 
     INSERT INTO dbo.ManoObra (empresa, clave, descripcion) VALUES (@empresa, ' ', 'Sin definicin')
                    
  IF NOT EXISTS ( SELECT  clave
                  FROM    dbo.ManoObra
                  WHERE   clave = 'D'
                          AND dbo.ManoObra.empresa = @empresa ) 
     INSERT INTO dbo.ManoObra (empresa, clave, descripcion) VALUES (@empresa,'D', 'Directos')

  IF NOT EXISTS ( SELECT  clave
                  FROM    dbo.ManoObra
                  WHERE   clave = 'I'
                          AND dbo.ManoObra.empresa = @empresa ) 
     INSERT INTO dbo.ManoObra (empresa, clave, descripcion) VALUES (@empresa, 'I', 'Indirectos')
GO

IF OBJECT_ID('dbo.NOM_TBL_SeleccionEmpresasCedula') IS NULL 
    BEGIN
        CREATE TABLE dbo.NOM_TBL_SeleccionEmpresasCedula
            (
			  usuario VARCHAR(50)
              , empresa INT
              , cedula INT
              , CONSTRAINT NOM_TBL_SeleccionEmpresasCedula_PK01 PRIMARY KEY CLUSTERED (usuario, empresa, cedula)
               WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                      IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                      ALLOW_PAGE_LOCKS = ON
					 ) ON [PRIMARY]
			)
        ON  [PRIMARY]
    END
GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'Obras')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE dbo.Obras
            (
              [obra] [numeric](18, 0) NOT NULL ,
              [empresa] [numeric](3, 0) NOT NULL ,
              [nombre] [varchar](30) NULL ,
              [razon_social] [varchar](70) NULL ,
              [registro_patronal] [char](11) NULL ,
              [calle] [varchar](30) NULL ,
              [n_interior] [int] NULL ,
              [n_exterior] [int] NULL ,
              [colonia] [varchar](30) NULL ,
              [municipio] [varchar](30) NULL ,
              [cp] [int] NULL ,
              [localidad] [varchar](30) NULL ,
              [ent_fed] [varchar](30) NULL ,
              [estatus] [char](2) NULL ,
              CONSTRAINT [PK_OBRAS] PRIMARY KEY CLUSTERED
                ( [obra] ASC, [empresa] ASC )
            )
        ON  [PRIMARY]


    END

GO

ALTER TABLE [dbo].[OBRAS]
ALTER COLUMN [nombre] VARCHAR(50) NULL

GO 

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'Obras_Emps')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    CREATE TABLE [dbo].[Obras_emps]
        (
          [Obra] [numeric](18, 0) NOT NULL ,
          [empresa] [numeric](3, 0) NOT NULL ,
          [codigo] [numeric](8, 0) NOT NULL ,
          [fecha_i] [datetime] NOT NULL ,
          [fecha_f] [datetime] NOT NULL ,
          [supervisor] [int] NOT NULL ,
          [dias] [int] NOT NULL ,
          [mes] [int] NOT NULL ,
          [ayo] [int] NOT NULL ,
          [serial] [int] IDENTITY(1, 1)
                         NOT NULL ,
          CONSTRAINT [PK_Obras_emps] PRIMARY KEY CLUSTERED
            ( [Obra] ASC, [empresa] ASC, [codigo] ASC, [mes] ASC, [ayo] ASC, [serial] ASC )
        )
    ON  [PRIMARY]

GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'saldiaint'
                        AND sysobjects.name = 'Obras_Emps' ) 
    ALTER TABLE Obras_Emps ADD saldiaint NUMERIC(10,2)

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'sueldo'
                        AND sysobjects.name = 'Obras_Emps' ) 
    ALTER TABLE Obras_Emps ADD sueldo NUMERIC(10,2)

GO

IF OBJECT_ID('dbo.OrigenAvisoImss') IS NULL 
    CREATE TABLE [dbo].[OrigenAvisoImss]
        (
          serial INT IDENTITY ,
          origen VARCHAR(2) ,
          descripcion VARCHAR(50) ,
          funcion VARCHAR(2) ,
          aviso INT 
        )
GO
-- nomina 1
-- sistema 2
-- alta 4
-- baja 8
-- ms 16
-- altarpu 32
-- bajarpu 64

IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'CM' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'CM', 'Captura Masiva', 'D',  31)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'VA' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'VA', 'Variable', 'B', 19)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'FA' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'FA', 'Cambio Mes', 'A', 31)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'AH' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'AH', 'Aviso Histrico', 'D', 31)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'EN' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'EN', 'Enlace Nmina', 'N',30)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'AM' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'AM', 'Aumento Masivo', 'M', 19)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'CI' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'CI', 'Captura Individual', 'D', 31)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'AR' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'AR', 'AutoRegularizacin', 'C', 19)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'CU' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'CU', 'Cambio Municipio', 'I', 99)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'FI' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'FI', 'Cambio Masivo Funcion I', 'I', 99)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'EC' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'EC', 'Elimino Cambio Salario', 'D', 99)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'ER' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'ER', 'Elimino Reingreso', 'D', 99)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'RH' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'RH', 'Recursos Humanos', 'D', 99)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'MA' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'MA', 'Motor Arranque', 'D', 99)
GO
IF NOT EXISTS ( SELECT  dbo.OrigenAvisoImss.origen
                FROM    dbo.OrigenAvisoImss
                WHERE   dbo.OrigenAvisoImss.origen = 'AC' ) 
    INSERT  dbo.OrigenAvisoImss
            ( origen, descripcion, funcion, aviso)
    VALUES  ( 'AC', 'APSI Check in-out', 'N', 99)
GO

IF NOT EXISTS (SELECT syscolumns.name
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE UPPER(syscolumns.name) = 'SSL' AND
                     UPPER(sysobjects.name) = 'PARAMETROS_EMPRESAS')
  BEGIN
    ALTER TABLE dbo.Parametros_Empresas ADD SSL CHAR(1)
    ALTER TABLE dbo.Parametros_Empresas ADD TLS CHAR(1)
  END  
GO

IF OBJECT_ID('dbo.PlantillaCampoSeleccionado') IS NULL 
    BEGIN
        CREATE TABLE [dbo].[PlantillaCampoSeleccionado]
            (
              id INT IDENTITY,
              empresa INT,
              usuario VARCHAR(50),
              CentrodeCostos BIT,
              Tabulador BIT,
              Clase BIT,
              Sexo BIT,
              EntidadNacimiento BIT,
              FechaNacimiento BIT,
              Rfc BIT,
              Curp BIT,
              DirectoInderecto BIT,
              Supervisor BIT,
              Horaro BIT,
              Banco BIT,
              TipoDesposito BIT,
              CuentaBancaria BIT,
              Clabe BIT,
              Calle BIT,
              NoExterior BIT,
              NoInterior BIT,
              Colonia BIT,
              Municipio BIT,
              Localidad BIT,
              EntidadFederativa BIT,
              CodigoPostal BIT,
              CuentaContable BIT,
              TipoRegimen BIT,
              TipoContrato BIT,
              CorreoElectronico BIT,
              CtaValesDespensa BIT,
              CampoLibre1 BIT,
              CampoLibre2 BIT,
              CampoLibre3 BIT,
              CampoLibre4 BIT,
              CampoLibre5 BIT,
              CampoLibre6 BIT,
              CampoLibre7 BIT,
              CampoLibre8 BIT,
              CampoLibre9 BIT,
              CampoLibre10 BIT,
              CampoLibre11 BIT,
              CampoLibre12 BIT,
              CampoLibre13 BIT,
              CampoLibre14 BIT,
              CampoLibre15 BIT,
              TipoSalario BIT,
              Sindicalizado BIT,
              EstadoCivil BIT,
              ClaveEntidadFederativa BIT,
              Telefono BIT,
              fechaGeneracion DATETIME,
              fechaActualizacion DATETIME
              
              CONSTRAINT [PlantillaCampoSeleccionado_ASC_PK01] PRIMARY KEY CLUSTERED (empresa ASC, usuario ASC, id ASC)
                         WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                                IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                                ALLOW_PAGE_LOCKS = ON )
              ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO
IF NOT EXISTS (SELECT syscolumns.name FROM syscolumns LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id WHERE syscolumns.name = 'CampoLibre9' AND sysobjects.name = 'PlantillaCampoSeleccionado') 
    ALTER TABLE dbo.PlantillaCampoSeleccionado ADD CampoLibre9 BIT
GO
IF NOT EXISTS (SELECT syscolumns.name FROM syscolumns LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id WHERE syscolumns.name = 'CampoLibre10' AND sysobjects.name = 'PlantillaCampoSeleccionado') 
    ALTER TABLE dbo.PlantillaCampoSeleccionado ADD CampoLibre10 BIT
GO
IF NOT EXISTS (SELECT syscolumns.name FROM syscolumns LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id WHERE syscolumns.name = 'CampoLibre11' AND sysobjects.name = 'PlantillaCampoSeleccionado') 
    ALTER TABLE dbo.PlantillaCampoSeleccionado ADD CampoLibre11 BIT
GO
IF NOT EXISTS (SELECT syscolumns.name FROM syscolumns LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id WHERE syscolumns.name = 'CampoLibre12' AND sysobjects.name = 'PlantillaCampoSeleccionado') 
    ALTER TABLE dbo.PlantillaCampoSeleccionado ADD CampoLibre12 BIT
GO
IF NOT EXISTS (SELECT syscolumns.name FROM syscolumns LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id WHERE syscolumns.name = 'CampoLibre13' AND sysobjects.name = 'PlantillaCampoSeleccionado') 
    ALTER TABLE dbo.PlantillaCampoSeleccionado ADD CampoLibre13 BIT
GO
IF NOT EXISTS (SELECT syscolumns.name FROM syscolumns LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id WHERE syscolumns.name = 'CampoLibre14' AND sysobjects.name = 'PlantillaCampoSeleccionado') 
    ALTER TABLE dbo.PlantillaCampoSeleccionado ADD CampoLibre14 BIT
GO
IF NOT EXISTS (SELECT syscolumns.name FROM syscolumns LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id WHERE syscolumns.name = 'CampoLibre15' AND sysobjects.name = 'PlantillaCampoSeleccionado')
    ALTER TABLE dbo.PlantillaCampoSeleccionado ADD CampoLibre15 BIT
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   sysobjects.name = 'rpu_trabajador' ) 
    CREATE TABLE [dbo].[rpu_trabajador]
        (
          [empresa] [numeric](5, 0) NOT NULL ,
          [codigo] [numeric](8, 0) NOT NULL ,
          [folio] [int] NOT NULL ,
          [mov] [char](2) NULL ,
          [fch_mov] [datetime] NULL ,
          [dias] [numeric](6, 0) NULL ,
          [rpu] [char](3) NULL ,
          [enviado] [char](2) NULL
        )
    ON  [PRIMARY]
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   sysobjects.name = 'rpu' ) 
    CREATE TABLE dbo.rpu
        (
          empresa NUMERIC(5, 0) NOT NULL ,
          rpu CHAR(3) NOT NULL ,
          reg_pat CHAR(11) NULL ,
          nombre VARCHAR(70) NULL ,
          referencia VARCHAR(70) NULL ,
          direccion VARCHAR(50) NULL ,
          colonia VARCHAR(50) NULL ,
          poblacion VARCHAR(50) NULL ,
          delegacion INT NULL ,
          subdelegacion INT NULL ,
          CONSTRAINT PK453 PRIMARY KEY NONCLUSTERED ( Rpu )
        )
GO


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'empresa'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD empresa NUMERIC(5,0) NOT NULL DEFAULT 0
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'nombre'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD nombre VARCHAR(70) NULL
GO 
IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'rpu'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'nombre'
          AND CHARACTER_OCTET_LENGTH = 50) IS NOT NULL
    ALTER TABLE dbo.rpu ALTER COLUMN nombre VARCHAR(70)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'referencia'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD referencia VARCHAR(70) NULL
GO 
IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'rpu'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'referencia'
          AND CHARACTER_OCTET_LENGTH = 50) IS NOT NULL
    ALTER TABLE dbo.rpu ALTER COLUMN referencia VARCHAR(70)
GO

IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'rpu'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'direccion'
          AND CHARACTER_OCTET_LENGTH = 50) IS NOT NULL
    ALTER TABLE dbo.rpu ALTER COLUMN direccion VARCHAR(60)
GO


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'zona_geografica'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD zona_geografica CHAR(1) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'guia'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD guia CHAR(5) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'entidad'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD entidad CHAR(2) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'nomentidad'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD nomentidad VARCHAR(30) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'folio_primer_empleo'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD folio_primer_empleo CHAR(25) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'representante_legal'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD representante_legal VARCHAR(50) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'puesto_representante'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD puesto_representante VARCHAR(30) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'actividad'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD actividad VARCHAR(100) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'nombre_sub_delegacion'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD nombre_sub_delegacion VARCHAR(30) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'patron_paga_cuotas_imss'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD patron_paga_cuotas_imss CHAR(01) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'clase'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD clase INT NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'fraccion_rt'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD fraccion_rt INT NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'regimen_seguridad_social'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD regimen_seguridad_social CHAR(01) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'cod_postal'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD cod_postal VARCHAR(05) NULL
GO 


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'prima_rt'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD prima_rt NUMERIC(7,5) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'clave'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD clave NCHAR(16) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'rfc'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD rfc NCHAR(13) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'control'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD control CHAR(1) NULL
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'reg_pat'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE rpu ADD reg_pat CHAR(11) NULL
GO 

IF EXISTS ( SELECT  syscolumns.name
            FROM    syscolumns
                    LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
            WHERE   syscolumns.name = 'domicilio'
                    AND sysobjects.name = 'rpu' ) 
    ALTER TABLE dbo.rpu ALTER COLUMN domicilio VARCHAR(100)
GO 
   
IF EXISTS ( SELECT  syscolumns.name
            FROM    syscolumns
                    LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
            WHERE   syscolumns.name = 'cololina'
                    AND sysobjects.name = 'rpu' ) 
    ALTER TABLE dbo.rpu ALTER COLUMN colonia VARCHAR(100)
GO 
        
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'numeroExterior'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE dbo.rpu ADD numeroExterior VARCHAR(25)
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'numeroInterior'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE dbo.rpu ADD numeroInterior VARCHAR(25)
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'municipio'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE dbo.rpu ADD municipio VARCHAR(100)
GO 
        
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'localidad'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE dbo.rpu ADD localidad VARCHAR(100)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'curp_representante'
                        AND sysobjects.name = 'rpu' ) 
    ALTER TABLE dbo.rpu ADD curp_representante VARCHAR(18)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   sysobjects.name = 'Rpu_PrimaRT' ) 
    CREATE TABLE dbo.Rpu_PrimaRT
        (
		  id INT IDENTITY NOT NULL
          , empresa INT NOT NULL
          , rpu CHAR(3) NOT NULL
		  , fecha DATETIME NOT NULL
		  , primaRt NUMERIC(7,5) NOT NULL
          CONSTRAINT PK_RpuPrimaRT PRIMARY KEY CLUSTERED (empresa, rpu, fecha, primaRt, id)
        )
GO

IF OBJECT_ID('dbo.TblUMA') IS NULL 
    BEGIN
        CREATE TABLE [dbo].[TblUMA]
            (
              idUma INT IDENTITY,
              fecha DATETIME,
              umaDiario NUMERIC(12,2),
              umaMensual NUMERIC(12,2),
              umaAnual NUMERIC(12,2),
              aplicaIMSS BIT,
              aplicaInfonavit BIT,
              aplicaISR BIT,
              CONSTRAINT [TblUMA_ASC_PK01] PRIMARY KEY CLUSTERED (fecha ASC, idUma ASC)
                         WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                                IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                                ALLOW_PAGE_LOCKS = ON )
              ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO

-- Enero 2017
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20170101', 73.04, 2220.42, 26645.04, 1, 1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20170101')
GO
-- Febrero 2017
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20170201', 75.49, 2294.90, 27538.80, 1 ,1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20170201')
GO   
-- Febrero 2018
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20180201', 80.60, 2450.24, 29402.88, 1 ,1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20180201')
GO   
-- Febrero 2019
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20190201', 84.49, 2568.50, 30822.00, 1 ,1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20190201')
GO   
-- Febrero 2020
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20200201', 86.88, 2641.15, 31693.80, 1 ,1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20200201')
GO   
-- Febrero 2021
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20210201', 89.62, 2724.45, 32693.40, 1 ,1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20210201')
GO   
-- Febrero 2022
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20220201', 96.22, 2925.09, 35101.08, 1 ,1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20220201')
GO
-- Febrero 2023
INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20230201', 103.74, 3153.70, 37844.40, 1 ,1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = '20230201')
GO   

-- Tabla para el calculo de credito infonavit tipo 3
IF OBJECT_ID('dbo.TblUMAFD') IS NULL 
    BEGIN
        CREATE TABLE [dbo].[TblUMAFD]
            (
              idUma INT IDENTITY,
              fecha DATETIME,
              umaDiario NUMERIC(12,2),
              umaMensual NUMERIC(12,2),
              umaAnual NUMERIC(12,2),
              aplicaIMSS BIT,
              aplicaInfonavit BIT,
              aplicaISR BIT,
              CONSTRAINT [TblUMAFD_ASC_PK01] PRIMARY KEY CLUSTERED (fecha ASC, idUma ASC)
                         WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                                IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                                ALLOW_PAGE_LOCKS = ON )
              ON [PRIMARY]
            )
        ON  [PRIMARY]
    END
GO

-- Enero 2018
INSERT dbo.TblUMAFD (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20180101', 78.43, 0, 0, 1, 1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMAFD AS uma WHERE uma.fecha = '20180101')
-- Enero 2019
INSERT dbo.TblUMAFD (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20190101', 82.22, 0, 0, 1, 1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMAFD AS uma WHERE uma.fecha = '20190101')
-- Enero 2020
INSERT dbo.TblUMAFD (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20200101', 84.55, 0, 0, 1, 1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMAFD AS uma WHERE uma.fecha = '20200101')
-- Enero 2021
INSERT dbo.TblUMAFD (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20210101', 87.21, 0, 0, 1, 1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMAFD AS uma WHERE uma.fecha = '20210101')
-- Enero 2022
INSERT dbo.TblUMAFD (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20220101', 91.56, 0, 0, 1, 1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMAFD AS uma WHERE uma.fecha = '20220101')
-- Enero 2023
INSERT dbo.TblUMAFD (fecha, umaDiario, umaMensual, umaAnual, aplicaIMSS, aplicaInfonavit, aplicaISR) SELECT '20230101', 96.32, 0, 0, 1, 1, 0 WHERE NOT EXISTS (SELECT 1 FROM dbo.TblUMAFD AS uma WHERE uma.fecha = '20230101')
GO
IF EXISTS (SELECT 1 FROM dbo.TblUmaFD WHERE fecha = '20220101' AND umaDiario = 93.63)
   UPDATE dbo.TblUMAFD
   SET umaDiario = 91.56
   WHERE fecha = '20220101'
         AND umaDiario = 93.63
GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[TemporalAmortizacion]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    CREATE TABLE [dbo].[TemporalAmortizacion]
        (
          [empresa] [int] ,
          [codigo] [int] ,
          [amortizacion] [float] ,
          [descuento] [float] ,
          clase varchar(2) ,
          tipo_cred CHAR(1) ,
          fecha DATETIME ,
          fch_otorga DATETIME ,
          fch_termino DATETIME ,
          numcredito NUMERIC(10)
        )
ELSE 
   BEGIN 
    IF NOT EXISTS ( SELECT  syscolumns.name
                    FROM    syscolumns
                            LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                    WHERE   syscolumns.name = 'clase'
                            AND sysobjects.name = 'TemporalAmortizacion' ) 
        ALTER TABLE dbo.TemporalAmortizacion ADD clase VARCHAR(2)
    ELSE 
       ALTER TABLE dbo.TemporalAmortizacion ALTER COLUMN clase VARCHAR(2)
       
    IF NOT EXISTS ( SELECT  syscolumns.name
                    FROM    syscolumns
                            LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                    WHERE   syscolumns.name = 'tipo_cred'
                            AND sysobjects.name = 'TemporalAmortizacion' ) 
        ALTER TABLE dbo.TemporalAmortizacion ADD tipo_cred CHAR(1)
       
    IF NOT EXISTS ( SELECT  syscolumns.name
                    FROM    syscolumns
                            LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                    WHERE   syscolumns.name = 'fecha'
                            AND sysobjects.name = 'TemporalAmortizacion' ) 
        ALTER TABLE dbo.TemporalAmortizacion ADD fecha DATETIME

    IF NOT EXISTS ( SELECT  syscolumns.name
                    FROM    syscolumns
                            LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                    WHERE   syscolumns.name = 'fch_otorga'
                            AND sysobjects.name = 'TemporalAmortizacion' ) 
        ALTER TABLE dbo.TemporalAmortizacion ADD fch_otorga DATETIME
       
    IF NOT EXISTS ( SELECT  syscolumns.name
                    FROM    syscolumns
                            LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                    WHERE   syscolumns.name = 'fch_termino'
                            AND sysobjects.name = 'TemporalAmortizacion' ) 
        ALTER TABLE dbo.TemporalAmortizacion ADD fch_termino DATETIME

    IF NOT EXISTS ( SELECT  syscolumns.name
                    FROM    syscolumns
                            LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                    WHERE   syscolumns.name = 'numcredito'
                            AND sysobjects.name = 'TemporalAmortizacion' ) 
        ALTER TABLE dbo.TemporalAmortizacion ADD numcredito NUMERIC(10,0)
   END
GO

/**************************************************************************************************
 * Name          : AjustaSaldiaInt
 * Project       : APSI Nomina
 * Description   : Ajusta el salario diario integrado a los topes y articulo 33 de ley
 * Table name    :
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoales, Marzo 10, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'FN'
                    AND name = 'AjustaSaldiaInt' )
    BEGIN
        DROP  FUNCTION [dbo].[AjustaSaldiaInt]
    END
GO

CREATE FUNCTION [dbo].[AjustaSaldiaInt]
    (
      @saldiaint FLOAT ,
      @topeDF FLOAT ,
      @topeRegion FLOAT ,
      @art39 FLOAT ,
      @mov CHAR(2)
    )
RETURNS FLOAT

AS
    BEGIN


        DECLARE @saldiaintReturn FLOAT

--if IsNull({empresas.fch_incremento}) or {avisos_imss.fch_mov} >= {empresas.fch_incremento}
--   then (ntopedf := {empresas.saldf} * 25; ntopemin := {empresas.salmin}) // * 1.0452)
--   else (ntopedf := {empresas.sal_df} * 25; ntopemin := {empresas.sal_min}); // * 1.0452);



        IF @mov <> 'B'
            BEGIN
                IF @saldiaint > @topeDF
                    SET @saldiaintReturn = @topeDF
                ELSE
                    IF @saldiaint < @topeRegion
                        SET @saldiaintReturn = @topeRegion
                    ELSE
                        SET @saldiaintReturn = @saldiaint

                IF @art39 > 0
                    IF @saldiaintReturn > ( @topeDF * ( @art39 / 100 ) )
                        SET @saldiaintReturn = ( @topeDF * ( @art39 / 100 ) )
            END
        ELSE
            SET @saldiaintReturn = 0

        RETURN @saldiaintReturn
    END
GO

IF OBJECT_ID('dbo.CalculaAyosAntiguedad') IS NOT NULL
   DROP FUNCTION dbo.CalculaAyosAntiguedad
GO


CREATE FUNCTION [dbo].[CalculaAyosAntiguedad]
    (
      @fechaInicio DATETIME ,
      @fechaTermino DATETIME
    )
RETURNS INT
AS 
    BEGIN
    
        SET @fechaTermino = dbo.fin_mes(MONTH(@fechaTermino),
                                        YEAR(@fechaTermino))
                                        
        DECLARE @ayos INT


        SET @ayos = DATEDIFF(yy, @fechaInicio, @fechaTermino)
            + CASE WHEN YEAR(@fechaInicio) <= YEAR(@fechaTermino)
                        AND MONTH(@fechaInicio) <= MONTH(@fechaTermino)
                        AND CASE WHEN DAY(@fechaInicio) = 31
                                      AND DAY(@fechaTermino) = 30 THEN 30
                                 WHEN DAY(@fechaInicio) >= 29 AND DAY(@fechaInicio) <= 31
                                      AND MONTH(@fechaInicio) = 1
                                      AND DAY(@fechaTermino) >= 28
                                      AND MONTH(@fechaTermino) = 2 THEN 28
                                 ELSE DAY(@fechaInicio)
                            END <= DAY(@fechaTermino) THEN 1
                   ELSE 0
              END 

        SET @ayos = ISNULL(@ayos, 0)
        
        SET @ayos = CASE WHEN @ayos <= 0 THEN 1 ELSE CASE WHEN @ayos > 45 THEN 45 ELSE @ayos END END
        
        RETURN(@ayos)
    END          
GO

/**************************************************************************************************
 * Name          : CalculaCuotaImss
 * Project       : APSI Nomina
 * Description   : Calcula cuota Imss
 * Table name    : 
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoales, Marzo 10, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.CalculaCuotaImss') IS NOT NULL 
    DROP FUNCTION dbo.CalculaCuotaImss
GO
CREATE FUNCTION [dbo].[CalculaCuotaImss]
    (
      @salarioBaseCotizacion FLOAT ,
      @diasTrabajados INT ,
      @diasIncapacidad INT ,
      @diasFaltas INT ,
      @primaImss FLOAT ,
      @excedente CHAR(1) ,
      @salarioDF FLOAT ,
      @cuotaDiaria FLOAT ,
      @fechaPeriodo DATETIME ,
      @simulaReforma INT ,
      @salarioMinimo FLOAT ,
      @esCuotaPatron INT ,
      @primaPatron FLOAT ,
      @primaTrabajador FLOAT
    )
RETURNS FLOAT
AS 
    BEGIN
        DECLARE @cuotaCalculada FLOAT
        DECLARE @salarioMinimoBaseCotizacion FLOAT
        DECLARE @gobiernoFederalPagaCuotas INT
        DECLARE @salarioMinimoBaseCotizacionDesde FLOAT
        DECLARE @salarioMinimoBaseCotizacionHasta FLOAT

        IF @simulaReforma = 1 
            BEGIN
                SET @salarioMinimoBaseCotizacion = ROUND(@salarioMinimo * 1.0452, 2)
                SET @salarioMinimoBaseCotizacionDesde = @salarioMinimoBaseCotizacion + .01
                SET @salarioMinimoBaseCotizacionHasta = ROUND(@salarioMinimoBaseCotizacion * 2, 2)
                SET @gobiernoFederalPagaCuotas = CASE WHEN @salarioBaseCotizacion >= @salarioMinimoBaseCotizacionDesde
                                                           AND @salarioBaseCotizacion <= @salarioMinimoBaseCotizacionHasta
                                                      THEN 1
                                                      ELSE 0
                                                 END     
            END
        ELSE 
            SET @gobiernoFederalPagaCuotas = 0
     

        IF @gobiernoFederalPagaCuotas = 1 
            IF @esCuotaPatron = 0
                OR @esCuotaPatron = 1 
                SET @primaImss = @primaPatron
            ELSE 
                IF @esCuotaPatron = 2 
                    SET @primaImss = 0
         
         
        IF @excedente = 'S' 
            BEGIN
                IF @salarioBaseCotizacion > ROUND(@salarioDF * 3, 2) 
                    SET @salarioBaseCotizacion = @salarioBaseCotizacion
                        - ROUND(@salarioDF * 3, 2)
                ELSE 
                    SET @salarioBaseCotizacion = 0
            END
            
        SET @cuotaCalculada = ROUND(@salarioBaseCotizacion * ( @diasTrabajados
                                                              - @diasIncapacidad
                                                              - @diasFaltas )
                                    * ( @primaImss / 100 ), 2)
     
        RETURN @cuotaCalculada
    END
GO

/**************************************************************************************************
 * Name          : CalculaCuotaImss
 * Project       : APSI Nomina
 * Description   : Calcula cuota Imss
 * Table name    : 
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoales, Marzo 10, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.CalculaCuotaImssUMA') IS NOT NULL 
    DROP FUNCTION dbo.CalculaCuotaImssUMA
GO
CREATE FUNCTION [dbo].[CalculaCuotaImssUMA]
    (
      @salarioBaseCotizacion FLOAT ,
      @diasTrabajados INT ,
      @diasIncapacidad INT ,
      @diasFaltas INT ,
      @primaImss FLOAT ,
      @excedente CHAR(1) ,
      @salarioDF FLOAT ,
      @cuotaDiaria FLOAT ,
      @fechaPeriodo DATETIME ,
      @simulaReforma INT ,
      @salarioMinimo FLOAT ,
      @esCuotaPatron INT ,
      @primaPatron FLOAT ,
      @primaTrabajador FLOAT
    )
RETURNS FLOAT
AS 
    BEGIN
        DECLARE @cuotaCalculada FLOAT
        DECLARE @salarioMinimoBaseCotizacion FLOAT
        DECLARE @gobiernoFederalPagaCuotas INT
        DECLARE @salarioMinimoBaseCotizacionDesde FLOAT
        DECLARE @salarioMinimoBaseCotizacionHasta FLOAT

        IF @simulaReforma = 1 
            BEGIN
                SET @salarioMinimoBaseCotizacion = ROUND(@salarioMinimo * 1.0452, 2)
                SET @salarioMinimoBaseCotizacionDesde = @salarioMinimoBaseCotizacion + .01
                SET @salarioMinimoBaseCotizacionHasta = ROUND(@salarioMinimoBaseCotizacion * 2, 2)
                SET @gobiernoFederalPagaCuotas = CASE WHEN @salarioBaseCotizacion >= @salarioMinimoBaseCotizacionDesde
                                                           AND @salarioBaseCotizacion <= @salarioMinimoBaseCotizacionHasta
                                                      THEN 1
                                                      ELSE 0
                                                 END     
            END
        ELSE 
            SET @gobiernoFederalPagaCuotas = 0
     

        IF @gobiernoFederalPagaCuotas = 1 
            IF @esCuotaPatron = 0
                OR @esCuotaPatron = 1 
                SET @primaImss = @primaPatron
            ELSE 
                IF @esCuotaPatron = 2 
                    SET @primaImss = 0
         
         
        IF @excedente = 'S' 
            BEGIN
                IF @salarioBaseCotizacion > ROUND(@salarioDF * 3, 2) 
                    SET @salarioBaseCotizacion = @salarioBaseCotizacion
                        - ROUND(@salarioDF * 3, 2)
                ELSE 
                    SET @salarioBaseCotizacion = 0
            END
            
        SET @cuotaCalculada = ROUND(@salarioBaseCotizacion * ( @diasTrabajados
                                                              - @diasIncapacidad
                                                              - @diasFaltas )
                                    * ( @primaImss / 100 ), 2)
     
        RETURN @cuotaCalculada
    END
GO

DECLARE @schema_name NVARCHAR(256)
DECLARE @table_name NVARCHAR(256)
DECLARE @col_name NVARCHAR(256)
DECLARE @Command  NVARCHAR(1000)

SET @schema_name = N'dbo'
SET @table_name = N'Historico'
SET @col_name = N'empresa'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

SET @col_name = N'codigo'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END


SET @Command = NULL
SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + name
FROM sys.key_constraints
WHERE [type] = 'PK'
      AND [parent_object_id] = OBJECT_ID(@schema_name + '.' + @table_name)

IF @Command IS NOT NULL    
   BEGIN
     EXECUTE (@Command)
   END

IF (OBJECT_ID('Refempresas453', 'F') IS NOT NULL)
   BEGIN
     ALTER TABLE dbo.Historico DROP CONSTRAINT Refempresas453
   END

IF (OBJECT_ID('Refempleados454', 'F') IS NOT NULL)
   BEGIN
     ALTER TABLE dbo.Historico DROP CONSTRAINT Refempleados454
   END
GO

IF EXISTS (SELECT 1
           FROM sys.indexes
           WHERE name='PK108' 
           AND OBJECT_ID = OBJECT_ID('[dbo].[Historico]'))
   BEGIN
     DROP INDEX [PK108] ON [dbo].[Historico]
   END
GO

--IF NOT EXISTS (SELECT 1
--               FROM sys.indexes
--               WHERE name='PK108' 
--               AND OBJECT_ID = OBJECT_ID('[dbo].[Historico]'))
--   BEGIN
--     CREATE CLUSTERED INDEX PK108 ON dbo.Historico (empresa,codigo,fecha_captura,folio)
--   END
--GO

/*
IF NOT EXISTS (SELECT name 
               FROM sys.indexes
               WHERE name = N'PK108')
   ALTER TABLE dbo.Historico ADD CONSTRAINT PK108 PRIMARY KEY CLUSTERED (empresa,codigo,fecha_captura,folio)
         WITH (PAD_INDEX = OFF,
               STATISTICS_NORECOMPUTE = OFF, 
               IGNORE_DUP_KEY = OFF, 
               ALLOW_ROW_LOCKS = ON, 
               ALLOW_PAGE_LOCKS  = ON)
         ON [PRIMARY]
*/
--ALTER TABLE [dbo].[empresas]  WITH CHECK ADD CHECK  (([empresa]>(0)))
IF (OBJECT_ID('Refempresas453', 'F') IS NULL)
   BEGIN
     ALTER TABLE [dbo].[Historico] WITH NOCHECK ADD CONSTRAINT [Refempresas453] FOREIGN KEY([empresa])
     REFERENCES [dbo].[empresas] ([empresa])

     ALTER TABLE [dbo].[Historico] CHECK CONSTRAINT [Refempresas453]
     ALTER TABLE [dbo].[Historico] ADD DEFAULT (0) FOR [empresa]
   END
GO

IF (OBJECT_ID('Refempleados454', 'F') IS NULL)
   BEGIN
     ALTER TABLE [dbo].[Historico] WITH CHECK ADD CONSTRAINT [Refempleados454] FOREIGN KEY([empresa], [codigo])
     REFERENCES [dbo].[empleados] ([empresa], [codigo])

     ALTER TABLE [dbo].[Historico] CHECK CONSTRAINT [Refempleados454]
     ALTER TABLE [dbo].[Historico] ADD DEFAULT (0) FOR [codigo]
   END
GO

UPDATE dbo.Historico SET fecha_captura = '19000101' WHERE fecha_captura IS NULL
GO

ALTER TABLE [dbo].[Historico] ALTER COLUMN fecha_captura DATETIME NOT NULL 
GO

IF  NOT EXISTS (SELECT name
                FROM sys.objects 
                WHERE object_id = OBJECT_ID(N'PK108') 
                      AND type in (N'U'))
    BEGIN
      ALTER TABLE dbo.Historico ADD CONSTRAINT PK108 PRIMARY KEY CLUSTERED (empresa,codigo,fecha_captura,folio)
            WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON)
            ON [PRIMARY]         
      --ALTER TABLE dbo.Historico ADD CONSTRAINT PK108 PRIMARY KEY CLUSTERED (empresa,codigo,fecha_captura,folio)
    END
GO

/**************************************************************************************************
 * Name          : CuentaRegistros
 * Project       : APSI Nomina
 * Description   : Cuenta cuantos registros tiene kardex
 * Table name    :
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoales, Julio 07, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'FN'
                    AND name = 'CuentaRegistros' )
    BEGIN
        DROP  FUNCTION [dbo].[CuentaRegistros]
    END
GO

CREATE FUNCTION [dbo].[CuentaRegistros]
    (
      @empresa INT ,
      @numeroConceptoInicio INT ,
      @numeroConceptoTermino INT ,
      @nomina VARCHAR(15)
    )
RETURNS INT 

AS
    BEGIN
    
        RETURN (select COUNT(DISTINCT(dbo.kardex.num_conc)) FROM dbo.kardex WHERE dbo.kardex.empresa = @empresa AND dbo.kardex.nomina = @nomina AND dbo.kardex.num_conc >= @numeroConceptoInicio AND dbo.kardex.num_conc <= @numeroConceptoTermino)
    END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'umaDiario'
                        AND sysobjects.name = 'AvisosImssTemporalCalculo' ) 
   OR NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'registro'
                        AND sysobjects.name = 'AvisosImssTemporalCalculo' ) 
   OR NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'aplicaIMSS'
                        AND sysobjects.name = 'AvisosImssTemporalCalculo' ) 
   BEGIN
        DROP TABLE dbo.AvisosImssTemporalCalculo
        CREATE TABLE [dbo].[AvisosImssTemporalCalculo]
            (
              [proceso] [varchar] (250) ,
              [fechaProceso] [datetime] ,
              [horaProceso] [varchar] (8) ,
              [empresa] [numeric](3, 0) NOT NULL ,
              [codigo] [numeric](8, 0) NOT NULL ,
              [serial] [int] NOT NULL ,
              [mes_operacion] [int] NOT NULL ,
              [ayo_operacion] [int] NOT NULL ,
              [fch_mov] [datetime] NOT NULL ,
              [fch_real] [datetime] NULL ,
              [mov] [varchar](2) NULL ,
              [saldiaint] [decimal](10, 2) NULL ,
              [saldiaiv] [decimal](10, 2) NULL ,
              [sueldo] [decimal](12, 2) NULL ,
              [diastr] [int] NULL ,
              [incap] [int] NULL ,
              [ausen] [decimal](5, 2) NULL ,
              [mot_baja] [varchar](30) NULL ,
              [clave_baja] [int] NULL ,
              [campo_01] [varchar](50) NULL ,
              [captura] [varchar](1) NULL ,
              [campo_02] [varchar](50) NULL ,
              [campo_03] [numeric](15, 5) NULL ,
              [campo_04] [numeric](15, 5) NULL ,
              [campo_05] [int] NULL ,
              [campo_06] [int] NULL ,
              [campo_07] [datetime] NULL ,
              [campo_08] [datetime] NULL ,
              [sueldoant] [decimal](12, 2) NULL ,
              [saldiaintant] [decimal](12, 2) NULL ,
              [origen] [varchar](2) NULL ,
              [rpu] [varchar](3) NULL ,
              [consecutivo] [int] NULL ,
              [fechaEnvio] [datetime] NULL ,
              [lote] [varchar](25) NULL ,
              [estatus] [varchar](25) NULL ,
              [fechaConfirmacion] [datetime] NULL ,
              [umaDiario] NUMERIC(12,2),
              [registro] INT NOT NULL,
              [aplicaIMSS] BIT,
              CONSTRAINT [AvisosImssTemporalCalculo_PK14] PRIMARY KEY CLUSTERED
                ( [proceso] ASC, [fechaProceso] ASC, [horaProceso] ASC, [empresa] ASC, [codigo] ASC, [fch_mov] ASC, [serial] ASC, registro )
                WITH ( PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF,
                       IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON,
                       ALLOW_PAGE_LOCKS = ON ) ON [PRIMARY]
            )
        ON  [PRIMARY]

        ALTER TABLE [dbo].[AvisosImssTemporalCalculo]  WITH CHECK ADD  CONSTRAINT [AvisosImssTemporalCalculo_Refempleados443] FOREIGN KEY([empresa], [codigo])
        REFERENCES [dbo].[empleados] ([empresa], [codigo])

        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] CHECK CONSTRAINT [AvisosImssTemporalCalculo_Refempleados443]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT ('') FOR [proceso]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT ('') FOR [fechaProceso]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT ('') FOR [horaProceso]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [empresa]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [codigo]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [serial]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [mes_operacion]
        ALTER TABLE [dbo].[AvisosImssTemporalCalculo] ADD  DEFAULT (0) FOR [ayo_operacion]
   END
GO

IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'empleados'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'rfcnum'
          AND DATA_TYPE <> 'char') IS NOT NULL
    ALTER TABLE dbo.empleados ALTER COLUMN rfcnum CHAR(6)
GO
IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'empleados'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'ap_materno'
          AND CHARACTER_MAXIMUM_LENGTH <> 50) IS NOT NULL
    ALTER TABLE dbo.empleados ALTER COLUMN ap_materno VARCHAR(50)
GO
IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'empleados'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'ap_paterno'
          AND CHARACTER_MAXIMUM_LENGTH <> 50) IS NOT NULL
    ALTER TABLE dbo.empleados ALTER COLUMN ap_paterno VARCHAR(50)
GO
IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'empleados'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'nombre'
          AND CHARACTER_MAXIMUM_LENGTH <> 50) IS NOT NULL
    ALTER TABLE dbo.empleados ALTER COLUMN nombre VARCHAR(50)
GO
IF (SELECT 1
    FROM Information_Schema.Columns
    WHERE TABLE_NAME = 'empleados'
          AND TABLE_SCHEMA = 'dbo'
          AND COLUMN_NAME = 'art39'
          AND NUMERIC_PRECISION <> 7
          AND NUMERIC_SCALE <> 4) IS NOT NULL
   ALTER TABLE dbo.empleados ALTER COLUMN art39 DECIMAL (7,4)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'resumenEmpresa'
                        AND sysobjects.name = 'empresas' ) 
    ALTER TABLE dbo.empresas ADD resumenEmpresa BIT
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'conexionReloj'
                        AND sysobjects.name = 'empresas' ) 
    ALTER TABLE dbo.empresas ADD conexionReloj NVARCHAR(1500)
GO
IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'nombre_cfdi'
                        AND sysobjects.name = 'empresas' ) 
    ALTER TABLE dbo.empresas ADD nombre_cfdi NVARCHAR(125)
GO
IF EXISTS ( SELECT syscolumns.name
            FROM syscolumns
                 LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
            WHERE syscolumns.name = 'nombre_cfdi'
                  AND sysobjects.name = 'empresas' ) 
   UPDATE dbo.empresas
   SET nombre_cfdi = nombre_empresa
   WHERE nombre_cfdi IS NULL
GO

-- esto es del actualiza 04_B
IF not EXISTS(select syscolumns.name  from syscolumns 
  left join sysobjects on syscolumns.id=sysobjects.id
  where syscolumns.name = 'JornadaSAT' and sysobjects.name='horarios_catalogo')
 Alter table horarios_catalogo add JornadaSAT bigint NULL 

GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'dbo.Jornadas_SAT')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE dbo.Jornadas_SAT
            (
              JornadaSAT Int NOT NULL ,
              Descripcion Varchar(50) NULL,
			  CONSTRAINT PKJornadas_SAT PRIMARY KEY NONCLUSTERED ( JornadaSAT )
            )

    END
GO

IF NOT EXISTS (SELECT syscolumns.name 
               FROM syscolumns
               LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
               WHERE UPPER(syscolumns.name) = 'SINDICATO' AND UPPER(sysobjects.name) = 'NOMINA1_ANUAL')
  BEGIN
    ALTER TABLE Nomina1_Anual ADD Sindicato    CHAR(1)    NULL
    ALTER TABLE Nomina1_Anual ADD ClaveEstado  VARCHAR(3) NULL
    ALTER TABLE Nomina1_Anual ADD Clase        VARCHAR(2) NULL
    ALTER TABLE Nomina1_Anual ADD TipoContrato INTEGER    NULL
    ALTER TABLE Nomina1_Anual ADD TipoRegimen  INTEGER    NULL
  END
GO
If Not Exists (Select SysColumns.Name
               From SysColumns 
               Left Join SysObjects ON SysColumns.id = SysObjects.id
               Where Upper(SysColumns.Name) = 'CLAVESAT' And Upper(SysObjects.Name) = 'NOMINA1_ANUAL')
  Begin
    Alter Table Nomina1_Anual Add ClaveSAT     VarChar(3)    DEFAULT ''
    Alter Table Nomina1_Anual Add PorcientoSAT Numeric(12,4) DEFAULT 0
  End
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'infonavit'
                        AND sysobjects.name = 'primas_imss' ) 
    BEGIN
        ALTER TABLE dbo.primas_imss ADD infonavit DECIMAL(8,5)
    END 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'art211'
                        AND sysobjects.name = 'primas_imss' ) 
    BEGIN
        ALTER TABLE dbo.primas_imss ADD art211 DECIMAL(8,5)
    END 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'seguroDesempleo'
                        AND sysobjects.name = 'primas_imss' ) 
    BEGIN
        ALTER TABLE dbo.primas_imss ADD seguroDesempleo DECIMAL(8,5)
    END 
GO

IF OBJECT_ID('dbo.Fun_ObtieneFactorIntegracion') IS NOT NULL
   DROP FUNCTION dbo.Fun_ObtieneFactorIntegracion
GO
CREATE FUNCTION dbo.Fun_ObtieneFactorIntegracion
(
 @fecha DATETIME
)

RETURNS NUMERIC(7,4)

AS
  BEGIN
    DECLARE @factorIntegracion NUMERIC(7,4)
	DECLARE @fechaAplcarNuevoFactor DATETIME

	SET @fechaAplcarNuevoFactor = '20230101'

	IF @fecha IS NULL OR @fecha < @fechaAplcarNuevoFactor
	   SET @factorIntegracion = 1.0452
	ELSE
       SET @factorIntegracion = 1.0493

  
    RETURN @factorIntegracion
  END
GO

/**************************************************************************************************
 * Name          : GetMinimumWage
 * Project       : APSI Nomina
 * Description   : Obtiene salarios minimos regional y DF  
 * Table name    : salarios_minimos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : LUNES, Octubre 19, 2009
 **************************************************************************************************/

IF OBJECT_ID('dbo.GetMinimumWage') IS NOT NULL 
    DROP FUNCTION dbo.GetMinimumWage
GO
CREATE FUNCTION [dbo].[GetMinimumWage] ( @month INT, @year INT )
RETURNS TABLE
    
AS

RETURN
    ( SELECT TOP 1
                dbo.salarios_minimos.zona_a ,
                dbo.salarios_minimos.zona_b ,
                dbo.salarios_minimos.zona_c ,
                dbo.salarios_minimos.fecha_ini
      FROM      dbo.salarios_minimos
      WHERE     dbo.salarios_minimos.fecha_fin >= dbo.fin_mes(@month, @year)  -- Se cambio rutina el 28/11/2012 Jorge Mtz.
                                                               -- para que tome el ultimo SM del mes y ao
                                                               -- indicado en las variables
      ORDER BY  dbo.salarios_minimos.fecha_ini ASC ,
                dbo.salarios_minimos.fecha_fin ASC
      --WHERE     CONVERT(DATETIME, LTRIM(STR(@year)) + RIGHT(STR(100 + @month),
      --                                                      2) + '01') >= dbo.salarios_minimos.fecha_ini
      --          AND CONVERT(DATETIME, LTRIM(STR(@year)) + RIGHT(STR(100
      --                                                        + @month), 2)
      --          + '01') <= dbo.salarios_minimos.fecha_fin
                
    )
GO

IF OBJECT_ID('dbo.ImporteEnLetraNomina') IS NOT NULL
   DROP FUNCTION dbo.ImporteEnLetraNomina
GO
CREATE FUNCTION dbo.ImporteEnLetraNomina
(
  @Numero Decimal(18,2)
)
RETURNS VARCHAR(250)
AS
  BEGIN
    DECLARE @ImpLetra VARCHAR(180)
    DECLARE @lnEntero INT,
            @lcRetorno VARCHAR(512),
            @lnTerna INT,
            @lcMiles VARCHAR(512),
            @lcCadena VARCHAR(512),
            @lnUnidades INT,
            @lnDecenas INT,
            @lnCentenas INT,
            @lnFraccion INT

    SELECT  @lnEntero = CAST(@Numero AS INT)
            , @lnFraccion = (@Numero - @lnEntero) * 100
            , @lcRetorno = ''
            , @lnTerna = 1

  WHILE @lnEntero > 0
    BEGIN 
      -- Recorro terna por terna
      SELECT @lcCadena = ''
      SELECT @lnUnidades = @lnEntero % 10
      SELECT @lnEntero = CAST(@lnEntero/10 AS INT)
      SELECT @lnDecenas = @lnEntero % 10
      SELECT @lnEntero = CAST(@lnEntero/10 AS INT)
      SELECT @lnCentenas = @lnEntero % 10
      SELECT @lnEntero = CAST(@lnEntero/10 AS INT)

      -- Analizo las unidades
      SELECT @lcCadena = CASE /* UNIDADES */
                              WHEN @lnUnidades = 1 THEN 'UN ' + @lcCadena
                              WHEN @lnUnidades = 2 THEN 'DOS ' + @lcCadena
                              WHEN @lnUnidades = 3 THEN 'TRES ' + @lcCadena
                              WHEN @lnUnidades = 4 THEN 'CUATRO ' + @lcCadena
                              WHEN @lnUnidades = 5 THEN 'CINCO ' + @lcCadena
                              WHEN @lnUnidades = 6 THEN 'SEIS ' + @lcCadena
                              WHEN @lnUnidades = 7 THEN 'SIETE ' + @lcCadena
                              WHEN @lnUnidades = 8 THEN 'OCHO ' + @lcCadena
                              WHEN @lnUnidades = 9 THEN 'NUEVE ' + @lcCadena
                              ELSE @lcCadena
                         END /* UNIDADES */

      -- Analizo las decenas
      SELECT @lcCadena = CASE /* DECENAS */
                              WHEN @lnDecenas = 1 THEN
                                   CASE @lnUnidades
                                        WHEN 0 THEN 'DIEZ '
                                        WHEN 1 THEN 'ONCE '
                                        WHEN 2 THEN 'DOCE '
                                        WHEN 3 THEN 'TRECE '
                                        WHEN 4 THEN 'CATORCE '
                                        WHEN 5 THEN 'QUINCE '
                                        WHEN 6 THEN 'DIEZ Y SEIS '
                                        WHEN 7 THEN 'DIEZ Y SIETE '
                                        WHEN 8 THEN 'DIEZ Y OCHO '
                                        WHEN 9 THEN 'DIEZ Y NUEVE '
                                   END

                              WHEN @lnDecenas = 2 THEN
                                   CASE @lnUnidades
                                        WHEN 0 THEN 'VEINTE '
                                               ELSE 'VEINTI' + @lcCadena
                                   END

                              WHEN @lnDecenas = 3 THEN
                                   CASE @lnUnidades
                                        WHEN 0 THEN 'TREINTA '
                                               ELSE 'TREINTA Y ' + @lcCadena
                                   END

                              WHEN @lnDecenas = 4 THEN
                                   CASE @lnUnidades
                                        WHEN 0 THEN 'CUARENTA'
                                               ELSE 'CUARENTA Y ' + @lcCadena
                                   END

                              WHEN @lnDecenas = 5 THEN
                                   CASE @lnUnidades
                                        WHEN 0 THEN 'CINCUENTA '
                                        ELSE 'CINCUENTA Y ' + @lcCadena
                                   END

                              WHEN @lnDecenas = 6 THEN
                                   CASE @lnUnidades
                                        WHEN 0 THEN 'SESENTA '
                                               ELSE 'SESENTA Y ' + @lcCadena
                                   END
              WHEN @lnDecenas = 7 THEN
                 CASE @lnUnidades
                    WHEN 0 THEN 'SETENTA '
                    ELSE 'SETENTA Y ' + @lcCadena
                 END
              WHEN @lnDecenas = 8 THEN
                CASE @lnUnidades
                    WHEN 0 THEN 'OCHENTA '
                    ELSE  'OCHENTA Y ' + @lcCadena
                END
              WHEN @lnDecenas = 9 THEN
                CASE @lnUnidades
                    WHEN 0 THEN 'NOVENTA '
                    ELSE 'NOVENTA Y ' + @lcCadena
                END
              ELSE @lcCadena
            END /* DECENAS */
            -- Analizo las centenas
            SELECT @lcCadena =
            CASE /* CENTENAS */
              WHEN @lnCentenas = 1 THEN 'CIENTO ' + @lcCadena
              WHEN @lnCentenas = 2 THEN 'DOSCIENTOS ' + @lcCadena
              WHEN @lnCentenas = 3 THEN 'TRESCIENTOS ' + @lcCadena
              WHEN @lnCentenas = 4 THEN 'CUATROCIENTOS ' + @lcCadena
              WHEN @lnCentenas = 5 THEN 'QUINIENTOS ' + @lcCadena
              WHEN @lnCentenas = 6 THEN 'SEISCIENTOS ' + @lcCadena
              WHEN @lnCentenas = 7 THEN 'SETECIENTOS ' + @lcCadena
              WHEN @lnCentenas = 8 THEN 'OCHOCIENTOS ' + @lcCadena
              WHEN @lnCentenas = 9 THEN 'NOVECIENTOS ' + @lcCadena
              ELSE @lcCadena
            END /* CENTENAS */
            -- Analizo la terna
            SELECT @lcCadena =
            CASE /* TERNA */
              WHEN @lnTerna = 1 THEN @lcCadena
              WHEN @lnTerna = 2 THEN @lcCadena + 'MIL '
              WHEN @lnTerna = 3 THEN @lcCadena + 'MILLONES '
              WHEN @lnTerna = 4 THEN @lcCadena + 'MIL '
              ELSE ''
            END /* TERNA */
            -- Armo el retorno terna a terna
            SELECT @lcRetorno = @lcCadena  + @lcRetorno
            SELECT @lnTerna = @lnTerna + 1
   END /* WHILE */
   IF @lnTerna = 1
       SELECT @lcRetorno = 'CERO'
   DECLARE @sFraccion VARCHAR(15)
   SET @sFraccion = '00' + LTRIM(CAST(@lnFraccion AS varchar))
   SELECT @ImpLetra = RTRIM(@lcRetorno) + ' PESOS ' + SUBSTRING(@sFraccion,LEN(@sFraccion)-1,2) + '/100 M.N.'

   RETURN @ImpLetra
END
GO

/**************************************************************************************************
 * Name          : LlenaAusentismoBimestre
 * Project       : APSI Nomina
 * Description   : Llena tabla con los ausentismos del bimestre
 * Table name    : empresa, empleados, deducciones
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'LlenaAusentismoBimestre' ) 
    BEGIN
        DROP  FUNCTION [dbo].[LlenaAusentismoBimestre]
    END
GO

CREATE FUNCTION [dbo].[LlenaAusentismoBimestre]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8),
	  @filtroInfonavit INT    -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
    )
RETURNS @cedulaBimestral TABLE
    (
      diastr INT NOT NULL
                 DEFAULT 0 ,
      incap INT NOT NULL
                DEFAULT 0 ,
      ausen FLOAT NOT NULL
                  DEFAULT 0 ,
      campo VARCHAR(50) COLLATE database_default,
      valor INT ,
      lic INT NOT NULL
                DEFAULT 0 
    )
AS 
    BEGIN
        DECLARE @diastr INT
        DECLARE @incap INT
        DECLARE @ausen INT
		DECLARE @lic INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @FechaFinita DATETIME

        SET @FechaFinita = '29991231'

        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

       
        INSERT  @cedulaBimestral
                ( diastr ,
                  incap ,
                  ausen ,
				  lic
                )
                SELECT  SUM(aItc.diastr) AS diasTr ,
                        SUM(aItc.incap - aItc.lic) AS incap ,
                        SUM(aItc.ausen) AS ausen ,
                        SUM(aItc.lic) AS lic 
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        --INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa AND dbo.empleados.codigo = dbo.Llaves.codigo
                        --INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                            AND dbo.empleados.codigo = aItc.codigo
                        --LEFT JOIN dbo.TemporalAmortizacion ON dbo.avisos_imss.empresa = dbo.TemporalAmortizacion.empresa AND dbo.avisos_imss.codigo = dbo.TemporalAmortizacion.codigo

                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = dbo.empleados.empresa
				                           AND i.codigo = dbo.empleados.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                WHERE   aItc.mes_operacion >= @mesNon 
                        AND aItc.mes_operacion <= @mesPar 
                        AND aItc.ayo_operacion = @ayo 
                        AND dbo.empleados.cotiza_imss = 'S' 
                        AND dbo.empleados.borrado = 'N' 
                        AND aItc.empresa >= CASE WHEN @empresa = 0 
                                                 THEN 0 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.empresa <= CASE WHEN @empresa = 0 
                                                 THEN 9999 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.codigo >= CASE WHEN @codigo = 0 
                                                THEN 0 
                                                ELSE @codigo 
                                           END 
                        AND aItc.codigo <= CASE WHEN @codigo = 0 
                                                THEN 99999999 
                                                ELSE @codigo 
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

                GROUP BY dbo.empleados.empresa --, dbo.Llaves.clase
                
        IF @porRenglon = 0
           BEGIN
             SELECT @diastr = cedulaBimestre.diastr ,
                    @incap = cedulaBimestre.incap ,
                    @ausen = cedulaBimestre.ausen ,
					@lic = cedulaBimestre.lic
             FROM @cedulaBimestral AS cedulaBimestre

             --INSERT @cedulaBimestral (campo, valor) VALUES ('Das Cotizados', @diastr)
             INSERT @cedulaBimestral (campo, valor) VALUES ('Incapacidades', @incap)
             INSERT @cedulaBimestral (campo, valor) VALUES ('Faltas', @ausen)
             INSERT @cedulaBimestral (campo, valor) VALUES ('Licencias Artculo 140 bis', @lic)
            
             DELETE cedulaBimestre FROM @cedulaBimestral AS cedulaBimestre WHERE cedulaBimestre.campo IS NULL
          END
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaAusentismoMes
 * Project       : APSI Nomina
 * Description   : Suma las faltas  y las incapacidades del mes seleccionado
 * Table name    : avisos_imss
 * Return        : Tabla con el total de faltas e incapacidades
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Septiembre 14, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'LlenaAusentismoMes' ) 
    BEGIN
        DROP  FUNCTION [dbo].[LlenaAusentismoMes]
    END
GO

CREATE FUNCTION [dbo].[LlenaAusentismoMes](
@empresa NUMERIC(5),
@codigo NUMERIC(8, 0),
@ayo INT,
@mes INT,
@porRenglon INT,
@proceso VARCHAR(250),
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8)
)

RETURNS @cedulaMensual TABLE
    (
      diastr INT NULL ,
      incap INT NULL ,
      ausen INT NULL ,
      campo VARCHAR(50) COLLATE database_default ,
      valor INT ,
	  lic INT
    )
    
AS 
    BEGIN
    
       DECLARE @diastr INT
       DECLARE @incap INT
       DECLARE @ausen INT
	   DECLARE @lic INT

       INSERT  @cedulaMensual
               ( diastr ,
                 incap ,
                 ausen ,
				 lic
                )
               SELECT  SUM(aItc.diastr) ,
                       SUM(aItc.incap - aItc.lic) ,
                       SUM(aItc.ausen) ,
					   SUM(aItc.lic )
               FROM    ( ( dbo.empresas
                           INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                          )
                          LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                                      AND conceptomarca.num_conc = 101
                       )
                       INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                           AND dbo.empleados.codigo = aItc.codigo
               WHERE   MONTH(aItc.fch_mov) = @mes
                       AND YEAR(aItc.fch_mov) = @ayo
                       AND aItc.empresa >= CASE WHEN @empresa = 0
                                                THEN 0
                                                ELSE @empresa
                                           END
                       AND aItc.empresa <= CASE WHEN @empresa = 0
                                                THEN 9999
                                                ELSE @empresa
                                           END
                       AND dbo.empleados.cotiza_imss = 'S'
                       AND conceptomarca.num_conc = 101
                       AND dbo.empleados.borrado = 'N'
                       AND aItc.codigo >= CASE WHEN @codigo = 0
                                               THEN 0
                                               ELSE @codigo
                                          END
                       AND aItc.codigo <= CASE WHEN @codigo = 0
                                               THEN 99999999
                                               ELSE @codigo
                                          END
                       AND aItc.horaProceso = @horaProceso
                       AND aItc.fechaProceso = @fechaProceso
                       AND aItc.proceso = @proceso
               GROUP BY dbo.empresas.empresa
       
       
       IF @porRenglon = 0
          BEGIN
            SELECT @diastr = cedulaMes.diastr ,
                   @incap = cedulaMes.incap ,
                   @ausen = cedulaMes. ausen ,
				   @lic = cedulaMes.lic
            FROM @cedulaMensual as cedulaMes

            --INSERT @cedulaMensual (campo, valor) VALUES ('Das Cotizados', @diastr)
            INSERT @cedulaMensual (campo, valor) VALUES ('Incapacidades', @incap)
            INSERT @cedulaMensual (campo, valor) VALUES ('Faltas', @ausen)
            INSERT @cedulaMensual (campo, valor) VALUES ('Licencias Artculo 140 bis', @lic)
            
            DELETE cedulaMes FROM @cedulaMensual AS cedulaMes WHERE cedulaMes.campo IS NULL
          END
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaCasosRT
 * Project       : APSI Nomina
 * Description   : Prepara tabla para imprimir los casos de RT
 * Table name    : Casos_rt
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Junio 22, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'LlenaCasosRT' ) 
    BEGIN
        DROP  FUNCTION [dbo].[LlenaCasosRT]
    END
GO

CREATE FUNCTION [dbo].[LlenaCasosRT]
    (
      @empresa NUMERIC(5) ,
      @ayo INT
    )
RETURNS @casosRT TABLE
    (
      tipo INT NULL ,
      folio INT NULL ,
      codigo INT NULL ,
      nombre VARCHAR(50) NULL ,
      ap_paterno VARCHAR(50) NULL ,
      ap_materno VARCHAR(50) NULL ,
      caso INT NULL ,
      ayo_operacion INT NULL ,
      st1_accidente VARCHAR(10) NULL ,
      st1_trayecto CHAR(1) NULL ,
      st1_fecha DATETIME NULL ,
      st2_accidente VARCHAR(10) NULL ,
      st2_fecha DATETIME NULL ,
      st3_accidente VARCHAR(9) NULL ,
      st3_valuacion INT NULL ,
      fechaIncapaciad DATETIME NULL ,
      diasIncapacidad INT NULL ,
      numeroIncapacidad VARCHAR(8) NULL ,
      sec_conIncapacidad VARCHAR(33) NULL ,
      ctr_incIncapacidad VARCHAR(18) NULL ,
      tipo_rtIncapacidad VARCHAR(22) NULL ,
      cuentaCaso INT NULL ,
      cuentaEmpleado INT NULL
    )
AS 
    BEGIN
    
        /*
        INSERT  @casosRT
                ( tipo ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  caso ,
                  ayo_operacion 
                )
                SELECT  1 ,
                        dbo.casos_rt.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.casos_rt.caso ,
                        dbo.casos_rt.ayo_operacion
                FROM    dbo.casos_rt
                        INNER JOIN dbo.empleados ON dbo.casos_rt.empresa = dbo.empleados.empresa
                                                    AND dbo.casos_rt.codigo = dbo.empleados.codigo
                WHERE   dbo.casos_rt.caso > 0
                        AND dbo.casos_rt.empresa = @empresa
                        AND dbo.casos_rt.ayo_operacion = @ayo
                ORDER BY dbo.casos_rt.codigo ,
                        dbo.casos_rt.st1_fecha ASC 


    
        INSERT  @casosRT
                ( tipo ,
                  codigo ,
                  caso ,
                  ayo_operacion ,
                  st1_accidente ,
                  st1_trayecto ,
                  st1_fecha ,
                  st2_accidente ,
                  st2_fecha ,
                  st3_accidente ,
                  st3_valuacion ,
                  fechaIncapaciad ,
                  diasIncapacidad ,
                  numeroIncapacidad ,
                  sec_conIncapacidad ,
                  ctr_incIncapacidad ,
                  tipo_rtIncapacidad 
                )
                SELECT  2 ,
                        dbo.casos_rt.codigo ,
                        dbo.casos_rt.caso ,
                        dbo.casos_rt.ayo_operacion ,
                        CASE WHEN dbo.casos_rt.st1_accidente = 1
                             THEN 'Acc. Trab.'
                             WHEN dbo.casos_rt.st1_accidente = 2
                             THEN 'Recaida'
                             ELSE ' '
                        END AS st1_accidente ,
                        dbo.casos_rt.st1_trayecto ,
                        dbo.casos_rt.st1_fecha ,
                        CASE WHEN dbo.casos_rt.st2_accidente = 1
                             THEN 'Acc. Trab.'
                             WHEN dbo.casos_rt.st2_accidente = 2
                             THEN 'Enf. Prof.'
                             ELSE ' '
                        END AS st2_accidente ,
                        dbo.casos_rt.st2_fecha ,
                        CASE WHEN dbo.casos_rt.st3_accidente = 1
                             THEN 'SIN ST3'
                             WHEN dbo.casos_rt.st3_accidente = 2 THEN 'IPP'
                             WHEN dbo.casos_rt.st3_accidente = 3 THEN 'IPT'
                             WHEN dbo.casos_rt.st3_accidente = 3 THEN 'DEF.'
                             ELSE ' '
                        END AS st3_accidente ,
                        dbo.casos_rt.st3_valuacion,
                        dbo.incapacidades_rt.fecha ,
                        dbo.incapacidades_rt.dias ,
                        dbo.incapacidades_rt.numeroinc ,
                        CASE WHEN incapacidades_rt.sec_con = 0 THEN 'Ninguna'
                             WHEN incapacidades_rt.sec_con = 1
                             THEN 'Incapacidad Temporal'
                             WHEN incapacidades_rt.sec_con = 2
                             THEN 'Valuacion Inicial Provisional'
                             WHEN incapacidades_rt.sec_con = 3
                             THEN 'Valuacion Inicial Definitiva'
                             WHEN incapacidades_rt.sec_con = 4
                             THEN 'Defuncion'
                             WHEN incapacidades_rt.sec_con = 5 THEN 'Recaida'
                             WHEN incapacidades_rt.sec_con = 6
                             THEN 'Valuacion Post. Al a Fecha de Alta'
                             WHEN incapacidades_rt.sec_con = 7
                             THEN 'Revaluacion Provisional'
                             WHEN incapacidades_rt.sec_con = 8
                             THEN 'Recaida sin alta medica'
                             WHEN incapacidades_rt.sec_con = 9
                             THEN 'Revaluacion definitiva'
                             ELSE ' '
                        END AS sec_con ,
                        CASE WHEN incapacidades_rt.sec_con = 0
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 1
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       WHEN incapacidades_rt.ctr_inc = 1
                                       THEN 'Unica'
                                       WHEN incapacidades_rt.ctr_inc = 2
                                       THEN 'Inicial'
                                       WHEN incapacidades_rt.ctr_inc = 3
                                       THEN 'Subsecuente'
                                       WHEN incapacidades_rt.ctr_inc = 4
                                       THEN 'Alta Medica o ST-2'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 2
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 3
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 4
                             THEN 'Defuncion o ST-3'
                             WHEN incapacidades_rt.sec_con = 5
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       WHEN incapacidades_rt.ctr_inc = 1
                                       THEN 'Unica'
                                       WHEN incapacidades_rt.ctr_inc = 2
                                       THEN 'Inicial'
                                       WHEN incapacidades_rt.ctr_inc = 3
                                       THEN 'Subsecuente'
                                       WHEN incapacidades_rt.ctr_inc = 4
                                       THEN 'Alta Medica o ST-2'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 6
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 7
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 8
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       WHEN incapacidades_rt.ctr_inc = 1
                                       THEN 'Unica'
                                       WHEN incapacidades_rt.ctr_inc = 2
                                       THEN 'Inicial'
                                       WHEN incapacidades_rt.ctr_inc = 3
                                       THEN 'Subsecuente'
                                       WHEN incapacidades_rt.ctr_inc = 4
                                       THEN 'Alta Medica o ST-2'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 9
                             THEN 'Valuacion o ST-3'
                             ELSE ' '
                        END AS ctr_inc ,
                        CASE WHEN incapacidades_rt.tipo_rt = 1
                             THEN 'Accidente de Trabajo'
                             WHEN incapacidades_rt.tipo_rt = 2
                             THEN 'Accidente de Trayecto'
                             WHEN incapacidades_rt.tipo_rt = 3
                             THEN 'Enfermedad Profesional'
                             ELSE ' '
                        END AS tipo_rt
                FROM    dbo.casos_rt
                        INNER JOIN dbo.incapacidades_rt ON dbo.casos_rt.empresa = dbo.incapacidades_rt.empresa
                                                           AND dbo.casos_rt.codigo = dbo.incapacidades_rt.codigo
                                                           AND dbo.casos_rt.caso = dbo.incapacidades_rt.caso
                                                           AND dbo.casos_rt.ayo_operacion = dbo.incapacidades_rt.ayo_operacion
                WHERE   dbo.casos_rt.caso > 0
                        AND dbo.casos_rt.empresa = @empresa
                        AND dbo.casos_rt.ayo_operacion = @ayo
                ORDER BY dbo.casos_rt.codigo ,
                        dbo.casos_rt.st1_fecha ASC ,
                        dbo.incapacidades_rt.fecha DESC  
        */                 





        INSERT  @casosRT
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  caso ,
                  ayo_operacion ,
                  st1_accidente ,
                  st1_trayecto ,
                  st1_fecha ,
                  st2_accidente ,
                  st2_fecha ,
                  st3_accidente ,
                  st3_valuacion ,
                  fechaIncapaciad ,
                  diasIncapacidad ,
                  numeroIncapacidad ,
                  sec_conIncapacidad ,
                  ctr_incIncapacidad ,
                  tipo_rtIncapacidad 
                )
                SELECT  dbo.casos_rt.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.casos_rt.caso ,
                        dbo.casos_rt.ayo_operacion ,
                        CASE WHEN dbo.casos_rt.st1_accidente = 1
                             THEN 'Acc. Trab.'
                             WHEN dbo.casos_rt.st1_accidente = 2
                             THEN 'Recaida'
                             ELSE ' '
                        END AS st1_accidente ,
                        dbo.casos_rt.st1_trayecto ,
                        dbo.casos_rt.st1_fecha ,
                        CASE WHEN dbo.casos_rt.st2_accidente = 1
                             THEN 'Acc. Trab.'
                             WHEN dbo.casos_rt.st2_accidente = 2
                             THEN 'Enf. Prof.'
                             ELSE ' '
                        END AS st2_accidente ,
                        dbo.casos_rt.st2_fecha ,
                        CASE WHEN dbo.casos_rt.st3_accidente = 1
                             THEN 'SIN ST3'
                             WHEN dbo.casos_rt.st3_accidente = 2 THEN 'IPP'
                             WHEN dbo.casos_rt.st3_accidente = 3 THEN 'IPT'
                             WHEN dbo.casos_rt.st3_accidente = 4
                             THEN 'DEFUNCION'
                             ELSE ' '
                        END AS st3_accidente ,
                        dbo.casos_rt.st3_valuacion ,
                        dbo.incapacidades_rt.fecha ,
                        dbo.incapacidades_rt.dias ,
                        dbo.incapacidades_rt.numeroinc ,
                        CASE WHEN incapacidades_rt.sec_con = 0 THEN 'Ninguna'
                             WHEN incapacidades_rt.sec_con = 1
                             THEN 'Incapacidad Temporal'
                             WHEN incapacidades_rt.sec_con = 2
                             THEN 'Valuacion Inicial Provisional'
                             WHEN incapacidades_rt.sec_con = 3
                             THEN 'Valuacion Inicial Definitiva'
                             WHEN incapacidades_rt.sec_con = 4
                             THEN 'Defuncion'
                             WHEN incapacidades_rt.sec_con = 5 THEN 'Recaida'
                             WHEN incapacidades_rt.sec_con = 6
                             THEN 'Valuacion Post. Ala Fecha de Alta'
                             WHEN incapacidades_rt.sec_con = 7
                             THEN 'Revaluacion Provisional'
                             WHEN incapacidades_rt.sec_con = 8
                             THEN 'Recaida sin alta medica'
                             WHEN incapacidades_rt.sec_con = 9
                             THEN 'Revaluacion definitiva'
                             ELSE ' '
                        END AS sec_con ,
                        CASE WHEN incapacidades_rt.sec_con = 0
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 1
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       WHEN incapacidades_rt.ctr_inc = 1
                                       THEN 'Unica'
                                       WHEN incapacidades_rt.ctr_inc = 2
                                       THEN 'Inicial'
                                       WHEN incapacidades_rt.ctr_inc = 3
                                       THEN 'Subsecuente'
                                       WHEN incapacidades_rt.ctr_inc = 4
                                       THEN 'Alta Medica o ST-2'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 2
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 3
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 4
                             THEN 'Defuncion o ST-3'
                             WHEN incapacidades_rt.sec_con = 5
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       WHEN incapacidades_rt.ctr_inc = 1
                                       THEN 'Unica'
                                       WHEN incapacidades_rt.ctr_inc = 2
                                       THEN 'Inicial'
                                       WHEN incapacidades_rt.ctr_inc = 3
                                       THEN 'Subsecuente'
                                       WHEN incapacidades_rt.ctr_inc = 4
                                       THEN 'Alta Medica o ST-2'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 6
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 7
                             THEN 'Valuacion o ST-3'
                             WHEN incapacidades_rt.sec_con = 8
                             THEN CASE WHEN incapacidades_rt.ctr_inc = 0
                                       THEN 'Ninguna'
                                       WHEN incapacidades_rt.ctr_inc = 1
                                       THEN 'Unica'
                                       WHEN incapacidades_rt.ctr_inc = 2
                                       THEN 'Inicial'
                                       WHEN incapacidades_rt.ctr_inc = 3
                                       THEN 'Subsecuente'
                                       WHEN incapacidades_rt.ctr_inc = 4
                                       THEN 'Alta Medica o ST-2'
                                       ELSE ' '
                                  END
                             WHEN incapacidades_rt.sec_con = 9
                             THEN 'Valuacion o ST-3'
                             ELSE ' '
                        END AS ctr_inc ,
                        CASE WHEN incapacidades_rt.tipo_rt = 1
                             THEN 'Accidente de Trabajo'
                             WHEN incapacidades_rt.tipo_rt = 2
                             THEN 'Accidente de Trayecto'
                             WHEN incapacidades_rt.tipo_rt = 3
                             THEN 'Enfermedad Profesional'
                             ELSE ' '
                        END AS tipo_rt
                FROM    dbo.casos_rt
                        INNER JOIN dbo.empleados ON dbo.casos_rt.empresa = dbo.empleados.empresa
                                                    AND dbo.casos_rt.codigo = dbo.empleados.codigo
                        INNER JOIN dbo.incapacidades_rt ON dbo.casos_rt.empresa = dbo.incapacidades_rt.empresa
                                                           AND dbo.casos_rt.codigo = dbo.incapacidades_rt.codigo
                                                           AND dbo.casos_rt.caso = dbo.incapacidades_rt.caso
                                                           AND dbo.casos_rt.ayo_operacion = dbo.incapacidades_rt.ayo_operacion
                WHERE   --dbo.casos_rt.caso > 0 AND 
                        dbo.casos_rt.empresa = @empresa
                        AND dbo.casos_rt.ayo_operacion = @ayo
                ORDER BY dbo.casos_rt.codigo ,
                        dbo.casos_rt.st1_fecha ASC ,
                        dbo.incapacidades_rt.fecha DESC  
                        
                        
        DECLARE @folio INT
        DECLARE @folioAnterior VARCHAR(20)
        DECLARE @codigoAnterior INT
        DECLARE @folioCodigo INT

        SET @folio = 0
        SET @folioAnterior = ' ' 
        SET @codigoAnterior = 0
        SET @folioCodigo = 0

        UPDATE  @casosRT
        SET     @folio = CASE WHEN @folioAnterior <> STR(codigo) + STR(caso)
                              THEN 0
                              ELSE @folio
                         END ,
                @folio = @folio + 1 ,
                @folioCodigo = CASE WHEN @codigoAnterior <> codigo THEN 1 ELSE 0 END,
                --@folioCodigo = @folioCodigo + 1
                nombre = CASE WHEN @folio = 1 THEN nombre
                              ELSE NULL
                         END ,
                ap_paterno = CASE WHEN @folio = 1 THEN ap_paterno
                                  ELSE NULL
                             END ,
                ap_materno = CASE WHEN @folio = 1 THEN ap_materno
                                  ELSE NULL
                             END ,
                ayo_operacion = CASE WHEN @folio = 1 THEN ayo_operacion
                                     ELSE NULL
                                END ,
                st1_accidente = CASE WHEN @folio = 1 THEN st1_accidente
                                     ELSE NULL
                                END ,
                st1_trayecto = CASE WHEN @folio = 1 THEN st1_trayecto
                                    ELSE NULL
                               END ,
                st1_fecha = CASE WHEN @folio = 1 THEN st1_fecha
                                 ELSE NULL
                            END ,
                st2_accidente = CASE WHEN @folio = 1 THEN st2_accidente
                                     ELSE NULL
                                END ,
                st2_fecha = CASE WHEN @folio = 1 THEN st2_fecha
                                 ELSE NULL
                            END ,
                st3_accidente = CASE WHEN @folio = 1 THEN st3_accidente
                                     ELSE NULL
                                END ,
                st3_valuacion = CASE WHEN @folio = 1 THEN st3_valuacion
                                     ELSE NULL
                                END ,
                cuentaCaso = CASE WHEN @folio = 1 THEN 1
                                  ELSE 0
                             END ,
                cuentaEmpleado = @folioCodigo ,
                folio = @folio ,
                @folioAnterior = STR(codigo) + STR(caso) ,
                @codigoAnterior = codigo
                
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaCedulaBimestral
 * Project       : APSI Nomina
 * Description   : Calcula y llena la tabla de salida de la cedula bimestral
 * Table name    : empresa, primas_imss, empleados, deducciones, infonavit
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Marzo 17, 2010
 **************************************************************************************************/

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'TF'
--                    AND name = 'LlenaCedulaBimestral' )
--    BEGIN
--        DROP  FUNCTION [dbo].[LlenaCedulaBimestral]
--    END
IF OBJECT_ID('dbo.LlenaCedulaBimestral') IS NOT NULL
   DROP FUNCTION dbo.LlenaCedulaBimestral
GO
CREATE FUNCTION [dbo].[LlenaCedulaBimestral]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT      
    )
RETURNS @cedulaBimestral TABLE
    (
      empresa INT NOT NULL
                  DEFAULT 0 ,
      codigo INT NOT NULL
                 DEFAULT 0 ,
      nombre VARCHAR(30) NOT NULL
                         DEFAULT 0 ,
      ap_paterno VARCHAR(30) NOT NULL
                             DEFAULT 0 ,
      ap_materno VARCHAR(30) NULL ,
      afiliacion VARCHAR(10) NULL ,
      digvera CHAR(1) NULL ,
      curp VARCHAR(18) NULL ,
      rfcalfa VARCHAR(4) NULL ,
      rfcnum CHAR(6) NULL ,
      rfchomo VARCHAR(3) NULL ,
      serial INT NOT NULL
                 DEFAULT 0 ,
      fch_mov DATETIME NULL ,
      mov VARCHAR(3) NULL ,
      saldiaint FLOAT NOT NULL
                      DEFAULT 0 ,
      diastr INT NOT NULL
                 DEFAULT 0 ,
      incap INT NOT NULL
                DEFAULT 0 ,
      ausen FLOAT NOT NULL
                  DEFAULT 0 ,
      retiro FLOAT NOT NULL
                   DEFAULT 0 ,
      cesantiaVejez FLOAT NOT NULL
                          DEFAULT 0 ,
      cesantiaVejezPatron FLOAT NOT NULL
                                DEFAULT 0 ,
      cesantiaVejezTrabajador FLOAT NOT NULL
                                    DEFAULT 0 ,
      aportacionInfonavit FLOAT, -- NOT NULL DEFAULT 0 ,
      numeroCredito CHAR(10) ,
      descuento FLOAT ,
      amortizacion FLOAT, -- NOT NULL DEFAULT 0 ,
      tipoCredito INT, -- NOT NULL DEFAULT 0 ,
      seguroVivienda FLOAT, -- NOT NULL DEFAULT 0 ,
      fechaInicioDescuento DATETIME ,
      fechaOtorgamiento DATETIME ,
      fechaSuspension DATETIME ,
      ntd INT ,
      info INT ,
      tipo INT NOT NULL DEFAULT 0 ,
      mes INT NOT NULL DEFAULT 0 ,
      infonavitSinCredito FLOAT, -- NOT NULL DEFAULT 0 ,
      infonavitConCredito FLOAT, -- NOT NULL DEFAULT 0 ,
      salarioDF FLOAT ,
      salarioRegion FLOAT ,
      sumaRCV FLOAT ,
      sumaAportacionInfoanvit FLOAT ,
      sumaAportacionInfonavitSinCredito FLOAT ,
      sumaAportacionInfonavitConCredito FLOAT ,
      sumaAmortizacion FLOAT ,
      cuentaEmpleado INT ,
      consecutivo INT IDENTITY ,
      pensionEmpleado VARCHAR(4) ,
      jornadaEmpleado VARCHAR(3) ,
      articulo33Empleado VARCHAR(6) ,
      sumaAmortizacionMasSeguro FLOAT ,
      sumaTotalInfonavit FLOAT ,
      sumaTotal FLOAT ,
      acreditado INT ,
      centro VARCHAR(15) ,
      centroNombre VARCHAR(30) ,
      rpu VARCHAR(3),
      tipoNomina INT,
      manoObra CHAR(1) ,
      seguroDesempleo FLOAT,
      noAcreditado INT
    )
AS
    BEGIN

        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        --DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @rpu CHAR(1)
        DECLARE @seguroDesempleo FLOAT

        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE
            BEGIN
                SET @esBimestre = 'N'
            END


-- Obtiene Area Geografica
        SELECT  @areaGeografica = empresa.zona_geografica ,
                --@patronPagaIMSS = empresa.patron_paga_cuotas_imss ,
                @ayoEmpresa = empresa.ayo_operacion ,
                @rpu = ISNULL(empresa.Rpu, 'N') 
        FROM    dbo.empresas AS empresa
        WHERE   empresa.empresa = @empresa

-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
                @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
                @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo

        SET @salarioDF = @salarioRegionA

        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END

        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion


-- Obtiene Primas IMSS
        SELECT  @retiro = primasImss.cvArt168I , --primasImss.retiro ,
                @cvArt168II = primasImss.cvArt168II ,
                @cvPat168II = primasImss.cvPat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
                @cvTra168II = primasImss.cvTra168ii, --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
                @infonavit = primasImss.infonavitPorciento ,
                @seguroDesempleo = ISNULL(primasImss.seguroDesempleoPorciento,0)
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss AS primasImss
        --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END



-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN concepto.hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN concepto.marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = concepto.variable1
        FROM    dbo.conceptos AS concepto
        WHERE   concepto.empresa = @empresa
                AND concepto.num_conc = 112


-- Registro empleado
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  saldiaint ,
                  numeroCredito ,
                  tipo ,
                  salarioDF ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  DISTINCT
                        dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        ISNULL(( SELECT TOP 1
                                        aItc.saldiaint
                                 FROM   dbo.AvisosImssTemporalCalculo AS aItc
                                 WHERE  aItc.empresa = @empresa
                                        AND aItc.codigo = dbo.empleados.codigo
                                        AND aItc.ayo_operacion = @ayo
                                        AND ( aItc.mes_operacion = @mesNon
                                              OR aItc.mes_operacion = @mesPar
                                            )
                                        AND aItc.diastr > 0
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                                 ORDER BY aItc.mes_operacion ASC ,
                                        aItc.serial ASC
                               ), 0) AS saldiaint ,
                        SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000
                                        + dbo.infonavit.numcredito)), 2, 10) ,
                        1 AS tipo ,
                        @salarioDF AS salarioDF ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        LEFT JOIN dbo.infonavit ON dbo.empleados.empresa = dbo.infonavit.empresa
                                                   AND dbo.empleados.codigo = dbo.infonavit.codigo
                WHERE   aItc.mes_operacion >= @mesNon
                        AND aItc.mes_operacion <= @mesPar
                        AND aItc.ayo_operacion = @ayo
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso


-- Registro Avisos
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  serial ,
                  fch_mov ,
                  mov ,
                  saldiaint ,
                  diastr ,
                  incap ,
                  ausen ,
                  retiro ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  aportacionInfonavit ,
                  amortizacion ,
                  mes ,
                  tipo ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra ,
                  seguroDesempleo
                )
                SELECT  dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        aItc.serial ,
                        aItc.fch_mov ,
                        CASE aItc.mov
                          WHEN 'IM' THEN ' '
                          WHEN 'RI' THEN 'R'
                          WHEN 'MS' THEN 'M/S'
                          ELSE aItc.mov
                        END AS mov ,
                        [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                @topeDF, @topeRegion,
                                                dbo.empleados.art39,
                                                aItc.mov) AS salario ,
                        aItc.diastr ,
                        aItc.incap ,
                        aItc.ausen ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @retiro, 0) AS retiro ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @infonavit, 0) AS aportacionInfonavit ,
                        0 AS amortizacion , 
                        aItc.mes_operacion ,
                        2 AS tipo ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @seguroDesempleo, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @seguroDesempleo, 0) AS seguroDesempleo
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                WHERE   aItc.mes_operacion >= @mesNon
                        AND aItc.mes_operacion <= @mesPar
                        AND aItc.ayo_operacion = @ayo
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND (
                             (aItc.mov = 'IM' AND aItc.diastr > 0)
                             OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                            )

        IF @esBimestre = 'S'
            BEGIN
                DELETE  cedulaBimestral
                FROM    @cedulaBimestral AS cedulaBimestral
                WHERE   cedulaBimestral.mov = 'IM'
                        OR cedulaBimestral.mov = ' '
                        AND MONTH(cedulaBimestral.fch_mov) = @mesPar
                        AND cedulaBimestral.diastr = 0
            END

                -- Registro Amortizacion
/*                
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  numeroCredito ,
                  descuento ,
                  tipoCredito ,
                  fechaInicioDescuento ,
                  fechaOtorgamiento ,
                  fechaSuspension ,
                  amortizacion ,
                  seguroVivienda ,
                  tipo ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  cedulaBimestre.empresa ,
                        cedulaBimestre.codigo ,
                        cedulaBimestre.nombre ,
                        cedulaBimestre.ap_paterno ,
                        cedulaBimestre.ap_materno ,
                        SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000
                                        + dbo.infonavit.numcredito)), 2, 10) ,
                        dbo.TemporalAmortizacion.descuento ,  
                        dbo.infonavit.tipo_cred ,
                        dbo.infonavit.fecha ,
                        dbo.infonavit.fch_otorga ,
                        dbo.infonavit.fch_termino ,
                        ISNULL(dbo.temporalAmortizacion.amortizacion, 0) ,   
                        0 AS seguroVivienda ,
                        3 ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    @cedulaBimestral AS cedulaBimestre
                        LEFT JOIN dbo.temporalAmortizacion ON cedulaBimestre.empresa = dbo.temporalAmortizacion.empresa
                                                              AND cedulaBimestre.codigo = dbo.temporalAmortizacion.codigo
                        INNER JOIN dbo.Llaves ON dbo.TemporalAmortizacion.empresa = dbo.Llaves.empresa
                                                 AND dbo.TemporalAmortizacion.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.infonavit ON dbo.temporalAmortizacion.empresa = dbo.infonavit.empresa
                                                    AND dbo.temporalAmortizacion.codigo = dbo.infonavit.codigo
                        INNER JOIN dbo.empleados ON cedulaBimestre.empresa = dbo.empleados.empresa AND cedulaBimestre.codigo = dbo.empleados.codigo
                WHERE   cedulaBimestre.tipo = 1
                        AND dbo.infonavit.fecha <= @ffPar
                        AND dbo.infonavit.fch_termino >= @fiNon
*/                        

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END

        UPDATE  cedulaBimestre
        SET     cuentaEmpleado = 1
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.empresa = @empresa
                AND cedulaBimestre.codigo + cedulaBimestre.consecutivo = ( SELECT TOP 1
                                                                                  cedulaBimestre2.codigo + cedulaBimestre2.consecutivo
                                                                           FROM @cedulaBimestral AS cedulaBimestre2
                                                                           WHERE cedulaBimestre2.empresa = @empresa
                                                                                 AND cedulaBimestre2.tipo > 1
                                                                                 AND cedulaBimestre2.codigo = cedulaBimestre.codigo )
                                                                                 
        UPDATE cedula
        SET cedula.numeroCredito = SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000 + dbo.infonavit.numcredito)), 2, 10),
            cedula.descuento = dbo.TemporalAmortizacion.descuento,
            cedula.tipoCredito = dbo.infonavit.tipo_cred,
            cedula.fechaInicioDescuento = dbo.infonavit.fecha,
            cedula.fechaOtorgamiento = dbo.infonavit.fch_otorga,
            cedula.fechaSuspension = dbo.infonavit.fch_termino,
            cedula.amortizacion = ISNULL(dbo.temporalAmortizacion.amortizacion, 0),
            cedula.seguroVivienda = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda ELSE 0 END,
            --cedula.infonavitSinCredito = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) = 0 THEN cedulaMensualInfonavit.aportacionInfonavit ELSE 0 END,
            --cedula.infonavitConCredito = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN cedulaMensualInfonavit.aportacionInfonavit ELSE 0 END,
            cedula.sumaTotalinfonavit = cedulaInfonavit.aportacionInfonavit + CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda + ISNULL(dbo.temporalAmortizacion.amortizacion, 0) ELSE 0 END,
            cedula.acreditado = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN 1 ELSE 0 END,
            cedula.noAcreditado = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN 0 ELSE 1 END
        FROM @cedulaBimestral AS cedula
             LEFT JOIN dbo.temporalAmortizacion ON cedula.empresa = dbo.temporalAmortizacion.empresa
                                                   AND cedula.codigo = dbo.temporalAmortizacion.codigo
             LEFT JOIN dbo.infonavit ON dbo.temporalAmortizacion.empresa = dbo.infonavit.empresa
                                        AND temporalAmortizacion.codigo = dbo.infonavit.codigo
                                        --AND dbo.infonavit.fecha <= @ff
                                        --AND dbo.infonavit.fch_termino >= @fi
                                        AND dbo.infonavit.fecha <= @ffPar
                                        AND dbo.infonavit.fch_termino >= @fiNon
             INNER JOIN (SELECT cedulaAportacion.empresa,
                                cedulaAportacion.codigo,
                                SUM(ISNULL(cedulaAportacion.aportacionInfonavit,0)) AS aportacionInfonavit 
                         FROM @cedulaBimestral AS cedulaAportacion
                         WHERE cedulaAportacion.tipo = 2
                         GROUP BY cedulaAportacion.empresa,
                                  cedulaAportacion.codigo) AS cedulaInfonavit ON cedula.codigo = cedulaInfonavit.codigo
                                                                                AND cedula.empresa = cedulaInfonavit.empresa
        WHERE   cedula.cuentaEmpleado = 1


        UPDATE  cedulaBimestre
        SET     cedulaBimestre.infonavitSinCredito = cedulaBimestre.aportacionInfonavit
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.tipo = 2

        UPDATE  cedulaBimestre
        SET     cedulaBimestre.infonavitSinCredito = 0 ,
                cedulaBimestre.infonavitConCredito = cedulaBimestre.aportacionInfonavit
        FROM    @cedulaBimestral AS cedulaBimestre
                INNER JOIN @cedulaBimestral AS cedulaBimestreCredito ON cedulaBimestreCredito.empresa = cedulaBimestre.empresa
                                                              AND cedulaBimestreCredito.codigo = cedulaBimestre.codigo
        WHERE   cedulaBimestre.tipo = 2
                --AND cedulaBimestreCredito.tipo = 3
                AND cedulaBimestreCredito.cuentaEmpleado = 1
                AND cedulaBimestreCredito.tipoCredito >= 1
                AND cedulaBimestreCredito.tipoCredito <= 3
                AND cedulaBimestreCredito.amortizacion >= 0

        UPDATE  cedulaBimestre
        SET     cedulaBimestre.sumaRCV = cedulaBimestre.retiro
                                         + cedulaBimestre.cesantiaVejez 
                                         --+ cedulaBimestre.seguroDesempleo ,
                --cedulaBimestre.sumaAportacionInfoanvit = cedulaBimestre.aportacionInfonavit ,
                --cedulaBimestre.sumaAportacionInfonavitSinCredito = cedulaBimestre.infonavitSinCredito ,
                --cedulaBimestre.sumaAportacionInfonavitConCredito = cedulaBimestre.infonavitConCredito ,
                --cedulaBimestre.sumaTotalInfonavit = ISNULL(cedulaBimestre.aportacionInfonavit,0) ,
                --cedulaBimestre.sumaTotal = cedulaBimestre.retiro
                --                           + cedulaBimestre.cesantiaVejez
                --                           + cedulaBimestre.aportacionInfonavit
                --                           + cedulaBimestre.seguroDesempleo
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.tipo = 2
/*
        UPDATE  cedulaBimestre
        SET     cedulaBimestre.seguroVivienda = @seguroVivienda ,
                cedulaBimestre.sumaAmortizacion = cedulaBimestre.amortizacion ,
                cedulaBimestre.sumaAmortizacionMasSeguro = cedulaBimestre.amortizacion
                                                           + @seguroVivienda ,
                cedulaBimestre.sumaTotalInfonavit = @seguroVivienda
                                                    + ISNULL(cedulaBimestre.amortizacion, 0) ,
                cedulaBimestre.sumaTotal = @seguroVivienda
                                           + cedulaBimestre.amortizacion ,
                acreditado = 1
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   --cedulaBimestre.tipo = 3
                cedulaBimestre.cuentaEmpleado = 1
                AND cedulaBimestre.amortizacion > 0
*/
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaCedulaBimestral
 * Project       : APSI Nomina
 * Description   : Calcula y llena la tabla de salida de la cedula bimestral
 * Table name    : empresa, primas_imss, empleados, deducciones, infonavit
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Marzo 17, 2010
 **************************************************************************************************/
IF OBJECT_ID('dbo.LlenaCedulaBimestralSinInfonavit') IS NOT NULL
   DROP FUNCTION dbo.LlenaCedulaBimestralSinInfonavit
GO
CREATE FUNCTION [dbo].[LlenaCedulaBimestralSinInfonavit]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT      
    )
RETURNS @cedulaBimestral TABLE
    (
      empresa INT NOT NULL
                  DEFAULT 0 ,
      codigo INT NOT NULL
                 DEFAULT 0 ,
      nombre VARCHAR(30) NOT NULL
                         DEFAULT 0 ,
      ap_paterno VARCHAR(30) NOT NULL
                             DEFAULT 0 ,
      ap_materno VARCHAR(30) NULL ,
      afiliacion VARCHAR(10) NULL ,
      digvera CHAR(1) NULL ,
      curp VARCHAR(18) NULL ,
      rfcalfa VARCHAR(4) NULL ,
      rfcnum CHAR(6) NULL ,
      rfchomo VARCHAR(3) NULL ,
      serial INT NOT NULL
                 DEFAULT 0 ,
      fch_mov DATETIME NULL ,
      mov VARCHAR(3) NULL ,
      saldiaint FLOAT NOT NULL
                      DEFAULT 0 ,
      diastr INT NOT NULL
                 DEFAULT 0 ,
      incap INT NOT NULL
                DEFAULT 0 ,
      ausen FLOAT NOT NULL
                  DEFAULT 0 ,
      retiro FLOAT NOT NULL
                   DEFAULT 0 ,
      cesantiaVejez FLOAT NOT NULL
                          DEFAULT 0 ,
      cesantiaVejezPatron FLOAT NOT NULL
                                DEFAULT 0 ,
      cesantiaVejezTrabajador FLOAT NOT NULL
                                    DEFAULT 0 ,
      aportacionInfonavit FLOAT NOT NULL
                                DEFAULT 0 ,
      numeroCredito CHAR(10) ,
      descuento FLOAT ,
      amortizacion FLOAT NOT NULL
                         DEFAULT 0 ,
      tipoCredito INT NOT NULL
                      DEFAULT 0 ,
      seguroVivienda FLOAT NOT NULL
                           DEFAULT 0 ,
      fechaInicioDescuento DATETIME ,
      fechaOtorgamiento DATETIME ,
      fechaSuspension DATETIME ,
      ntd INT ,
      info INT ,
      tipo INT NOT NULL
               DEFAULT 0 ,
      mes INT NOT NULL
              DEFAULT 0 ,
      infonavitSinCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      infonavitConCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      salarioDF FLOAT ,
      salarioRegion FLOAT ,
      sumaRCV FLOAT ,
      sumaAportacionInfoanvit FLOAT ,
      sumaAportacionInfonavitSinCredito FLOAT ,
      sumaAportacionInfonavitConCredito FLOAT ,
      sumaAmortizacion FLOAT ,
      cuentaEmpleado INT ,
      consecutivo INT IDENTITY ,
      pensionEmpleado VARCHAR(4) ,
      jornadaEmpleado VARCHAR(3) ,
      articulo33Empleado VARCHAR(6) ,
      sumaAmortizacionMasSeguro FLOAT ,
      sumaTotalInfonavit FLOAT ,
      sumaTotal FLOAT ,
      acreditado INT ,
      centro VARCHAR(15) ,
      centroNombre VARCHAR(30) ,
      rpu VARCHAR(3),
      tipoNomina INT,
      manoObra CHAR(1) ,
      seguroDesempleo FLOAT
    )
AS
    BEGIN

        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @rpu CHAR(1)
        DECLARE @seguroDesempleo FLOAT

        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE
            BEGIN
                SET @esBimestre = 'N'
            END


-- Obtiene Area Geografica
        SELECT  @areaGeografica = empresa.zona_geografica ,
                @ayoEmpresa = empresa.ayo_operacion ,
                @rpu = ISNULL(empresa.Rpu, 'N') 
        FROM    dbo.empresas AS empresa
        WHERE   empresa.empresa = @empresa

-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
                @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
                @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo

        SET @salarioDF = @salarioRegionA

        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END

        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion

-- Obtiene Primas IMSS
        SELECT  @retiro = primasImss.cvArt168I,
                @cvArt168II = primasImss.cvArt168II,
                @cvPat168II = primasImss.cvPat168II,
                @cvTra168II = primasImss.cvTra168ii,
                @infonavit = primasImss.infonavitPorciento ,
                @seguroDesempleo = ISNULL(primasImss.seguroDesempleoPorciento,0)
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss

-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN concepto.hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN concepto.marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = concepto.variable1
        FROM    dbo.conceptos AS concepto
        WHERE   concepto.empresa = @empresa
                AND concepto.num_conc = 112


-- Registro empleado
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  saldiaint ,
                  numeroCredito ,
                  tipo ,
                  salarioDF ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  DISTINCT
                        dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        ISNULL(( SELECT TOP 1
                                        aItc.saldiaint
                                 FROM   dbo.AvisosImssTemporalCalculo AS aItc
                                 WHERE  aItc.empresa = @empresa
                                        AND aItc.codigo = dbo.empleados.codigo
                                        AND aItc.ayo_operacion = @ayo
                                        AND ( aItc.mes_operacion = @mesNon
                                              OR aItc.mes_operacion = @mesPar
                                            )
                                        AND aItc.diastr > 0
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                                 ORDER BY aItc.mes_operacion ASC ,
                                        aItc.serial ASC
                               ), 0) AS saldiaint ,
                        SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000
                                        + dbo.infonavit.numcredito)), 2, 10) ,
                        1 AS tipo ,
                        @salarioDF AS salarioDF ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        LEFT JOIN dbo.infonavit ON dbo.empleados.empresa = dbo.infonavit.empresa
                                                   AND dbo.empleados.codigo = dbo.infonavit.codigo
                WHERE   aItc.mes_operacion >= @mesNon
                        AND aItc.mes_operacion <= @mesPar
                        AND aItc.ayo_operacion = @ayo
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso


-- Registro Avisos
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  serial ,
                  fch_mov ,
                  mov ,
                  saldiaint ,
                  diastr ,
                  incap ,
                  ausen ,
                  retiro ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  aportacionInfonavit ,
                  amortizacion ,
                  mes ,
                  tipo ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra ,
                  seguroDesempleo
                )
                SELECT  dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        aItc.serial ,
                        aItc.fch_mov ,
                        CASE aItc.mov
                          WHEN 'IM' THEN ' '
                          WHEN 'RI' THEN 'R'
                          WHEN 'MS' THEN 'M/S'
                          ELSE aItc.mov
                        END AS mov ,
                        [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                @topeDF, @topeRegion,
                                                dbo.empleados.art39,
                                                aItc.mov) AS salario ,
                        aItc.diastr ,
                        aItc.incap ,
                        aItc.ausen ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @retiro, 0) AS retiro ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @infonavit, 0) AS aportacionInfonavit ,
                        0 AS amortizacion , 
                        aItc.mes_operacion ,
                        2 AS tipo ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @seguroDesempleo, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @seguroDesempleo, 0) AS seguroDesempleo
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                WHERE   aItc.mes_operacion >= @mesNon
                        AND aItc.mes_operacion <= @mesPar
                        AND aItc.ayo_operacion = @ayo
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND (
                             (aItc.mov = 'IM' AND aItc.diastr > 0)
                             OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                            )

        IF @esBimestre = 'S'
            BEGIN
                DELETE  cedulaBimestral
                FROM    @cedulaBimestral AS cedulaBimestral
                WHERE   cedulaBimestral.mov = 'IM'
                        OR cedulaBimestral.mov = ' '
                        AND MONTH(cedulaBimestral.fch_mov) = @mesPar
                        AND cedulaBimestral.diastr = 0
            END

/*
-- Registro Amortizacion
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  numeroCredito ,
                  descuento ,
                  tipoCredito ,
                  fechaInicioDescuento ,
                  fechaOtorgamiento ,
                  fechaSuspension ,
                  amortizacion ,
                  seguroVivienda ,
                  tipo ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  cedulaBimestre.empresa ,
                        cedulaBimestre.codigo ,
                        cedulaBimestre.nombre ,
                        cedulaBimestre.ap_paterno ,
                        cedulaBimestre.ap_materno ,
                        SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000
                                        + dbo.infonavit.numcredito)), 2, 10) ,
                        dbo.TemporalAmortizacion.descuento ,  
                        dbo.infonavit.tipo_cred ,
                        dbo.infonavit.fecha ,
                        dbo.infonavit.fch_otorga ,
                        dbo.infonavit.fch_termino ,
                        ISNULL(dbo.temporalAmortizacion.amortizacion, 0) ,   
                        0 AS seguroVivienda ,
                        3 ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    @cedulaBimestral AS cedulaBimestre
                        LEFT JOIN dbo.temporalAmortizacion ON cedulaBimestre.empresa = dbo.temporalAmortizacion.empresa
                                                              AND cedulaBimestre.codigo = dbo.temporalAmortizacion.codigo
                        INNER JOIN dbo.Llaves ON dbo.TemporalAmortizacion.empresa = dbo.Llaves.empresa
                                                 AND dbo.TemporalAmortizacion.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.infonavit ON dbo.temporalAmortizacion.empresa = dbo.infonavit.empresa
                                                    AND dbo.temporalAmortizacion.codigo = dbo.infonavit.codigo
                        INNER JOIN dbo.empleados ON cedulaBimestre.empresa = dbo.empleados.empresa AND cedulaBimestre.codigo = dbo.empleados.codigo
                WHERE   cedulaBimestre.tipo = 1
                        AND dbo.infonavit.fecha <= @ffPar
                        AND dbo.infonavit.fch_termino >= @fiNon

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END


        UPDATE  cedulaBimestre
        SET     cedulaBimestre.infonavitSinCredito = cedulaBimestre.aportacionInfonavit
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.tipo = 2

        UPDATE  cedulaBimestre
        SET     cedulaBimestre.infonavitSinCredito = 0 ,
                cedulaBimestre.infonavitConCredito = cedulaBimestre.aportacionInfonavit
        FROM    @cedulaBimestral AS cedulaBimestre
                INNER JOIN @cedulaBimestral AS cedulaBimestreCredito ON cedulaBimestreCredito.empresa = cedulaBimestre.empresa
                                                              AND cedulaBimestreCredito.codigo = cedulaBimestre.codigo
        WHERE   cedulaBimestre.tipo = 2
                AND cedulaBimestreCredito.tipo = 3
                AND cedulaBimestreCredito.tipoCredito >= 1
                AND cedulaBimestreCredito.tipoCredito <= 3
                AND cedulaBimestreCredito.amortizacion >= 0
*/

        UPDATE  cedulaBimestre
        SET     cedulaBimestre.sumaRCV = cedulaBimestre.retiro
                                         + cedulaBimestre.cesantiaVejez 
                                         + cedulaBimestre.seguroDesempleo ,
                cedulaBimestre.sumaAportacionInfoanvit = cedulaBimestre.aportacionInfonavit ,
                cedulaBimestre.sumaAportacionInfonavitSinCredito = cedulaBimestre.infonavitSinCredito ,
                cedulaBimestre.sumaAportacionInfonavitConCredito = cedulaBimestre.infonavitConCredito ,
                cedulaBimestre.sumaTotalInfonavit = ISNULL(cedulaBimestre.aportacionInfonavit,
                                                           0) ,
                cedulaBimestre.sumaTotal = cedulaBimestre.retiro
                                           + cedulaBimestre.cesantiaVejez
                                           + cedulaBimestre.aportacionInfonavit
                                           + cedulaBimestre.seguroDesempleo
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.tipo = 2

/*
        UPDATE  cedulaBimestre
        SET     cedulaBimestre.seguroVivienda = @seguroVivienda ,
                cedulaBimestre.sumaAmortizacion = cedulaBimestre.amortizacion ,
                cedulaBimestre.sumaAmortizacionMasSeguro = cedulaBimestre.amortizacion
                                                           + @seguroVivienda ,
                cedulaBimestre.sumaTotalInfonavit = @seguroVivienda
                                                    + ISNULL(cedulaBimestre.amortizacion, 0) ,
                cedulaBimestre.sumaTotal = @seguroVivienda
                                           + cedulaBimestre.amortizacion ,
                acreditado = 1
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.tipo = 3
                AND cedulaBimestre.amortizacion > 0
*/                

        UPDATE  cedulaBimestre
        SET     cuentaEmpleado = 1
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.empresa = @empresa
                AND cedulaBimestre.codigo + cedulaBimestre.consecutivo = ( SELECT TOP 1
                                                                                  cedulaBimestre2.codigo + cedulaBimestre2.consecutivo
                                                                           FROM @cedulaBimestral AS cedulaBimestre2
                                                                           WHERE cedulaBimestre2.empresa = @empresa
                                                                                 AND cedulaBimestre2.tipo > 1
                                                                                 AND cedulaBimestre2.codigo = cedulaBimestre.codigo
                                                                         )
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaCedulaBimestralUMA
 * Project       : APSI Nomina
 * Description   : Calcula y llena la tabla de salida de la cedula bimestral
 * Table name    : empresa, primas_imss, empleados, deducciones, infonavit
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Marzo 17, 2010
 **************************************************************************************************/

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'TF'
--                    AND name = 'LlenaCedulaBimestral' )
--    BEGIN
--        DROP  FUNCTION [dbo].[LlenaCedulaBimestral]
--    END
IF OBJECT_ID('dbo.LlenaCedulaBimestralUMA') IS NOT NULL
   DROP FUNCTION dbo.LlenaCedulaBimestralUMA
GO
CREATE FUNCTION [dbo].[LlenaCedulaBimestralUMA]
    (
      @empresa INT,
      @codigo INT,
      @ayo INT,
      @mesNon INT,
      @mesPar INT,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME,
      @horaProceso VARCHAR(8),
      @simulaReforma INT,
	  @filtroInfonavit INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
    )

/*
DECLARE @empresa INT = 1
DECLARE @codigo INT = 0
DECLARE @ayo INT = 2021
DECLARE @mesNon INT = 7
DECLARE @mesPar INT = 8
DECLARE @proceso VARCHAR(250) = 'CedulaBimestral'
DECLARE @fechaProceso DATETIME = '2021-10-29'
DECLARE @horaProceso VARCHAR(8) = '17:16:01'
DECLARE @simulaReforma INT = 0
DECLARE @filtroInfonavit INT = 1   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
DECLARE @cedulaBimestral TABLE
*/
RETURNS @cedulaBimestral TABLE
    (
      empresa INT NOT NULL
                  DEFAULT 0 ,
      codigo INT NOT NULL
                 DEFAULT 0 ,
      nombre VARCHAR(50) NOT NULL
                         DEFAULT 0 ,
      ap_paterno VARCHAR(50) NOT NULL
                             DEFAULT 0 ,
      ap_materno VARCHAR(50) NULL ,
      afiliacion VARCHAR(10) NULL ,
      digvera CHAR(1) NULL ,
      curp VARCHAR(18) NULL ,
      rfcalfa VARCHAR(4) NULL ,
      rfcnum CHAR(6) NULL ,
      rfchomo VARCHAR(3) NULL ,
      serial INT NOT NULL
                 DEFAULT 0 ,
      fch_mov DATETIME NULL ,
      mov VARCHAR(3) NULL ,
      saldiaint FLOAT NOT NULL
                      DEFAULT 0 ,
      diastr INT NOT NULL
                 DEFAULT 0 ,
      incap INT NOT NULL
                DEFAULT 0 ,
      ausen FLOAT NOT NULL
                  DEFAULT 0 ,
      retiro FLOAT NOT NULL
                   DEFAULT 0 ,
      cesantiaVejez FLOAT NOT NULL
                          DEFAULT 0 ,
      cesantiaVejezPatron FLOAT NOT NULL
                                DEFAULT 0 ,
      cesantiaVejezTrabajador FLOAT NOT NULL
                                    DEFAULT 0 ,
      aportacionInfonavit FLOAT, -- NOT NULL DEFAULT 0 ,
      numeroCredito CHAR(10) ,
      descuento FLOAT ,
      amortizacion FLOAT, -- NOT NULL DEFAULT 0 ,
      tipoCredito INT, -- NOT NULL DEFAULT 0 ,
      seguroVivienda FLOAT, -- NOT NULL DEFAULT 0 ,
      fechaInicioDescuento DATETIME ,
      fechaOtorgamiento DATETIME ,
      fechaSuspension DATETIME ,
      ntd INT ,
      info INT ,
      tipo INT NOT NULL DEFAULT 0 ,
      mes INT NOT NULL DEFAULT 0 ,
      infonavitSinCredito FLOAT, -- NOT NULL DEFAULT 0 ,
      infonavitConCredito FLOAT, -- NOT NULL DEFAULT 0 ,
      salarioDF FLOAT ,
      salarioRegion FLOAT ,
      sumaRCV FLOAT ,
      sumaAportacionInfoanvit FLOAT ,
      sumaAportacionInfonavitSinCredito FLOAT ,
      sumaAportacionInfonavitConCredito FLOAT ,
      sumaAmortizacion FLOAT ,
      cuentaEmpleado INT ,
      consecutivo INT IDENTITY ,
      pensionEmpleado VARCHAR(4) ,
      jornadaEmpleado VARCHAR(3) ,
      articulo33Empleado VARCHAR(6) ,
      sumaAmortizacionMasSeguro FLOAT ,
      sumaTotalInfonavit FLOAT ,
      sumaTotal FLOAT ,
      acreditado INT ,
      centro VARCHAR(15) ,
      centroNombre VARCHAR(30) ,
      rpu VARCHAR(3),
      tipoNomina INT,
      manoObra CHAR(1) ,
      seguroDesempleo FLOAT,
      noAcreditado INT,
	  lic INT,
	  serial1 INT,
      reg_pat CHAR(11),
      nombreEmpresa VARCHAR(70),
      referencia VARCHAR(70),
      direccion VARCHAR(50),
      colonia VARCHAR(50),
      poblacion VARCHAR(50),
      zona_geografica CHAR(1),
      actividad VARCHAR(100),
      cod_postal VARCHAR(5),
      prima_rt NUMERIC(7,5),
      rfc CHAR(13),
      registros INT,
      altas INT,
      bajas INT,
      ms INT,
	  finGrupo INT
    )
AS
    BEGIN

        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        --DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @Rpu CHAR(3)
        DECLARE @seguroDesempleo FLOAT
        DECLARE @fechaAplicaUMA DATETIME
        DECLARE @fechaAplicaSiroc DATETIME
		DECLARE @fechaOperacion DATETIME
		DECLARE @mesEmpresa INT
        DECLARE @FechaFinita DATETIME
        DECLARE @EsRpu CHAR(1)
        DECLARE @EsRpuEspecial INT
        DECLARE @reg_pat VARCHAR(11)
        DECLARE @EsMultiple INT

        DECLARE @TblDatosPatron TABLE(empresa INT
                                      , rpu CHAR(3)
                                      , reg_pat CHAR(11)
                                      , nombre VARCHAR(70)
                                      , referencia VARCHAR(70)
                                      , direccion VARCHAR(50)
                                      , colonia VARCHAR(50)
                                      , poblacion VARCHAR(50)
                                      , zona_geografica CHAR(1)
                                      , actividad VARCHAR(100)
                                      , cod_postal VARCHAR(5)
                                      , prima_rt NUMERIC(7, 5)
                                      , rfc CHAR(13)
								      , registros INT
                                      , altas INT
                                      , bajas INT
                                      , ms INT)

        SET @EsRpuEspecial = dbo.EsRpuEspecial(@empresa)
        SET @FechaFinita = '29991231'
        SET @fechaAplicaSiroc = CONVERT(DATETIME, '20170901')
        SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo) 
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2) AND @mesNon < @mesPar
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE
            BEGIN
                SET @esBimestre = 'N'
            END


-- Obtiene Area Geografica
        SELECT  @areaGeografica = empresa.zona_geografica ,
                --@patronPagaIMSS = empresa.patron_paga_cuotas_imss ,
                @ayoEmpresa = empresa.ayo_operacion ,
                @EsRpu = ISNULL(empresa.Rpu, 'N'),
				@mesEmpresa = empresa.mes_operacion,
                @Rpu = LEFT(empresa.registro_patronal,3),
                @reg_pat = empresa.registro_patronal
        FROM    dbo.empresas AS empresa
        WHERE   empresa.empresa = @empresa

        SET @fechaOperacion = CONVERT(DATETIME, LTRIM(STR(@ayoEmpresa)) + RIGHT(100 + @mesEmpresa,2) + '01')

-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
                @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
                @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo

        SET @salarioDF = @salarioRegionA

        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END

        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion


-- Obtiene Primas IMSS
        SELECT  @retiro = primasImss.cvArt168I , --primasImss.retiro ,
                @cvArt168II = primasImss.cvArt168II ,
                @cvPat168II = primasImss.cvPat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
                @cvTra168II = primasImss.cvTra168ii, --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
                @infonavit = primasImss.infonavitPorciento ,
                @seguroDesempleo = ISNULL(primasImss.seguroDesempleoPorciento,0)
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss AS primasImss
        --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END



-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 
		                         THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN concepto.hrs_min3 = 999 
				                  THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN concepto.marca2 = 'M' 
				                  THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = concepto.variable1
        FROM    dbo.conceptos AS concepto
        WHERE   concepto.empresa = @empresa
                AND concepto.num_conc = 112

        SET @EsMultiple = CHARINDEX('"', @proceso)   

        IF @EsRpuEspecial = 1
           BEGIN
             INSERT @TblDatosPatron (empresa
                                     , rpu
                                     , reg_pat
                                     , nombre
                                     , referencia
                                     , direccion
                                     , colonia
                                     , poblacion
                                     , zona_geografica
                                     , actividad
                                     , cod_postal
                                     , rfc)
                    SELECT r.empresa
                           , r.rpu
                           , r.reg_pat
                           , r.nombre
                           , r.referencia
                           , r.direccion
                           , r.colonia
                           , r.poblacion
                           , r.zona_geografica
                           , r.actividad
                           , r.cod_postal
                           , r.rfc
	                FROM dbo.rpu AS r
	       END
        ELSE
           IF @EsRpu = 'N' OR @EsMultiple > 0
              BEGIN
                INSERT @TblDatosPatron (empresa
                                        , rpu
                                        , reg_pat
                                        , nombre
                                        , referencia
                                        , direccion
                                        , colonia
                                        , poblacion
                                        , zona_geografica
                                        , actividad
                                        , cod_postal
                                        , rfc)
                       SELECT empresa.empresa
                              , LEFT(empresa.registro_patronal,3) AS rpu
                              , empresa.registro_patronal AS reg_pat
                              , empresa.nombre_empresa AS nombre_empresa
                              , empresa.referencia AS referencia
                              , empresa.direccion_empresa AS direccion
                              , empresa.colonia_empresa AS colinia
                              , empresa.poblacion_empresa AS poblacion
                              , empresa.zona_geografica AS zona_geografica
                              , empresa.actividad_empresa AS actividad
                              , empresa.codigo_postal_empresa AS cod_postal
                              , empresa.rfc_empresa AS rfc
                       FROM dbo.empresas AS empresa
                       WHERE empresa.empresa = @empresa
              END
           ELSE
              BEGIN
                INSERT @TblDatosPatron (empresa
                                        , rpu
                                        , reg_pat
                                        , nombre
                                        , referencia
                                        , direccion
                                        , colonia
                                        , poblacion
                                        , zona_geografica
                                        , actividad
                                        , cod_postal
                                        , rfc)
                       SELECT r.empresa
                              , r.rpu
                              , @reg_pat AS reg_pat
                              , r.nombre
                              , r.referencia
                              , r.direccion
                              , r.colonia
                              , r.poblacion
                              , @areaGeografica AS zona_geografica
                              , r.actividad
                              , r.cod_postal
                              , r.rfc
	                   FROM dbo.rpu AS r
			           WHERE r.empresa = @empresa
              END

-- Registro empleado
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  saldiaint ,
                  numeroCredito ,
                  tipo ,
                  salarioDF ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  DISTINCT
                        dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        ISNULL(( SELECT TOP 1
                                        aItc.saldiaint
                                 FROM   dbo.AvisosImssTemporalCalculo AS aItc
                                 WHERE  aItc.empresa = @empresa
                                        AND aItc.codigo = dbo.empleados.codigo
                                        AND aItc.ayo_operacion = @ayo
                                        AND ( aItc.mes_operacion = @mesNon
                                              OR aItc.mes_operacion = @mesPar
                                            )
                                        AND aItc.diastr > 0
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                                 ORDER BY aItc.fch_mov ASC ,
                                        aItc.serial ASC
                               ), 0) AS saldiaint ,
                        SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000 + i.numcredito)), 2, 10) ,
                        1 AS tipo ,
                        @salarioDF AS salarioDF ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @EsRpu = 'S' THEN ISNULL(aItc.rpu, @Rpu) ELSE @Rpu END, --CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                --FROM    dbo.empresas
                --        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                FROM dbo.empleados 
                     INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                         AND dbo.empleados.codigo = aItc.codigo

                     INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = dbo.empleados.empresa
													      AND CASE WHEN @EsMultiple > 0 
                                                                   THEN '' 
                                                                   ELSE tdp.rpu 
                                                              END = CASE WHEN @EsMultiple > 0 
                                                                         THEN '' 
                                                                         ELSE CASE WHEN @EsRpuEspecial = 1 
                                                                                   THEN ISNULL(aItc.rpu, @Rpu) 
                                                                                   ELSE tdp.rpu --@Rpu 
                                                                              END 
                                                                    END

                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
											, i.numcredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = dbo.empleados.empresa
				                           AND i.codigo = dbo.empleados.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                WHERE   aItc.mes_operacion >= @mesNon
                        AND aItc.mes_operacion <= @mesPar
                        AND aItc.ayo_operacion = @ayo
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
						AND CASE WHEN @fiNon >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fiNon >= @fechaOperacion THEN 'S' ELSE '' END
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        --AND aItc.empresa <= CASE WHEN @empresa = 0
                        --                         THEN 9999
                        --                         ELSE @empresa
                        --                    END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

-- Registro Avisos
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  serial ,
                  fch_mov ,
                  mov ,
                  saldiaint ,
                  diastr ,
                  incap ,
                  ausen ,
                  retiro ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  aportacionInfonavit ,
                  amortizacion ,
                  mes ,
                  tipo ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra ,
                  seguroDesempleo,
				  lic
                )
                SELECT  dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        aItc.serial ,
                        aItc.fch_mov ,
                        CASE aItc.mov
                             WHEN 'IM' THEN ' '
                             WHEN 'RI' THEN 'R'
                             WHEN 'MS' THEN 'M/S'
                             WHEN 'UM' THEN 'UMA'
                             ELSE aItc.mov
                        END AS mov ,
                        [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                salarioMinimo.topeRegion,
                                                dbo.empleados.art39,
                                                aItc.mov) AS salario ,
                        aItc.diastr ,
                        aItc.incap ,
                        aItc.ausen ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              salarioMinimo.topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                                 0, @retiro, 0) AS retiro ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              salarioMinimo.topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                                 0, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              salarioMinimo.topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                                 1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              salarioMinimo.topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                                 2, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              salarioMinimo.topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                                 0, @infonavit, 0) AS aportacionInfonavit ,
                        0 AS amortizacion , 
                        aItc.mes_operacion ,
                        2 AS tipo ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @EsRpu = 'S' THEN ISNULL(aItc.rpu, @Rpu) ELSE @Rpu END, --CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              salarioMinimo.topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @seguroDesempleo, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                                 0, @seguroDesempleo, 0) AS seguroDesempleo,
                        aItc.lic 
                --FROM    dbo.empresas
                --        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                FROM dbo.empleados
                     INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                         AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa

                     INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = dbo.empleados.empresa
													      AND CASE WHEN @EsMultiple > 0 
                                                                   THEN '' 
                                                                   ELSE tdp.rpu 
                                                              END = CASE WHEN @EsMultiple > 0 
                                                                         THEN '' 
                                                                         ELSE CASE WHEN @EsRpuEspecial = 1 
                                                                                   THEN ISNULL(aItc.rpu, @Rpu) 
                                                                                   ELSE tdp.rpu --@Rpu 
                                                                              END 
                                                                    END

                        CROSS APPLY (SELECT TOP 1 --salarioMinimo.zona_a AS salarioRegion,
	                                        CASE tdp.zona_geografica WHEN 'A' THEN salarioMinimo.zona_a
                                                                     WHEN 'B' THEN salarioMinimo.zona_b
                                                                     WHEN 'C' THEN salarioMinimo.zona_c
                                                                     ELSE @salarioRegion
                                            END AS salarioRegion,
                                            salarioMinimo.zona_a AS topeRegion
                                     FROM dbo.salarios_minimos AS salarioMinimo
                                     WHERE salarioMinimo.fecha_ini <= aItc.fch_mov
                                     ORDER BY salarioMinimo.fecha_ini DESC) AS salarioMinimo

                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = dbo.empleados.empresa
				                           AND i.codigo = dbo.empleados.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i
                                                      
                WHERE   aItc.mes_operacion >= @mesNon
                        AND aItc.mes_operacion <= @mesPar
                        AND aItc.ayo_operacion = @ayo
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
						AND CASE WHEN @fiNon >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fiNon >= @fechaOperacion THEN 'S' ELSE '' END
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND (
                             (aItc.mov = 'IM' AND aItc.diastr > 0)
                             OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'UM' AND aItc.diastr IS NOT NULL)
                            )
                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

				ORDER BY aItc.codigo,
				         aItc.fch_mov,
						 aItc.serial


        IF @esBimestre = 'S'
            BEGIN
                DELETE  cedulaBimestral
                FROM    @cedulaBimestral AS cedulaBimestral
                WHERE   cedulaBimestral.mov = 'IM'
                        OR cedulaBimestral.mov = ' '
                        --AND MONTH(cedulaBimestral.fch_mov) = @mesPar
						AND cedulaBimestral.fch_mov = @fiPar
                        AND cedulaBimestral.diastr = 0
            END

                -- Registro Amortizacion

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END

        UPDATE  cedulaBimestre
        SET     cuentaEmpleado = 1
        FROM    @cedulaBimestral AS cedulaBimestre
                INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaBimestre.empresa
        WHERE   --cedulaBimestre.empresa = @empresa
                --AND
				CASE WHEN @EsRpuEspecial = 1
				         THEN cedulaBimestre.rpu 
				         ELSE '' 
                    END + RIGHT(100000000 + cedulaBimestre.codigo,8) + RIGHT(100000000 + cedulaBimestre.consecutivo,8) 
					= ( SELECT TOP 1 
					           CASE WHEN @EsRpuEspecial = 1
				                    THEN cedulaBimestre2.rpu 
				                    ELSE ''
							   END + RIGHT(100000000 + cedulaBimestre2.codigo,8) + RIGHT(100000000 + cedulaBimestre2.consecutivo,8)
                        FROM @cedulaBimestral AS cedulaBimestre2
                        WHERE cedulaBimestre2.empresa = cedulaBimestre.empresa
                              AND cedulaBimestre2.tipo > 1
                              AND cedulaBimestre2.codigo = cedulaBimestre.codigo 
                              AND CASE WHEN @EsRpuEspecial = 1
                                       THEN cedulaBimestre2.rpu 
                                       ELSE '' 
                                  END = CASE WHEN @EsRpuEspecial = 1
                                             THEN cedulaBimestre.rpu 
                                             ELSE '' 
                                        END)

                                                                                 
        UPDATE cedula
        SET cedula.numeroCredito = SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000 + dbo.temporalAmortizacion.numcredito)), 2, 10),
            cedula.descuento = dbo.TemporalAmortizacion.descuento,
			cedula.tipoCredito = dbo.temporalAmortizacion.tipo_cred,
            cedula.fechaInicioDescuento = dbo.infonavit.fecha,
            cedula.fechaOtorgamiento = dbo.infonavit.fch_otorga,
            cedula.fechaSuspension = dbo.infonavit.fch_termino,
            cedula.amortizacion = ISNULL(dbo.temporalAmortizacion.amortizacion, 0),
            cedula.seguroVivienda = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda ELSE 0 END,
            cedula.sumaTotalinfonavit = cedulaInfonavit.aportacionInfonavit + CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda + ISNULL(dbo.temporalAmortizacion.amortizacion, 0) ELSE 0 END,
            cedula.acreditado = CASE WHEN ISNULL(dbo.temporalAmortizacion.numcredito, 0) > 0 THEN 1 ELSE 0 END,
            cedula.noAcreditado = CASE WHEN ISNULL(dbo.temporalAmortizacion.numcredito, 0) > 0 THEN 0 ELSE 1 END
        FROM @cedulaBimestral AS cedula
             INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedula.empresa
             LEFT JOIN dbo.temporalAmortizacion ON dbo.temporalAmortizacion.empresa = cedula.empresa
                                                   AND dbo.temporalAmortizacion.codigo = cedula.codigo
             LEFT JOIN dbo.infonavit ON dbo.infonavit.empresa = dbo.temporalAmortizacion.empresa
                                        AND dbo.infonavit.codigo = temporalAmortizacion.codigo
                                        AND dbo.infonavit.fecha <= @ffPar
                                        AND dbo.infonavit.fch_termino >= @fiNon
             INNER JOIN (SELECT cedulaAportacion.empresa,
                                cedulaAportacion.codigo,
                                SUM(ISNULL(cedulaAportacion.aportacionInfonavit,0)) AS aportacionInfonavit 
                         FROM @cedulaBimestral AS cedulaAportacion
                         WHERE cedulaAportacion.tipo = 2
                         GROUP BY cedulaAportacion.empresa,
                                  cedulaAportacion.codigo) AS cedulaInfonavit ON cedulaInfonavit.codigo = cedula.codigo
                                                                                AND cedulaInfonavit.empresa = cedula.empresa
        WHERE   cedula.cuentaEmpleado = 1


        UPDATE  cedulaBimestre
        SET     cedulaBimestre.infonavitSinCredito = cedulaBimestre.aportacionInfonavit
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.tipo = 2

        UPDATE  cedulaBimestre
        SET     cedulaBimestre.infonavitSinCredito = 0 ,
                cedulaBimestre.infonavitConCredito = cedulaBimestre.aportacionInfonavit
        FROM    @cedulaBimestral AS cedulaBimestre
                INNER JOIN @cedulaBimestral AS cedulaBimestreCredito ON cedulaBimestreCredito.empresa = cedulaBimestre.empresa
                                                              AND cedulaBimestreCredito.codigo = cedulaBimestre.codigo
        WHERE   cedulaBimestre.tipo = 2
                AND cedulaBimestreCredito.cuentaEmpleado = 1
                AND cedulaBimestreCredito.tipoCredito >= 1
                AND cedulaBimestreCredito.tipoCredito <= 3
                AND cedulaBimestreCredito.amortizacion >= 0

        UPDATE  cedulaBimestre
        SET     cedulaBimestre.sumaRCV = cedulaBimestre.retiro
                                         + cedulaBimestre.cesantiaVejez 
        FROM    @cedulaBimestral AS cedulaBimestre
        WHERE   cedulaBimestre.tipo = 2

        UPDATE RpuPatron
        SET RpuPatron.registros = cedulaBimestral.registros
            , RpuPatron.altas   = cedulaBimestral.altas
            , RpuPatron.bajas   = cedulaBimestral.bajas
            , RpuPatron.ms      = cedulaBimestral.ms
        FROM @TblDatosPatron AS RpuPatron
             CROSS APPLY (SELECT COUNT(DISTINCT cedulaBimestral.codigo) AS registros
                                 , COUNT(CASE WHEN cedulaBimestral.mov = 'A' OR cedulaBimestral.mov = 'R' THEN 1 ELSE NULL END) AS altas
                                 , COUNT(CASE WHEN cedulaBimestral.mov = 'B' THEN 1 ELSE NULL END) AS bajas
                                 , COUNT(CASE WHEN cedulabimestral.mov = 'M/S' THEN 1 ELSE NULL END) AS ms
                          FROM @cedulaBimestral AS cedulaBimestral
                          WHERE cedulaBimestral.empresa = RpuPatron.empresa
                                --AND CASE WHEN @EsRpu = 'S' THEN ISNULL(cedulaBimestral.rpu, @Rpu) ELSE @Rpu END = RpuPatron.rpu
                                AND CASE WHEN @EsMultiple > 0
                                         THEN ''
                                         ELSE CASE WHEN @EsRpu = 'S' 
                                                   THEN ISNULL(cedulaBimestral.rpu, @Rpu) 
                                                   ELSE @Rpu 
                                              END
                                    END = CASE WHEN @EsMultiple > 0
                                               THEN ''
                                               ELSE RpuPatron.rpu
                                          END
                         ) AS cedulaBimestral
        --WHERE RpuPatron.empresa = @empresa

        UPDATE cedulaBimestral
        SET cedulaBimestral.serial = cedulaBimestral.serial1
        FROM (SELECT TOP 2147483647
		             cedulaBimestral.serial
                     , ROW_NUMBER() OVER (PARTITION BY cedulaBimestral.empresa
                                                       , cedulaBimestral.rpu					  
                                          ORDER BY cedulaBimestral.empresa
										           , cedulaBimestral.rpu
										           , cedulaBimestral.ap_paterno
                                                   , cedulaBimestral.ap_materno
                                                   , cedulaBimestral.nombre 
                                                   , cedulaBimestral.tipo 				
                                                   ) AS serial1
              FROM @cedulaBimestral AS cedulaBimestral
			       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaBimestral.empresa
			  WHERE cedulaBimestral.tipo > 1
              ORDER BY cedulaBimestral.empresa ,
                       cedulaBimestral.rpu,
                       cedulaBimestral.ap_paterno,
                       cedulaBimestral.ap_materno,
                       cedulaBimestral.nombre,
                       cedulaBimestral.tipo,
                       cedulaBimestral.mes,
                       cedulaBimestral.serial
			 ) AS cedulaBimestral


        UPDATE cedulaBimestral
        SET cedulaBimestral.finGrupo = cedulaBimestral.empresa
        FROM @cedulaBimestral AS cedulaBimestral
             INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaBimestral.empresa

             CROSS APPLY (SELECT MAX(cedulaBimestral2.serial) AS serial
                          FROM @cedulaBimestral AS cedulaBimestral2
                          WHERE cedulaBimestral2.empresa = cedulaBimestral.empresa
                                AND CASE WHEN @EsMultiple > 0
		                                 THEN ''
                                         ELSE CASE WHEN @EsRpu = 'S' 
                                                   THEN ISNULL(cedulaBimestral2.rpu, @Rpu) 
                                                   ELSE @Rpu 
                                              END
                                    END = CASE WHEN @EsMultiple > 0
                                               THEN ''
                                               ELSE CASE WHEN @EsRpu = 'S' 
                                                         THEN tdp.rpu
                                                         ELSE @Rpu
                                                    END
                                          END
                         ) AS cedulaBimestral2
        WHERE cedulaBimestral.serial = cedulaBimestral2.serial

        UPDATE cedulaBimestral
        SET cedulaBimestral.reg_pat = RpuPatron.reg_pat,
            cedulaBimestral.nombreEmpresa = RpuPatron.nombre,
            cedulaBimestral.referencia = RpuPatron.referencia,
            cedulaBimestral.direccion = RpuPatron.direccion,
            cedulaBimestral.colonia = RpuPatron.colonia,
            cedulaBimestral.poblacion = RpuPatron.poblacion,
            cedulaBimestral.zona_geografica = RpuPatron.zona_geografica,
            cedulaBimestral.actividad = RpuPatron.actividad,
            cedulaBimestral.cod_postal = RpuPatron.cod_postal,
            cedulaBimestral.rfc = RpuPatron.rfc,
            cedulaBimestral.registros = RpuPatron.registros,
            cedulaBimestral.altas = RpuPatron.altas,
            cedulaBimestral.bajas = RpuPatron.bajas,
            cedulaBimestral.ms = RpuPatron.ms             
		FROM @cedulaBimestral AS cedulaBimestral
             CROSS APPLY (SELECT TOP 1
                                   RpuPatron.reg_pat         
                                 , RpuPatron.nombre          
                                 , RpuPatron.referencia      
                                 , RpuPatron.direccion       
                                 , RpuPatron.colonia         
                                 , RpuPatron.poblacion       
                                 , RpuPatron.zona_geografica 
                                 , RpuPatron.actividad       
                                 , RpuPatron.cod_postal      
                                 , RpuPatron.rfc             
                                 , RpuPatron.registros       
                                 , RpuPatron.altas           
                                 , RpuPatron.bajas           
                                 , RpuPatron.ms              
                          FROM @TblDatosPatron AS RpuPatron
						  WHERE RpuPatron.empresa = cedulaBimestral.empresa
			                    AND RpuPatron.rpu = CASE WHEN @EsRpu = 'S' THEN ISNULL(cedulaBimestral.rpu, @Rpu) ELSE @Rpu END) AS RpuPatron
		WHERE cedulaBimestral.serial1 = 1



        UPDATE cedulaBimestral
        SET cedulaBimestral.reg_pat = RpuPatronAnterior.reg_pat,
            cedulaBimestral.nombreEmpresa = RpuPatronAnterior.nombre,
            cedulaBimestral.referencia = RpuPatronAnterior.referencia,
            cedulaBimestral.direccion = RpuPatronAnterior.direccion,
            cedulaBimestral.colonia = RpuPatronAnterior.colonia,
            cedulaBimestral.poblacion = RpuPatronAnterior.poblacion,
            cedulaBimestral.zona_geografica = RpuPatronAnterior.zona_geografica,
            cedulaBimestral.actividad = RpuPatronAnterior.actividad,
            cedulaBimestral.cod_postal = RpuPatronAnterior.cod_postal,
            cedulaBimestral.rfc = RpuPatronAnterior.rfc
		FROM @cedulaBimestral AS cedulaBimestral
		     CROSS APPLY (SELECT TOP 1
                                 RpuPatronAnterior.reg_pat         
                                 , RpuPatronAnterior.nombre          
                                 , RpuPatronAnterior.referencia      
                                 , RpuPatronAnterior.direccion       
                                 , RpuPatronAnterior.colonia         
                                 , RpuPatronAnterior.poblacion       
                                 , RpuPatronAnterior.zona_geografica 
                                 , RpuPatronAnterior.actividad       
                                 , RpuPatronAnterior.cod_postal      
                                 , RpuPatronAnterior.prima_rt        
                                 , RpuPatronAnterior.rfc             
                          FROM @TblDatosPatron AS RpuPatronAnterior
                          WHERE (RpuPatronAnterior.empresa > cedulaBimestral.empresa
						         OR CASE WHEN @EsMultiple > 0
                                         THEN ''
                                         ELSE RpuPatronAnterior.rpu
                                    END > CASE WHEN @EsMultiple > 0
                                               THEN ''
                                               ELSE CASE WHEN @EsRpu = 'S' 
                                                         THEN ISNULL(cedulaBimestral.rpu, @Rpu) 
                                                         ELSE @Rpu 
                                                    END
                                          END)
                                AND cedulaBimestral.finGrupo > 0
                          ORDER BY RpuPatronAnterior.empresa ASC
                                   , RpuPatronAnterior.rpu ASC
                         ) AS RpuPatronAnterior


        RETURN
    END
--SELECT @EsRpu, @Rpu,* FROM @TblDatosPatron AS RpuPatron
GO

/**************************************************************************************************
 * Name          : LlenaCedulaMensual
 * Project       : APSI Nomina
 * Description   : Calcula y llana la tabla de salida de la cedula mensual
 * Table name    : empresa, primas_imss, primas_rt, empleados, deducciones,
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Sabado, Marzo 13, 2010
 **************************************************************************************************/
IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'LlenaCedulaMensual' ) 
    BEGIN
        DROP  FUNCTION [dbo].[LlenaCedulaMensual]
    END
GO
CREATE FUNCTION [dbo].[LlenaCedulaMensual]
    (
      @empresa NUMERIC(5) ,
      @codigo NUMERIC(8, 0) ,
      @ayo INT ,
      @mes INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT
    )
RETURNS @cedulaMensual TABLE
    (
      codigo NUMERIC(8, 0) NOT NULL
                           DEFAULT 0 ,
      nombre VARCHAR(30) NOT NULL
                         DEFAULT ' ' ,
      ap_paterno VARCHAR(30) NOT NULL
                             DEFAULT ' ' ,
      ap_materno VARCHAR(30) NULL ,
      afiliacion VARCHAR(10) NULL ,
      digvera CHAR(1) NULL ,
      curp VARCHAR(18) NULL ,
      art39 DECIMAL(6, 3) NULL ,
      jornada INT NOT NULL
                  DEFAULT 0 ,
      rfcalfa VARCHAR(4) NULL ,
      rfcnum CHAR(6) NULL ,
      rfchomo VARCHAR(3) NULL ,
      fch_mov DATETIME NULL ,
      mov VARCHAR(3) NULL ,
      salario FLOAT NULL ,
      diastr INT NULL ,
      incap INT NULL ,
      ausen DECIMAL(5, 2) NULL ,
      primaRT FLOAT NULL ,
      cuotaFija FLOAT NULL ,
      excedente FLOAT NULL ,
      excedentePatron FLOAT NULL ,
      exccedenteTrabajador FLOAT NULL ,
      prestacionesDinero FLOAT NULL ,
      prestacionesPatron FLOAT NULL ,
      prestacionesTrabajador FLOAT NULL ,
      gmp FLOAT NULL ,
      gmpPatron FLOAT NULL ,
      gmpTrabajador FLOAT NULL ,
      rt FLOAT NULL ,
      invalidezVida FLOAT NULL ,
      invalidezVidaPatron FLOAT NULL ,
      invalidezVidaTrabajador FLOAT NULL ,
      guarderias FLOAT NULL ,
      numeroIncapacidad VARCHAR(12) NULL ,
      nombreConcepto VARCHAR(30) NULL ,
      empresa INT NOT NULL
                  DEFAULT 0 ,
      tipo INT NOT NULL
               DEFAULT 0 ,
      tieneArt33 CHAR(1) ,
      tieneSemanaReducida CHAR(1) ,
      tieneJornadaReducida CHAR(2) ,
      salarioRegion NUMERIC(8, 2) ,
      salarioDF NUMERIC(8, 2) ,
      sumaPrimas FLOAT ,
      cuentaEmpleado INT ,
      consecutivo INT IDENTITY ,
      pensionEmpleado VARCHAR(4) ,
      jornadaEmpleado VARCHAR(3) ,
      articulo33Empleado VARCHAR(6) ,
      centro VARCHAR(15) ,
      centroNombre VARCHAR(30) ,
      diaFalta INT ,
      diaIncapacidad INT ,
      sumaPrimasPatron FLOAT ,
      sumaPrimasTrabajador FLOAT ,
      sumaPrimasPatronMasTrabajador FLOAT ,
      cesantiaVejez FLOAT NULL ,
      cesantiaVejezPatron FLOAT NULL ,
      cesantiaVejezTrabajador FLOAT NULL ,
      retiro FLOAT NULL ,
      infonavit FLOAT NULL ,
      rpu VARCHAR(3),
      tipoNomina INT,
      manoObra CHAR(1)
    )
    
AS 
    BEGIN

        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        --DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @fi DATETIME
        DECLARE @ff DATETIME
        DECLARE @prima_rt FLOAT
        DECLARE @ayoEmpresa INT
        --DECLARE @primaGuarderia FLOAT
        DECLARE @diasFaltaTope INT
        DECLARE @cvArt168I FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @rpu CHAR(1)
        DECLARE @art211 FLOAT

        --SET @infonavit = 5
        SET @diasFaltaTope = 7


        SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
        SET @ff = dbo.fin_mes(@mes, @ayo)


-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion ,
                @rpu = ISNULL(dbo.empresas.Rpu, 'N')
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion
                    

-- Obtiene Primas IMSS
             SELECT  @eymArt25 = primasImss.eymart25 ,
                     @eymPat25 = primasImss.eympat25 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra25 ELSE 0 END ,
                     @eymTra25 = primasImss.eymtra25, --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra25 END ,
                     @eymArt106I = primasImss.eymart106I ,
                     @eymArt1062 = primasImss.eymart1062 ,
                     @eymPat1062 = primasImss.eympat1062 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra1062 ELSE 0 END ,
                     @eymTra1062 = primasImss.eymtra1062 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra1062 END ,
                     @eymArt107 = primasImss.eymart107 ,
                     @eymPat107 = primasImss.eympat107 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra107 ELSE 0 END ,
                     @eymTra107 = primasImss.eymtra107 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra107 END ,
                     @ivArt147 = primasImss.ivart147 ,
                     @ivPat147 = primasImss.ivpat147 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.ivtra147 ELSE 0 END ,
                     @ivTra147 = primasImss.ivtra147 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.ivtra147 END ,
                     @cvArt168II = primasImss.cvart168II ,
                     @cvPat168II = primasImss.cvpat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
                     @cvTra168II = primasImss.cvtra168ii , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
                     @cvArt168I = primasImss.cvArt168I ,
                     @infonavit = primasImss.infonavitPorciento ,
                     @art211 = primasImss.art211
             FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
             --FROM    dbo.primas_imss AS primasImss
             --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa
             --                                        THEN @ayoEmpresa
             --                                        ELSE @ayo
             --                                   END

-- Obtiene Prima RT
        SELECT  @prima_rt = dbo.primas_rt.prima_rt
        FROM    dbo.primas_rt
        WHERE   dbo.primas_rt.empresa = @empresa
                AND dbo.primas_rt.fecha_inicial <= @fi
                AND dbo.primas_rt.fecha_final >= @ff


-- Prima Guarderias
        --SET @primaGuarderia = 1

        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  jornada ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  mov ,
                  empresa ,
                  tipo ,
                  tieneArt33 ,
                  tieneSemanaReducida ,
                  tieneJornadaReducida ,
                  primaRT ,
                  salarioRegion ,
                  salarioDF ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  articulo33Empleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  DISTINCT
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.jornada ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        ' ' ,
                        dbo.empresas.empresa ,
                        1 AS tipo ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN '+'
                             ELSE ' '
                        END AS tieneArticulo33 ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN '*'
                             ELSE ' '
                        END AS tieneSemanaReducida ,
                        CASE WHEN dbo.empleados.jornada = 6 THEN '**'
                             ELSE '  '
                        END AS tieneJornadaReducida ,
                        @prima_RT ,
                        @salarioRegion ,
                        @salarioDF ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN 'ART.33'
                             ELSE NULL
                        END AS articulo33Empleado ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON aItc.empresa = dbo.Llaves.empresa
                                                 AND aItc.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   aItc.mes_operacion = @mes
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  art39 ,
                  jornada ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  fch_mov ,
                  mov ,
                  salario ,
                  diastr ,
                  incap ,
                  ausen ,
                  primaRT ,
                  cuotaFija ,
                  excedente ,
                  excedentePatron ,
                  exccedenteTrabajador ,
                  prestacionesDinero ,
                  prestacionesPatron ,
                  prestacionesTrabajador ,
                  gmp ,
                  gmpPatron ,
                  gmpTrabajador ,
                  rt ,
                  invalidezVida ,
                  invalidezVidaPatron ,
                  invalidezVidaTrabajador ,
                  guarderias ,
                  empresa ,
                  tipo ,
                  salarioRegion ,
                  salarioDF ,
                  tieneArt33 ,
                  tieneSemanaReducida ,
                  tieneJornadaReducida ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  articulo33Empleado ,
                  centro ,
                  centroNombre ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  retiro ,
                  infonavit ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.art39 ,
                        dbo.empleados.jornada ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        aItc.fch_mov ,
                        CASE aItc.mov
                          WHEN 'IM' THEN ' '
                          WHEN 'RI' THEN 'R'
                          WHEN 'MS' THEN 'M/S'
                          ELSE aItc.mov
                        END AS mov ,
                        [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                @topeDF, @topeRegion,
                                                dbo.empleados.art39,
                                                aItc.mov) AS salario ,
                        aItc.diastr ,
                        aItc.incap ,
                        aItc.ausen ,
                        @prima_rt AS primaRT ,
                        [dbo].[CalculaCuotaImss](@salarioDF,
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymArt106I, 0 ) AS cuotaFija ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymPat1062, @eymTra1062) AS excedente ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymPat1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @eymPat1062, @eymTra1062) AS excedentePatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymTra1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @eymPat1062, @eymTra1062) AS exccedenteTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymPat107, @eymTra107) AS prestacionesDinero ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymPat107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @eymPat107, @eymTra107) AS prestacionesPatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymTra107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @eymPat107, @eymTra107) AS prestacionesTrabajador ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymArt25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @eymPat25, @eymTra25)
                        END AS gmp ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymPat25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           1, @eymPat25, @eymTra25)
                        END AS gmpPatron ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymTra25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           2, @eymPat25, @eymTra25)
                        END AS gmpTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @prima_rt, 0) AS rt ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivArt147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @ivPat147, @ivTra147)
                        END AS invalidezVida ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivPat147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           1, @ivPat147, @ivTra147)
                        END AS invalidezVidaPatron ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivTra147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           2, @ivPat147, @ivTra147)
                        END AS invalidezVidaTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @art211, 0) AS guarderias ,
                        dbo.empresas.empresa ,
                        2 AS tipo ,
                        @salarioRegion ,
                        @salarioDF ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN '+'
                             ELSE ' '
                        END AS tieneArticulo33 ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN '*'
                             ELSE ' '
                        END AS tieneSemanaReducida ,
                        CASE WHEN dbo.empleados.jornada = 6 THEN '**'
                             ELSE '  '
                        END AS tieneJornadaReducida ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN 'ART.33'
                             ELSE NULL
                        END AS articulo33Empleado ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @cvPat168II, @cvTra168II) AS cesantiaVejezTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @cvArt168I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvArt168II, 0) AS retiro ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @infonavit, 0) AS infonavit ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    ( ( dbo.empresas
                            INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                          )
                          LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                              AND conceptomarca.num_conc = 101
                        )
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   aItc.mes_operacion = @mes
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND conceptomarca.num_conc = 101
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND (
                             (aItc.mov = 'IM' AND aItc.diastr > 0)
                             OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                            )

-- Cuota Fija   106 I
-- Exec.        106 II
-- Pd.          107
-- Gmp          25
-- RT           71
-- Iv           147
-- Gps          211  
                                                      
    
    
        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  fch_mov ,
                  mov ,
                  --diastr ,
                  empresa ,
                  numeroIncapacidad ,
                  nombreConcepto ,
                  tipo ,
                  centro ,
                  centroNombre ,
                  diaFalta ,
                  diaIncapacidad ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.deducciones.fchinicio ,
                        dbo.deducciones.tipoinc ,
                        --dbo.deducciones.dias ,
                        dbo.empresas.empresa ,
                        dbo.deducciones.numeroinc ,
                        dbo.conceptos.concepto ,
                        3 AS tipo ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN dbo.deducciones.num_conc = 108
                             THEN dbo.deducciones.dias
                             ELSE NULL
                        END ,
                        CASE WHEN dbo.deducciones.num_conc >= 109
                                  AND dbo.deducciones.num_conc <= 111
                             THEN dbo.deducciones.dias
                             ELSE NULL
                        END ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        LEFT JOIN dbo.deducciones ON dbo.empleados.empresa = dbo.deducciones.empresa
                                                     AND dbo.empleados.codigo = dbo.deducciones.codigo
                        LEFT JOIN dbo.conceptos ON dbo.deducciones.empresa = dbo.conceptos.empresa
                                                   AND dbo.deducciones.num_conc = dbo.conceptos.num_conc
                                                   AND dbo.deducciones.clase = dbo.conceptos.clase
                                                   AND dbo.deducciones.centro = dbo.conceptos.centro
                        INNER JOIN dbo.Llaves ON dbo.deducciones.empresa = dbo.Llaves.empresa
                                                 AND dbo.deducciones.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   ( ( dbo.deducciones.fchinicio <= @fi
                            AND dbo.deducciones.fchtermino >= @fi
                            AND dbo.deducciones.fchinicio <= @ff
                          )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchtermino <= @ff
                             )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchinicio <= @ff
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                          OR ( dbo.deducciones.fchinicio <= @fi
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                        )
                        AND dbo.deducciones.empresa >= CASE WHEN @empresa = 0
                                                            THEN 0
                                                            ELSE @empresa
                                                       END
                        AND dbo.deducciones.empresa <= CASE WHEN @empresa = 0
                                                            THEN 9999
                                                            ELSE @empresa
                                                       END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND dbo.deducciones.codigo >= CASE WHEN @codigo = 0
                                                           THEN 0
                                                           ELSE @codigo
                                                      END
                        AND dbo.deducciones.codigo <= CASE WHEN @codigo = 0
                                                           THEN 99999999
                                                           ELSE @codigo
                                                      END
                        AND dbo.deducciones.num_conc >= 108
                        AND dbo.deducciones.num_conc <= 111
                        

        UPDATE  @cedulaMensual
        SET     sumaPrimas = cuotaFija + excedente + prestacionesDinero + gmp
                + rt + invalidezVida + guarderias ,
                sumaPrimasPatron = cuotaFija + excedentePatron
                + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron
                + guarderias ,
                sumaPrimasTrabajador = exccedenteTrabajador
                + prestacionesTrabajador + gmpTrabajador
                + invalidezVidaTrabajador ,
                sumaPrimasPatronMasTrabajador = cuotaFija + excedentePatron
                + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron
                + guarderias + exccedenteTrabajador + prestacionesTrabajador
                + gmpTrabajador + invalidezVidaTrabajador
        WHERE   empresa = @empresa
                AND tipo = 2
        
        UPDATE  cedulaMensual
        SET     cuentaEmpleado = 1
        FROM    @cedulaMensual AS cedulaMensual
        WHERE   cedulaMensual.empresa = @empresa
                AND cedulaMensual.codigo + cedulaMensual.consecutivo = ( SELECT TOP 1
                                                              cedulaMensual2.codigo
                                                              + cedulaMensual2.consecutivo
                                                              FROM
                                                              @cedulaMensual
                                                              AS cedulaMensual2
                                                              WHERE
                                                              cedulaMensual2.empresa = @empresa
                                                              AND cedulaMensual2.tipo > 1
                                                              AND cedulaMensual2.codigo = cedulaMensual.codigo
                                                              )
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaCedulaMensual
 * Project       : APSI Nomina
 * Description   : Calcula y llana la tabla de salida de la cedula mensual
 * Table name    : empresa, primas_imss, primas_rt, empleados, deducciones,
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Sabado, Marzo 13, 2010
 **************************************************************************************************/
IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'LlenaCedulaMensualUMA' ) 
    BEGIN
        DROP  FUNCTION [dbo].[LlenaCedulaMensualUMA]
    END
GO
CREATE FUNCTION [dbo].[LlenaCedulaMensualUMA]
    (
      @empresa NUMERIC(5) ,
      @codigo NUMERIC(8, 0) ,
      @ayo INT ,
      @mes INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT
    )
RETURNS @cedulaMensual TABLE
    (
      codigo NUMERIC(8, 0) NOT NULL
                           DEFAULT 0 ,
      nombre VARCHAR(50) NOT NULL
                         DEFAULT ' ' ,
      ap_paterno VARCHAR(50) NOT NULL
                             DEFAULT ' ' ,
      ap_materno VARCHAR(50) NULL ,
      afiliacion VARCHAR(10) NULL ,
      digvera CHAR(1) NULL ,
      curp VARCHAR(18) NULL ,
      art39 DECIMAL(6, 3) NULL ,
      jornada INT NOT NULL
                  DEFAULT 0 ,
      rfcalfa VARCHAR(4) NULL ,
      rfcnum CHAR(6) NULL ,
      rfchomo VARCHAR(3) NULL ,
      fch_mov DATETIME NULL ,
      mov VARCHAR(3) NULL ,
      salario FLOAT NULL ,
      diastr INT NULL ,
	  lic INT NULL,
      incap INT NULL ,
      ausen DECIMAL(5, 2) NULL ,
      primaRT FLOAT NULL ,
      cuotaFija FLOAT NULL ,
      excedente FLOAT NULL ,
      excedentePatron FLOAT NULL ,
      exccedenteTrabajador FLOAT NULL ,
      prestacionesDinero FLOAT NULL ,
      prestacionesPatron FLOAT NULL ,
      prestacionesTrabajador FLOAT NULL ,
      gmp FLOAT NULL ,
      gmpPatron FLOAT NULL ,
      gmpTrabajador FLOAT NULL ,
      rt FLOAT NULL ,
      invalidezVida FLOAT NULL ,
      invalidezVidaPatron FLOAT NULL ,
      invalidezVidaTrabajador FLOAT NULL ,
      guarderias FLOAT NULL ,
      numeroIncapacidad VARCHAR(12) NULL ,
      nombreConcepto VARCHAR(30) NULL ,
      empresa INT NOT NULL
                  DEFAULT 0 ,
      tipo INT NOT NULL
               DEFAULT 0 ,
      tieneArt33 CHAR(1) ,
      tieneSemanaReducida CHAR(1) ,
      tieneJornadaReducida CHAR(2) ,
      salarioRegion NUMERIC(8, 2) ,
      salarioDF NUMERIC(8, 2) ,
      sumaPrimas FLOAT ,
      cuentaEmpleado INT ,
      consecutivo INT IDENTITY ,
      pensionEmpleado VARCHAR(4) ,
      jornadaEmpleado VARCHAR(3) ,
      articulo33Empleado VARCHAR(6) ,
      centro VARCHAR(15) ,
      centroNombre VARCHAR(30) ,
      diaFalta INT ,
      diaIncapacidad INT ,
	  diaLicencia INT ,
      sumaPrimasPatron FLOAT ,
      sumaPrimasTrabajador FLOAT ,
      sumaPrimasPatronMasTrabajador FLOAT ,
      cesantiaVejez FLOAT NULL ,
      cesantiaVejezPatron FLOAT NULL ,
      cesantiaVejezTrabajador FLOAT NULL ,
      retiro FLOAT NULL ,
      infonavit FLOAT NULL ,
      rpu VARCHAR(3),
      tipoNomina INT,
      manoObra CHAR(1),
      aportacionInfonavit FLOAT,
      infonavitSinCredito FLOAT,
      infonavitConCredito FLOAT,
      folioObra INT,
      nombreObra VARCHAR(50),
      fechaInicioObra DATETIME,
      fechaFinObra DATETIME,
      diasObra INT
	  
    )
    
AS 
    BEGIN

        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        --DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @fi DATETIME
        DECLARE @ff DATETIME
        DECLARE @prima_rt FLOAT
        DECLARE @ayoEmpresa INT
        --DECLARE @primaGuarderia FLOAT
        DECLARE @diasFaltaTope INT
        DECLARE @cvArt168I FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @rpu CHAR(1)
        DECLARE @art211 FLOAT
        DECLARE @mesPago CHAR(6)
        DECLARE @mesAplicaUMA CHAR(6)
        DECLARE @fechaAplicaSiroc DATETIME
		DECLARE @fechaOperacion DATETIME
		DECLARE @mesEmpresa INT
        
        SET @fechaAplicaSiroc = CONVERT(DATETIME, '20170901')
        
        SET @mesPago = RIGHT(STR(@ayo),4) + RIGHT(STR(100 + @mes),2)
        SET @mesAplicaUMA = '201701'

        --SET @infonavit = 5
        SET @diasFaltaTope = 7


        SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
        SET @ff = dbo.fin_mes(@mes, @ayo)


-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion ,
                @rpu = ISNULL(dbo.empresas.Rpu, 'N'),
				@mesEmpresa = dbo.empresas.mes_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa

        SET @fechaOperacion = CONVERT(DATETIME, LTRIM(STR(@ayoEmpresa)) + RIGHT(100 + @mesEmpresa,2) + '01')


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion
                    

-- Obtiene Primas IMSS
             SELECT  @eymArt25 = primasImss.eymart25 ,
                     @eymPat25 = primasImss.eympat25 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra25 ELSE 0 END ,
                     @eymTra25 = primasImss.eymtra25, --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra25 END ,
                     @eymArt106I = primasImss.eymart106I ,
                     @eymArt1062 = primasImss.eymart1062 ,
                     @eymPat1062 = primasImss.eympat1062 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra1062 ELSE 0 END ,
                     @eymTra1062 = primasImss.eymtra1062 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra1062 END ,
                     @eymArt107 = primasImss.eymart107 ,
                     @eymPat107 = primasImss.eympat107 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra107 ELSE 0 END ,
                     @eymTra107 = primasImss.eymtra107 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra107 END ,
                     @ivArt147 = primasImss.ivart147 ,
                     @ivPat147 = primasImss.ivpat147 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.ivtra147 ELSE 0 END ,
                     @ivTra147 = primasImss.ivtra147 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.ivtra147 END ,
                     @cvArt168II = primasImss.cvart168II ,
                     @cvPat168II = primasImss.cvpat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
                     @cvTra168II = primasImss.cvtra168ii , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
                     @cvArt168I = primasImss.cvArt168I ,
                     @infonavit = primasImss.infonavitPorciento ,
                     @art211 = primasImss.art211
             FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
             --FROM    dbo.primas_imss AS primasImss
             --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa
             --                                        THEN @ayoEmpresa
             --                                        ELSE @ayo
             --                                   END

-- Obtiene Prima RT
        SELECT  @prima_rt = dbo.primas_rt.prima_rt
        FROM    dbo.primas_rt
        WHERE   dbo.primas_rt.empresa = @empresa
                AND dbo.primas_rt.fecha_inicial <= @fi
                AND dbo.primas_rt.fecha_final >= @ff


-- Prima Guarderias
        --SET @primaGuarderia = 1

        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  jornada ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  mov ,
                  empresa ,
                  tipo ,
                  tieneArt33 ,
                  tieneSemanaReducida ,
                  tieneJornadaReducida ,
                  primaRT ,
                  salarioRegion ,
                  salarioDF ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  articulo33Empleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  DISTINCT
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.jornada ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        ' ' ,
                        dbo.empresas.empresa ,
                        1 AS tipo ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN '+'
                             ELSE ' '
                        END AS tieneArticulo33 ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN '*'
                             ELSE ' '
                        END AS tieneSemanaReducida ,
                        CASE WHEN dbo.empleados.jornada = 6 THEN '**'
                             ELSE '  '
                        END AS tieneJornadaReducida ,
                        @prima_RT ,
                        @salarioRegion ,
                        @salarioDF ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN 'ART.33'
                             ELSE NULL
                        END AS articulo33Empleado ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON aItc.empresa = dbo.Llaves.empresa
                                                 AND aItc.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   aItc.mes_operacion = @mes
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  art39 ,
                  jornada ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  fch_mov ,
                  mov ,
                  salario ,
				  lic ,
                  diastr ,
                  incap ,
                  ausen ,
                  primaRT ,
                  cuotaFija ,
                  excedente ,
                  excedentePatron ,
                  exccedenteTrabajador ,
                  prestacionesDinero ,
                  prestacionesPatron ,
                  prestacionesTrabajador ,
                  gmp ,
                  gmpPatron ,
                  gmpTrabajador ,
                  rt ,
                  invalidezVida ,
                  invalidezVidaPatron ,
                  invalidezVidaTrabajador ,
                  guarderias ,
                  empresa ,
                  tipo ,
                  salarioRegion ,
                  salarioDF ,
                  tieneArt33 ,
                  tieneSemanaReducida ,
                  tieneJornadaReducida ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  articulo33Empleado ,
                  centro ,
                  centroNombre ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  retiro ,
                  infonavit ,
                  rpu,
                  tipoNomina,
                  manoObra,
                  aportacioninfonavit
                )
                SELECT  dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.art39 ,
                        dbo.empleados.jornada ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        aItc.fch_mov ,
                        CASE aItc.mov
                          WHEN 'IM' THEN ' '
                          WHEN 'RI' THEN 'R'
                          WHEN 'MS' THEN 'M/S'
                          WHEN 'UM' THEN 'UMA'
                          ELSE aItc.mov
                        END AS mov ,
                        [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                @topeRegion,
                                                dbo.empleados.art39,
                                                aItc.mov) AS salario ,
                        aItc.lic ,
                        aItc.diastr ,
                        aItc.incap ,
                        aItc.ausen ,
                        @prima_rt AS primaRT ,
                        [dbo].[CalculaCuotaImssUMA](CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END,
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymArt106I, 0 ) AS cuotaFija ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymPat1062, @eymTra1062) AS excedente ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymPat1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @eymPat1062, @eymTra1062) AS excedentePatron ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymTra1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @eymPat1062, @eymTra1062) AS exccedenteTrabajador ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymPat107, @eymTra107) AS prestacionesDinero ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymPat107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @eymPat107, @eymTra107) AS prestacionesPatron ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymTra107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @eymPat107, @eymTra107) AS prestacionesTrabajador ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymArt25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @eymPat25, @eymTra25)
                        END AS gmp ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymPat25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           1, @eymPat25, @eymTra25)
                        END AS gmpPatron ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymTra25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           2, @eymPat25, @eymTra25)
                        END AS gmpTrabajador ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @prima_rt, 0) AS rt ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivArt147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @ivPat147, @ivTra147)
                        END AS invalidezVida ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivPat147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           1, @ivPat147, @ivTra147)
                        END AS invalidezVidaPatron ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivTra147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           2, @ivPat147, @ivTra147)
                        END AS invalidezVidaTrabajador ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @art211, 0) AS guarderias ,
                        dbo.empresas.empresa ,
                        2 AS tipo ,
                        @salarioRegion ,
                        @salarioDF ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN '+'
                             ELSE ' '
                        END AS tieneArticulo33 ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN '*'
                             ELSE ' '
                        END AS tieneSemanaReducida ,
                        CASE WHEN dbo.empleados.jornada = 6 THEN '**'
                             ELSE '  '
                        END AS tieneJornadaReducida ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN 'ART.33'
                             ELSE NULL
                        END AS articulo33Empleado ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @cvPat168II, @cvTra168II) AS cesantiaVejezTrabajador ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @cvArt168I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvArt168II, 0) AS retiro ,
                        [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @infonavit, 0) AS infonavit ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra,

                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @infonavit, 0) AS aportacionInfonavit 
                        
                FROM    ( ( dbo.empresas
                            INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                          )
                          LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                              AND conceptomarca.num_conc = 101
                        )
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   aItc.mes_operacion = @mes
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND conceptomarca.num_conc = 101
                        AND dbo.empleados.borrado = 'N'
						AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND (
                             (aItc.mov = 'IM' AND aItc.diastr > 0)
                             OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'UM' AND aItc.diastr IS NOT NULL)
                            )

-- Cuota Fija   106 I
-- Exec.        106 II
-- Pd.          107
-- Gmp          25
-- RT           71
-- Iv           147
-- Gps          211  
                                                      
    
    
        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  fch_mov ,
                  mov ,
                  --diastr ,
                  empresa ,
                  numeroIncapacidad ,
                  nombreConcepto ,
                  tipo ,
                  centro ,
                  centroNombre ,
                  diaFalta ,
                  diaIncapacidad ,
				  diaLicencia ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        --dbo.deducciones.fchinicio ,
                        CASE WHEN dbo.deducciones.fchinicio <= @fi THEN @fi ELSE dbo.deducciones.fchinicio END AS 'fchinicio',
                        dbo.deducciones.tipoinc ,
                        --dbo.deducciones.dias ,
                        dbo.empresas.empresa ,
                        dbo.deducciones.numeroinc ,
                        --dbo.conceptos.concepto AS nombreConcepto ,
						[dbo].[NOM_FUN_ObtieneDescripcionIncidencia](dbo.deducciones.empresa, dbo.deducciones.num_conc, dbo.deducciones.justificar, dbo.deducciones.inicsubs, dbo.deducciones.clase, dbo.deducciones.centro) AS nombreConcepto,
                        3 AS tipo ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN dbo.deducciones.num_conc = 108
                             --THEN dbo.deducciones.dias
                             THEN CASE WHEN dbo.deducciones.fchinicio <= @fi
                                            AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @fi
                                            AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                       THEN DATEDIFF(dd, @fi, dbo.deducciones.fchinicio + dbo.deducciones.dias)
                                       ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                      AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                                 THEN dbo.deducciones.dias
                                                 ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                                AND dbo.deducciones.fchinicio <= @ff
                                                                AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                           THEN DATEDIFF(dd, dbo.deducciones.fchinicio, @ff) + 1
                                                           ELSE CASE WHEN dbo.deducciones.fchinicio <= @fi
                                                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                     THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                                     ELSE 0
                                                                END
                                                      END
                                            END
                                  END
                             ELSE NULL
                        END ,
                        CASE WHEN dbo.deducciones.num_conc >= 109
                                  AND dbo.deducciones.num_conc <= 111
                             THEN CASE WHEN dbo.deducciones.fchinicio <= @fi
                                            AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @fi
                                            AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                       THEN DATEDIFF(dd, @fi, dbo.deducciones.fchinicio + dbo.deducciones.dias)
                                       ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                      AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                                 THEN dbo.deducciones.dias
                                                 ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                                AND dbo.deducciones.fchinicio <= @ff
                                                                AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                           THEN DATEDIFF(dd, dbo.deducciones.fchinicio, @ff) + 1
                                                           ELSE CASE WHEN dbo.deducciones.fchinicio <= @fi
                                                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                     THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                                     ELSE 0
                                                                END
                                                      END
                                            END
                                  END
                             ELSE NULL
                        END ,
						CASE WHEN dbo.deducciones.num_conc = 109 AND dbo.deducciones.inicsubs = '4'
                             THEN CASE WHEN dbo.deducciones.fchinicio <= @fi
                                            AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @fi
                                            AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                       THEN DATEDIFF(dd, @fi, dbo.deducciones.fchinicio + dbo.deducciones.dias)
                                       ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                      AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                                 THEN dbo.deducciones.dias
                                                 ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                                AND dbo.deducciones.fchinicio <= @ff
                                                                AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                           THEN DATEDIFF(dd, dbo.deducciones.fchinicio, @ff) + 1
                                                           ELSE CASE WHEN dbo.deducciones.fchinicio <= @fi
                                                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                     THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                                     ELSE 0
                                                                END
                                                      END
                                            END
                                  END
                             ELSE NULL
                        END AS diaLicencia ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        LEFT JOIN dbo.deducciones ON dbo.empleados.empresa = dbo.deducciones.empresa
                                                     AND dbo.empleados.codigo = dbo.deducciones.codigo
                        LEFT JOIN dbo.conceptos ON dbo.deducciones.empresa = dbo.conceptos.empresa
                                                   AND dbo.deducciones.num_conc = dbo.conceptos.num_conc
                                                   AND dbo.deducciones.clase = dbo.conceptos.clase
                                                   AND dbo.deducciones.centro = dbo.conceptos.centro
                        INNER JOIN dbo.Llaves ON dbo.deducciones.empresa = dbo.Llaves.empresa
                                                 AND dbo.deducciones.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   ( ( dbo.deducciones.fchinicio <= @fi
                            AND dbo.deducciones.fchtermino >= @fi
                            AND dbo.deducciones.fchinicio <= @ff
                          )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchtermino <= @ff
                             )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchinicio <= @ff
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                          OR ( dbo.deducciones.fchinicio <= @fi
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                        )
                        AND dbo.deducciones.empresa >= CASE WHEN @empresa = 0
                                                            THEN 0
                                                            ELSE @empresa
                                                       END
                        AND dbo.deducciones.empresa <= CASE WHEN @empresa = 0
                                                            THEN 9999
                                                            ELSE @empresa
                                                       END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
						AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                        AND dbo.deducciones.codigo >= CASE WHEN @codigo = 0
                                                           THEN 0
                                                           ELSE @codigo
                                                      END
                        AND dbo.deducciones.codigo <= CASE WHEN @codigo = 0
                                                           THEN 99999999
                                                           ELSE @codigo
                                                      END
                        AND dbo.deducciones.num_conc >= 108
                        AND dbo.deducciones.num_conc <= 111
          
        IF @fi >= @fechaAplicaSiroc
           BEGIN
             INSERT @cedulaMensual
                    ( codigo,
                      nombre,
                      ap_paterno,
                      ap_materno,
                      empresa,
                      tipo,
                      centro,
                      centroNombre,
                      rpu,
                      tipoNomina,
                      manoObra,
                      folioObra,
                      nombreObra,
                      fechaInicioObra,
                      fechaFinObra,
                      diasObra
                    )
                    SELECT oe.codigo,
                           e.nombre,
                           e.ap_paterno,
                           e.ap_materno,
                           oe.empresa,
                           4 AS tipo,
                           ll.centro,
                           c.nomdepto AS centroNombre,
                           e.rpu,
                           ll.tiponom AS tipoNomina,
                           e.manoObra,
                           oe.Obra AS folioObra,
                           o.nombre AS nombreObra,
                           oe.fecha_i AS fechaInicioObra,
                           oe.fecha_f AS fechaFinObra,
                           CASE WHEN oe.fecha_i <= @fi AND oe.fecha_f >= @fi AND oe.fecha_f <= @ff
                                THEN DATEDIFF(dd, @fi, oe.fecha_f) + 1
                                ELSE CASE WHEN oe.fecha_i >= @fi AND oe.fecha_f <= @ff
                                          THEN DATEDIFF(dd, oe.fecha_i, oe.fecha_f) + 1
                                          ELSE CASE WHEN oe.fecha_i >= @fi AND oe.fecha_i <= @ff AND oe.fecha_f >= @ff
                                                    THEN DATEDIFF(dd, oe.fecha_i, @ff) + 1
                                                    ELSE CASE WHEN oe.fecha_i <= @fi AND oe.fecha_f >= @ff
                                                              THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                              ELSE 0
                                                         END
                                               END
                                     END
                           END AS diasObra
                    FROM dbo.Obras_emps AS oe
                         INNER JOIN dbo.Obras AS o ON oe.obra = o.obra AND oe.empresa = o.empresa
                         INNER JOIN dbo.empleados AS e ON oe.codigo = e.codigo AND oe.empresa = e.empresa
                         INNER JOIN dbo.Llaves AS ll ON e.codigo = ll.codigo AND e.empresa = ll.empresa
                         INNER JOIN dbo.centros AS c ON LTRIM(RTRIM(ll.centro)) = LTRIM(RTRIM(c.centro)) AND ll.empresa = c.empresa
                    WHERE ((oe.fecha_i <= @fi AND oe.fecha_f >= @fi AND oe.fecha_i <= @ff)
                           OR (oe.fecha_i >= @fi AND oe.fecha_f <= @ff)
                           OR (oe.fecha_i >= @fi AND oe.fecha_i <= @ff AND oe.fecha_f >= @ff)
                           OR (oe.fecha_i <= @fi AND oe.fecha_f >= @ff))
                          AND oe.empresa >= CASE WHEN @empresa = 0 THEN 0 ELSE @empresa END
                          AND oe.empresa <= CASE WHEN @empresa = 0 THEN 9999 ELSE @empresa END
                          AND e.cotiza_imss = 'S'
                          AND e.borrado = 'N'
						  AND CASE WHEN @fi >= @fechaOperacion THEN e.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                          AND oe.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END
                          AND oe.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END
           END

        UPDATE  @cedulaMensual
        SET     sumaPrimas = cuotaFija + excedente + prestacionesDinero + gmp
                + rt + invalidezVida + guarderias ,
                sumaPrimasPatron = cuotaFija + excedentePatron
                + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron
                + guarderias ,
                sumaPrimasTrabajador = exccedenteTrabajador
                + prestacionesTrabajador + gmpTrabajador
                + invalidezVidaTrabajador ,
                sumaPrimasPatronMasTrabajador = cuotaFija + excedentePatron
                + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron
                + guarderias + exccedenteTrabajador + prestacionesTrabajador
                + gmpTrabajador + invalidezVidaTrabajador
        WHERE   empresa = @empresa
                AND tipo = 2
        
        UPDATE  cedulaMensual
        SET     cuentaEmpleado = 1
        FROM    @cedulaMensual AS cedulaMensual
        WHERE   cedulaMensual.empresa = @empresa
                AND cedulaMensual.codigo + cedulaMensual.consecutivo = ( SELECT TOP 1
                                                              cedulaMensual2.codigo
                                                              + cedulaMensual2.consecutivo
                                                              FROM
                                                              @cedulaMensual
                                                              AS cedulaMensual2
                                                              WHERE
                                                              cedulaMensual2.empresa = @empresa
                                                              AND cedulaMensual2.tipo > 1
                                                              AND cedulaMensual2.codigo = cedulaMensual.codigo
                                                              )
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaCedulaMensual
 * Project       : APSI Nomina
 * Description   : Calcula y llana la tabla de salida de la cedula mensual
 * Table name    : empresa, primas_imss, primas_rt, empleados, deducciones,
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Sabado, Marzo 13, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'LlenaCedulaMensualInfonavit' ) 
    BEGIN
        DROP  FUNCTION [dbo].[LlenaCedulaMensualInfonavit]
    END
GO

CREATE FUNCTION [dbo].[LlenaCedulaMensualInfonavit]
    (
      @empresa NUMERIC(5) ,
      @codigo NUMERIC(8, 0) ,
      @ayo INT ,
      @mes INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT
    )
RETURNS @cedulaMensual TABLE
    (
      codigo NUMERIC(8, 0) NOT NULL
                           DEFAULT 0 ,
      nombre VARCHAR(30) NOT NULL
                         DEFAULT ' ' ,
      ap_paterno VARCHAR(30) NOT NULL
                             DEFAULT ' ' ,
      ap_materno VARCHAR(30) NULL ,
      afiliacion VARCHAR(10) NULL ,
      digvera CHAR(1) NULL ,
      curp VARCHAR(18) NULL ,
      art39 DECIMAL(6, 3) NULL ,
      jornada INT NOT NULL
                  DEFAULT 0 ,
      rfcalfa VARCHAR(4) NULL ,
      rfcnum CHAR(6) NULL ,
      rfchomo VARCHAR(3) NULL ,
      fch_mov DATETIME NULL ,
      mov VARCHAR(3) NULL ,
      salario FLOAT NULL ,
      diastr INT NULL ,
	  lic INT NULL,
      incap INT NULL ,
      ausen DECIMAL(5, 2) NULL ,
      primaRT FLOAT NULL ,
      cuotaFija FLOAT NULL ,
      excedente FLOAT NULL ,
      excedentePatron FLOAT NULL ,
      exccedenteTrabajador FLOAT NULL ,
      prestacionesDinero FLOAT NULL ,
      prestacionesPatron FLOAT NULL ,
      prestacionesTrabajador FLOAT NULL ,
      gmp FLOAT NULL ,
      gmpPatron FLOAT NULL ,
      gmpTrabajador FLOAT NULL ,
      rt FLOAT NULL ,
      invalidezVida FLOAT NULL ,
      invalidezVidaPatron FLOAT NULL ,
      invalidezVidaTrabajador FLOAT NULL ,
      guarderias FLOAT NULL ,
      numeroIncapacidad VARCHAR(12) NULL ,
      nombreConcepto VARCHAR(30) NULL ,
      empresa INT NOT NULL DEFAULT 0 ,
      tipo INT NOT NULL DEFAULT 0 ,
      tieneArt33 CHAR(1) ,
      tieneSemanaReducida CHAR(1) ,
      tieneJornadaReducida CHAR(2) ,
      salarioRegion NUMERIC(8, 2) ,
      salarioDF NUMERIC(8, 2) ,
      sumaPrimas FLOAT ,
      cuentaEmpleado INT ,
      consecutivo INT IDENTITY ,
      pensionEmpleado VARCHAR(4) ,
      jornadaEmpleado VARCHAR(3) ,
      articulo33Empleado VARCHAR(6) ,
      centro VARCHAR(15) ,
      centroNombre VARCHAR(30) ,
      diaFalta INT ,
      diaIncapacidad INT ,
	  diaLicencia INT ,
      sumaPrimasPatron FLOAT ,
      sumaPrimasTrabajador FLOAT ,
      sumaPrimasPatronMasTrabajador FLOAT ,
      cesantiaVejez FLOAT NULL ,
      cesantiaVejezPatron FLOAT NULL ,
      cesantiaVejezTrabajador FLOAT NULL ,
      retiro FLOAT NULL ,
      infonavit FLOAT NULL ,
      rpu VARCHAR(3),
      tipoNomina INT,
      manoObra CHAR(1),
      aportacionInfonavit FLOAT , --NOT NULL DEFAULT 0 ,
      numeroCredito CHAR(10) ,
      descuento FLOAT ,
      amortizacion FLOAT ,
      tipoCredito INT ,
      seguroVivienda FLOAT ,
      fechaInicioDescuento DATETIME ,
      fechaOtorgamiento DATETIME ,
      fechaSuspension DATETIME ,
      ntd INT ,
      info INT ,
      mes INT ,
      infonavitSinCredito FLOAT ,
      infonavitConCredito FLOAT ,
      sumaAportacionInfoanvit FLOAT ,
      sumaAportacionInfonavitSinCredito FLOAT ,
      sumaAportacionInfonavitConCredito FLOAT ,
      sumaAmortizacion FLOAT ,
      sumaAmortizacionMasSeguro FLOAT ,
      sumaTotalInfonavit FLOAT ,
      sumaTotal FLOAT ,
      acreditado INT 
    )
    
AS 
    BEGIN

        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        --DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @fi DATETIME
        DECLARE @ff DATETIME
        DECLARE @prima_rt FLOAT
        DECLARE @ayoEmpresa INT
        --DECLARE @primaGuarderia FLOAT
        DECLARE @diasFaltaTope INT
        DECLARE @cvArt168I FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @rpu CHAR(1)
        DECLARE @art211 FLOAT
        DECLARE @seguroVivienda INT

        --SET @infonavit = 5
        SET @diasFaltaTope = 7


        SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
        SET @ff = dbo.fin_mes(@mes, @ayo)


-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion ,
                @rpu = ISNULL(dbo.empresas.Rpu, 'N')
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion
                    

-- Obtiene Primas IMSS
             SELECT  @eymArt25 = primasImss.eymart25 ,
                     @eymPat25 = primasImss.eympat25 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra25 ELSE 0 END ,
                     @eymTra25 = primasImss.eymtra25, --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra25 END ,
                     @eymArt106I = primasImss.eymart106I ,
                     @eymArt1062 = primasImss.eymart1062 ,
                     @eymPat1062 = primasImss.eympat1062 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra1062 ELSE 0 END ,
                     @eymTra1062 = primasImss.eymtra1062 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra1062 END ,
                     @eymArt107 = primasImss.eymart107 ,
                     @eymPat107 = primasImss.eympat107 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra107 ELSE 0 END ,
                     @eymTra107 = primasImss.eymtra107 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra107 END ,
                     @ivArt147 = primasImss.ivart147 ,
                     @ivPat147 = primasImss.ivpat147 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.ivtra147 ELSE 0 END ,
                     @ivTra147 = primasImss.ivtra147 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.ivtra147 END ,
                     @cvArt168II = primasImss.cvart168II ,
                     @cvPat168II = primasImss.cvpat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
                     @cvTra168II = primasImss.cvtra168ii , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
                     @cvArt168I = primasImss.cvArt168I ,
                     @infonavit = primasImss.infonavitPorciento ,
                     @art211 = primasImss.art211
             FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
             --FROM    dbo.primas_imss AS primasImss
             --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa
             --                                        THEN @ayoEmpresa
             --                                        ELSE @ayo
             --                                   END

-- Obtiene Prima RT
        SELECT  @prima_rt = dbo.primas_rt.prima_rt
        FROM    dbo.primas_rt
        WHERE   dbo.primas_rt.empresa = @empresa
                AND dbo.primas_rt.fecha_inicial <= @fi
                AND dbo.primas_rt.fecha_final >= @ff


        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  jornada ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  mov ,
                  empresa ,
                  tipo ,
                  tieneArt33 ,
                  tieneSemanaReducida ,
                  tieneJornadaReducida ,
                  primaRT ,
                  salarioRegion ,
                  salarioDF ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  articulo33Empleado ,
                  centro ,
                  centroNombre ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  DISTINCT
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.jornada ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        ' ' ,
                        dbo.empresas.empresa ,
                        1 AS tipo ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN '+'
                             ELSE ' '
                        END AS tieneArticulo33 ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN '*'
                             ELSE ' '
                        END AS tieneSemanaReducida ,
                        CASE WHEN dbo.empleados.jornada = 6 THEN '**'
                             ELSE '  '
                        END AS tieneJornadaReducida ,
                        @prima_RT ,
                        @salarioRegion ,
                        @salarioDF ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN 'ART.33'
                             ELSE NULL
                        END AS articulo33Empleado ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON aItc.empresa = dbo.Llaves.empresa
                                                 AND aItc.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   aItc.mes_operacion = @mes
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  art39 ,
                  jornada ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  fch_mov ,
                  mov ,
                  salario ,
				  lic ,
                  diastr ,
                  incap ,
                  ausen ,
                  primaRT ,
                  cuotaFija ,
                  excedente ,
                  excedentePatron ,
                  exccedenteTrabajador ,
                  prestacionesDinero ,
                  prestacionesPatron ,
                  prestacionesTrabajador ,
                  gmp ,
                  gmpPatron ,
                  gmpTrabajador ,
                  rt ,
                  invalidezVida ,
                  invalidezVidaPatron ,
                  invalidezVidaTrabajador ,
                  guarderias ,
                  empresa ,
                  tipo ,
                  salarioRegion ,
                  salarioDF ,
                  tieneArt33 ,
                  tieneSemanaReducida ,
                  tieneJornadaReducida ,
                  pensionEmpleado ,
                  jornadaEmpleado ,
                  articulo33Empleado ,
                  centro ,
                  centroNombre ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  retiro ,
                  aportacionInfonavit ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.art39 ,
                        dbo.empleados.jornada ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        aItc.fch_mov ,
                        CASE aItc.mov
                          WHEN 'IM' THEN ' '
                          WHEN 'RI' THEN 'R'
                          WHEN 'MS' THEN 'M/S'
                          ELSE aItc.mov
                        END AS mov ,
                        [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                @topeDF, @topeRegion,
                                                dbo.empleados.art39,
                                                aItc.mov) AS salario ,
						aItc.lic ,
                        aItc.diastr ,
                        aItc.incap ,
                        aItc.ausen ,
                        @prima_rt AS primaRT ,
                        [dbo].[CalculaCuotaImss](@salarioDF,
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymArt106I, 0 ) AS cuotaFija ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymPat1062, @eymTra1062) AS excedente ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymPat1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @eymPat1062, @eymTra1062) AS excedentePatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymTra1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @eymPat1062, @eymTra1062) AS exccedenteTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @eymPat107, @eymTra107) AS prestacionesDinero ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymPat107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @eymPat107, @eymTra107) AS prestacionesPatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap, 0,
                                                 @eymTra107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @eymPat107, @eymTra107) AS prestacionesTrabajador ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymArt25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @eymPat25, @eymTra25)
                        END AS gmp ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymPat25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           1, @eymPat25, @eymTra25)
                        END AS gmpPatron ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           0, @eymTra25, 'N',
                                                           0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           2, @eymPat25, @eymTra25)
                        END AS gmpTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @prima_rt, 0) AS rt ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivArt147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @ivPat147, @ivTra147)
                        END AS invalidezVida ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivPat147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           1, @ivPat147, @ivTra147)
                        END AS invalidezVidaPatron ,
                        CASE WHEN dbo.empleados.pension_iv_cv = 'I'
                                  OR dbo.empleados.pension_iv_cv = 'C' THEN 0
                             ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @ivTra147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           2, @ivPat147, @ivTra147)
                        END AS invalidezVidaTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @art211, 0) AS guarderias ,
                        dbo.empresas.empresa ,
                        2 AS tipo ,
                        @salarioRegion ,
                        @salarioDF ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN '+'
                             ELSE ' '
                        END AS tieneArticulo33 ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN '*'
                             ELSE ' '
                        END AS tieneSemanaReducida ,
                        CASE WHEN dbo.empleados.jornada = 6 THEN '**'
                             ELSE '  '
                        END AS tieneJornadaReducida ,
                        ( SELECT TOP 1
                                    CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                         THEN 'P/IV'
                                         WHEN dbo.excepciones.excepcion1 = 'CV'
                                         THEN 'P/CV'
                                         ELSE NULL
                                    END
                          FROM      dbo.excepciones
                          WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                                    AND dbo.excepciones.codigo = dbo.empleados.codigo
                                    AND ( dbo.excepciones.excepcion1 = 'IV'
                                          OR dbo.excepciones.excepcion1 = 'CV'
                                        )
                        ) AS pensionEmpleado ,
                        CASE WHEN dbo.empleados.jornada >= 1
                                  AND dbo.empleados.jornada <= 5 THEN 'S/R'
                             WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                             ELSE NULL
                        END AS jornadaEmpleado ,
                        CASE WHEN dbo.empleados.art39 > 0 THEN 'ART.33'
                             ELSE NULL
                        END AS articulo33Empleado ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr,
                                                 aItc.incap,
                                                 aItc.ausen,
                                                 @cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 2, @cvPat168II, @cvTra168II) AS cesantiaVejezTrabajador ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @cvArt168I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @cvArt168II, 0) AS retiro ,
                        [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion, 0, --dbo.empleados.art39,
                                                              aItc.mov),
                                                 aItc.diastr, 0,
                                                 aItc.ausen,
                                                 @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                 0, @infonavit, 0) AS infonavit ,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu
                             ELSE NULL
                        END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    ( ( dbo.empresas
                            INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                          )
                          LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                              AND conceptomarca.num_conc = 101
                        )
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   aItc.mes_operacion = @mes
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND conceptomarca.num_conc = 101
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

                        AND (
                             (aItc.mov = 'IM' AND aItc.diastr > 0)
                             OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                             OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                            )
                              
-- Cuota Fija   106 I     
-- Exec.        106 II
-- Pd.          107
-- Gmp          25
-- RT           71
-- Iv           147
-- Gps          211  


        INSERT  @cedulaMensual
                ( codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  fch_mov ,
                  mov ,
                  empresa ,
                  numeroIncapacidad ,
                  nombreConcepto ,
                  tipo ,
                  centro ,
                  centroNombre ,
                  diaFalta ,
                  diaIncapacidad ,
				  diaLicencia ,
                  rpu,
                  tipoNomina,
                  manoObra
                )
                SELECT  dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.deducciones.fchinicio ,
                        dbo.deducciones.tipoinc ,
                        dbo.empresas.empresa ,
                        dbo.deducciones.numeroinc ,
                        --dbo.conceptos.concepto AS nombreConcepto ,
						[dbo].[NOM_FUN_ObtieneDescripcionIncidencia](dbo.deducciones.empresa, dbo.deducciones.num_conc, dbo.deducciones.justificar, dbo.deducciones.inicsubs, dbo.deducciones.clase, dbo.deducciones.centro) AS nombreConcepto,
                        3 AS tipo ,
                        dbo.Llaves.centro ,
                        dbo.centros.nomdepto ,
                        CASE WHEN dbo.deducciones.num_conc = 108 THEN dbo.deducciones.dias ELSE NULL END ,
                        CASE WHEN dbo.deducciones.num_conc >= 109 AND dbo.deducciones.num_conc <= 111 THEN dbo.deducciones.dias ELSE NULL END AS diaIncapacidad,
						CASE WHEN dbo.deducciones.num_conc = 109 AND dbo.deducciones.inicsubs = '4' THEN dbo.deducciones.dias ELSE NULL END AS diaLicencia,
                        CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                        dbo.Llaves.tiponom,
                        dbo.empleados.manoobra
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        LEFT JOIN dbo.deducciones ON dbo.empleados.empresa = dbo.deducciones.empresa
                                                     AND dbo.empleados.codigo = dbo.deducciones.codigo
                        LEFT JOIN dbo.conceptos ON dbo.deducciones.empresa = dbo.conceptos.empresa
                                                   AND dbo.deducciones.num_conc = dbo.conceptos.num_conc
                                                   AND dbo.deducciones.clase = dbo.conceptos.clase
                                                   AND dbo.deducciones.centro = dbo.conceptos.centro
                        INNER JOIN dbo.Llaves ON dbo.deducciones.empresa = dbo.Llaves.empresa
                                                 AND dbo.deducciones.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                WHERE   ( ( dbo.deducciones.fchinicio <= @fi
                            AND dbo.deducciones.fchtermino >= @fi
                            AND dbo.deducciones.fchinicio <= @ff
                          )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchtermino <= @ff
                             )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchinicio <= @ff
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                          OR ( dbo.deducciones.fchinicio <= @fi
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                        )
                        AND dbo.deducciones.empresa >= CASE WHEN @empresa = 0
                                                            THEN 0
                                                            ELSE @empresa
                                                       END
                        AND dbo.deducciones.empresa <= CASE WHEN @empresa = 0
                                                            THEN 9999
                                                            ELSE @empresa
                                                       END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND dbo.deducciones.codigo >= CASE WHEN @codigo = 0
                                                           THEN 0
                                                           ELSE @codigo
                                                      END
                        AND dbo.deducciones.codigo <= CASE WHEN @codigo = 0
                                                           THEN 99999999
                                                           ELSE @codigo
                                                      END
                        AND dbo.deducciones.num_conc >= 108
                        AND dbo.deducciones.num_conc <= 111
                        

        UPDATE  @cedulaMensual
        SET     sumaPrimas = cuotaFija + excedente + prestacionesDinero + gmp + rt + invalidezVida + guarderias ,
                sumaPrimasPatron = cuotaFija + excedentePatron + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron + guarderias ,
                sumaPrimasTrabajador = exccedenteTrabajador + prestacionesTrabajador + gmpTrabajador + invalidezVidaTrabajador ,
                sumaPrimasPatronMasTrabajador = cuotaFija + excedentePatron + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron + guarderias + exccedenteTrabajador + prestacionesTrabajador + gmpTrabajador + invalidezVidaTrabajador
        WHERE   empresa = @empresa
                AND tipo = 2
                
                
        UPDATE  cedulaMensual
        SET     cuentaEmpleado = 1
        FROM    @cedulaMensual AS cedulaMensual
        WHERE   cedulaMensual.empresa = @empresa
                AND cedulaMensual.codigo + cedulaMensual.consecutivo = (SELECT TOP 1
                                                                               cedulaMensual2.codigo + cedulaMensual2.consecutivo
                                                                        FROM @cedulaMensual AS cedulaMensual2
                                                                        WHERE cedulaMensual2.empresa = @empresa
                                                                              AND cedulaMensual2.tipo > 1
                                                                              AND cedulaMensual2.codigo = cedulaMensual.codigo
                                                                       )
                                                              
        -- Registro Amortizacion
        SET @seguroVivienda = CASE WHEN @fi >= CONVERT(DATETIME, '20060101') AND @ff <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fi >= CONVERT(DATETIME, '20090101') AND @ff <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fi >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END
                              
        UPDATE cedulaMensual
        SET numeroCredito = SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000 + dbo.infonavit.numcredito)), 2, 10),
            descuento = dbo.TemporalAmortizacion.descuento,
            tipoCredito = dbo.infonavit.tipo_cred,
            fechaInicioDescuento = dbo.infonavit.fecha,
            fechaOtorgamiento = dbo.infonavit.fch_otorga,
            fechaSuspension = dbo.infonavit.fch_termino,
            amortizacion = ISNULL(dbo.temporalAmortizacion.amortizacion, 0),
            seguroVivienda = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda ELSE 0 END,
            infonavitSinCredito = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) = 0 THEN cedulaMensualInfonavit.aportacionInfonavit ELSE 0 END,
            infonavitConCredito = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN cedulaMensualInfonavit.aportacionInfonavit ELSE 0 END,
            cedulaMensual.sumaTotal = cedulaMensualInfonavit.aportacionInfonavit + CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda + ISNULL(dbo.temporalAmortizacion.amortizacion, 0) ELSE 0 END,
            acreditado = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN 1 ELSE 0 END
        FROM @cedulaMensual AS cedulaMensual
             LEFT JOIN dbo.temporalAmortizacion ON cedulaMensual.empresa = dbo.temporalAmortizacion.empresa
                                                   AND cedulaMensual.codigo = dbo.temporalAmortizacion.codigo
             LEFT JOIN dbo.infonavit ON dbo.temporalAmortizacion.empresa = dbo.infonavit.empresa
                                        AND dbo.temporalAmortizacion.codigo = dbo.infonavit.codigo
                                        AND dbo.infonavit.fecha <= @ff
                                        AND dbo.infonavit.fch_termino >= @fi
             LEFT JOIN (SELECT cedulaMensualAportacion.empresa,
                                cedulaMensualAportacion.codigo,
                                SUM(ISNULL(cedulaMensualAportacion.aportacionInfonavit,0)) AS aportacionInfonavit 
                         FROM @cedulaMensual AS cedulaMensualAportacion
                         WHERE cedulaMensualAportacion.tipo = 2
                         GROUP BY cedulaMensualAportacion.empresa,
                                  cedulaMensualAportacion.codigo) AS cedulaMensualInfonavit ON cedulaMensual.codigo = cedulaMensualinfonavit.codigo
                                                                                              AND cedulaMensual.empresa = cedulaMensualInfonavit.empresa
             
        WHERE   cedulaMensual.cuentaEmpleado = 1
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaComprobanteAfore
 * Project       : APSI Nomina
 * Description   : Llena tabla con los resumen de cuotas obrero-patron del bimestre
 * Table name    : empresa, empleados, deducciones
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.LlenaComprobanteAfore') IS NOT NULL 
    DROP FUNCTION [dbo].[LlenaComprobanteAfore]
GO
CREATE FUNCTION [dbo].[LlenaComprobanteAfore]
    (
      @empresa INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @procesoName VARCHAR(100) ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT
    )
RETURNS @cedulaBimestral TABLE
    (
      empresa INT NOT NULL
                  DEFAULT 0 ,
      codigo INT NOT NULL
                 DEFAULT 0 ,
      nombre VARCHAR(30) NOT NULL
                         DEFAULT 0 ,
      ap_paterno VARCHAR(30) NOT NULL
                             DEFAULT 0 ,
      ap_materno VARCHAR(30) NULL ,
      afiliacion VARCHAR(10) NULL ,
      digvera CHAR(1) NULL ,
      curp VARCHAR(18) NULL ,
      rfcalfa VARCHAR(4) NULL ,
      rfcnum CHAR(6) NULL ,
      rfchomo VARCHAR(3) NULL ,
      retiro FLOAT NOT NULL
                   DEFAULT 0 ,
      cesantiaVejez FLOAT NOT NULL
                          DEFAULT 0 ,
      aportacionInfonavit FLOAT NOT NULL
                                DEFAULT 0 ,
      amortizacion FLOAT NOT NULL
                         DEFAULT 0 ,
      seguroVivienda FLOAT NOT NULL
                           DEFAULT 0 ,
      descuento FLOAT ,
      tipoCredito INT ,
      fechaInicioDescuento DATETIME ,
      fechaOtorgamiento DATETIME ,
      fechaSuspension DATETIME ,
      numeroCredito NUMERIC,
      cvArt168II FLOAT ,
      centro VARCHAR(15) ,
      nomDepto VARCHAR(30) ,
      seguroDesempleoCuota FLOAT ,
      seguroDesempleoPorciento FLOAT ,
      infonavitPorciento FLOAT
    )
AS 
    BEGIN
        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @seguroDesempleo FLOAT
        
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar 
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE 
            BEGIN
                SET @esBimestre = 'N'
            END
    
    
-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion    
    

-- Obtiene Primas IMSS
        SELECT  @retiro = primasImss.cvArt168I , --dbo.primas_imss.retiro ,
                @cvArt168II = primasImss.cvArt168II ,   --dbo.primas_imss.cvart168II ,
                @cvPat168II = primasImss.cvPat168II , --dbo.primas_imss.cvpat168II + CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.cvtra168ii ELSE 0 END ,
                @cvTra168II = primasImss.cvTra168II , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE dbo.primas_imss.cvtra168ii END ,
                @infonavit = primasImss.infonavitPorciento , --dbo.primas_imss.infonavit ,
                @seguroDesempleo = primasImss.seguroDesempleoPorciento
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss
        --WHERE   YEAR(dbo.primas_imss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END    
                                                
                                                
                                                
-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN concepto.hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN concepto.marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = concepto.variable1
        FROM    dbo.conceptos AS concepto
        WHERE   concepto.empresa = @empresa
                AND concepto.num_conc = 112                                                
    

        --SET @seguroVivienda = CASE WHEN YEAR(@fiNon) >= 2006
        --                                AND YEAR(@fiNon) <= 2008 THEN 8
        --                           WHEN YEAR(@fiNon) >= 2009 THEN 13
        --                           ELSE 0
        --                      END

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101')
                                        AND @ffPar <= CONVERT(DATETIME, '20081231')
                                   THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101')
                                        AND @ffPar <= CONVERT(DATETIME, '20101031')
                                   THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101')
                                   THEN 15
                                   ELSE 0
                              END

    
-- Registro Avisos
        INSERT  @cedulaBimestral
                ( empresa ,
                  codigo ,
                  nombre ,
                  ap_paterno ,
                  ap_materno ,
                  afiliacion ,
                  digvera ,
                  curp ,
                  rfcalfa ,
                  rfcnum ,
                  rfchomo ,
                  retiro ,
                  cesantiaVejez ,
                  aportacionInfonavit ,
                  amortizacion ,
                  seguroVivienda ,
                  descuento ,
                  tipoCredito ,
                  fechaInicioDescuento ,
                  fechaOtorgamiento ,
                  fechaSuspension ,
                  numeroCredito,
                  cvArt168II ,
                  centro ,
                  nomDepto ,
                  seguroDesempleoCuota ,
                  seguroDesempleoPorciento ,
                  infonavitPorciento
                )
                SELECT  dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           0,
                                                           aItc.ausen,
                                                           @retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @retiro, 0)),
                              2) AS retiro ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           aItc.incap,
                                                           aItc.ausen,
                                                           @cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @cvPat168II, 0)),
                              2) AS cesantiaVejez ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           0,
                                                           aItc.ausen,
                                                           @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @infonavit, 0)),
                              2) AS aportacionInfonavit ,
                        0 ,
                        0 ,
                        dbo.infonavit.descuento ,
                        dbo.infonavit.tipo_cred ,
                        dbo.infonavit.fecha ,
                        dbo.infonavit.fch_otorga ,
                        dbo.infonavit.fch_termino ,
                        dbo.infonavit.numcredito,
                        @cvArt168II ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                              @topeDF,
                                                              @topeRegion,
                                                              dbo.empleados.art39,
                                                              aItc.mov),
                                                           aItc.diastr,
                                                           0,
                                                           aItc.ausen,
                                                           @seguroDesempleo, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion,
                                                           0, @seguroDesempleo, 0)),
                              2) AS seguroDesempleoCuota ,
                        @seguroDesempleo AS seguroDesempleoPorciento ,
                        @infonavit
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        LEFT JOIN dbo.TemporalAmortizacion ON aItc.empresa = dbo.TemporalAmortizacion.empresa
                                                              AND aItc.codigo = dbo.TemporalAmortizacion.codigo
                        LEFT JOIN dbo.infonavit ON dbo.TemporalAmortizacion.empresa = dbo.infonavit.empresa
                                                   AND dbo.TemporalAmortizacion.codigo = dbo.infonavit.codigo
                        INNER JOIN dbo.SeleccionElementos ON dbo.empleados.empresa = dbo.SeleccionElementos.empresa
                                                             AND dbo.empleados.codigo = dbo.SeleccionElementos.codigo
                WHERE   aItc.mes_operacion >= @mesNon
                        AND aItc.mes_operacion <= @mesPar
                        AND aItc.ayo_operacion = @ayo
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.SeleccionElementos.procesoName = @procesoName
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                GROUP BY dbo.empleados.empresa ,
                        dbo.empleados.codigo ,
                        dbo.empleados.nombre ,
                        dbo.empleados.ap_paterno ,
                        dbo.empleados.ap_materno ,
                        dbo.empleados.afiliacion ,
                        dbo.empleados.digvera ,
                        dbo.empleados.curp ,
                        dbo.empleados.rfcalfa ,
                        dbo.empleados.rfcnum ,
                        dbo.empleados.rfchomo ,
                        dbo.infonavit.descuento ,
                        dbo.infonavit.tipo_cred ,
                        dbo.infonavit.fecha ,
                        dbo.infonavit.fch_otorga ,
                        dbo.infonavit.fch_termino ,
                        dbo.infonavit.numcredito ,
                        dbo.centros.centro ,
                        dbo.centros.nomdepto
                
        UPDATE  cedulaBimestre
        SET     cedulaBimestre.amortizacion = ISNULL(( SELECT SUM(dbo.TemporalAmortizacion.amortizacion)
                                                       FROM   dbo.TemporalAmortizacion
                                                       WHERE  dbo.TemporalAmortizacion.empresa = @empresa
                                                              AND dbo.TemporalAmortizacion.codigo = cedulaBimestre.codigo
                                                     ), 0) ,
                cedulaBimestre.seguroVivienda = @seguroVivienda
                * ISNULL(( SELECT   COUNT(*)
                           FROM     dbo.TemporalAmortizacion
                           WHERE    dbo.TemporalAmortizacion.empresa = @empresa
                                    AND dbo.TemporalAmortizacion.codigo = cedulaBimestre.codigo
                                    AND dbo.TemporalAmortizacion.amortizacion > 0
                         ), 0)
        FROM    @cedulaBimestral AS cedulaBimestre
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaImpresionNomina
 * Project       : APSI Nomina
 * Description   : llena la tabla de salida de la nomina
 * Table name    : empresa, primas_imss, empleados, llaves,
 *               : avisos_imss, conceptos, kardex
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Viernes, Julio 02, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.LlenaImpresionNomina') IS NOT NULL
    DROP  FUNCTION [dbo].[LlenaImpresionNomina]
GO
CREATE FUNCTION [dbo].[LlenaImpresionNomina]
    (
      @empresa INT ,
      @tipoNomina INT ,
      @nomina CHAR(3) ,
      @incluirProvisiones CHAR(1) ,
      @procesoName VARCHAR(100) ,
      @ordenadoPor INT ,
      @desglosadoPor INT ,
      @porCentro INT ,
      @esRecibo INT ,
      @codigoSeleccionado VARCHAR(500) ,
      @ayoEjercicio INT ,
      @saltoPagina CHAR(1)
    )
RETURNS @kardex TABLE
    (
      empresa INT ,
      codigoId VARCHAR(100) ,
      codigo INT ,
      nombre VARCHAR(100) ,
      fechaAlta DATETIME ,
      numeroSeguridadSocial VARCHAR(10) ,
      digitoVerificador CHAR(1) ,
      curp VARCHAR(18) ,
      centro VARCHAR(16) ,
      nombreCentro VARCHAR(50) ,
      cuentaBanco VARCHAR(30) ,
      nombreBanco VARCHAR(50) ,
      ocupacion INT ,
      categoria VARCHAR(50) ,
      tipoSalario INT ,
      renglon INT ,
      jornada INT ,
      sueldoDiario FLOAT ,
      salarioBaseCotizacion FLOAT ,
      clase VARCHAR(3) ,
      nombreClase VARCHAR(50) ,
      supervisor INT ,
      nombreSupervisor VARCHAR(50) ,
      marcaContraPercepcion CHAR(1) ,
      numeroConceptoPercepcion INT ,
      nombreConceptoPercepcion VARCHAR(50) ,
      importeConceptoPercepcion FLOAT ,
      gravablePercepcion FLOAT ,
      exentoPercepcion FLOAT ,
      saldoPercepcion FLOAT ,
      anexoConceptoPercepcion VARCHAR(150) ,
      marcaContraDeduccion CHAR(1) ,
      numeroConceptoDeduccion INT ,
      nombreConceptoDeduccion VARCHAR(50) ,
      importeConceptoDeduccion FLOAT ,
      gravableDeduccion FLOAT ,
      exentoDeduccion FLOAT ,
      saldoDeduccion FLOAT ,
      anexoConceptoDeduccion VARCHAR(150) ,
      numeroConceptoProvision INT ,
      nombreConceptoProvision VARCHAR(50) ,
      importeConceptoProvision FLOAT ,
      empleados INT ,
      provisionIMSS FLOAT ,
      provisionRCV FLOAT ,
      provisionINFONAVIT FLOAT ,
      retencionIMSS FLOAT ,
      retencionRCV FLOAT ,
      retencionINFONAVIT FLOAT ,
      empleadosConCuentaBancaria INT ,
      empleadosSinCuentaBancaria INT ,
      percepcionesConCuentaBancaria FLOAT ,
      deduccionesConCuentaBancaria FLOAT ,
      percepcionesSinCuentaBancaria FLOAT ,
      deduccionesSinCuentaBancaria FLOAT ,
      basePorcientoSobreNomina FLOAT ,
      porcientoSobreNomina FLOAT ,
      fondoAhorroAportacionEmpleado FLOAT ,
      fondoAhorroAportacionPatron FLOAT ,
      sueldoNetoGeneral FLOAT ,
      ejercicio INT ,
      diarioOficialDia INT ,
      diarioOficialMes INT ,
      diarioOficialAyo INT ,
      salarioMinimoDF FLOAT ,
      salarioMinimoRegion FLOAT ,
      eymArt25 FLOAT ,
      eymArt106ii FLOAT ,
      eymArt107 FLOAT ,
      ivArt147 FLOAT ,
      cvArt168ii FLOAT ,
      baseCalculo INT ,
      grupo VARCHAR(500) ,
      cuantosRecibos INT ,
      numeroRecibo INT ,
      recibo INT ,
      percepcionesEmpleado FLOAT ,
      deduccionesEmpleado FLOAT ,
      netoPagarEmpleado FLOAT ,
      grupoRecibo VARCHAR(500) ,
      rfcAlfa VARCHAR(4) ,
      rfcNum VARCHAR(6) ,
      rfcHomo VARCHAR(3) ,
      acumuladoPercepcion FLOAT ,
      acumuladoPercepcionGravable FLOAT ,
      acumuladoIsr FLOAT ,
      acumuladoInfonavit FLOAT ,
      acumuladoSar FLOAT ,
      acumuladoCv FLOAT ,
      email VARCHAR(100) ,
      fechaAntiguedad DATETIME ,
      procesoName VARCHAR(100) ,
      nomina CHAR(3) ,
      saltarPagina CHAR(1) ,
      firma CHAR(1) ,
      mov CHAR(2) ,
      foto VARCHAR(255),
      baseISN1      FLOAT,
      porcientoISN1 FLOAT,
      importeISN1   FLOAT,
      empleadosISN1 INT,
      baseISN2      FLOAT,
      porcientoISN2 FLOAT,
      importeISN2   FLOAT,
      empleadosISN2 INT ,
      imprimirResumen INT
    )
AS
    BEGIN
-- Variables para Primas IMSS
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @mesEmpresa INT
        DECLARE @ayoEmpresa INT
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @registroPatronal VARCHAR(10)
        DECLARE @consulta VARCHAR(4000)
        DECLARE @orden VARCHAR(200)
        DECLARE @numeroConceptoPercepcionInicioKardex INT
        DECLARE @numeroConceptoPercepcionTerminoKardex INT
        DECLARE @numeroConceptoContraPercepcionInicioKardex INT
        DECLARE @numeroConceptoContraPercepcionTerminoKardex INT
        DECLARE @numeroConceptoDeduccionInicioKardex INT
        DECLARE @numeroConceptoDeduccionTerminoKardex INT
        DECLARE @numeroConceptoContraDeduccionInicioKardex INT
        DECLARE @numeroConceptoContraDeduccionTerminoKardex INT
        DECLARE @numeroConceptoProvisionInicioKardex INT
        DECLARE @numeroConceptoProvisionTerminoKardex INT
        DECLARE @ejercicio INT
        DECLARE @diarioOficial DATETIME
        DECLARE @baseCalculo VARCHAR(25)
        DECLARE @codigoAnterior INT
        DECLARE @numeroRecibo INT
        DECLARE @cuantosRecibos INT
        DECLARE @percepcionesEmpleado FLOAT
        DECLARE @deduccionesEmpleado FLOAT
        DECLARE @netoPagarEmpleado FLOAT
        DECLARE @ayoOperacion INT
        DECLARE @firma CHAR(1)
        DECLARE @Regimen_Seguridad_Social CHAR(1)
        DECLARE @renglon TABLE
            (
              codigo INT ,
              nombre VARCHAR(100) ,
              centro VARCHAR(15) ,
              supervisor INT ,
              grupo VARCHAR(500) ,
              grupoRecibo VARCHAR(500) ,
              diferenciaRenglon INT ,
              ultimoRenglon INT ,
              renglon INT ,
              renglonesAgregar INT
            )
        DECLARE @agregaRenglon TABLE ( renglon INT )

        INSERT  @agregaRenglon
                ( renglon )
        VALUES  ( 1 )
        INSERT  @agregaRenglon
                ( renglon )
        VALUES  ( 2 )
        INSERT  @agregaRenglon
                ( renglon )
        VALUES  ( 3 )

        SET @numeroConceptoPercepcionInicioKardex = 1
        SET @numeroConceptoPercepcionTerminoKardex = 99
        SET @numeroConceptoContraPercepcionInicioKardex = 1101
        SET @numeroConceptoContraPercepcionTerminoKardex = 1199
        SET @numeroConceptoDeduccionInicioKardex = 101
        SET @numeroConceptoDeduccionTerminoKardex = 199
        SET @numeroConceptoContraDeduccionInicioKardex = 1001
        SET @numeroConceptoContraDeduccionTerminoKardex = 1099
        SET @numeroConceptoProvisionInicioKardex = CASE WHEN @incluirProvisiones = 'S'
                                                        THEN 201
                                                        ELSE 0
                                                   END
        SET @numeroConceptoProvisionTerminoKardex = CASE WHEN @incluirProvisiones = 'S'
                                                         THEN 299
                                                         ELSE 0
                                                    END



-- Obtiene datos de empresas
        SELECT TOP 1
                @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion ,
                @mesEmpresa = dbo.empresas.mes_operacion ,
                @registroPatronal = SUBSTRING(dbo.empresas.registro_patronal,
                                              1, 10) ,
                @Regimen_Seguridad_Social = dbo.empresas.Regimen_Seguridad_Social
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene primas IMSS en base al ao de operacion de la tabla empresas
        SELECT TOP 1
                @eymArt25 = dbo.primas_imss.eymart25 ,
                @eymPat25 = dbo.primas_imss.eympat25
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra25
                       ELSE 0
                  END ,
                @eymTra25 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                 ELSE dbo.primas_imss.eymtra25
                            END ,
                @eymArt106I = dbo.primas_imss.eymart106I ,
                @eymArt1062 = dbo.primas_imss.eymart1062 ,
                @eymPat1062 = dbo.primas_imss.eympat1062
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra1062
                       ELSE 0
                  END ,
                @eymTra1062 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                   ELSE dbo.primas_imss.eymtra1062
                              END ,
                @eymArt107 = dbo.primas_imss.eymart107 ,
                @eymPat107 = dbo.primas_imss.eympat107
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra107
                       ELSE 0
                  END ,
                @eymTra107 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                  ELSE dbo.primas_imss.eymtra107
                             END ,
                @ivArt147 = dbo.primas_imss.ivart147 ,
                @ivPat147 = dbo.primas_imss.ivpat147
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.ivtra147
                       ELSE 0
                  END ,
                @ivTra147 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                 ELSE dbo.primas_imss.ivtra147
                            END ,
                @retiro = dbo.primas_imss.retiro ,
                @cvArt168II = dbo.primas_imss.cvart168II ,
                @cvPat168II = dbo.primas_imss.cvpat168II
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.cvtra168ii
                       ELSE 0
                  END ,
                @cvTra168II = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                   ELSE dbo.primas_imss.cvtra168ii
                              END
        FROM    dbo.primas_imss
        WHERE   YEAR(dbo.primas_imss.periodo) = @ayoEmpresa



        SET @eymArt25 = CASE WHEN @eymArt25 IS NULL THEN 0
                             ELSE @eymArt25
                        END
        SET @eymPat25 = CASE WHEN @eymPat25 IS NULL THEN 0
                             ELSE @eymPat25
                        END
        SET @eymTra25 = CASE WHEN @eymTra25 IS NULL THEN 0
                             ELSE @eymTra25
                        END
        SET @eymArt106I = CASE WHEN @eymArt106I IS NULL THEN 0
                               ELSE @eymArt106I
                          END
        SET @eymArt1062 = CASE WHEN @eymArt1062 IS NULL THEN 0
                               ELSE @eymArt1062
                          END
        SET @eymPat1062 = CASE WHEN @eymPat1062 IS NULL THEN 0
                               ELSE @eymPat1062
                          END
        SET @eymTra1062 = CASE WHEN @eymTra1062 IS NULL THEN 0
                               ELSE @eymTra1062
                          END
        SET @eymArt107 = CASE WHEN @eymArt107 IS NULL THEN 0
                              ELSE @eymArt107
                         END
        SET @eymPat107 = CASE WHEN @eymPat107 IS NULL THEN 0
                              ELSE @eymPat107
                         END
        SET @eymTra107 = CASE WHEN @eymTra107 IS NULL THEN 0
                              ELSE @eymTra107
                         END
        SET @ivArt147 = CASE WHEN @ivArt147 IS NULL THEN 0
                             ELSE @ivArt147
                        END
        SET @ivPat147 = CASE WHEN @ivPat147 IS NULL THEN 0
                             ELSE @ivPat147
                        END
        SET @ivTra147 = CASE WHEN @ivTra147 IS NULL THEN 0
                             ELSE @ivTra147
                        END
        SET @retiro = CASE WHEN @retiro IS NULL THEN 0
                           ELSE @retiro
                      END
        SET @cvArt168II = CASE WHEN @cvArt168II IS NULL THEN 0
                               ELSE @cvArt168II
                          END
        SET @cvPat168II = CASE WHEN @cvPat168II IS NULL THEN 0
                               ELSE @cvPat168II
                          END
        SET @cvTra168II = CASE WHEN @cvTra168II IS NULL THEN 0
                               ELSE @cvTra168II
                          END
        SET @patronPagaIMSS = CASE WHEN @patronPagaIMSS IS NULL THEN 'N'
                                   ELSE @patronPagaIMSS
                              END


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesEmpresa, @ayoEmpresa)

        SET @salarioDF = @salarioRegionA

        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END

        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion

        SELECT  @ayoOperacion = ISNULL(dbo.Periodos.ayo_operacion, 0)
        FROM    dbo.Periodos
        WHERE   dbo.Periodos.empresa = @empresa
                AND dbo.Periodos.tiponom = @tipoNomina
                AND dbo.Periodos.estatus = 'A'

        SELECT  @firma = CASE WHEN dbo.Parametros_Nominas.Firma IS NULL
                              THEN 'N'
                              WHEN dbo.Parametros_Nominas.Firma <> 'T'
                              THEN 'N'
                              ELSE 'S'
                         END
        FROM    dbo.Parametros_Nominas
        WHERE   dbo.Parametros_Nominas.Empresa = @empresa
                AND dbo.Parametros_Nominas.TipoNom = @tipoNomina

        IF @procesoName = 'NominaDetalle'
            BEGIN
-- Prepara tabla virtual
                INSERT  @kardex
                        ( empresa ,
                          codigoId ,
                          codigo ,
                          nombre ,
                          fechaAlta ,
                          numeroSeguridadSocial ,
                          digitoVerificador ,
                          curp ,
                          centro ,
                          nombreCentro ,
                          cuentaBanco ,
                          nombreBanco ,
                          ocupacion ,
                          categoria ,
                          tipoSalario ,
                          jornada ,
                          sueldoDiario ,
                          salarioBaseCotizacion ,
                          clase ,
                          nombreClase ,
                          supervisor ,
                          nombreSupervisor ,
                          renglon ,
                          grupo ,
                          rfcAlfa ,
                          rfcNum ,
                          rfcHomo ,
                          email ,
                          fechaAntiguedad ,
                          procesoName ,
                          nomina ,
                          firma

                        )
                        SELECT DISTINCT
                                dbo.kardex.empresa ,
                                RIGHT(STR(100000000 + dbo.kardex.codigo), 8)
                                + RIGHT(STR(1000000000 + dbo.kardex.renglon),
                                        9) AS codigoId ,
                                dbo.kardex.codigo AS codigo ,
                                RTRIM(dbo.empleados.ap_paterno) + ' '
                                + RTRIM(dbo.empleados.ap_materno) + ' '
                                + RTRIM(dbo.empleados.nombre) AS nombre ,
                                dbo.empleados.fchalta ,
                                dbo.empleados.afiliacion ,
                                dbo.empleados.digvera ,
                                CASE WHEN LEN(dbo.empleados.curp) = 18
                                     THEN dbo.empleados.curp
                                     ELSE dbo.empleados.rfcalfa
                                          + dbo.empleados.rfcnum
                                          + dbo.empleados.rfchomo
                                END AS curp ,
                                dbo.Llaves.centro ,
                                dbo.centros.nomdepto ,
                                dbo.empleados.cta_bco_no ,
                                dbo.bancos.nombre AS nombreBanco ,
                                dbo.Llaves.ocupacion ,
                                dbo.tabulador.actividad ,
                                dbo.empleados.tiposal ,
                                dbo.empleados.jornada ,
                                dbo.empleados.sueldo ,
                                dbo.empleados.saldiaint ,
                                dbo.Llaves.clase ,
                                dbo.clases.nombre AS nombreClase ,
                                dbo.Llaves.supervisor ,
                                dbo.supervisores.nombre AS nombreSupervisor ,
                                dbo.kardex.renglon ,
                                CASE WHEN ( ( @ordenadoPor & 4 > 0
                                              OR @ordenadoPor & 8 > 0
                                            )
                                            OR ( ( @ordenadoPor & 1 > 0
                                                   OR @ordenadoPor & 2 > 0
                                                 )
                                                 AND @desglosadoPor & 2 > 0
                                               )
                                          )
                                     THEN SUBSTRING(dbo.Llaves.centro, 1, 15)
                                     WHEN ( @ordenadoPor & 16 > 0
                                            OR @ordenadopor & 32 > 0
                                          )
                                     THEN RTRIM(dbo.Llaves.centro)
                                          + RIGHT(STR(100000000
                                                      + dbo.Llaves.supervisor),
                                                  8)
                                     ELSE NULL
                                END ,
                                dbo.empleados.rfcalfa ,
                                dbo.empleados.rfcnum ,
                                dbo.empleados.rfchomo ,
                                dbo.datosemps.email ,
                                dbo.empleados.fchantigua ,
                                @procesoName ,
                                @nomina ,
                                @firma
                        FROM    dbo.kardex
                                INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                            AND dbo.kardex.codigo = dbo.empleados.codigo
                                INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                         AND dbo.empleados.codigo = dbo.Llaves.codigo
                                INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                          AND dbo.Llaves.empresa = dbo.centros.empresa
                                INNER JOIN dbo.tabulador ON dbo.centros.empresa = dbo.tabulador.empresa
                                                            AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
                                INNER JOIN dbo.bancos ON dbo.Llaves.banco = dbo.bancos.banco
                                INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa
                                                         AND dbo.Llaves.clase = dbo.clases.clase
                                INNER JOIN dbo.supervisores ON dbo.Llaves.empresa = dbo.supervisores.empresa
                                                              AND dbo.Llaves.supervisor = dbo.supervisores.supervisor
                                INNER JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                                            AND dbo.empleados.codigo = dbo.datosemps.codigo
                                INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN RTRIM(LTRIM(dbo.Llaves.centro))
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.nomina
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.kardex.nomina
                                                              ELSE '1'
                                                              END
                        WHERE   dbo.kardex.empresa = CASE WHEN @desglosadoPor
                                                              & 1 > 0
                                                          THEN @empresa
                                                          ELSE 0
                                                     END
                                AND dbo.kardex.nomina = @nomina
                                AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicioKardex
                                          AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTerminoKardex
                                        )
                                        OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicioKardex
                                             AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTerminoKardex
                                           )
                                      )
                                      OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicioKardex
                                             AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTerminoKardex
                                           )
                                           OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicioKardex
                                                AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTerminoKardex
                                              )
                                         )
                                      OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicioKardex
                                           AND dbo.kardex.num_conc <= @numeroConceptoProvisionTerminoKardex
                                         )
                                    )

--SELECT 1,* FROM @kardex ORDER BY centro, codigo, renglon

        -- Agrega Centros de nivel superior
                IF @desglosadoPor & 1 > 0
                   AND (@ordenadoPor & 4 > 0 OR @ordenadoPor & 8 > 0 OR @ordenadoPor & 16 > 0 OR @ordenadoPor & 32 > 0)
                    BEGIN
                        INSERT  @kardex
                                ( empresa ,
                                  codigoId ,
                                  codigo ,
                                  nombre ,
                                  fechaAlta ,
                                  numeroSeguridadSocial ,
                                  digitoVerificador ,
                                  curp ,
                                  centro ,
                                  nombreCentro ,
                                  cuentaBanco ,
                                  nombreBanco ,
                                  ocupacion ,
                                  categoria ,
                                  tipoSalario ,
                                  jornada ,
                                  sueldoDiario ,
                                  salarioBaseCotizacion ,
                                  clase ,
                                  nombreClase ,
                                  supervisor ,
                                  nombreSupervisor ,
                                  renglon ,
                                  grupo ,
                                  procesoName ,
                                  nomina
                                )
                                SELECT DISTINCT
                                        @empresa ,
                                        RIGHT(STR(100000000
                                                  + [dbo].[ResumenPorCentroNomina].codigo),
                                              8) + RIGHT(STR(1000000000
                                                             + [dbo].[ResumenPorCentroNomina].renglon),
                                                         9)
                                        + [dbo].[ResumenPorCentroNomina].centro AS codigoId ,
                                        [dbo].[ResumenPorCentroNomina].codigo ,
                                        CASE WHEN [dbo].[ResumenPorCentroNomina].codigo = 999999995
                                             THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZXXXX'
                                             ELSE 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ'
                                        END ,
                                        NULL AS fchalta ,
                                        NULL AS afiliacion ,
                                        NULL AS digvera ,
                                        NULL AS curp ,
                                        [dbo].[ResumenPorCentroNomina].centro ,
                                        CASE WHEN RTRIM(LTRIM(dbo.centros.centro)) = '99999999999997'
                                             THEN ' ' -- 'GENERAL'
                                             ELSE dbo.centros.nomdepto
                                        END ,
                                        NULL AS cta_bco_no ,
                                        NULL AS nombreBanco ,
                                        NULL AS ocupacion ,
                                        NULL AS actividad ,
                                        NULL AS tiposal ,
                                        NULL AS jornada ,
                                        NULL AS sueldo ,
                                        NULL AS saldiaint ,
                                        NULL AS clase ,
                                        NULL AS nombreClase ,
                                        CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                      OR @ordenadoPor & 32 > 0
                                                    )
                                                    AND ( @desglosadoPor & 1 > 0
                                                          OR @desglosadoPor
                                                          & 2 > 0
                                                        )
                                                  )
                                             THEN [dbo].[ResumenPorCentroNomina].supervisor
                                             ELSE NULL
                                        END AS supervisor ,
                                        CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                      OR @ordenadoPor & 32 > 0
                                                    )
                                                    AND ( @desglosadoPor & 1 > 0
                                                          OR @desglosadoPor
                                                          & 2 > 0
                                                        )
                                                  )
                                             THEN [dbo].[supervisores].nombre
                                             ELSE NULL
                                        END AS nombreSupervidor ,
                                        [dbo].[ResumenPorCentroNomina].renglon ,
                                        CASE WHEN ( ( @ordenadoPor & 4 > 0
                                                      OR @ordenadoPor & 8 > 0
                                                    )
                                                    OR ( ( @ordenadoPor & 1 > 0
                                                           OR @ordenadoPor & 2 > 0
                                                         )
                                                         AND @desglosadoPor
                                                         & 2 > 0
                                                       )
                                                  )
                                             THEN SUBSTRING([dbo].[ResumenPorCentroNomina].centro,
                                                            1, 15)
                                             WHEN ( ( @ordenadoPor & 16 > 0
                                                      OR @ordenadoPor & 32 > 0
                                                    )
                                                    AND ( @desglosadoPor & 1 > 0
                                                          OR @desglosadoPor
                                                          & 2 > 0
                                                        )
                                                  )
                                             THEN RTRIM([dbo].[ResumenPorCentroNomina].centro)
                                                  + RIGHT(STR(100000000
                                                              + CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              THEN 999999995
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END), 8)
                                             ELSE CASE WHEN @desglosadoPor & 4 > 0
                                                       THEN ''
                                                       ELSE NULL
                                                  END
                                        END ,
                                        @procesoName ,
                                        @nomina
                                FROM    [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'N', @tipoNomina,
                                                              'G',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              2, --@desglosadoPor,
                                                              @porCentro)
                                        INNER JOIN dbo.centros ON CASE
                                                              WHEN @porCentro = 1
                                                              AND [dbo].[ResumenPorCentroNomina].centro = '99999999999996'
                                                              THEN '99999999999997'
                                                              ELSE RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              END = RTRIM(LTRIM(dbo.centros.centro))
                                        INNER JOIN dbo.supervisores ON dbo.centros.empresa = dbo.supervisores.empresa
                                                              AND CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999995
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor IS NULL
                                                              THEN 0
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END = dbo.supervisores.supervisor
                                WHERE   dbo.centros.empresa = @empresa

--SELECT 2,* FROM @kardex ORDER BY centro, codigo, renglon
                    END
                ELSE
                   IF @esRecibo = 0
                      BEGIN
                            INSERT  @kardex
                                    ( empresa ,
                                      codigoId ,
                                      codigo ,
                                      nombre ,
                                      fechaAlta ,
                                      numeroSeguridadSocial ,
                                      digitoVerificador ,
                                      curp ,
                                      centro ,
                                      nombreCentro ,
                                      cuentaBanco ,
                                      nombreBanco ,
                                      ocupacion ,
                                      categoria ,
                                      tipoSalario ,
                                      jornada ,
                                      sueldoDiario ,
                                      salarioBaseCotizacion ,
                                      clase ,
                                      nombreClase ,
                                      supervisor ,
                                      nombreSupervisor ,
                                      renglon ,
                                      grupo ,
                                      procesoName ,
                                      nomina

                                    )
                                    SELECT DISTINCT
                                            @empresa ,
                                            RIGHT(STR(100000000
                                                      + [dbo].[ResumenPorCentroNomina].codigo),
                                                  8) + RIGHT(STR(1000000000
                                                              + [dbo].[ResumenPorCentroNomina].renglon),
                                                             9)
                                            + [dbo].[ResumenPorCentroNomina].centro AS codigoId ,
                                            [dbo].[ResumenPorCentroNomina].codigo ,
                                            CASE WHEN [dbo].[ResumenPorCentroNomina].codigo = 999999995
                                                 THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZXXXX'
                                                 ELSE 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ'
                                            END ,
                                            NULL AS fchalta ,
                                            NULL AS afiliacion ,
                                            NULL AS digvera ,
                                            NULL AS curp ,
                                            [dbo].[ResumenPorCentroNomina].centro ,
                                            CASE WHEN RTRIM(LTRIM(dbo.centros.centro)) = '99999999999997'
                                                 THEN ' ' -- 'GENERAL'
                                                 ELSE dbo.centros.nomdepto
                                            END ,
                                            NULL AS cta_bco_no ,
                                            NULL AS nombreBanco ,
                                            NULL AS ocupacion ,
                                            NULL AS actividad ,
                                            NULL AS tiposal ,
                                            NULL AS jornada ,
                                            NULL AS sueldo ,
                                            NULL AS saldiaint ,
                                            NULL AS clase ,
                                            NULL AS nombreClase ,
                                            CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                          OR @ordenadoPor & 32 > 0
                                                        )
                                                        AND ( @desglosadoPor
                                                              & 1 > 0
                                                              OR @desglosadoPor
                                                              & 2 > 0
                                                            )
                                                      )
                                                 THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                 ELSE NULL
                                            END AS supervisor ,
                                            CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                          OR @ordenadoPor & 32 > 0
                                                        )
                                                        AND ( @desglosadoPor
                                                              & 1 > 0
                                                              OR @desglosadoPor
                                                              & 2 > 0
                                                            )
                                                      )
                                                 THEN [dbo].[supervisores].nombre
                                                 ELSE NULL
                                            END AS nombreSupervidor ,
                                            [dbo].[ResumenPorCentroNomina].renglon ,
                                            CASE WHEN ( ( @ordenadoPor & 4 > 0
                                                          OR @ordenadoPor & 8 > 0
                                                        )
                                                        OR ( ( @ordenadoPor
                                                              & 1 > 0
                                                              OR @ordenadoPor
                                                              & 2 > 0
                                                             )
                                                             AND @desglosadoPor
                                                             & 2 > 0
                                                           )
                                                      )
                                                 THEN SUBSTRING([dbo].[ResumenPorCentroNomina].centro,
                                                              1, 15)
                                                 WHEN ( ( @ordenadoPor & 16 > 0
                                                          OR @ordenadoPor & 32 > 0
                                                        )
                                                        AND ( @desglosadoPor
                                                              & 1 > 0
                                                              OR @desglosadoPor
                                                              & 2 > 0
                                                            )
                                                      )
                                                 THEN RTRIM([dbo].[ResumenPorCentroNomina].centro)
                                                      + RIGHT(STR(100000000
                                                              + CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              THEN 999999995
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END), 8)
                                                 ELSE CASE WHEN @desglosadoPor
                                                              & 4 > 0 THEN ''
                                                           ELSE NULL
                                                      END
                                            END ,
                                            @procesoName ,
                                            @nomina
                                    FROM    [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'N', @tipoNomina,
                                                              'G',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadoPor,
                                                              @porCentro)
                                            INNER JOIN dbo.centros ON CASE
                                                              WHEN @porCentro = 1
                                                              AND [dbo].[ResumenPorCentroNomina].centro = '99999999999996'
                                                              THEN '99999999999997'
                                                              ELSE RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              END = RTRIM(LTRIM(dbo.centros.centro))
                                            INNER JOIN dbo.supervisores ON dbo.centros.empresa = dbo.supervisores.empresa
                                                              AND CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999995
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor IS NULL
                                                              THEN 0
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END = dbo.supervisores.supervisor
                                    WHERE   dbo.centros.empresa = @empresa


               --SELECT 3,* FROM @kardex ORDER BY centro, codigo, renglon
               --SELECT 2,* FROM @kardex ORDER BY codigo, renglon
                        END



                    --SELECT 3,* FROM @kardex ORDER BY centro, codigo, renglon



                -- solo cuando quiere imprimir el detalle de empleado
                IF @desglosadoPor & 1 > 0
                    BEGIN
                        -- Carga Percepciones por empleado
                        UPDATE  @kardex
                        SET     marcaContraPercepcion = CASE WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                             THEN 'C'
                                                             WHEN dbo.kardex.tipo_mov = 'FIN'
                                                             THEN 'F'
                                                             ELSE NULL
                                                        END ,
                                numeroConceptoPercepcion = dbo.kardex.num_conc ,
                                nombreConceptoPercepcion = dbo.kardex.concepto ,
                                importeConceptoPercepcion = dbo.kardex.importe ,
                                gravablePercepcion = dbo.kardex.igravable ,
                                exentoPercepcion = dbo.kardex.iexento ,
                                saldoPercepcion = CASE WHEN dbo.kardex.saldo > 0
                                                       THEN dbo.kardex.saldo
                                                       ELSE NULL
                                                  END ,
                                anexoConceptoPercepcion = CASE
                                      -- Detalle Sueldo
                                                              WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 8
                                                              THEN CONVERT(VARCHAR(15), dbo.AgregaComa(dbo.kardex.impor_base))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle Horas Extras
                                                              WHEN dbo.kardex.num_conc >= 10
                                                              AND dbo.kardex.num_conc <= 13
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.horas))
                                                              + ' Horas'

                                      -- Detalle Prima Vacacional
                                                              WHEN dbo.kardex.num_conc = 17
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle Vacaciones
                                                              WHEN dbo.kardex.num_conc = 30
                                                              THEN CONVERT(VARCHAR(15), dbo.AgregaComa(dbo.kardex.impor_base))
                                                              + ' * ' + '('
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + 'H' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + 'D' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + 'F' + ')'

                                      -- Detalle Subsidio para el Empleo
                                                              WHEN dbo.kardex.num_conc = 36
                                                              THEN CASE
                                                              WHEN dbo.kardex.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoEmpresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoEmpresa < 2014
                                                                        THEN 'Art 8vo Trans$'
                                                                        ELSE 'Art 10 Trans$'
                                                                   END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              ELSE ''
                                                              END
                                                              END
                                                              

                                      -- Detalle Concepto 53 Por Registro Patronal
                                                              WHEN dbo.kardex.num_conc = 53
                                                              AND ( @registroPatronal = 'R131234638'
                                                              OR @registroPatronal = 'C166197810'
                                                              OR @registroPatronal = 'C166939010'
                                                              OR @registroPatronal = 'E647730310'
                                                              OR @registroPatronal = 'E648122510'
                                                              OR @registroPatronal = 'C534928610'
                                                              )
                                                              THEN SUBSTRING(dbo.kardex.referencia,
                                                              01, 06)
                                                              + RIGHT(RTRIM(dbo.kardex.referencia),
                                                              02) + ' (M'
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.unidades))
                                                              + ')'

                                      -- Detalle Sueldo Neto
                                                              WHEN dbo.kardex.num_conc = 99
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle de conceptos de Contras del 1107 al 1111
                                                              WHEN dbo.kardex.num_conc >= 1107
                                                              AND dbo.kardex.num_conc <= 1111
                                                              THEN CASE
                                                              WHEN dbo.kardex.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'
                                                              ELSE ''
                                                              END

                                      -- Detalle Conceptos con Valor Variable
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                              END
                                                          END ,
                                mov = CASE WHEN dbo.kardex.num_conc <= 6
                                           THEN RTRIM(dbo.kardex.referencia)
                                           ELSE NULL
                                      END
                        FROM    @kardex
                                INNER JOIN dbo.kardex ON [@kardex].empresa = dbo.kardex.empresa
                                                         AND [@kardex].codigo = dbo.kardex.codigo
                                                         AND [@kardex].renglon = dbo.kardex.renglon
                                                         AND @nomina = dbo.kardex.nomina
                        WHERE   [@kardex].empresa = @empresa
                                AND ( ( dbo.kardex.num_conc >= 1
                                        AND dbo.kardex.num_conc <= 99
                                      )
                                      OR ( dbo.kardex.num_conc >= 1101
                                           AND dbo.kardex.num_conc <= 1199
                                         )
                                    )
                                AND dbo.kardex.nomina = @nomina

                        -- Carga Deducciones
                        UPDATE  @kardex
                        SET     marcaContraDeduccion = CASE WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                            THEN 'C'
                                                            WHEN dbo.kardex.tipo_mov = 'FIN'
                                                            THEN 'F'
                                                            ELSE NULL
                                                       END ,
                                numeroConceptoDeduccion = dbo.kardex.num_conc ,
                                nombreConceptoDeduccion = dbo.kardex.concepto ,
                                importeConceptoDeduccion = dbo.kardex.importe ,
                                gravableDeduccion = dbo.kardex.igravable ,
                                exentoDeduccion = dbo.kardex.iexento ,
                                saldoDeduccion = CASE WHEN dbo.kardex.saldo > 0
                                                      THEN --CASE WHEN dbo.kardex.num_conc = 126 THEN dbo.kardex.importe + dbo.kardex.saldo
                                                   --     WHEN dbo.kardex.num_conc = 127 THEN dbo.kardex.importe + dbo.kardex.saldo
                                                   --     ELSE dbo.kardex.saldo
                                                   --END
                                                           CASE
                                                              WHEN ( dbo.conceptos.marca2 = 'P'
                                                              OR ( dbo.kardex.num_conc >= 115
                                                              AND dbo.kardex.num_conc <= 117
                                                              )
                                                              )
                                                              THEN dbo.kardex.saldo
                                                              - dbo.kardex.importe
                                                              WHEN ( dbo.conceptos.marca2 = 'H'
                                                                   OR ( dbo.kardex.num_conc >= 125
                                                                   AND dbo.kardex.num_conc <= 127
                                                                   )
                                                                   OR dbo.kardex.num_conc = 112
                                                                   )
                                                              THEN dbo.kardex.saldo
                                                              + dbo.kardex.importe
                                                              ELSE NULL
                                                           END
                                                      ELSE NULL
                                                 END ,
                                anexoConceptoDeduccion = CASE
                                      -- Detalle Cuotas IMSS
                                                              WHEN (dbo.kardex.num_conc >= 101
                                                                    AND dbo.kardex.num_conc <= 105
                                                                    AND @Regimen_Seguridad_Social <> '2')
                                                                   THEN CONVERT(VARCHAR(15), CASE WHEN dbo.kardex.num_conc = 102
                                                                                                       THEN CASE WHEN dbo.kardex.saldiaint > ( @salarioDF * 3 )
                                                                                                                      THEN dbo.AgregaComa(dbo.kardex.saldiaint - ( @salarioDF * 3 ))
                                                                                                                      ELSE dbo.AgregaComa(dbo.kardex.saldiaint)
                                                                                                                 END
                                                                                                       ELSE dbo.AgregaComa(dbo.kardex.saldiaint)
                                                                                             END) + ' * ' + CASE WHEN dbo.kardex.num_conc = 101 THEN CONVERT(VARCHAR(15), @eymTra25)
                                                                                                                 WHEN dbo.kardex.num_conc = 102 THEN CONVERT(VARCHAR(15), @eymTra1062)
                                                                                                                 WHEN dbo.kardex.num_conc = 103 THEN CONVERT(VARCHAR(15), @eymTra107)
                                                                                                                 WHEN dbo.kardex.num_conc = 104 THEN CONVERT(VARCHAR(15), @ivTra147)
                                                                                                                 WHEN dbo.kardex.num_conc = 105 THEN CONVERT(VARCHAR(15), @cvTra168II)
                                                                                                                 ELSE ''
                                                                                                            END + ' * ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias_imss))

                                      -- Detalle Retencion IMSS por Faltas
                                                              WHEN (dbo.kardex.num_conc = 106 AND @Regimen_Seguridad_Social <> '2')
                                                                    OR dbo.kardex.num_conc = 107
                                                                    OR dbo.kardex.num_conc = 109
                                                                    OR dbo.kardex.num_conc = 110
                                                                    OR dbo.kardex.num_conc = 111
                                                                    OR dbo.kardex.num_conc = 130
                                                                   THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias)) + ' Da(s)'

                                      -- Detalle Faltas
                                                              WHEN dbo.kardex.num_conc = 108
                                                                   THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                        + ' Da(s)'
                                                                        + ' + '
                                                                        + CONVERT(VARCHAR(15), dbo.ChecaDecimales(ABS(dbo.kardex.descuento
                                                                        - 100))) + '%'

                                      -- Detalle Creditos INFONAVIT
                                                              WHEN dbo.kardex.num_conc = 112 AND dbo.kardex.saldo = 0 AND dbo.kardex.dias > 0
                                                                   THEN CASE WHEN dbo.kardex.descuento > 0
                                                                                  THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.saldiaint))
                                                                                       + ' * '
                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                                       + ' * '
                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.descuento))
                                                                                       + '%'
                                                                                  ELSE CONVERT(VARCHAR(15), CONVERT(NUMERIC(15,
                                                                                       2), dbo.ChecaDecimales(ROUND(dbo.kardex.importe
                                                                                       / dbo.kardex.dias,
                                                                                       2)))) + ' * '
                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                                       + 'DS'
                                                                        END

                                      -- Detalle Fondo de Ahorro
                                                              WHEN dbo.kardex.num_conc = 125
                                                                   OR dbo.kardex.num_conc = 126
                                                                   OR dbo.kardex.num_conc = 127
                                                                   OR (dbo.kardex.num_conc = 112 AND dbo.kardex.saldo > 0)
                                                                   THEN 'Saldo $ '
                                                                        + dbo.AgregaComa(dbo.kardex.saldo
                                                                        + dbo.kardex.importe)

                                      -- Detalle ISR
                                                              WHEN dbo.kardex.num_conc = 136
                                                                   THEN CASE WHEN dbo.kardex.variable1 = '1991'
                                                                             THEN '1991'
                                                                             ELSE CASE WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                                                            THEN CASE WHEN @ayoEmpresa < 2008
                                                                                                      THEN 'Art. 115 $'
                                                                                                      WHEN @ayoEmpresa < 2014
                                                                                                      THEN 'Art. 8vo Trans$'
                                                                                                      ELSE 'Art 10 Trans$'
                                                                                                 END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                                                            ELSE ''
                                                                                  END
                                                                        END

                                      -- Contra Sueldo
                                                              WHEN dbo.kardex.num_conc >= 1001
                                                                   AND dbo.kardex.num_conc <= 1007
                                                                   THEN CASE WHEN dbo.kardex.dias > 0
                                                                             THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                                  + ' Da(s)'
                                                                             ELSE ''
                                                                        END

                                      -- Detalle los demas conceptos
                                                              ELSE CASE WHEN dbo.kardex.saldo > 0
                                                                        THEN 'Saldo $ '
                                                                             + dbo.AgregaComa(dbo.kardex.saldo
                                                                             + CASE WHEN dbo.conceptos.marca2 = 'H'
                                                                                         OR --'A'
                                                                                         dbo.conceptos.num_conc IN (125, 126, 127 )
                                                                                    THEN 1
                                                                                    ELSE -1
                                                                               END
                                                                             * dbo.kardex.importe)
                                                -- Detalle de conceptos con valores variable
                                                                        ELSE CASE WHEN dbo.kardex.num_conc >= 101 AND dbo.kardex.num_conc <= 106 AND @Regimen_Seguridad_Social = '2'
                                                                                  THEN ''
                                                                                  ELSE CASE WHEN dbo.kardex.varia1 > 0
                                                                                            THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                                                                 + ': '
                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                                                                 + CASE WHEN dbo.kardex.varia2 > 0
                                                                                                        THEN ','
                                                                                                             + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                                                                             + ': '
                                                                                                             + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                                                                             + CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                    THEN ','
                                                                                                                         + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                         + ': '
                                                                                                                         + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                         + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                                THEN ','
                                                                                                                                     + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                     + ': '
                                                                                                                                     + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                                ELSE ''
                                                                                                                           END
                                                                                                                    ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                              THEN ','
                                                                                                                                   + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                   + ': '
                                                                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                              ELSE ''
                                                                                                                         END
                                                                                                               END
                                                                                                        ELSE CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                  THEN ','
                                                                                                                       + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                       + ': '
                                                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                       + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                              THEN ','
                                                                                                                                   + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                   + ': '
                                                                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                              ELSE ''
                                                                                                                         END
                                                                                                                  ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                            THEN ','
                                                                                                                                 + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                 + ': '
                                                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                            ELSE ''
                                                                                                                       END
                                                                                                             END
                                                                                                   END
                                                                                            ELSE CASE WHEN dbo.kardex.varia2 > 0
                                                                                                      THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                                                                           + ': '
                                                                                                           + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                                                                           + CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                  THEN ','
                                                                                                                       + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                       + ': '
                                                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                       + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                              THEN ','
                                                                                                                                   + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                   + ': '
                                                                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                              ELSE ''
                                                                                                                         END
                                                                                                                  ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                            THEN ','
                                                                                                                                 + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                 + ': '
                                                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                            ELSE ''
                                                                                                                       END
                                                                                                             END
                                                                                                      ELSE CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                THEN ','
                                                                                                                     + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                     + ': '
                                                                                                                     + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                     + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                            THEN ','
                                                                                                                                 + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                 + ': '
                                                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                            ELSE ''
                                                                                                                       END
                                                                                                                ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                          THEN ','
                                                                                                                               + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                               + ': '
                                                                                                                               + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                          ELSE NULL -- Agregar mas condiciones
                                                                                                                     END
                                                                                                           END
                                                                                                 END
                                                                                       END
                                                                             END
                                                                   END
                                                         END
                        FROM    @kardex
                                INNER JOIN dbo.kardex ON [@kardex].empresa = dbo.kardex.empresa
                                                         AND [@kardex].codigo = dbo.kardex.codigo
                                                         AND [@kardex].renglon = dbo.kardex.renglon
                                                         AND @nomina = dbo.kardex.nomina
                                INNER JOIN dbo.conceptos ON dbo.kardex.empresa = dbo.conceptos.empresa
                                                            AND dbo.kardex.num_conc = dbo.conceptos.num_conc
                                                            AND dbo.kardex.clase = dbo.conceptos.clase
                                                            AND dbo.kardex.centro = dbo.conceptos.centro
                        WHERE   [@kardex].empresa = @empresa
                                AND ( ( dbo.kardex.num_conc >= 101
                                        AND dbo.kardex.num_conc <= 199
                                      )
                                      OR ( dbo.kardex.num_conc >= 1001
                                           AND dbo.kardex.num_conc <= 1099
                                         )
                                    )
                                AND dbo.kardex.nomina = @nomina
--SELECT 4,* FROM @kardex ORDER BY centro, codigo, renglon
                    END



                -- Percepciones. Actualiza el subtotal y total de resumen de centro de costos
                UPDATE  @kardex
                SET     [@kardex].numeroConceptoPercepcion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                        [@kardex].nombreConceptoPercepcion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                        [@kardex].importeConceptoPercepcion = [dbo].[ResumenPorCentroNomina].importe ,
                        [@kardex].gravablePercepcion = [dbo].[ResumenPorCentroNomina].gravable ,
                        [@kardex].exentoPercepcion = [dbo].[ResumenPorCentroNomina].exento ,
                        [@kardex].saldoPercepcion = [dbo].[ResumenPorCentroNomina].saldoPercepcion ,
                        [@kardex].anexoConceptoPercepcion = [dbo].[ResumenPorCentroNomina].anexoConceptoPercepcion
                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'P',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroNomina].renglon
                WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1
                            AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 99
                          )
                          OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1101
                               AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1199
                             )
                        )



                -- Deducciones. Actualiza el subtotal y total de resumen de centro de costos
                UPDATE  @kardex
                SET     [@kardex].numeroConceptoDeduccion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                        [@kardex].nombreConceptoDeduccion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                        [@kardex].importeConceptoDeduccion = [dbo].[ResumenPorCentroNomina].importe ,
                        [@kardex].gravableDeduccion = [dbo].[ResumenPorCentroNomina].gravable ,
                        [@kardex].exentoDeduccion = [dbo].[ResumenPorCentroNomina].exento ,
                        [@kardex].anexoConceptoDeduccion = [dbo].[ResumenPorCentroNomina].anexoConceptoDeduccion
                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'D',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroNomina].renglon
                WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 101
                            AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 199
                          )
                          OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1001
                               AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1099
                             )
                        )
--SELECT 5,* FROM @kardex ORDER BY centro, codigo, renglon

        -- Actualiza Centros de Nivel Superior
                IF @desglosadoPor & 1 > 0
                   AND (@ordenadoPor & 4 > 0 OR @ordenadoPor & 8 > 0 OR @ordenadoPor & 16 > 0 OR @ordenadoPor & 32 > 0)
                    BEGIN
                -- Percepciones. Actualiza el subtotal y total de resumen de centro de costos
                        UPDATE  @kardex
                        SET     --[@kardex].numeroConceptoPercepcion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                                --[@kardex].nombreConceptoPercepcion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                                [@kardex].importeConceptoPercepcion = [dbo].[ResumenPorCentroNomina].importe ,
                                [@kardex].gravablePercepcion = [dbo].[ResumenPorCentroNomina].gravable ,
                                [@kardex].exentoPercepcion = [dbo].[ResumenPorCentroNomina].exento ,
                                [@kardex].saldoPercepcion = [dbo].[ResumenPorCentroNomina].saldoPercepcion ,
                                [@kardex].anexoConceptoPercepcion = [dbo].[ResumenPorCentroNomina].anexoConceptoPercepcion
                        FROM    @kardex
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'P',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              2, --@desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroNomina].renglon
                                                              AND [@kardex].numeroConceptoPercepcion = [dbo].[ResumenPorCentroNomina].numeroConcepto
                                                              AND [@kardex].nombreConceptoPercepcion = [dbo].[ResumenPorCentroNomina].nombreConcepto
                        WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1
                                    AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 99
                                  )
                                  OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1101
                                       AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1199
                                     )
                                )



                -- Deducciones. Actualiza el subtotal y total de resumen de centro de costos
                        UPDATE  @kardex
                        SET     --[@kardex].numeroConceptoDeduccion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                                --[@kardex].nombreConceptoDeduccion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                                [@kardex].importeConceptoDeduccion = [dbo].[ResumenPorCentroNomina].importe ,
                                [@kardex].gravableDeduccion = [dbo].[ResumenPorCentroNomina].gravable ,
                                [@kardex].exentoDeduccion = [dbo].[ResumenPorCentroNomina].exento ,
                                [@kardex].anexoConceptoDeduccion = [dbo].[ResumenPorCentroNomina].anexoConceptoDeduccion
                        FROM    @kardex
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'D',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              2, --@desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroNomina].renglon
                                                              AND [@kardex].numeroConceptoDeduccion = [dbo].[ResumenPorCentroNomina].numeroConcepto
                                                              AND [@kardex].nombreConceptoDeduccion = [dbo].[ResumenPorCentroNomina].nombreConcepto
                        WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 101
                                    AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 199
                                  )
                                  OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1001
                                       AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1099
                                     )
                                )
--SELECT 6,* FROM @kardex ORDER BY centro, codigo, renglon
                    END

-- Carga Provisiones
                IF @incluirProvisiones = 'S'
                    BEGIN
                        UPDATE  @kardex
                        SET     numeroConceptoProvision = dbo.kardex.num_conc ,
                                nombreConceptoProvision = dbo.kardex.concepto ,
                                importeConceptoProvision = dbo.kardex.importe
                        FROM    @kardex
                                INNER JOIN dbo.kardex ON [@kardex].empresa = dbo.kardex.empresa
                                                         AND [@kardex].codigo = dbo.kardex.codigo
                                                         AND [@kardex].renglon = dbo.kardex.renglon
                                                         AND @nomina = dbo.kardex.nomina
                        WHERE   [@kardex].empresa = @empresa
                                AND ( dbo.kardex.num_conc >= 201
                                      AND dbo.kardex.num_conc <= 299
                                    )
                                AND dbo.kardex.nomina = @nomina

                -- Provision. Actualiza el subtotal y total de resumen de centro de costos
                        UPDATE  @kardex
                        SET     [@kardex].numeroConceptoProvision = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                                [@kardex].nombreConceptoProvision = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                                [@kardex].importeConceptoProvision = [dbo].[ResumenPorCentroNomina].importe
                        FROM    @kardex
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'I',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroNomina].renglon
                        WHERE   ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 201
                                  AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 299
                                )
                    END

--SELECT 1,* FROM @kardex ORDER BY codigo, renglon
                -- Registro Totales
                UPDATE  @kardex
                SET     [@kardex].empleados = [dbo].[ResumenPorCentroNomina].empleados ,
                        [@kardex].provisionIMSS = [dbo].[ResumenPorCentroNomina].provisionIMSS ,
                        [@kardex].provisionRCV = [dbo].[ResumenPorCentroNomina].provisionRCV ,
                        [@kardex].provisionINFONAVIT = [dbo].[ResumenPorCentroNomina].provisionINFONAVIT ,
                        [@kardex].retencionIMSS = [dbo].[ResumenPorCentroNomina].retencionIMSS ,
                        [@kardex].retencionRCV = [dbo].[ResumenPorCentroNomina].retencionRCV ,
                        [@kardex].retencionINFONAVIT = [dbo].[ResumenPorCentroNomina].retencionINFONAVIT ,
                        [@kardex].empleadosConCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosConCuentaBancaria ,
                        [@kardex].empleadosSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosSinCuentaBancaria ,
                        [@kardex].percepcionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesConCuentaBancaria ,
                        [@kardex].deduccionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesConCuentaBancaria ,
                        [@kardex].percepcionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesSinCuentaBancaria ,
                        [@kardex].deduccionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesSinCuentaBancaria ,
                        [@kardex].basePorcientoSobreNomina = [dbo].[ResumenPorCentroNomina].basePorcientoSobreNomina ,
                        [@kardex].porcientoSobreNomina = [dbo].[ResumenPorCentroNomina].porcientoSobreNomina ,
                        [@kardex].fondoAhorroAportacionEmpleado = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionEmpleado ,
                        [@kardex].fondoAhorroAportacionPatron = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionPatron ,
                        [@kardex].sueldoNetoGeneral = [dbo].[ResumenPorCentroNomina].sueldoNetoGeneral,

                        [@kardex].baseISN1 = [dbo].[ResumenPorCentroNomina].baseISN1,
                        [@kardex].porcientoISN1 = [dbo].[ResumenPorCentroNomina].porcientoISN1,
                        [@kardex].importeISN1 = [dbo].[ResumenPorCentroNomina].importeISN1,
                        [@kardex].empleadosISN1 = [dbo].[ResumenPorCentroNomina].empleadosISN1,
                        [@kardex].baseISN2 = [dbo].[ResumenPorCentroNomina].baseISN2,
                        [@kardex].porcientoISN2 = [dbo].[ResumenPorCentroNomina].porcientoISN2,
                        [@kardex].importeISN2 = [dbo].[ResumenPorCentroNomina].importeISN2,
                        [@kardex].empleadosISN2 = [dbo].[ResumenPorCentroNomina].empleadosISN2

                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'T', @tipoNomina,
                                                              '', @ordenadoPor,
                                                              @salarioDF,
                                                              @salarioRegion,
                                                              @eymArt25,
                                                              @eymArt1062,
                                                              @eymArt107,
                                                              @ivArt147,
                                                              @cvArt168II,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                WHERE   [dbo].[ResumenPorCentroNomina].numeroConcepto = 9996
--SELECT 7,* FROM @kardex ORDER BY centro, codigo, renglon

--SELECT 2,* FROM @kardex ORDER BY codigo, renglon

        -- Actualizadb Centros de Nivel Superior
                IF @desglosadoPor & 1 > 0
                   AND (@ordenadoPor & 4 > 0 OR @ordenadoPor & 8 > 0 OR @ordenadoPor & 16 > 0 OR @ordenadoPor & 32 > 0)
                    BEGIN
                -- Registro Totales
                        UPDATE  @kardex
                        SET     [@kardex].empleados = [dbo].[ResumenPorCentroNomina].empleados ,
                                [@kardex].provisionIMSS = [dbo].[ResumenPorCentroNomina].provisionIMSS ,
                                [@kardex].provisionRCV = [dbo].[ResumenPorCentroNomina].provisionRCV ,
                                [@kardex].provisionINFONAVIT = [dbo].[ResumenPorCentroNomina].provisionINFONAVIT ,
                                [@kardex].retencionIMSS = [dbo].[ResumenPorCentroNomina].retencionIMSS ,
                                [@kardex].retencionRCV = [dbo].[ResumenPorCentroNomina].retencionRCV ,
                                [@kardex].retencionINFONAVIT = [dbo].[ResumenPorCentroNomina].retencionINFONAVIT ,
                                [@kardex].empleadosConCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosConCuentaBancaria ,
                                [@kardex].empleadosSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosSinCuentaBancaria ,
                                [@kardex].percepcionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesConCuentaBancaria ,
                                [@kardex].deduccionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesConCuentaBancaria ,
                                [@kardex].percepcionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesSinCuentaBancaria ,
                                [@kardex].deduccionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesSinCuentaBancaria ,
                                [@kardex].basePorcientoSobreNomina = [dbo].[ResumenPorCentroNomina].basePorcientoSobreNomina ,
                                [@kardex].porcientoSobreNomina = [dbo].[ResumenPorCentroNomina].porcientoSobreNomina ,
                                [@kardex].fondoAhorroAportacionEmpleado = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionEmpleado ,
                                [@kardex].fondoAhorroAportacionPatron = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionPatron ,
                                [@kardex].sueldoNetoGeneral = [dbo].[ResumenPorCentroNomina].sueldoNetoGeneral,

                                [@kardex].baseISN1 = [dbo].[ResumenPorCentroNomina].baseISN1,
                                [@kardex].porcientoISN1 = [dbo].[ResumenPorCentroNomina].porcientoISN1,
                                [@kardex].importeISN1 = [dbo].[ResumenPorCentroNomina].importeISN1,
                                [@kardex].empleadosISN1 = [dbo].[ResumenPorCentroNomina].empleadosISN1,
                                [@kardex].baseISN2 = [dbo].[ResumenPorCentroNomina].baseISN2,
                                [@kardex].porcientoISN2 = [dbo].[ResumenPorCentroNomina].porcientoISN2,
                                [@kardex].importeISN2 = [dbo].[ResumenPorCentroNomina].importeISN2,
                                [@kardex].empleadosISN2 = [dbo].[ResumenPorCentroNomina].empleadosISN2

                        FROM    @kardex
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'T', @tipoNomina,
                                                              '', @ordenadoPor,
                                                              @salarioDF,
                                                              @salarioRegion,
                                                              @eymArt25,
                                                              @eymArt1062,
                                                              @eymArt107,
                                                              @ivArt147,
                                                              @cvArt168II, 2, --@desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                        WHERE   [dbo].[ResumenPorCentroNomina].numeroConcepto = 9996
--SELECT 8,* FROM @kardex ORDER BY centro, codigo, renglon
                    END

--SELECT 3,* FROM @kardex ORDER BY codigo, renglon

                UPDATE  @kardex
                SET     [@kardex].ejercicio = [dbo].[ResumenPorCentroNomina].ejercicio ,
                        [@kardex].diarioOficialDia = [dbo].[ResumenPorCentroNomina].diarioOficialDia ,
                        [@kardex].diarioOficialMes = [dbo].[ResumenPorCentroNomina].diarioOficialMes ,
                        [@kardex].diarioOficialAyo = [dbo].[ResumenPorCentroNomina].diarioOficialAyo ,
                        [@kardex].salarioMinimoDF = [dbo].[ResumenPorCentroNomina].salarioMinimoDF ,
                        [@kardex].salarioMinimoRegion = [dbo].[ResumenPorCentroNomina].salarioMinimoRegion ,
                        [@kardex].eymArt25 = [dbo].[ResumenPorCentroNomina].eymArt25 ,
                        [@kardex].eymArt106ii = [dbo].[ResumenPorCentroNomina].eymArt106ii ,
                        [@kardex].eymArt107 = [dbo].[ResumenPorCentroNomina].eymArt107 ,
                        [@kardex].ivArt147 = [dbo].[ResumenPorCentroNomina].ivArt147 ,
                        [@kardex].cvArt168ii = [dbo].[ResumenPorCentroNomina].cvArt168ii ,
                        [@kardex].baseCalculo = [dbo].[ResumenPorCentroNomina].baseCalculo
                        /*
                        [@kardex].baseISN1 = [dbo].[ResumenPorCentroNomina].baseISN1,
                        [@kardex].porcientoISN1 = [dbo].[ResumenPorCentroNomina].porcientoISN1,
                        [@kardex].importeISN1 = [dbo].[ResumenPorCentroNomina].importeISN1,
                        [@kardex].empleadosISN1 = [dbo].[ResumenPorCentroNomina].empleadosISN1,
                        [@kardex].baseISN2 = [dbo].[ResumenPorCentroNomina].baseISN2,
                        [@kardex].porcientoISN2 = [dbo].[ResumenPorCentroNomina].porcientoISN2,
                        [@kardex].importeISN2 = [dbo].[ResumenPorCentroNomina].importeISN2,
                        [@kardex].empleadosISN2 = [dbo].[ResumenPorCentroNomina].empleadosISN2
                        */
                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'T', @tipoNomina,
                                                              '', @ordenadoPor,
                                                              @salarioDF,
                                                              @salarioRegion,
                                                              @eymArt25,
                                                              @eymArt1062,
                                                              @eymArt107,
                                                              @ivArt147,
                                                              @cvArt168II,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                WHERE   [dbo].[ResumenPorCentroNomina].numeroConcepto = 9996
                        AND [@kardex].codigo = 999999996
                        AND [@kardex].centro = '99999999999997'
--SELECT 9,* FROM @kardex ORDER BY centro, codigo, renglon
--SELECT 4,* FROM @kardex ORDER BY codigo, renglon
            END

        IF @esRecibo = 0
            BEGIN
                DELETE  @kardex
                WHERE   [@kardex].empresa = @empresa
                        AND [@kardex].codigo = 999999995
                        AND [@kardex].numeroConceptoPercepcion IS NULL
                        AND [@kardex].numeroConceptoDeduccion IS NULL
                        AND [@kardex].numeroConceptoProvision IS NULL
            END
--SELECT 10,* FROM @kardex ORDER BY centro, codigo, renglon

        IF @firma = 'S'
            AND @desglosadoPor & 1 > 0
            BEGIN
                INSERT  @renglon
                        ( codigo ,
                          nombre ,
                          centro ,
                          supervisor ,
                          grupo ,
                          grupoRecibo ,
                          diferenciaRenglon ,
                          ultimoRenglon

                        )
                        SELECT  kardex.codigo ,
                                kardex.nombre ,
                                kardex.centro ,
                                kardex.supervisor ,
                                kardex.grupo ,
                                kardex.grupoRecibo ,
                                SUM(CASE WHEN ISNULL(kardex.numeroConceptoPercepcion,
                                                     0) > 0 THEN 1
                                         ELSE 0
                                    END
                                    - CASE WHEN ISNULL(kardex.numeroConceptoDeduccion,
                                                       0) > 0 THEN 1
                                           ELSE 0
                                      END) ,
                                MAX(kardex.renglon)
                        FROM    @kardex AS kardex
                        WHERE   kardex.codigo <= 99999999
                        GROUP BY kardex.codigo ,
                                kardex.nombre ,
                                kardex.centro ,
                                kardex.supervisor ,
                                kardex.grupo ,
                                kardex.grupoRecibo
                        ORDER BY kardex.codigo

                INSERT  @renglon
                        ( codigo ,
                          nombre ,
                          centro ,
                          supervisor ,
                          grupo ,
                          grupoRecibo ,
                          diferenciaRenglon ,
                          ultimoRenglon ,
                          renglon ,
                          renglonesAgregar


                        )
                        SELECT  codigo ,
                                nombre ,
                                centro ,
                                supervisor ,
                                grupo ,
                                grupoRecibo ,
                                diferenciaRenglon ,
                                ultimoRenglon ,
                                agregaRenglon.renglon ,
                                ultimoRenglon + agregaRenglon.renglon
                        FROM    @renglon ,
                                @agregaRenglon AS agregaRenglon
                        WHERE   diferenciaRenglon > -3

                DELETE  renglon
                FROM    @renglon AS renglon
                WHERE   renglonesAgregar IS NULL
                        OR codigo = 999999996

                INSERT  @kardex
                        ( empresa ,
                          codigo ,
                          nombre ,
                          centro ,
                          supervisor ,
                          grupo ,
                          grupoRecibo ,
                          renglon ,
                          procesoName ,
                          firma

                        )
                        SELECT  @empresa ,
                                renglon.codigo ,
                                renglon.nombre ,
                                renglon.centro ,
                                renglon.supervisor ,
                                renglon.grupo ,
                                renglon.grupoRecibo ,
                                renglon.renglonesAgregar ,
                                @procesoName ,
                                @firma
                        FROM    @renglon AS renglon
                        WHERE   renglon <= ABS(-3 - diferenciaRenglon)
                        ORDER BY codigo ,
                                renglonesAgregar
            END

        IF @saltoPagina = 'S'
            AND ( @ordenadoPor & 4 > 0
                  OR @ordenadoPor & 8 > 0
                  OR @ordenadoPor & 16 > 0
                  OR @ordenadoPor & 32 > 0
                )
            AND ( @desglosadoPor & 1 > 0
                  OR @desglosadoPor & 2 > 0
                )
            BEGIN
                DECLARE @tablaOrdenada TABLE
                    (
                      serial INT IDENTITY ,
                      grupo VARCHAR(500) ,
                      codigo INT ,
                      campo VARCHAR(500) ,
                      renglon INT ,
                      saltarPagina VARCHAR(1)
                    )

                DECLARE @grupoAnterior VARCHAR(500)
                DECLARE @saltarPagina VARCHAR(1)

                INSERT  @tablaOrdenada
                        (
                          grupo ,
                          codigo ,
                          campo ,
                          renglon

                        )
                        SELECT  DISTINCT
                                grupo ,
                                codigo,
                                CASE WHEN @ordenadoPor & 4 > 0
                                     THEN centro + nombre
                                     WHEN @ordenadoPor & 8 > 0
                                     THEN centro + STR(codigo)
                                     WHEN @ordenadoPor & 16 > 0
                                     THEN centro + STR(supervisor) + nombre
                                     WHEN @ordenadoPor & 32 > 0
                                     THEN centro + STR(supervisor)
                                          + STR(codigo)
                                END ,
                                1
                        FROM    @kardex
                        WHERE   centro <> '99999999999997' AND codigo <> 999999996 AND renglon = 1
                        --WHERE   centro <> '99999999999997' AND codigo <= 99999999 AND renglon = 1
                        ORDER BY grupo ,
                                CASE WHEN @ordenadoPor & 4 > 0
                                     THEN centro + nombre
                                     WHEN @ordenadoPor & 8 > 0
                                     THEN centro + STR(codigo)
                                     WHEN @ordenadoPor & 16 > 0
                                     THEN centro + STR(supervisor) + nombre
                                     WHEN @ordenadoPor & 32 > 0
                                     THEN centro + STR(supervisor)
                                          + STR(codigo)
                                END

                SELECT TOP 1
                        @grupoAnterior = grupo
                FROM    @tablaOrdenada

                UPDATE  @tablaOrdenada
                SET     @saltarPagina = CASE WHEN (@grupoAnterior <> grupo OR codigo = 999999995) AND serial <> 1
                                             THEN 'S'
                                             ELSE NULL
                                        END ,
                        saltarPagina = @saltarPagina ,
                        @grupoAnterior = grupo


                UPDATE  tablaKardex
                SET     tablaKardex.saltarPagina = tablaOrdenada.saltarPagina
                FROM    @kardex AS tablaKardex
                        INNER JOIN @tablaOrdenada AS tablaOrdenada ON tablaKardex.grupo = tablaOrdenada.grupo
                                                              AND tablaKardex.renglon = tablaOrdenada.renglon
                                                              AND CASE
                                                              WHEN @ordenadoPor
                                                              & 4 > 0
                                                              THEN tablaKardex.centro
                                                              + tablaKardex.nombre
                                                              WHEN @ordenadoPor
                                                              & 8 > 0
                                                              THEN tablaKardex.centro
                                                              + STR(tablaKardex.codigo)
                                                              WHEN @ordenadoPor
                                                              & 16 > 0
                                                              THEN tablaKardex.centro
                                                              + STR(tablaKardex.supervisor)
                                                              + tablaKardex.nombre
                                                              WHEN @ordenadoPor
                                                              & 32 > 0
                                                              THEN tablaKardex.centro
                                                              + STR(tablaKardex.supervisor)
                                                              + STR(tablaKardex.codigo)
                                                              END = tablaOrdenada.campo

                --UPDATE  tablaKardex
                --SET     tablaKardex.grupo = RTRIM(LTRIM(tablaKardex.grupo)) + '.' + '999999995' ,
                --        tablaKardex.imprimirResumen = CASE WHEN tablaKardex.codigo = 999999996 THEN 1 ELSE NULL END
                --FROM    @kardex AS tablaKardex
                --WHERE tablaKardex.codigo = 999999995 OR tablaKardex.codigo = 999999996
            END

        UPDATE  tablaKardex
        SET     tablaKardex.grupo = CASE WHEN RTRIM(LTRIM(tablaKardex.centro)) = '99999999999997' THEN RTRIM(LTRIM(tablaKardex.grupo)) + '.' + '999999995' ELSE tablaKardex.grupo END , --RTRIM(LTRIM(tablaKardex.grupo)) + '.' + '999999995' ,
                tablaKardex.imprimirResumen = CASE WHEN tablaKardex.codigo = 999999996 THEN 1 ELSE NULL END
        FROM    @kardex AS tablaKardex
        WHERE tablaKardex.codigo = 999999995 OR tablaKardex.codigo = 999999996


        IF @procesoName = 'NominaDetalle'
            BEGIN
                DECLARE @fechaCierreNomina DATETIME
                DECLARE @tFechaAltaEmpleado TABLE
                    (
                      codigo INT ,
                      fechaAltaEmpleado DATETIME
                    )

                SELECT  @fechaCierreNomina = dbo.Periodos.cierre
                FROM    dbo.Periodos
                WHERE   dbo.Periodos.empresa = @empresa
                        AND dbo.Periodos.tiponom = @tipoNomina
                        AND dbo.Periodos.estatus = 'A'

                INSERT  @tFechaAltaEmpleado
                        ( codigo ,
                          fechaAltaEmpleado
                        )
                        SELECT  dbo.empleados.codigo ,
                                ISNULL(( SELECT TOP 1
                                                dbo.avisos_imss.fch_mov
                                         FROM   dbo.avisos_imss
                                         WHERE  dbo.avisos_imss.empresa = dbo.empleados.empresa
                                                AND dbo.avisos_imss.codigo = dbo.empleados.codigo
                                                AND ( dbo.avisos_imss.mov = 'A'
                                                      OR dbo.avisos_imss.mov = 'RI'
                                                    )
                                                AND dbo.avisos_imss.fch_mov <= @fechaCierreNomina
                                         ORDER BY dbo.avisos_imss.fch_mov DESC
                                       ), dbo.empleados.fchalta) AS fechaAlta
                        FROM    dbo.empleados
                                INNER JOIN @kardex AS tablaKardex ON dbo.empleados.empresa = tablaKardex.empresa
                                                                     AND dbo.empleados.codigo = tablaKardex.codigo
                        WHERE dbo.empleados.empresa = @empresa

                UPDATE  tablaKardex
                SET     tablaKardex.fechaAlta = tFechaAltaEmpleado.fechaAltaEmpleado
                FROM    @kardex AS tablaKardex
                        INNER JOIN @tFechaAltaEmpleado AS tFechaAltaEmpleado ON tFechaAltaEmpleado.codigo = tablaKardex.codigo
            END

        /*
        IF @ordenadoPor IN (4,8,16,32) AND @desglosadoPor = 1 AND @saltoPagina = 'S' AND @esRecibo = 0
          BEGIN

            DECLARE @tmpKardex TABLE
            (
              empresa INT ,
              codigoId VARCHAR(100) ,
              codigo INT ,
              nombre VARCHAR(100) ,
              fechaAlta DATETIME ,
              numeroSeguridadSocial VARCHAR(10) ,
              digitoVerificador CHAR(1) ,
              curp VARCHAR(18) ,
              centro VARCHAR(16) ,
              nombreCentro VARCHAR(50) ,
              cuentaBanco VARCHAR(30) ,
              nombreBanco VARCHAR(50) ,
              ocupacion INT ,
              categoria VARCHAR(50) ,
              tipoSalario INT ,
              renglon INT ,
              jornada INT ,
              sueldoDiario FLOAT ,
              salarioBaseCotizacion FLOAT ,
              clase VARCHAR(3) ,
              nombreClase VARCHAR(50) ,
              supervisor INT ,
              nombreSupervisor VARCHAR(50) ,
              marcaContraPercepcion CHAR(1) ,
              numeroConceptoPercepcion INT ,
              nombreConceptoPercepcion VARCHAR(50) ,
              importeConceptoPercepcion FLOAT ,
              gravablePercepcion FLOAT ,
              exentoPercepcion FLOAT ,
              saldoPercepcion FLOAT ,
              anexoConceptoPercepcion VARCHAR(150) ,
              marcaContraDeduccion CHAR(1) ,
              numeroConceptoDeduccion INT ,
              nombreConceptoDeduccion VARCHAR(50) ,
              importeConceptoDeduccion FLOAT ,
              gravableDeduccion FLOAT ,
              exentoDeduccion FLOAT ,
              saldoDeduccion FLOAT ,
              anexoConceptoDeduccion VARCHAR(150) ,
              numeroConceptoProvision INT ,
              nombreConceptoProvision VARCHAR(50) ,
              importeConceptoProvision FLOAT ,
              empleados INT ,
              provisionIMSS FLOAT ,
              provisionRCV FLOAT ,
              provisionINFONAVIT FLOAT ,
              retencionIMSS FLOAT ,
              retencionRCV FLOAT ,
              retencionINFONAVIT FLOAT ,
              empleadosConCuentaBancaria INT ,
              empleadosSinCuentaBancaria INT ,
              percepcionesConCuentaBancaria FLOAT ,
              deduccionesConCuentaBancaria FLOAT ,
              percepcionesSinCuentaBancaria FLOAT ,
              deduccionesSinCuentaBancaria FLOAT ,
              basePorcientoSobreNomina FLOAT ,
              porcientoSobreNomina FLOAT ,
              fondoAhorroAportacionEmpleado FLOAT ,
              fondoAhorroAportacionPatron FLOAT ,
              sueldoNetoGeneral FLOAT ,
              ejercicio INT ,
              diarioOficialDia INT ,
              diarioOficialMes INT ,
              diarioOficialAyo INT ,
              salarioMinimoDF FLOAT ,
              salarioMinimoRegion FLOAT ,
              eymArt25 FLOAT ,
              eymArt106ii FLOAT ,
              eymArt107 FLOAT ,
              ivArt147 FLOAT ,
              cvArt168ii FLOAT ,
              baseCalculo INT ,
              grupo VARCHAR(500) ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              percepcionesEmpleado FLOAT ,
              deduccionesEmpleado FLOAT ,
              netoPagarEmpleado FLOAT ,
              grupoRecibo VARCHAR(500) ,
              rfcAlfa VARCHAR(4) ,
              rfcNum VARCHAR(6) ,
              rfcHomo VARCHAR(3) ,
              acumuladoPercepcion FLOAT ,
              acumuladoPercepcionGravable FLOAT ,
              acumuladoIsr FLOAT ,
              acumuladoInfonavit FLOAT ,
              acumuladoSar FLOAT ,
              acumuladoCv FLOAT ,
              email VARCHAR(60) ,
              fechaAntiguedad DATETIME ,
              procesoName VARCHAR(100) ,
              nomina CHAR(3) ,
              saltarPagina CHAR(1) ,
              firma CHAR(1) ,
              mov CHAR(2) ,
              foto VARCHAR(255),
              baseISN1      FLOAT,
              porcientoISN1 FLOAT,
              importeISN1   FLOAT,
              empleadosISN1 INT,
              baseISN2      FLOAT,
              porcientoISN2 FLOAT,
              importeISN2   FLOAT,
              empleadosISN2 INT ,
              imprimirResumen INT
            )

            INSERT INTO @tmpKardex
            SELECT *
            FROM @kardex
            ORDER BY centro, codigo, codigoId

            DECLARE @codigo INT
            DECLARE @centro VARCHAR(16)
            DECLARE @salta  CHAR(1)

            SET @codigo = 0
            SET @centro = ''
            SET @salta  = 'N'

            UPDATE @tmpKardex
            SET saltarPagina = @salta,
                @salta       = CASE WHEN @centro <> centro AND @codigo > 0 AND centro <> '99999999999997'
                                    THEN 'S'
                                    ELSE 'N'
                               END,
                @codigo = codigo,
                @centro = centro


            DELETE @kardex


            INSERT INTO @kardex
            SELECT *
            FROM @tmpKardex

          END
        */

        RETURN

    END
GO

IF OBJECT_ID('dbo.LlenaImpresionRecibo') IS NOT NULL
   DROP  FUNCTION [dbo].[LlenaImpresionRecibo]
GO

CREATE FUNCTION [dbo].[LlenaImpresionRecibo]
    (
      @empresa INT ,
      @tipoNomina INT ,
      @nomina CHAR(3) ,
      @incluirProvisiones CHAR(1) ,
      @procesoName VARCHAR(100) ,
      @ordenadoPor INT ,
      @desglosadoPor INT ,
      @porCentro INT ,
      @esRecibo INT ,
      @codigoSeleccionado VARCHAR(500) ,
      @ayoEjercicio INT
    )
RETURNS @kardex TABLE
    (
      empresa INT ,
      codigoId VARCHAR(100) ,
      codigo INT ,
      nombre VARCHAR(100) ,
      fechaAlta DATETIME ,
      numeroSeguridadSocial VARCHAR(10) ,
      digitoVerificador CHAR(1) ,
      curp VARCHAR(18) ,
      centro VARCHAR(16) ,
      nombreCentro VARCHAR(50) ,
      cuentaBanco VARCHAR(30) ,
      nombreBanco VARCHAR(50) ,
      ocupacion INT ,
      categoria VARCHAR(50) ,
      tipoSalario INT ,
      renglon INT ,
      jornada INT ,
      sueldoDiario FLOAT ,
      salarioBaseCotizacion FLOAT ,
      clase VARCHAR(3) ,
      nombreClase VARCHAR(50) ,
      supervisor INT ,
      nombreSupervisor VARCHAR(50) ,
      marcaContraPercepcion CHAR(1) ,
      numeroConceptoPercepcion INT ,
      nombreConceptoPercepcion VARCHAR(50) ,
      importeConceptoPercepcion FLOAT ,
      gravablePercepcion FLOAT ,
      exentoPercepcion FLOAT ,
      saldoPercepcion FLOAT ,
      anexoConceptoPercepcion VARCHAR(150) ,
      marcaContraDeduccion CHAR(1) ,
      numeroConceptoDeduccion INT ,
      nombreConceptoDeduccion VARCHAR(50) ,
      importeConceptoDeduccion FLOAT ,
      gravableDeduccion FLOAT ,
      exentoDeduccion FLOAT ,
      saldoDeduccion FLOAT ,
      anexoConceptoDeduccion VARCHAR(150) ,
      numeroConceptoProvision INT ,
      nombreConceptoProvision VARCHAR(50) ,
      importeConceptoProvision FLOAT ,
      empleados INT ,
      provisionIMSS FLOAT ,
      provisionRCV FLOAT ,
      provisionINFONAVIT FLOAT ,
      retencionIMSS FLOAT ,
      retencionRCV FLOAT ,
      retencionINFONAVIT FLOAT ,
      empleadosConCuentaBancaria INT ,
      empleadosSinCuentaBancaria INT ,
      percepcionesConCuentaBancaria FLOAT ,
      deduccionesConCuentaBancaria FLOAT ,
      percepcionesSinCuentaBancaria FLOAT ,
      deduccionesSinCuentaBancaria FLOAT ,
      basePorcientoSobreNomina FLOAT ,
      porcientoSobreNomina FLOAT ,
      fondoAhorroAportacionEmpleado FLOAT ,
      fondoAhorroAportacionPatron FLOAT ,
      sueldoNetoGeneral FLOAT ,
      ejercicio INT ,
      diarioOficialDia INT ,
      diarioOficialMes INT ,
      diarioOficialAyo INT ,
      salarioMinimoDF FLOAT ,
      salarioMinimoRegion FLOAT ,
      eymArt25 FLOAT ,
      eymArt106ii FLOAT ,
      eymArt107 FLOAT ,
      ivArt147 FLOAT ,
      cvArt168ii FLOAT ,
      baseCalculo INT ,
      grupo VARCHAR(500) ,
      cuantosRecibos INT ,
      numeroRecibo INT ,
      recibo INT ,
      percepcionesEmpleado FLOAT ,
      deduccionesEmpleado FLOAT ,
      netoPagarEmpleado FLOAT ,
      grupoRecibo VARCHAR(500) ,
      rfcAlfa VARCHAR(4) ,
      rfcNum VARCHAR(6) ,
      rfcHomo VARCHAR(3) ,
      acumuladoPercepcion FLOAT ,
      acumuladoPercepcionGravable FLOAT ,
      acumuladoIsr FLOAT ,
      acumuladoInfonavit FLOAT ,
      acumuladoSar FLOAT ,
      acumuladoCv FLOAT ,
      email VARCHAR(100) ,
      fechaAntiguedad DATETIME ,
      procesoName VARCHAR(100) ,
      nomina CHAR(3) ,
      saltarPagina CHAR(1) ,
      firma CHAR(1),
      mov CHAR(2),
      foto VARCHAR(255),
      substotal FLOAT ,
      baseISN1 FLOAT,
      porcientoISN1 FLOAT,
      importeISN1 FLOAT,
      empleadosISN1 INT,
      baseISN2 FLOAT,
      porcientoISN2 FLOAT,
      importeISN2 FLOAT,
      empleadosISN2 INT ,
      imprimirResumen CHAR(1)
    )
AS
    BEGIN

    DECLARE @renglonTope INT
    DECLARE @reciboSeleccionado VARCHAR(6)

    SELECT  @reciboSeleccionado = SUBSTRING(dbo.Parametros_Nominas.Recibo, 1,
                                            6)
    FROM    dbo.Parametros_Nominas
    WHERE   dbo.Parametros_Nominas.Empresa = @empresa
            AND dbo.Parametros_Nominas.TipoNom = @tipoNomina

    IF @reciboSeleccionado = 'Apsi 3'
        SET @renglonTope = 17
    ELSE
        SET @renglonTope = 20


-- Variables para Primas IMSS
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @mesEmpresa INT
        DECLARE @ayoEmpresa INT
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @registroPatronal VARCHAR(10)
        DECLARE @consulta VARCHAR(4000)
        DECLARE @orden VARCHAR(200)
        DECLARE @numeroConceptoPercepcionInicioKardex INT
        DECLARE @numeroConceptoPercepcionTerminoKardex INT
        DECLARE @numeroConceptoContraPercepcionInicioKardex INT
        DECLARE @numeroConceptoContraPercepcionTerminoKardex INT
        DECLARE @numeroConceptoDeduccionInicioKardex INT
        DECLARE @numeroConceptoDeduccionTerminoKardex INT
        DECLARE @numeroConceptoContraDeduccionInicioKardex INT
        DECLARE @numeroConceptoContraDeduccionTerminoKardex INT
        DECLARE @numeroConceptoProvisionInicioKardex INT
        DECLARE @numeroConceptoProvisionTerminoKardex INT
        DECLARE @ejercicio INT
        DECLARE @diarioOficial DATETIME
        DECLARE @baseCalculo VARCHAR(25)
        DECLARE @codigoAnterior INT
        DECLARE @numeroRecibo INT
        DECLARE @cuantosRecibos INT
        DECLARE @percepcionesEmpleado FLOAT
        DECLARE @deduccionesEmpleado FLOAT
        DECLARE @netoPagarEmpleado FLOAT
        DECLARE @ayoOperacion INT
        DECLARE @nombreAnterior VARCHAR(100)
        DECLARE @copiasRecibo INT
        DECLARE @cuentaCopia INT

        DECLARE @codigoBase TABLE
            (
              codigo INT ,
              renglon INT ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              centro VARCHAR(16) ,
              supervisor INT ,
              nombre VARCHAR(100)
            )

        DECLARE @tablaNumeroRecibo TABLE
            (
              codigo INT ,
              renglon INT ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              centro VARCHAR(16) ,
              supervisor INT ,
              nombre VARCHAR(100)
            )

        DECLARE @tablaBaseRenglon TABLE ( renglon INT )

        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 1 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 2 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 3 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 4 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 5 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 6 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 7 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 8 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 9 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 10 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 11 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 12 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 13 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 14 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 15 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 16 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 17 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 18 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 19 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 20 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 21 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 22 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 23 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 24 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 25 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 26 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 27 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 28 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 29 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 30 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 31 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 32 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 33 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 34 )

        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 35 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 36 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 37 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 38 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 39 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 40 )
                
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 41 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 42 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 43 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 44 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 45 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 46 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 47 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 48 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 49 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 50 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 51 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 52 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 53 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 54 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 55 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 56 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 57 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 58 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 59 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 60 )
                
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 61 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 62 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 63 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 64 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 65 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 66 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 67 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 68 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 69 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 70 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 71 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 72 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 73 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 74 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 75 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 76 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 77 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 78 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 79 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 80 )

        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 81 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 82 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 83 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 84 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 85 )

        IF @renglonTope = 20
            BEGIN
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 86 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 87 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 88 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 89 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 90 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 91 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 92 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 93 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 94 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 95 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 96 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 97 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 98 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 99 )
                INSERT  @tablaBaseRenglon
                        ( renglon )
                VALUES  ( 100 )
                
                
            END

        SET @cuentaCopia = 2
        SET @copiasRecibo = 0
        SET @numeroConceptoPercepcionInicioKardex = 1
        SET @numeroConceptoPercepcionTerminoKardex = 99
        SET @numeroConceptoContraPercepcionInicioKardex = 1101
        SET @numeroConceptoContraPercepcionTerminoKardex = 1199
        SET @numeroConceptoDeduccionInicioKardex = 101
        SET @numeroConceptoDeduccionTerminoKardex = 199
        SET @numeroConceptoContraDeduccionInicioKardex = 1001
        SET @numeroConceptoContraDeduccionTerminoKardex = 1099
        SET @numeroConceptoProvisionInicioKardex = CASE WHEN @incluirProvisiones = 'S'
                                                        THEN 201
                                                        ELSE 0
                                                   END
        SET @numeroConceptoProvisionTerminoKardex = CASE WHEN @incluirProvisiones = 'S'
                                                         THEN 299
                                                         ELSE 0
                                                    END



-- Obtiene datos de empresas
        SELECT TOP 1
                @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion ,
                @mesEmpresa = dbo.empresas.mes_operacion ,
                @registroPatronal = SUBSTRING(dbo.empresas.registro_patronal,
                                              1, 10)
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene primas IMSS en base al ao de operacion de la tabla empresas
        SELECT TOP 1
                @eymArt25 = dbo.primas_imss.eymart25 ,
                @eymPat25 = dbo.primas_imss.eympat25
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra25
                       ELSE 0
                  END ,
                @eymTra25 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                 ELSE dbo.primas_imss.eymtra25
                            END ,
                @eymArt106I = dbo.primas_imss.eymart106I ,
                @eymArt1062 = dbo.primas_imss.eymart1062 ,
                @eymPat1062 = dbo.primas_imss.eympat1062
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra1062
                       ELSE 0
                  END ,
                @eymTra1062 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                   ELSE dbo.primas_imss.eymtra1062
                              END ,
                @eymArt107 = dbo.primas_imss.eymart107 ,
                @eymPat107 = dbo.primas_imss.eympat107
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra107
                       ELSE 0
                  END ,
                @eymTra107 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                  ELSE dbo.primas_imss.eymtra107
                             END ,
                @ivArt147 = dbo.primas_imss.ivart147 ,
                @ivPat147 = dbo.primas_imss.ivpat147
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.ivtra147
                       ELSE 0
                  END ,
                @ivTra147 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                 ELSE dbo.primas_imss.ivtra147
                            END ,
                @retiro = dbo.primas_imss.retiro ,
                @cvArt168II = dbo.primas_imss.cvart168II ,
                @cvPat168II = dbo.primas_imss.cvpat168II
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.cvtra168ii
                       ELSE 0
                  END ,
                @cvTra168II = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                   ELSE dbo.primas_imss.cvtra168ii
                              END
        FROM    dbo.primas_imss
        WHERE   YEAR(dbo.primas_imss.periodo) = @ayoEmpresa



        SET @eymArt25 = CASE WHEN @eymArt25 IS NULL THEN 0
                             ELSE @eymArt25
                        END
        SET @eymPat25 = CASE WHEN @eymPat25 IS NULL THEN 0
                             ELSE @eymPat25
                        END
        SET @eymTra25 = CASE WHEN @eymTra25 IS NULL THEN 0
                             ELSE @eymTra25
                        END
        SET @eymArt106I = CASE WHEN @eymArt106I IS NULL THEN 0
                               ELSE @eymArt106I
                          END
        SET @eymArt1062 = CASE WHEN @eymArt1062 IS NULL THEN 0
                               ELSE @eymArt1062
                          END
        SET @eymPat1062 = CASE WHEN @eymPat1062 IS NULL THEN 0
                               ELSE @eymPat1062
                          END
        SET @eymTra1062 = CASE WHEN @eymTra1062 IS NULL THEN 0
                               ELSE @eymTra1062
                          END
        SET @eymArt107 = CASE WHEN @eymArt107 IS NULL THEN 0
                              ELSE @eymArt107
                         END
        SET @eymPat107 = CASE WHEN @eymPat107 IS NULL THEN 0
                              ELSE @eymPat107
                         END
        SET @eymTra107 = CASE WHEN @eymTra107 IS NULL THEN 0
                              ELSE @eymTra107
                         END
        SET @ivArt147 = CASE WHEN @ivArt147 IS NULL THEN 0
                             ELSE @ivArt147
                        END
        SET @ivPat147 = CASE WHEN @ivPat147 IS NULL THEN 0
                             ELSE @ivPat147
                        END
        SET @ivTra147 = CASE WHEN @ivTra147 IS NULL THEN 0
                             ELSE @ivTra147
                        END
        SET @retiro = CASE WHEN @retiro IS NULL THEN 0
                           ELSE @retiro
                      END
        SET @cvArt168II = CASE WHEN @cvArt168II IS NULL THEN 0
                               ELSE @cvArt168II
                          END
        SET @cvPat168II = CASE WHEN @cvPat168II IS NULL THEN 0
                               ELSE @cvPat168II
                          END
        SET @cvTra168II = CASE WHEN @cvTra168II IS NULL THEN 0
                               ELSE @cvTra168II
                          END
        SET @patronPagaIMSS = CASE WHEN @patronPagaIMSS IS NULL THEN 'N'
                                   ELSE @patronPagaIMSS
                              END


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesEmpresa, @ayoEmpresa)

        SET @salarioDF = @salarioRegionA

        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END

        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion

        SELECT  @ayoOperacion = ISNULL(dbo.Periodos.ayo_operacion, 0)
        FROM    dbo.Periodos
        WHERE   dbo.Periodos.empresa = @empresa
                AND dbo.Periodos.tiponom = @tipoNomina
                AND dbo.Periodos.estatus = 'A'


        IF @procesoName = 'NominaDetalle'
            BEGIN
-- Prepara tabla virtual
                INSERT  @kardex
                        ( empresa ,
                          codigoId ,
                          codigo ,
                          nombre ,
                          fechaAlta ,
                          numeroSeguridadSocial ,
                          digitoVerificador ,
                          curp ,
                          centro ,
                          nombreCentro ,
                          cuentaBanco ,
                          nombreBanco ,
                          ocupacion ,
                          categoria ,
                          tipoSalario ,
                          jornada ,
                          sueldoDiario ,
                          salarioBaseCotizacion ,
                          clase ,
                          nombreClase ,
                          supervisor ,
                          nombreSupervisor ,
                          renglon ,
                          grupo ,
                          rfcAlfa ,
                          rfcNum ,
                          rfcHomo ,
                          email ,
                          fechaAntiguedad ,
                          procesoName ,
                          nomina ,
                          foto
                        )
                        SELECT DISTINCT
                                dbo.recibos.empresa ,
                                RIGHT(STR(100000000 + dbo.recibos.codigo), 8)
                                + RIGHT(STR(1000000000 + dbo.recibos.renglon),
                                        9) AS codigoId ,
                                dbo.recibos.codigo AS codigo ,
                                RTRIM(dbo.empleados.ap_paterno) + ' '
                                + RTRIM(dbo.empleados.ap_materno) + ' '
                                + RTRIM(dbo.empleados.nombre) AS nombre ,
                                dbo.empleados.fchalta ,
                                dbo.empleados.afiliacion ,
                                dbo.empleados.digvera ,
                                CASE WHEN LEN(dbo.empleados.curp) = 18
                                     THEN dbo.empleados.curp
                                     ELSE dbo.empleados.rfcalfa
                                          + dbo.empleados.rfcnum  -- RIGHT(STR(dbo.empleados.rfcnum), 6)
                                          + dbo.empleados.rfchomo
                                END AS curp ,
                                dbo.Llaves.centro ,
                                dbo.centros.nomdepto ,
                                dbo.empleados.cta_bco_no ,
                                dbo.bancos.nombre AS nombreBanco ,
                                dbo.Llaves.ocupacion ,
                                dbo.tabulador.actividad ,
                                dbo.empleados.tiposal ,
                                dbo.empleados.jornada ,
                                ISNULL(salarios.sueldo,dbo.empleados.sueldo) AS sueldo ,
                                ISNULL(salarios.saldiaint,dbo.empleados.saldiaint) AS saldiaint ,
                                dbo.Llaves.clase ,
                                dbo.clases.nombre AS nombreClase ,
                                dbo.Llaves.supervisor ,
                                dbo.supervisores.nombre AS nombreSupervisor ,
                                dbo.recibos.renglon ,
                                CASE WHEN ( ( @ordenadoPor & 4 > 0
                                              OR @ordenadoPor & 8 > 0
                                            )
                                            OR ( ( @ordenadoPor & 1 > 0
                                                   OR @ordenadoPor & 2 > 0
                                                 )
                                                 AND @desglosadoPor & 2 > 0
                                               )
                                          )
                                     THEN SUBSTRING(dbo.Llaves.centro, 1, 15)
                                     WHEN ( @ordenadoPor & 16 > 0
                                            OR @ordenadopor & 32 > 0
                                          )
                                     THEN RTRIM(dbo.Llaves.centro)
                                          + RIGHT(STR(100000000
                                                      + dbo.Llaves.supervisor),
                                                  8)
                                     ELSE NULL
                                END ,
                                dbo.empleados.rfcalfa ,
                                dbo.empleados.rfcnum ,
                                dbo.empleados.rfchomo ,
                                dbo.datosemps.email ,
                                dbo.empleados.fchantigua ,
                                @procesoName ,
                                @nomina ,
                                dbo.datosemps.foto
                        FROM    dbo.recibos
                                INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                            AND dbo.recibos.codigo = dbo.empleados.codigo
                                INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                         AND dbo.empleados.codigo = dbo.Llaves.codigo
                                INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                          AND dbo.Llaves.empresa = dbo.centros.empresa
                                INNER JOIN dbo.tabulador ON dbo.centros.empresa = dbo.tabulador.empresa
                                                            AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
                                INNER JOIN dbo.bancos ON dbo.Llaves.banco = dbo.bancos.banco
                                INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa
                                                         AND dbo.Llaves.clase = dbo.clases.clase
                                INNER JOIN dbo.supervisores ON dbo.Llaves.empresa = dbo.supervisores.empresa
                                                              AND dbo.Llaves.supervisor = dbo.supervisores.supervisor
                                INNER JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                                            AND dbo.empleados.codigo = dbo.datosemps.codigo

                                -- Buscar el ultimo sueldo e integrado antes del cierre, cuando existen movimientos
                                -- posteriores estaba imprimiendo unos valores que no correspondian con los calculos
                                -- de los conceptos de sueldo ni las retenciones IMSS e INFONAVIT
                                INNER JOIN (SELECT emps.codigo,
                                                   (SELECT TOP 1 avisos_imss.sueldo
                                                    FROM avisos_imss
                                                    WHERE avisos_imss.codigo = emps.codigo AND
                                                          avisos_imss.fch_mov <= periodos.cierre and
                                                          avisos_imss.mov <> 'B' and
                                                          avisos_imss.empresa = @empresa
                                                    ORDER BY avisos_imss.fch_mov DESC, avisos_imss.serial DESC) AS sueldo,
                                                   (SELECT TOP 1 avisos_imss.saldiaint
                                                    FROM avisos_imss
                                                    WHERE avisos_imss.codigo = emps.codigo AND
                                                          avisos_imss.fch_mov <= periodos.cierre and
                                                          avisos_imss.mov <> 'B' and
                                                          avisos_imss.empresa = @empresa
                                                    ORDER BY avisos_imss.fch_mov DESC, avisos_imss.serial DESC) AS saldiaint
                                            FROM empleados as emps
                                            INNER JOIN llaves on llaves.codigo = emps.codigo and llaves.empresa = emps.empresa
                                            INNER JOIN periodos on periodos.tiponom = llaves.tiponom and periodos.estatus = 'A' and periodos.empresa = emps.empresa
                                            WHERE emps.activo = 'S' AND
                                                  emps.borrado <> 'S' AND
                                                  emps.empresa = @empresa) AS salarios on salarios.codigo = empleados.codigo
                                -- 25 de Julio 2012

                                INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.Llaves.codigo
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.codigo
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.procesoName
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN @procesoName
                                                              ELSE '1'
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.nomina
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.recibos.nomina
                                                              ELSE '1'
                                                              END
                                /*
                                INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN RTRIM(LTRIM(dbo.Llaves.centro))
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                */
                        WHERE   dbo.recibos.empresa = CASE WHEN @desglosadoPor
                                                              & 1 > 0
                                                           THEN @empresa
                                                           ELSE 0
                                                      END
                                AND dbo.recibos.nomina = @nomina
                                AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicioKardex
                                          AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTerminoKardex
                                        )
                                        OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicioKardex
                                             AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTerminoKardex
                                           )
                                      )
                                      OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicioKardex
                                             AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTerminoKardex
                                           )
                                           OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicioKardex
                                                AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTerminoKardex
                                              )
                                         )
                                      OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicioKardex
                                           AND dbo.recibos.num_conc <= @numeroConceptoProvisionTerminoKardex
                                         )
                                    )
                                --AND dbo.recibos.codigo = 1002

-- Carga Percepciones
                UPDATE  @kardex
                SET     marcaContraPercepcion = CASE WHEN dbo.recibos.num_conc >= 1101
                                                          AND dbo.recibos.num_conc <= 1199
                                                     THEN 'C'
                                                     ELSE NULL
                                                END ,
                        numeroConceptoPercepcion = dbo.recibos.num_conc ,
                        nombreConceptoPercepcion = dbo.recibos.concepto ,
                        importeConceptoPercepcion = dbo.recibos.importe ,
                        gravablePercepcion = dbo.recibos.igravable ,
                        exentoPercepcion = dbo.recibos.iexento ,
                        saldoPercepcion = CASE WHEN dbo.recibos.saldo > 0
                                               THEN dbo.recibos.saldo
                                               ELSE NULL
                                          END ,
                        anexoConceptoPercepcion = CASE
                                      -- Detalle Sueldo
                                                       WHEN dbo.recibos.num_conc >= 1
                                                            AND dbo.recibos.num_conc <= 8
                                                            AND @registroPatronal <> 'A341223110'
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.impor_base))
                                                            + ' * '
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                            + ' Das'

                                     -- Detalle sueldo para Leticia
                                                       WHEN dbo.recibos.num_conc >= 1
                                                            AND dbo.recibos.num_conc <= 8
                                                            AND @registroPatronal = 'A341223110'
                                                       THEN ''

                                      -- Detalle Laboras en Dia de Descanso
                                                       WHEN dbo.recibos.num_conc = 10 AND @registroPatronal <> 'A341223110'
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.horas))
                                                            + ' Horas'

                                      -- Detella Horas Extras
                                                       WHEN dbo.recibos.num_conc >= 11
                                                            AND dbo.recibos.num_conc <= 13
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.horas))
                                                            + ' Horas'

                                      -- Detalle Prima Vacacional
                                                       WHEN dbo.recibos.num_conc = 17
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                            + ' Das'

                                      -- Detalle Vacaciones
                                                       WHEN dbo.recibos.num_conc = 30
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.impor_base))
                                                            + ' * ' + '('
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                            + 'H' + ' '
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                            + 'D' + ' '
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                            + 'F' + ')'

                                      -- Detalle Subsidio para el Empleo
                                                       WHEN dbo.recibos.num_conc = 36
                                                       THEN CASE
                                                              WHEN dbo.recibos.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.recibos.variable2 = 'MUESTRA'
                                                              THEN CASE
                                                              WHEN @ayoEmpresa < 2008
                                                              THEN 'Art. 115 $'
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                              ELSE 'Art 8vo Trans$'
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                              END
                                                              ELSE ''
                                                              END
                                                            END

                                      -- Detalle Concepto 53 Por Registro Patronal
                                                       WHEN dbo.recibos.num_conc = 53
                                                            AND ( @registroPatronal = 'R131234638'
                                                              OR @registroPatronal = 'C166197810'
                                                              OR @registroPatronal = 'C166939010'
                                                              OR @registroPatronal = 'E647730310'
                                                              OR @registroPatronal = 'E648122510'
                                                              )
                                                       THEN SUBSTRING(dbo.recibos.referencia,
                                                              01, 06)
                                                            + RIGHT(RTRIM(dbo.recibos.referencia),
                                                              02) + ' (M'
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.unidades))
                                                            + ')'

                                      -- Detalle Sueldo Neto
                                                       WHEN dbo.recibos.num_conc = 99
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                            + ' Das'

                                      -- Detalle de conceptos de Contras del 1107 al 1111
                                                       WHEN dbo.recibos.num_conc >= 1107
                                                            AND dbo.recibos.num_conc <= 1111
                                                       THEN CASE
                                                              WHEN dbo.recibos.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Das'
                                                              ELSE ''
                                                            END

                                      -- Detalle Conceptos con Valor Variable
                                                       ELSE CASE
                                                              WHEN dbo.recibos.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable1)))
                                                                   + ': '
                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                                   + CASE
                                                                       WHEN dbo.recibos.varia2 > 0
                                                                       THEN ','
                                                                            + RTRIM(LTRIM(UPPER(dbo.recibos.variable2)))
                                                                            + ': '
                                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                                            + CASE
                                                                                WHEN dbo.recibos.varia3 > 0
                                                                                THEN ','
                                                                                     + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                                                     + ': '
                                                                                     + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                                                     + CASE
                                                                                         WHEN dbo.recibos.varia4 > 0
                                                                                         THEN ','
                                                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                              + ': '
                                                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                         ELSE ''
                                                                                       END
                                                                                ELSE CASE
                                                                                       WHEN dbo.recibos.varia4 > 0
                                                                                       THEN ','
                                                                                            + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                            + ': '
                                                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                       ELSE ''
                                                                                     END
                                                                              END
                                                                       ELSE CASE
                                                                              WHEN dbo.recibos.varia3 > 0
                                                                              THEN ','
                                                                                   + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                                                   + ': '
                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                                                   + CASE
                                                                                       WHEN dbo.recibos.varia4 > 0
                                                                                       THEN ','
                                                                                            + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                            + ': '
                                                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                       ELSE ''
                                                                                     END
                                                                              ELSE CASE
                                                                                     WHEN dbo.recibos.varia4 > 0
                                                                                     THEN ','
                                                                                          + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                          + ': '
                                                                                          + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                     ELSE ''
                                                                                   END
                                                                            END
                                                                     END
                                                              ELSE CASE
                                                                     WHEN dbo.recibos.varia2 > 0
                                                                     THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable2)))
                                                                          + ': '
                                                                          + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                                          + CASE
                                                                              WHEN dbo.recibos.varia3 > 0
                                                                              THEN ','
                                                                                   + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                                                   + ': '
                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                                                   + CASE
                                                                                       WHEN dbo.recibos.varia4 > 0
                                                                                       THEN ','
                                                                                            + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                            + ': '
                                                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                       ELSE ''
                                                                                     END
                                                                              ELSE CASE
                                                                                     WHEN dbo.recibos.varia4 > 0
                                                                                     THEN ','
                                                                                          + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                          + ': '
                                                                                          + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                     ELSE ''
                                                                                   END
                                                                            END
                                                                     ELSE CASE
                                                                            WHEN dbo.recibos.varia3 > 0
                                                                            THEN ','
                                                                                 + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                                                 + ': '
                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                                                 + CASE
                                                                                     WHEN dbo.recibos.varia4 > 0
                                                                                     THEN ','
                                                                                          + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                          + ': '
                                                                                          + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                     ELSE ''
                                                                                   END
                                                                            ELSE CASE
                                                                                   WHEN dbo.recibos.varia4 > 0
                                                                                   THEN ','
                                                                                        + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                                                        + ': '
                                                                                        + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                   ELSE NULL -- Agregar mas condiciones
                                                                                 END
                                                                          END
                                                                   END
                                                            END
                                                  END
                FROM    @kardex
                        INNER JOIN dbo.recibos ON [@kardex].empresa = dbo.recibos.empresa
                                                  AND [@kardex].codigo = dbo.recibos.codigo
                                                  AND [@kardex].renglon = dbo.recibos.renglon
                                                  AND @nomina = dbo.recibos.nomina
                WHERE   [@kardex].empresa = @empresa
                        AND ( ( dbo.recibos.num_conc >= 1
                                AND dbo.recibos.num_conc <= 99
                              )
                              OR ( dbo.recibos.num_conc >= 1101
                                   AND dbo.recibos.num_conc <= 1199
                                 )
                            )
                        AND dbo.recibos.nomina = @nomina

                -- Percepciones. Actualiza el subtotal y total de resumen de centro de costos
                UPDATE  @kardex
                SET     [@kardex].numeroConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].numeroConcepto ,
                        [@kardex].nombreConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].nombreConcepto ,
                        [@kardex].importeConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].importe ,
                        [@kardex].gravablePercepcion = [dbo].[ResumenPorCentroRecibo].gravable ,
                        [@kardex].exentoPercepcion = [dbo].[ResumenPorCentroRecibo].exento ,
                        [@kardex].saldoPercepcion = [dbo].[ResumenPorCentroRecibo].saldoPercepcion ,
                        [@kardex].anexoConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].anexoConceptoPercepcion
                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'P',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroRecibo].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroRecibo].renglon
                WHERE   ( ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 1
                            AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 99
                          )
                          OR ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 1101
                               AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 1199
                             )
                        )


-- Carga Deducciones
                UPDATE  @kardex
                SET     marcaContraDeduccion = CASE WHEN dbo.recibos.num_conc >= 1001
                                                         AND dbo.recibos.num_conc <= 1099
                                                    THEN 'C'
                                                    ELSE NULL
                                               END ,
                        numeroConceptoDeduccion = dbo.recibos.num_conc ,
                        nombreConceptoDeduccion = dbo.recibos.concepto ,
                        importeConceptoDeduccion = dbo.recibos.importe ,
                        gravableDeduccion = dbo.recibos.igravable ,
                        exentoDeduccion = dbo.recibos.iexento ,
                        saldoDeduccion = CASE WHEN dbo.recibos.saldo > 0
                                              THEN --CASE WHEN dbo.recibos.num_conc = 126 THEN dbo.recibos.importe + dbo.recibos.saldo
                                                   --     WHEN dbo.recibos.num_conc = 127 THEN dbo.recibos.importe + dbo.recibos.saldo
                                                   --     ELSE dbo.recibos.saldo
                                                   --END
                                                   CASE WHEN ( dbo.conceptos.marca2 = 'P'
                                                              OR ( dbo.recibos.num_conc >= 115
                                                              AND dbo.recibos.num_conc <= 117
                                                              )
                                                             )
                                                        THEN dbo.recibos.saldo
                                                             - dbo.recibos.importe
                                                        WHEN ( dbo.conceptos.marca2 = 'H'
                                                              OR ( dbo.recibos.num_conc >= 125
                                                              AND dbo.recibos.num_conc <= 127
                                                              )
                                                             )
                                                        THEN dbo.recibos.saldo
                                                             + dbo.recibos.importe
                                                        ELSE NULL
                                                   END
                                              ELSE NULL
                                         END ,
                        anexoConceptoDeduccion = CASE
                                      -- Detalle Cuotas IMSS
                                                      WHEN dbo.recibos.num_conc >= 101 AND dbo.recibos.num_conc <= 105 THEN CONVERT(VARCHAR(15), CASE WHEN dbo.recibos.num_conc = 102
                                                                                                                                                      THEN CASE WHEN dbo.recibos.saldiaint > (@salarioDF * 3)
                                                                                                                                                                THEN dbo.ChecaDecimales(dbo.recibos.saldiaint - (@salarioDF * 3))
                                                                                                                                                                ELSE dbo.ChecaDecimales(dbo.recibos.saldiaint)
                                                                                                                                                           END
                                                                                                                                                      ELSE dbo.ChecaDecimales(dbo.recibos.saldiaint)
                                                                                                                                                 END) + ' * ' + CASE WHEN dbo.recibos.num_conc = 101 THEN CONVERT(VARCHAR(15), @eymTra25)
                                                                                                                                                                     WHEN dbo.recibos.num_conc = 102 THEN CONVERT(VARCHAR(15), @eymTra1062)
                                                                                                                                                                     WHEN dbo.recibos.num_conc = 103 THEN CONVERT(VARCHAR(15), @eymTra107)
                                                                                                                                                                     WHEN dbo.recibos.num_conc = 104 THEN CONVERT(VARCHAR(15), @ivTra147)
                                                                                                                                                                     WHEN dbo.recibos.num_conc = 105 THEN CONVERT(VARCHAR(15), @cvTra168II)
                                                                                                                                                                     ELSE ''
                                                                                                                                                                END + ' * ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias_imss))

                                      -- Detalle Retencion IMSS por Faltas
                                                      WHEN dbo.recibos.num_conc = 106
                                                           OR dbo.recibos.num_conc = 107
                                                           OR dbo.recibos.num_conc = 109
                                                           OR dbo.recibos.num_conc = 110
                                                           OR dbo.recibos.num_conc = 111
                                                           OR dbo.recibos.num_conc = 130 THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias)) + ' Da(s)'

                                      -- Detalle Faltas
                                                      WHEN dbo.recibos.num_conc = 108 THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias)) + ' Da(s)' + ' + ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(ABS(dbo.recibos.descuento - 100))) + '%'

                                      -- Detalle Creditos INFONAVIT
                                                      WHEN dbo.recibos.num_conc = 112 THEN CASE WHEN dbo.recibos.descuento > 0
                                                                                                THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.saldiaint)) + ' * ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias)) + ' * ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.descuento)) + '%'
                                                                                                ELSE CONVERT(VARCHAR(15), CONVERT(NUMERIC(15,2), dbo.ChecaDecimales(ROUND(dbo.recibos.importe / dbo.recibos.dias,2)))) + ' * ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias)) + 'DS'
                                                                                           END

                                      -- Detalle Fondo de Ahorro
                                                      WHEN (dbo.recibos.num_conc = 126 OR dbo.recibos.num_conc = 127) AND (@reciboSeleccionado <> 'Apsi 4' AND @reciboSeleccionado <> 'Apsi 5' AND @reciboSeleccionado <> 'Apsi 6' AND @reciboSeleccionado <> 'Apsi 7') THEN 'Saldo $ ' + CONVERT(VARCHAR(15), dbo.recibos.saldo + dbo.recibos.importe)

                                      -- Detalle ISR
                                                      WHEN dbo.recibos.num_conc = 136 THEN CASE WHEN dbo.recibos.variable1 = '1991'
                                                                                                THEN '1991'
                                                                                                ELSE CASE WHEN dbo.recibos.variable2 = 'MUESTRA'
                                                                                                          THEN CASE WHEN @ayoEmpresa < 2008
                                                                                                                    THEN 'Art. 115 $' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                                                                                    ELSE 'Art 8vo Trans$' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                                                                               END
                                                                                                          ELSE ''
                                                                                                     END
                                                                                           END

                                      -- Contra Sueldo
                                                      WHEN dbo.recibos.num_conc >= 1001 AND dbo.recibos.num_conc <= 1007 THEN CASE WHEN dbo.recibos.dias > 0
                                                                                                                                   THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias)) + ' Da(s)'
                                                                                                                                   ELSE ''
                                                                                                                              END

                                      -- Detalle los demas conceptos
                                                      ELSE CASE WHEN dbo.recibos.saldo > 0 AND (@reciboSeleccionado <> 'Apsi 4' AND @reciboSeleccionado <> 'Apsi 5' AND @reciboSeleccionado <> 'Apsi 6' AND @reciboSeleccionado <> 'Apsi 7')
                                                                THEN 'Saldo $ ' + CONVERT(VARCHAR(15), dbo.recibos.saldo + CASE WHEN dbo.conceptos.marca2 = 'H' OR --A'
                                                                                                                                     dbo.conceptos.num_conc in (125,126,127)
                                                                                                                                THEN 1
                                                                                                                                ELSE -1
                                                                                                                           END * dbo.recibos.descuento)
                                                -- Detalle de conceptos con valores variable
                                                                ELSE CASE WHEN dbo.recibos.varia1 > 0
                                                                          THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable1))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1)) + CASE WHEN dbo.recibos.varia2 > 0
                                                                                                                                                                                                       THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable2))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2)) + CASE WHEN dbo.recibos.varia3 > 0
                                                                                                                                                                                                                                                                                                                                          THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable3))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3)) + CASE WHEN dbo.recibos.varia4 > 0
                                                                                                                                                                                                                                                                                                                                                                                                                                                                             THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                                                                                                                                                                                                                                                                                                                                                                                             ELSE ''
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        END
                                                                                                                                                                                                                                                                                                                                          ELSE CASE WHEN dbo.recibos.varia4 > 0
                                                                                                                                                                                                                                                                                                                                                    THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                                                                                                                                                                                                                                                                    ELSE ''
                                                                                                                                                                                                                                                                                                                                               END
                                                                                                                                                                                                                                                                                                                                     END
                                                                                                                                                                                                       ELSE CASE WHEN dbo.recibos.varia3 > 0
                                                                                                                                                                                                                 THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable3))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3)) + CASE WHEN dbo.recibos.varia4 > 0
                                                                                                                                                                                                                                                                                                                                                    THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                                                                                                                                                                                                                                                                    ELSE ''
                                                                                                                                                                                                                                                                                                                                               END
                                                                                                                                                                                                                 ELSE CASE WHEN dbo.recibos.varia4 > 0
                                                                                                                                                                                                                           THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                                                                                                                                           ELSE ''
                                                                                                                                                                                                                      END
                                                                                                                                                                                                            END
                                                                                                                                                                                                  END
                                                                          ELSE CASE WHEN dbo.recibos.varia2 > 0
                                                                                    THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable2))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2)) + CASE WHEN dbo.recibos.varia3 > 0
                                                                                                                                                                                                                 THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable3))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3)) + CASE WHEN dbo.recibos.varia4 > 0
                                                                                                                                                                                                                                                                                                                                                    THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                                                                                                                                                                                                                                                                    ELSE ''
                                                                                                                                                                                                                                                                                                                                               END
                                                                                                                                                                                                                 ELSE CASE WHEN dbo.recibos.varia4 > 0
                                                                                                                                                                                                                           THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                                                                                                                                           ELSE ''
                                                                                                                                                                                                                      END
                                                                                                                                                                                                            END
                                                                                    ELSE CASE WHEN dbo.recibos.varia3 > 0
                                                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable3))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3)) + CASE WHEN dbo.recibos.varia4 > 0
                                                                                                                                                                                                                                 THEN ',' + RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                                                                                                                                                 ELSE ''
                                                                                                                                                                                                                            END
                                                                                              ELSE CASE WHEN dbo.recibos.varia4 > 0
                                                                                                        THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable4))) + ': ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                                                                        ELSE NULL -- Agregar mas condiciones
                                                                                                   END
                                                                                         END
                                                                               END
                                                                        END
                                                           END
                                                 END
                FROM    @kardex
                        INNER JOIN dbo.recibos ON [@kardex].empresa = dbo.recibos.empresa
                                                  AND [@kardex].codigo = dbo.recibos.codigo
                                                  AND [@kardex].renglon = dbo.recibos.renglon
                                                  AND @nomina = dbo.recibos.nomina
                        INNER JOIN dbo.conceptos ON dbo.recibos.empresa = dbo.conceptos.empresa
                                                    AND dbo.recibos.num_conc = dbo.conceptos.num_conc
                                                    AND dbo.recibos.clase = dbo.conceptos.clase
                                                    AND dbo.recibos.centro = dbo.conceptos.centro
                WHERE   [@kardex].empresa = @empresa
                        AND ( ( dbo.recibos.num_conc >= 101
                                AND dbo.recibos.num_conc <= 199
                              )
                              OR ( dbo.recibos.num_conc >= 1001
                                   AND dbo.recibos.num_conc <= 1099
                                 )
                            )
                        AND dbo.recibos.nomina = @nomina

                -- Deducciones. Actualiza el subtotal y total de resumen de centro de costos
                UPDATE  @kardex
                SET     [@kardex].numeroConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].numeroConcepto ,
                        [@kardex].nombreConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].nombreConcepto ,
                        [@kardex].importeConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].importe ,
                        [@kardex].gravableDeduccion = [dbo].[ResumenPorCentroRecibo].gravable ,
                        [@kardex].exentoDeduccion = [dbo].[ResumenPorCentroRecibo].exento ,
                        [@kardex].anexoConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].anexoConceptoDeduccion
                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'D',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                                                              AND [@kardex].centro = [dbo].[ResumenPorCentroRecibo].centro
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroRecibo].renglon
                WHERE   ( ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 101
                            AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 199
                          )
                          OR ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 1001
                               AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 1099
                             )
                        )

-- Carga Provisiones
                IF @incluirProvisiones = 'S'
                    BEGIN
                        UPDATE  @kardex
                        SET     numeroConceptoProvision = dbo.recibos.num_conc ,
                                nombreConceptoProvision = dbo.recibos.concepto ,
                                importeConceptoProvision = dbo.recibos.importe
                        FROM    @kardex
                                INNER JOIN dbo.recibos ON [@kardex].empresa = dbo.recibos.empresa
                                                          AND [@kardex].codigo = dbo.recibos.codigo
                                                          AND [@kardex].renglon = dbo.recibos.renglon
                                                          AND @nomina = dbo.recibos.nomina
                        WHERE   [@kardex].empresa = @empresa
                                AND ( dbo.recibos.num_conc >= 201
                                      AND dbo.recibos.num_conc <= 299
                                    )
                                AND dbo.recibos.nomina = @nomina

                -- Provision. Actualiza el subtotal y total de resumen de centro de costos
                        UPDATE  @kardex
                        SET     [@kardex].numeroConceptoProvision = [dbo].[ResumenPorCentroRecibo].numeroConcepto ,
                                [@kardex].nombreConceptoProvision = [dbo].[ResumenPorCentroRecibo].nombreConcepto ,
                                [@kardex].importeConceptoProvision = [dbo].[ResumenPorCentroRecibo].importe
                        FROM    @kardex
                                INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'S', @tipoNomina,
                                                              'I',
                                                              @ordenadoPor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                                                              AND [@kardex].centro = [dbo].[ResumenPorCentroRecibo].centro
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                                                              ELSE 1
                                                              END
                                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroRecibo].renglon
                        WHERE   ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 201
                                  AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 299
                                )
                    END


                -- Registro Totales
                UPDATE  @kardex
                SET     [@kardex].empleados = [dbo].[ResumenPorCentroRecibo].empleados ,
                        [@kardex].provisionIMSS = [dbo].[ResumenPorCentroRecibo].provisionIMSS ,
                        [@kardex].provisionRCV = [dbo].[ResumenPorCentroRecibo].provisionRCV ,
                        [@kardex].provisionINFONAVIT = [dbo].[ResumenPorCentroRecibo].provisionINFONAVIT ,
                        [@kardex].retencionIMSS = [dbo].[ResumenPorCentroRecibo].retencionIMSS ,
                        [@kardex].retencionRCV = [dbo].[ResumenPorCentroRecibo].retencionRCV ,
                        [@kardex].retencionINFONAVIT = [dbo].[ResumenPorCentroRecibo].retencionINFONAVIT ,
                        [@kardex].empleadosConCuentaBancaria = [dbo].[ResumenPorCentroRecibo].empleadosConCuentaBancaria ,
                        [@kardex].empleadosSinCuentaBancaria = [dbo].[ResumenPorCentroRecibo].empleadosSinCuentaBancaria ,
                        [@kardex].percepcionesConCuentaBancaria = [dbo].[ResumenPorCentroRecibo].percepcionesConCuentaBancaria ,
                        [@kardex].deduccionesConCuentaBancaria = [dbo].[ResumenPorCentroRecibo].deduccionesConCuentaBancaria ,
                        [@kardex].percepcionesSinCuentaBancaria = [dbo].[ResumenPorCentroRecibo].percepcionesSinCuentaBancaria ,
                        [@kardex].deduccionesSinCuentaBancaria = [dbo].[ResumenPorCentroRecibo].deduccionesSinCuentaBancaria ,
                        [@kardex].basePorcientoSobreNomina = [dbo].[ResumenPorCentroRecibo].basePorcientoSobreNomina ,
                        [@kardex].porcientoSobreNomina = [dbo].[ResumenPorCentroRecibo].porcientoSobreNomina ,
                        [@kardex].fondoAhorroAportacionEmpleado = [dbo].[ResumenPorCentroRecibo].fondoAhorroAportacionEmpleado ,
                        [@kardex].fondoAhorroAportacionPatron = [dbo].[ResumenPorCentroRecibo].fondoAhorroAportacionPatron ,
                        [@kardex].sueldoNetoGeneral = [dbo].[ResumenPorCentroRecibo].sueldoNetoGeneral
                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'T', @tipoNomina,
                                                              '', @ordenadoPor,
                                                              @salarioDF,
                                                              @salarioRegion,
                                                              @eymArt25,
                                                              @eymArt1062,
                                                              @eymArt107,
                                                              @ivArt147,
                                                              @cvArt168II,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroRecibo].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [@kardex].supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadoPor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                                                              ELSE 1
                                                              END
                WHERE   [dbo].[ResumenPorCentroRecibo].numeroConcepto = 9996


                UPDATE  @kardex
                SET     [@kardex].ejercicio = [dbo].[ResumenPorCentroRecibo].ejercicio ,
                        [@kardex].diarioOficialDia = [dbo].[ResumenPorCentroRecibo].diarioOficialDia ,
                        [@kardex].diarioOficialMes = [dbo].[ResumenPorCentroRecibo].diarioOficialMes ,
                        [@kardex].diarioOficialAyo = [dbo].[ResumenPorCentroRecibo].diarioOficialAyo ,
                        [@kardex].salarioMinimoDF = [dbo].[ResumenPorCentroRecibo].salarioMinimoDF ,
                        [@kardex].salarioMinimoRegion = [dbo].[ResumenPorCentroRecibo].salarioMinimoRegion ,
                        [@kardex].eymArt25 = [dbo].[ResumenPorCentroRecibo].eymArt25 ,
                        [@kardex].eymArt106ii = [dbo].[ResumenPorCentroRecibo].eymArt106ii ,
                        [@kardex].eymArt107 = [dbo].[ResumenPorCentroRecibo].eymArt107 ,
                        [@kardex].ivArt147 = [dbo].[ResumenPorCentroRecibo].ivArt147 ,
                        [@kardex].cvArt168ii = [dbo].[ResumenPorCentroRecibo].cvArt168ii ,
                        [@kardex].baseCalculo = [dbo].[ResumenPorCentroRecibo].baseCalculo
                FROM    @kardex
                        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa,
                                                              @nomina,
                                                              @incluirProvisiones,
                                                              'T', @tipoNomina,
                                                              '', @ordenadoPor,
                                                              @salarioDF,
                                                              @salarioRegion,
                                                              @eymArt25,
                                                              @eymArt1062,
                                                              @eymArt107,
                                                              @ivArt147,
                                                              @cvArt168II,
                                                              @desglosadoPor,
                                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                                                              AND [@kardex].centro = [dbo].[ResumenPorCentroRecibo].centro
                WHERE   [dbo].[ResumenPorCentroRecibo].numeroConcepto = 9996
                        AND [@kardex].codigo = 999999996
                        AND [@kardex].centro = '99999999999997'

            END

        IF @esRecibo = 0
            BEGIN
                DELETE  @kardex
                WHERE   [@kardex].empresa = @empresa
                        AND [@kardex].codigo = 999999995
                        AND [@kardex].numeroConceptoPercepcion IS NULL
                        AND [@kardex].numeroConceptoDeduccion IS NULL
                        AND [@kardex].numeroConceptoProvision IS NULL
            END
        ELSE
            BEGIN

                INSERT  @codigoBase
                        ( codigo ,
                          renglon ,
                          centro ,
                          supervisor ,
                          nombre
                        )
                        SELECT DISTINCT
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon ,
                                [@kardex].centro ,
                                [@kardex].supervisor ,
                                [@kardex].nombre
                        FROM    @kardex ,
                                @tablaBaseRenglon
                        --WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                        --                                            THEN CASE WHEN @renglonTope = 17 THEN 34 ELSE 40 END
                        --                                            ELSE CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                        --                                       END
                        --WHERE   [@tablaBaseRenglon].renglon <= ROUND((CONVERT(FLOAT, [@kardex].renglon) / @renglonTope) + .5,0) * @renglonTope
                        WHERE [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 0 AND [@kardex].renglon <= @renglonTope THEN @renglonTope
                                                                  WHEN [@kardex].renglon >= @renglonTope + 1 AND [@kardex].renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                  WHEN [@kardex].renglon >= @renglonTope * 2 + 1 AND [@kardex].renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                  WHEN [@kardex].renglon >= @renglonTope * 3 + 1 AND [@kardex].renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                  ELSE @renglonTope * 5
                                                             END

                        


                --SELECT * --renglon,
                       --@renglonTope ,
                       --ROUND((CONVERT(NUMERIC(5,2), [@kardex].renglon) / @renglonTope),.5)
                --       renglon / @renglonTope
                --FROM @kardex
                --SELECT CASE WHEN renglon > 0 AND renglon <= @renglonTope THEN @renglonTope
                --            WHEN renglon >= @renglonTope + 1 AND renglon <= @renglonTope * 2 THEN @renglonTope * 2
                --            WHEN renglon >= @renglonTope * 2 + 1 AND renglon <= @renglonTope * 3 THEN @renglonTope * 3
                --            WHEN renglon >= @renglonTope * 3 + 1 AND renglon <= @renglonTope * 4 THEN @renglonTope * 4
                --            ELSE @renglonTope * 5
                --       END, * 
                --FROM @codigoBase

                SET @codigoAnterior = 0
                SET @numeroRecibo = 0
                SET @nombreAnterior = ''
                
                -- Ordenado por Cdigo
                IF @ordenadoPor & 1 > 0
                    BEGIN
                        INSERT  @tablaNumeroRecibo
                                ( codigo ,
                                  renglon
                                )
                                SELECT DISTINCT
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon
                                FROM    @kardex ,
                                        @tablaBaseRenglon
                                --WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                                            THEN CASE WHEN @renglonTope = 17 THEN 34 ELSE 40 END
                                --                                            ELSE CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                                       END
                                WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 0 AND [@kardex].renglon <= @renglonTope THEN @renglonTope
                                                                            WHEN [@kardex].renglon >= @renglonTope + 1 AND [@kardex].renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                            WHEN [@kardex].renglon >= @renglonTope * 2 + 1 AND [@kardex].renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                            WHEN [@kardex].renglon >= @renglonTope * 3 + 1 AND [@kardex].renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                            ELSE @renglonTope * 5
                                                             END
                                ORDER BY [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon

                        UPDATE  @tablaNumeroRecibo
                        SET     @numeroRecibo = @numeroRecibo
                                + CASE WHEN [@tablaNumeroRecibo].codigo <> @codigoAnterior
                                       THEN 1
                                       ELSE 0
                                  END ,
                                [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                                @codigoAnterior = [@tablaNumeroRecibo].codigo
                        --SELECT 'C', * FROM @tablaNumeroRecibo
                    END

                -- Ordenado por Nombre
                IF @ordenadoPor & 2 > 0
                    BEGIN
                        INSERT  @tablaNumeroRecibo
                                ( codigo ,
                                  renglon ,
                                  nombre
                                )
                                SELECT DISTINCT
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon ,
                                        [@kardex].nombre
                                FROM    @kardex ,
                                        @tablaBaseRenglon
                                --WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                                            THEN CASE WHEN @renglonTope = 17 THEN 34 ELSE 40 END
                                --                                            ELSE CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                                       END
                                WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 0 AND [@kardex].renglon <= @renglonTope THEN @renglonTope
                                                                            WHEN [@kardex].renglon >= @renglonTope + 1 AND [@kardex].renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                            WHEN [@kardex].renglon >= @renglonTope * 2 + 1 AND [@kardex].renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                            WHEN [@kardex].renglon >= @renglonTope * 3 + 1 AND [@kardex].renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                            ELSE @renglonTope * 5
                                                             END
                                ORDER BY [@kardex].nombre ,
                                        [@tablaBaseRenglon].renglon

                        UPDATE  @tablaNumeroRecibo
                        SET     @numeroRecibo = @numeroRecibo
                                + CASE WHEN [@tablaNumeroRecibo].nombre <> @nombreAnterior
                                       THEN 1
                                       ELSE 0
                                  END ,
                                [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                                @nombreAnterior = [@tablaNumeroRecibo].nombre
                        --SELECT 'N', * FROM @tablaNumeroRecibo
                    END

                -- Ordenado por Centro y Nombre
                IF @ordenadoPor & 4 > 0
                    BEGIN
                        INSERT  @tablaNumeroRecibo
                                ( codigo ,
                                  renglon ,
                                  nombre ,
                                  centro
                                )
                                SELECT DISTINCT
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon ,
                                        [@kardex].nombre ,
                                        [@kardex].centro
                                FROM    @kardex ,
                                        @tablaBaseRenglon
                                --WHERE   [@tablaBaseRenglon].renglon <= CASE
                                --                              WHEN [@kardex].renglon > CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              THEN CASE WHEN @renglonTope = 17 THEN 34 ELSE 40 END
                                --                              ELSE CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              END
                                WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 0 AND [@kardex].renglon <= @renglonTope THEN @renglonTope
                                                                            WHEN [@kardex].renglon >= @renglonTope + 1 AND [@kardex].renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                            WHEN [@kardex].renglon >= @renglonTope * 2 + 1 AND [@kardex].renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                            WHEN [@kardex].renglon >= @renglonTope * 3 + 1 AND [@kardex].renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                            ELSE @renglonTope * 5
                                                             END
                                ORDER BY [@kardex].centro ,
                                        [@kardex].nombre ,
                                        [@tablaBaseRenglon].renglon

                        UPDATE  @tablaNumeroRecibo
                        SET     @numeroRecibo = @numeroRecibo
                                + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                            + [@tablaNumeroRecibo].nombre <> @nombreAnterior
                                       THEN 1
                                       ELSE 0
                                  END ,
                                [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                                @nombreAnterior = [@tablaNumeroRecibo].centro
                                + ' ' + [@tablaNumeroRecibo].nombre
                        --SELECT 'CN', * FROM @tablaNumeroRecibo
                    END

                -- Ordenado por Centro y Cdigo
                IF @ordenadoPor & 8 > 0
                    BEGIN
                        INSERT  @tablaNumeroRecibo
                                ( codigo ,
                                  renglon ,
                                  centro
                                )
                                SELECT DISTINCT
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon ,
                                        [@kardex].centro
                                FROM    @kardex ,
                                        @tablaBaseRenglon
                                --WHERE   [@tablaBaseRenglon].renglon <= CASE
                                --                              WHEN [@kardex].renglon > CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              THEN CASE WHEN @renglonTope = 17 THEN 34 ELSE 40 END
                                --                              ELSE CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              END
                                WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 0 AND [@kardex].renglon <= @renglonTope THEN @renglonTope
                                                                            WHEN [@kardex].renglon >= @renglonTope + 1 AND [@kardex].renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                            WHEN [@kardex].renglon >= @renglonTope * 2 + 1 AND [@kardex].renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                            WHEN [@kardex].renglon >= @renglonTope * 3 + 1 AND [@kardex].renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                            ELSE @renglonTope * 5
                                                             END
                                ORDER BY [@kardex].centro ,
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon

                        UPDATE  @tablaNumeroRecibo
                        SET     @numeroRecibo = @numeroRecibo
                                + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                            + STR([@tablaNumeroRecibo].codigo) <> @nombreAnterior
                                       THEN 1
                                       ELSE 0
                                  END ,
                                [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                                @nombreAnterior = [@tablaNumeroRecibo].centro
                                + ' ' + STR([@tablaNumeroRecibo].codigo)
                        --SELECT 'CC', * FROM @tablaNumeroRecibo
                    END

                -- Ordenado por Centro, Supervisor y Nombre
                IF @ordenadoPor & 16 > 0
                    BEGIN
                        INSERT  @tablaNumeroRecibo
                                ( codigo ,
                                  renglon ,
                                  centro ,
                                  nombre ,
                                  supervisor
                                )
                                SELECT DISTINCT
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon ,
                                        [@kardex].centro ,
                                        [@kardex].nombre ,
                                        [@kardex].supervisor
                                FROM    @kardex ,
                                        @tablaBaseRenglon
                                --WHERE   [@tablaBaseRenglon].renglon <= CASE
                                --                              WHEN [@kardex].renglon > CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              THEN CASE WHEN @renglonTope = 17 THEN 34 else 40 END
                                --                              ELSE CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              END
                                WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 0 AND [@kardex].renglon <= @renglonTope THEN @renglonTope
                                                                            WHEN [@kardex].renglon >= @renglonTope + 1 AND [@kardex].renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                            WHEN [@kardex].renglon >= @renglonTope * 2 + 1 AND [@kardex].renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                            WHEN [@kardex].renglon >= @renglonTope * 3 + 1 AND [@kardex].renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                            ELSE @renglonTope * 5
                                                             END
                                ORDER BY [@kardex].centro ,
                                        [@kardex].supervisor ,
                                        [@kardex].nombre ,
                                        [@tablaBaseRenglon].renglon

                        UPDATE  @tablaNumeroRecibo
                        SET     @numeroRecibo = @numeroRecibo
                                + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                            + STR([@tablaNumeroRecibo].supervisor)
                                            + ' '
                                            + [@tablaNumeroRecibo].nombre <> @nombreAnterior
                                       THEN 1
                                       ELSE 0
                                  END ,
                                [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                                @nombreAnterior = [@tablaNumeroRecibo].centro
                                + ' ' + STR([@tablaNumeroRecibo].supervisor)
                                + ' ' + [@tablaNumeroRecibo].nombre
                        --SELECT 'CSN', * FROM @tablaNumeroRecibo
                    END

                -- Ordenado por Centro, Supervisor y Cdigo
                IF @ordenadoPor & 32 > 0
                    BEGIN
                        INSERT  @tablaNumeroRecibo
                                ( codigo ,
                                  renglon ,
                                  centro ,
                                  supervisor
                                )
                                SELECT DISTINCT
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon ,
                                        [@kardex].centro ,
                                        [@kardex].supervisor
                                FROM    @kardex ,
                                        @tablaBaseRenglon
                                --WHERE   [@tablaBaseRenglon].renglon <= CASE
                                --                              WHEN [@kardex].renglon > CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              THEN CASE WHEN @renglonTope = 17 THEN 34 ELSE 40 END
                                --                              ELSE CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                                --                              END
                                WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 0 AND [@kardex].renglon <= @renglonTope THEN @renglonTope
                                                                            WHEN [@kardex].renglon >= @renglonTope + 1 AND [@kardex].renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                            WHEN [@kardex].renglon >= @renglonTope * 2 + 1 AND [@kardex].renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                            WHEN [@kardex].renglon >= @renglonTope * 3 + 1 AND [@kardex].renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                            ELSE @renglonTope * 5
                                                             END
                                ORDER BY [@kardex].centro ,
                                        [@kardex].supervisor ,
                                        [@kardex].codigo ,
                                        [@tablaBaseRenglon].renglon

                        UPDATE  @tablaNumeroRecibo
                        SET     @numeroRecibo = @numeroRecibo
                                + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                            + STR([@tablaNumeroRecibo].supervisor)
                                            + ' '
                                            + STR([@tablaNumeroRecibo].codigo) <> @nombreAnterior
                                       THEN 1
                                       ELSE 0
                                  END ,
                                [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                                @nombreAnterior = [@tablaNumeroRecibo].centro
                                + ' ' + STR([@tablaNumeroRecibo].supervisor)
                                + ' ' + STR([@tablaNumeroRecibo].codigo)
                        --SELECT 'CSC', * FROM @tablaNumeroRecibo
                    END

                SET @cuantosRecibos = 0
                SET @codigoAnterior = 0
                SET @numeroRecibo = 0
                
                

                /*
                SELECT codigoBase.renglon, ROUND((CONVERT(FLOAT, codigoBase.renglon) / @renglonTope) + .5,0) ,                                          
                       [@codigoBase].renglon, ROUND((CONVERT(FLOAT, [@codigoBase].renglon) / @renglonTope) ,0)
                FROM    @codigoBase
                        INNER JOIN ( SELECT [@codigoBase].codigo ,
                                            MAX([@codigoBase].renglon) AS renglon
                                     FROM   @codigoBase
                                     GROUP BY [@codigoBase].codigo
                                   ) AS codigoBase ON [@codigoBase].codigo = codigoBase.codigo
                        INNER JOIN @tablaNumeroRecibo ON [@codigoBase].codigo = [@tablaNumeroRecibo].codigo
                                                         AND [@codigoBase].renglon = [@tablaNumeroRecibo].renglon
                */ 


                UPDATE  @codigoBase
                SET     --@cuantosRecibos = CASE WHEN codigoBase.renglon <= CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 end
                        --                       THEN 1
                        --                       ELSE 2
                        --                  END ,

                        @cuantosRecibos = CASE WHEN codigoBase.renglon > 0 AND codigoBase.renglon <= @renglonTope THEN 1
                                               WHEN codigoBase.renglon >= @renglonTope + 1 AND codigoBase.renglon <= @renglonTope * 2 THEN 2
                                               WHEN codigoBase.renglon >= @renglonTope * 2 + 1 AND codigoBase.renglon <= @renglonTope * 3 THEN 3
                                               WHEN codigoBase.renglon >= @renglonTope * 3 + 1 AND codigoBase.renglon <= @renglonTope * 4 THEN 4
                                               ELSE 5
                                          END
 ,                                          
                        [@codigoBase].cuantosRecibos = @cuantosRecibos ,
                        --[@codigoBase].recibo = CASE WHEN [@codigoBase].renglon <= CASE WHEN @renglonTope = 17 THEN 17 ELSE 20 END
                        --                            THEN 1
                        --                            ELSE 2
                        --                       END ,
                        [@codigoBase].recibo = CASE WHEN [@codigoBase].renglon > 0 AND [@codigoBase].renglon <= @renglonTope THEN 1
                                                    WHEN [@codigoBase].renglon >= @renglonTope + 1 AND [@codigoBase].renglon <= @renglonTope * 2 THEN 2
                                                    WHEN [@codigoBase].renglon >= @renglonTope * 2 + 1 AND [@codigoBase].renglon <= @renglonTope * 3 THEN 3
                                                    WHEN [@codigoBase].renglon >= @renglonTope * 3 + 1 AND [@codigoBase].renglon <= @renglonTope * 4 THEN 4
                                                    ELSE 5
                                               END ,
                        @numeroRecibo = @numeroRecibo + CASE WHEN [@codigoBase].codigo <> @codigoAnterior THEN 1 ELSE 0 END ,
                        @codigoAnterior = [@codigoBase].codigo ,
                        [@codigoBase].numeroRecibo = [@tablaNumeroRecibo].numeroRecibo
                        --, [@codigoBase].numeroRecibo = @numeroRecibo
                FROM    @codigoBase
                        INNER JOIN ( SELECT [@codigoBase].codigo ,
                                            MAX([@codigoBase].renglon) AS renglon
                                     FROM   @codigoBase
                                     GROUP BY [@codigoBase].codigo
                                   ) AS codigoBase ON [@codigoBase].codigo = codigoBase.codigo
                        INNER JOIN @tablaNumeroRecibo ON [@codigoBase].codigo = [@tablaNumeroRecibo].codigo
                                                         AND [@codigoBase].renglon = [@tablaNumeroRecibo].renglon
                                                         
                --SELECT 'A', * FROM @codigoBase

                INSERT  @kardex
                        ( empresa ,
                          codigo ,
                          renglon ,
                          codigoId ,
                          nombre ,
                          centro ,
                          supervisor ,
                          procesoName ,
                          nomina
                        )
                        SELECT  @empresa ,
                                [@codigoBase].codigo ,
                                [@codigoBase].renglon ,
                                RIGHT(STR(100000000 + [@codigoBase].codigo), 8)
                                + RIGHT(STR(1000000000 + [@codigoBase].renglon),
                                        9) ,
                                [@codigoBase].nombre ,
                                [@codigoBase].centro ,
                                [@codigoBase].supervisor ,
                                @procesoName ,
                                @nomina
                        FROM    @kardex
                                RIGHT JOIN @codigoBase ON [@kardex].codigo = [@codigoBase].codigo
                                                          AND [@kardex].renglon = [@codigoBase].renglon
                        WHERE   [@kardex].renglon IS NULL


                UPDATE  @kardex
                SET     [@kardex].cuantosRecibos = [@codigoBase].cuantosRecibos ,
                        [@kardex].recibo = [@codigoBase].recibo ,
                        [@kardex].numeroRecibo = [@codigoBase].numeroRecibo ,
                        [@kardex].grupoRecibo = RIGHT(STR(100000000
                                                          + [@codigoBase].codigo),
                                                      8) + '01'
                        + RIGHT(STR(100 + [@codigoBase].recibo), 2)
                FROM    @kardex
                        INNER JOIN @codigoBase ON [@kardex].codigo = [@codigoBase].codigo
                                                  AND [@kardex].renglon = [@codigoBase].renglon


                UPDATE  [@kardex]
                SET     [@kardex].percepcionesEmpleado = dbo.nomina_tot.tot_percep ,
                        [@kardex].deduccionesEmpleado = dbo.nomina_tot.tot_deducc ,
                        [@kardex].netoPagarEmpleado = dbo.nomina_tot.tot_percep
                        - dbo.nomina_tot.tot_deducc ,
                        [@kardex].acumuladoPercepcion = dbo.acum_emps.acu_percep , --+ dbo.nomina_tot.tot_percep - dbo.nomina_tot.tot_deduc ,
                        [@kardex].acumuladoPercepcionGravable = dbo.acum_emps.gravable , -- + dbo.nomina_tot.percep_grava - dbo.nomina_tor.dedu_grava ,
                        [@kardex].acumuladoIsr = dbo.acum_emps.ispt , --+ dbo.nomina_tot.tot_ispt ,
                        [@kardex].acumuladoInfonavit = dbo.acum_emps.acu_info ,
                        [@kardex].acumuladoSar = dbo.acum_emps.acu_sar ,
                        [@kardex].acumuladoCv = dbo.acum_emps.acu_cv,
                        [@kardex].subsTotal = dbo.nomina_tot.subsidio
                FROM    @kardex
                        INNER JOIN dbo.nomina_tot ON [@kardex].empresa = dbo.nomina_tot.empresa
                                                     AND [@kardex].codigo = dbo.nomina_tot.codigo
                        LEFT JOIN dbo.acum_emps ON dbo.nomina_tot.empresa = dbo.acum_emps.empresa
                                                   AND dbo.nomina_tot.codigo = dbo.acum_emps.codigo
                                                   AND @ayoOperacion = dbo.acum_emps.ejercicio
                WHERE   ( ( [@kardex].cuantosRecibos = 1 AND [@kardex].renglon = @renglonTope )
                          OR ( [@kardex].cuantosRecibos = 2 AND [@kardex].renglon = @renglonTope * 2 )
                          OR ( [@kardex].cuantosRecibos = 3 AND [@kardex].renglon = @renglonTope * 3 )
                          OR ( [@kardex].cuantosRecibos = 4 AND [@kardex].renglon = @renglonTope * 4 )
                          OR ( [@kardex].cuantosRecibos = 5 AND [@kardex].renglon = @renglonTope * 5 )
                        )
                        AND dbo.nomina_tot.tiponom = @tipoNomina



                --- Para cuando se va a imprimir mas de una copia de recibo
                SELECT  @copiasRecibo = ISNULL(dbo.Parametros_Empresas.Copias_Recibo,
                                               0)
                FROM    dbo.Parametros_Empresas
                WHERE   dbo.Parametros_Empresas.Empresa = @empresa

                IF @copiasRecibo > 1
                    BEGIN
                        WHILE @cuentaCopia <= @copiasRecibo
                            BEGIN
                                INSERT  @kardex
                                        ( empresa ,
                                          codigoId ,
                                          codigo ,
                                          nombre ,
                                          fechaAlta ,
                                          numeroSeguridadSocial ,
                                          digitoVerificador ,
                                          curp ,
                                          centro ,
                                          nombreCentro ,
                                          cuentaBanco ,
                                          nombreBanco ,
                                          ocupacion ,
                                          categoria ,
                                          tipoSalario ,
                                          renglon ,
                                          jornada ,
                                          sueldoDiario ,
                                          salarioBaseCotizacion ,
                                          clase ,
                                          nombreClase ,
                                          supervisor ,
                                          nombreSupervisor ,
                                          marcaContraPercepcion ,
                                          numeroConceptoPercepcion ,
                                          nombreConceptoPercepcion ,
                                          importeConceptoPercepcion ,
                                          gravablePercepcion ,
                                          exentoPercepcion ,
                                          saldoPercepcion ,
                                          anexoConceptoPercepcion ,
                                          marcaContraDeduccion ,
                                          numeroConceptoDeduccion ,
                                          nombreConceptoDeduccion ,
                                          importeConceptoDeduccion ,
                                          gravableDeduccion ,
                                          exentoDeduccion ,
                                          saldoDeduccion ,
                                          anexoConceptoDeduccion ,
                                          numeroConceptoProvision ,
                                          nombreConceptoProvision ,
                                          importeConceptoProvision ,
                                          empleados ,
                                          provisionIMSS ,
                                          provisionRCV ,
                                          provisionINFONAVIT ,
                                          retencionIMSS ,
                                          retencionRCV ,
                                          retencionINFONAVIT ,
                                          empleadosConCuentaBancaria ,
                                          empleadosSinCuentaBancaria ,
                                          percepcionesConCuentaBancaria ,
                                          deduccionesConCuentaBancaria ,
                                          percepcionesSinCuentaBancaria ,
                                          deduccionesSinCuentaBancaria ,
                                          basePorcientoSobreNomina ,
                                          porcientoSobreNomina ,
                                          fondoAhorroAportacionEmpleado ,
                                          fondoAhorroAportacionPatron ,
                                          sueldoNetoGeneral ,
                                          ejercicio ,
                                          diarioOficialDia ,
                                          diarioOficialMes ,
                                          diarioOficialAyo ,
                                          salarioMinimoDF ,
                                          salarioMinimoRegion ,
                                          eymArt25 ,
                                          eymArt106ii ,
                                          eymArt107 ,
                                          ivArt147 ,
                                          cvArt168ii ,
                                          baseCalculo ,
                                          grupo ,
                                          cuantosRecibos ,
                                          numeroRecibo ,
                                          recibo ,
                                          percepcionesEmpleado ,
                                          deduccionesEmpleado ,
                                          netoPagarEmpleado ,
                                          grupoRecibo ,
                                          rfcAlfa ,
                                          rfcNum ,
                                          rfcHomo ,
                                          acumuladoPercepcion ,
                                          acumuladoPercepcionGravable ,
                                          acumuladoIsr ,
                                          acumuladoInfonavit ,
                                          acumuladoSar ,
                                          acumuladoCv ,
                                          email ,
                                          fechaAntiguedad ,
                                          procesoName ,
                                          nomina ,
                                          foto ,
                                          subsTotal
                                        )
                                        SELECT  empresa ,
                                                codigoId ,
                                                codigo ,
                                                nombre ,
                                                fechaAlta ,
                                                numeroSeguridadSocial ,
                                                digitoVerificador ,
                                                curp ,
                                                centro ,
                                                nombreCentro ,
                                                cuentaBanco ,
                                                nombreBanco ,
                                                ocupacion ,
                                                categoria ,
                                                tipoSalario ,
                                                renglon ,
                                                jornada ,
                                                sueldoDiario ,
                                                salarioBaseCotizacion ,
                                                clase ,
                                                nombreClase ,
                                                supervisor ,
                                                nombreSupervisor ,
                                                marcaContraPercepcion ,
                                                numeroConceptoPercepcion ,
                                                nombreConceptoPercepcion ,
                                                importeConceptoPercepcion ,
                                                gravablePercepcion ,
                                                exentoPercepcion ,
                                                saldoPercepcion ,
                                                anexoConceptoPercepcion ,
                                                marcaContraDeduccion ,
                                                numeroConceptoDeduccion ,
                                                nombreConceptoDeduccion ,
                                                importeConceptoDeduccion ,
                                                gravableDeduccion ,
                                                exentoDeduccion ,
                                                saldoDeduccion ,
                                                anexoConceptoDeduccion ,
                                                numeroConceptoProvision ,
                                                nombreConceptoProvision ,
                                                importeConceptoProvision ,
                                                empleados ,
                                                provisionIMSS ,
                                                provisionRCV ,
                                                provisionINFONAVIT ,
                                                retencionIMSS ,
                                                retencionRCV ,
                                                retencionINFONAVIT ,
                                                empleadosConCuentaBancaria ,
                                                empleadosSinCuentaBancaria ,
                                                percepcionesConCuentaBancaria ,
                                                deduccionesConCuentaBancaria ,
                                                percepcionesSinCuentaBancaria ,
                                                deduccionesSinCuentaBancaria ,
                                                basePorcientoSobreNomina ,
                                                porcientoSobreNomina ,
                                                fondoAhorroAportacionEmpleado ,
                                                fondoAhorroAportacionPatron ,
                                                sueldoNetoGeneral ,
                                                ejercicio ,
                                                diarioOficialDia ,
                                                diarioOficialMes ,
                                                diarioOficialAyo ,
                                                salarioMinimoDF ,
                                                salarioMinimoRegion ,
                                                eymArt25 ,
                                                eymArt106ii ,
                                                eymArt107 ,
                                                ivArt147 ,
                                                cvArt168ii ,
                                                baseCalculo ,
                                                grupo ,
                                                cuantosRecibos ,
                                                numeroRecibo ,
                                                recibo ,
                                                percepcionesEmpleado ,
                                                deduccionesEmpleado ,
                                                netoPagarEmpleado ,
                                                SUBSTRING(grupoRecibo, 1, 8)
                                                + RIGHT(STR(100 + @cuentaCopia),
                                                        2)
                                                + SUBSTRING(grupoRecibo, 11, 50) ,
                                                rfcAlfa ,
                                                rfcNum ,
                                                rfcHomo ,
                                                acumuladoPercepcion ,
                                                acumuladoPercepcionGravable ,
                                                acumuladoIsr ,
                                                acumuladoInfonavit ,
                                                acumuladoSar ,
                                                acumuladoCv ,
                                                email ,
                                                fechaAntiguedad ,
                                                procesoName ,
                                                nomina ,
                                                foto ,
                                                subsTotal
                                        FROM    @kardex
                                        WHERE   SUBSTRING(grupoRecibo, 1, 10) = RIGHT(STR(100000000
                                                              + codigo),
                                                              8) + '01'
                                SET @cuentaCopia = @cuentaCopia + 1
                            END
                    END
            END

        IF @procesoName = 'NominaDetalle'
            BEGIN
                DECLARE @fechaCierreNomina DATETIME
                DECLARE @tFechaAltaEmpleado TABLE
                    (
                      codigo INT ,
                      fechaAltaEmpleado DATETIME
                    )

                SELECT  @fechaCierreNomina = dbo.Periodos.cierre
                FROM    dbo.Periodos
                WHERE   dbo.Periodos.empresa = @empresa
                        AND dbo.Periodos.tiponom = @tipoNomina
                        AND dbo.Periodos.estatus = 'A'

                INSERT  @tFechaAltaEmpleado
                        ( codigo ,
                          fechaAltaEmpleado
                        )
                        SELECT  dbo.empleados.codigo ,
                                ISNULL(( SELECT TOP 1
                                                dbo.avisos_imss.fch_mov
                                         FROM   dbo.avisos_imss
                                         WHERE  dbo.avisos_imss.empresa = dbo.empleados.empresa
                                                AND dbo.avisos_imss.codigo = dbo.empleados.codigo
                                                AND ( dbo.avisos_imss.mov = 'A'
                                                      OR dbo.avisos_imss.mov = 'RI'
                                                    )
                                                AND dbo.avisos_imss.fch_mov <= @fechaCierreNomina
                                         ORDER BY dbo.avisos_imss.fch_mov DESC
                                       ), dbo.empleados.fchalta) AS fechaAlta
                        FROM    dbo.empleados
                                INNER JOIN @kardex AS tablaKardex ON dbo.empleados.empresa = tablaKardex.empresa
                                                                     AND dbo.empleados.codigo = tablaKardex.codigo
                        WHERE dbo.empleados.empresa = @empresa

                UPDATE  tablaKardex
                SET     tablaKardex.fechaAlta = tFechaAltaEmpleado.fechaAltaEmpleado
                FROM    @kardex AS tablaKardex
                        INNER JOIN @tFechaAltaEmpleado AS tFechaAltaEmpleado ON tFechaAltaEmpleado.codigo = tablaKardex.codigo
            END
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaImpresionReciboNoOrdinaria
 * Project       : APSI Nomina
 * Description   : llena la tabla de salida de recibo
 * Table name    : empresa, primas_imss, empleados, llaves,
 *               : avisos_imss, conceptos, recibo
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Viernes, Julio 02, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.LlenaImpresionReciboNoOrdinaria') IS NOT NULL
    DROP  FUNCTION [dbo].[LlenaImpresionReciboNoOrdinaria]
GO
CREATE FUNCTION [dbo].[LlenaImpresionReciboNoOrdinaria]
    (
      @empresa INT ,
      @tipoNomina INT ,
      @nomina CHAR(3) ,
      @incluirProvisiones CHAR(1) ,
      @procesoName VARCHAR(100) ,
      @ordenadoPor INT ,
      @desglosadoPor INT ,
      @porCentro INT ,
      @esRecibo INT ,
      @codigoSeleccionado VARCHAR(500) ,
      @ayoEjercicio INT
    )
RETURNS @kardex TABLE
    (
      empresa INT ,
      codigoId VARCHAR(100) ,
      codigo INT ,
      nombre VARCHAR(100) ,
      fechaAlta DATETIME ,
      numeroSeguridadSocial VARCHAR(10) ,
      digitoVerificador CHAR(1) ,
      curp VARCHAR(18) ,
      centro VARCHAR(16) ,
      nombreCentro VARCHAR(50) ,
      cuentaBanco VARCHAR(30) ,
      nombreBanco VARCHAR(50) ,
      ocupacion INT ,
      categoria VARCHAR(50) ,
      tipoSalario INT ,
      renglon INT ,
      jornada INT ,
      sueldoDiario FLOAT ,
      salarioBaseCotizacion FLOAT ,
      clase VARCHAR(3) ,
      nombreClase VARCHAR(50) ,
      supervisor INT ,
      nombreSupervisor VARCHAR(50) ,
      marcaContraPercepcion CHAR(1) ,
      numeroConceptoPercepcion INT ,
      nombreConceptoPercepcion VARCHAR(50) ,
      importeConceptoPercepcion FLOAT ,
      gravablePercepcion FLOAT ,
      exentoPercepcion FLOAT ,
      saldoPercepcion FLOAT ,
      anexoConceptoPercepcion VARCHAR(150) ,
      marcaContraDeduccion CHAR(1) ,
      numeroConceptoDeduccion INT ,
      nombreConceptoDeduccion VARCHAR(50) ,
      importeConceptoDeduccion FLOAT ,
      gravableDeduccion FLOAT ,
      exentoDeduccion FLOAT ,
      saldoDeduccion FLOAT ,
      anexoConceptoDeduccion VARCHAR(150) ,
      numeroConceptoProvision INT ,
      nombreConceptoProvision VARCHAR(50) ,
      importeConceptoProvision FLOAT ,
      empleados INT ,
      provisionIMSS FLOAT ,
      provisionRCV FLOAT ,
      provisionINFONAVIT FLOAT ,
      retencionIMSS FLOAT ,
      retencionRCV FLOAT ,
      retencionINFONAVIT FLOAT ,
      empleadosConCuentaBancaria INT ,
      empleadosSinCuentaBancaria INT ,
      percepcionesConCuentaBancaria FLOAT ,
      deduccionesConCuentaBancaria FLOAT ,
      percepcionesSinCuentaBancaria FLOAT ,
      deduccionesSinCuentaBancaria FLOAT ,
      basePorcientoSobreNomina FLOAT ,
      porcientoSobreNomina FLOAT ,
      fondoAhorroAportacionEmpleado FLOAT ,
      fondoAhorroAportacionPatron FLOAT ,
      sueldoNetoGeneral FLOAT ,
      ejercicio INT ,
      diarioOficialDia INT ,
      diarioOficialMes INT ,
      diarioOficialAyo INT ,
      salarioMinimoDF FLOAT ,
      salarioMinimoRegion FLOAT ,
      eymArt25 FLOAT ,
      eymArt106ii FLOAT ,
      eymArt107 FLOAT ,
      ivArt147 FLOAT ,
      cvArt168ii FLOAT ,
      baseCalculo INT ,
      grupo VARCHAR(500) ,
      cuantosRecibos INT ,
      numeroRecibo INT ,
      recibo INT ,
      percepcionesEmpleado FLOAT ,
      deduccionesEmpleado FLOAT ,
      netoPagarEmpleado FLOAT ,
      grupoRecibo VARCHAR(500) ,
      rfcAlfa VARCHAR(4) ,
      rfcNum VARCHAR(6) ,
      rfcHomo VARCHAR(3) ,
      acumuladoPercepcion FLOAT ,
      acumuladoPercepcionGravable FLOAT ,
      acumuladoIsr FLOAT ,
      acumuladoInfonavit FLOAT ,
      acumuladoSar FLOAT ,
      acumuladoCv FLOAT ,
      email VARCHAR(100) ,
      fechaAntiguedad DATETIME ,
      procesoName VARCHAR(100) ,
      nomina CHAR(3) ,
      saltarPagina CHAR(1) ,
      firma CHAR(1) ,
      mov CHAR(2) ,
      foto VARCHAR(255) ,
      substotal FLOAT ,
      baseISN1 FLOAT ,
      porcientoISN1 FLOAT ,
      importeISN1 FLOAT ,
      empleadosISN1 INT ,
      baseISN2 FLOAT ,
      porcientoISN2 FLOAT ,
      importeISN2 FLOAT ,
      empleadosISN2 INT ,
      imprimirResumen CHAR(1)
    )
AS
    BEGIN
-- Variables para Primas IMSS
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @mesEmpresa INT
        DECLARE @ayoEmpresa INT
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @registroPatronal VARCHAR(10)
        DECLARE @consulta VARCHAR(4000)
        DECLARE @orden VARCHAR(200)
        DECLARE @numeroConceptoPercepcionInicioKardex INT
        DECLARE @numeroConceptoPercepcionTerminoKardex INT
        DECLARE @numeroConceptoContraPercepcionInicioKardex INT
        DECLARE @numeroConceptoContraPercepcionTerminoKardex INT
        DECLARE @numeroConceptoDeduccionInicioKardex INT
        DECLARE @numeroConceptoDeduccionTerminoKardex INT
        DECLARE @numeroConceptoContraDeduccionInicioKardex INT
        DECLARE @numeroConceptoContraDeduccionTerminoKardex INT
        DECLARE @numeroConceptoProvisionInicioKardex INT
        DECLARE @numeroConceptoProvisionTerminoKardex INT
        DECLARE @ejercicio INT
        DECLARE @diarioOficial DATETIME
        DECLARE @baseCalculo VARCHAR(25)
        DECLARE @codigoAnterior INT
        DECLARE @numeroRecibo INT
        DECLARE @cuantosRecibos INT
        DECLARE @percepcionesEmpleado FLOAT
        DECLARE @deduccionesEmpleado FLOAT
        DECLARE @netoPagarEmpleado FLOAT
        DECLARE @ayoOperacion INT
        DECLARE @nombreAnterior VARCHAR(100)
        DECLARE @copiasRecibo INT
        DECLARE @cuentaCopia INT

        DECLARE @codigoBase TABLE
            (
              codigo INT ,
              renglon INT ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              centro VARCHAR(16) ,
              supervisor INT ,
              nombre VARCHAR(100)
            )

        DECLARE @tablaNumeroRecibo TABLE
            (
              codigo INT ,
              renglon INT ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              centro VARCHAR(16) ,
              supervisor INT ,
              nombre VARCHAR(100)
            )

        DECLARE @tablaBaseRenglon TABLE ( renglon INT )

        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 1 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 2 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 3 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 4 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 5 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 6 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 7 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 8 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 9 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 10 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 11 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 12 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 13 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 14 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 15 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 16 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 17 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 18 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 19 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 20 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 21 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 22 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 23 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 24 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 25 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 26 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 27 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 28 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 29 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 30 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 31 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 32 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 33 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 34 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 35 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 36 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 37 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 38 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 39 )
        INSERT  @tablaBaseRenglon
                ( renglon )
        VALUES  ( 40 )

        SET @cuentaCopia = 2
        SET @copiasRecibo = 0
        SET @numeroConceptoPercepcionInicioKardex = 1
        SET @numeroConceptoPercepcionTerminoKardex = 99
        SET @numeroConceptoContraPercepcionInicioKardex = 1101
        SET @numeroConceptoContraPercepcionTerminoKardex = 1199
        SET @numeroConceptoDeduccionInicioKardex = 101
        SET @numeroConceptoDeduccionTerminoKardex = 199
        SET @numeroConceptoContraDeduccionInicioKardex = 1001
        SET @numeroConceptoContraDeduccionTerminoKardex = 1099
        SET @numeroConceptoProvisionInicioKardex = CASE WHEN @incluirProvisiones = 'S'
                                                        THEN 201
                                                        ELSE 0
                                                   END
        SET @numeroConceptoProvisionTerminoKardex = CASE WHEN @incluirProvisiones = 'S'
                                                         THEN 299
                                                         ELSE 0
                                                    END



-- Obtiene datos de empresas
        SELECT TOP 1
                @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion ,
                @mesEmpresa = dbo.empresas.mes_operacion ,
                @registroPatronal = SUBSTRING(dbo.empresas.registro_patronal,
                                              1, 10)
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene primas IMSS en base al ao de operacion de la tabla empresas
        SELECT TOP 1
                @eymArt25 = dbo.primas_imss.eymart25 ,
                @eymPat25 = dbo.primas_imss.eympat25
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra25
                       ELSE 0
                  END ,
                @eymTra25 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                 ELSE dbo.primas_imss.eymtra25
                            END ,
                @eymArt106I = dbo.primas_imss.eymart106I ,
                @eymArt1062 = dbo.primas_imss.eymart1062 ,
                @eymPat1062 = dbo.primas_imss.eympat1062
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra1062
                       ELSE 0
                  END ,
                @eymTra1062 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                   ELSE dbo.primas_imss.eymtra1062
                              END ,
                @eymArt107 = dbo.primas_imss.eymart107 ,
                @eymPat107 = dbo.primas_imss.eympat107
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.eymtra107
                       ELSE 0
                  END ,
                @eymTra107 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                  ELSE dbo.primas_imss.eymtra107
                             END ,
                @ivArt147 = dbo.primas_imss.ivart147 ,
                @ivPat147 = dbo.primas_imss.ivpat147
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.ivtra147
                       ELSE 0
                  END ,
                @ivTra147 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                 ELSE dbo.primas_imss.ivtra147
                            END ,
                @retiro = dbo.primas_imss.retiro ,
                @cvArt168II = dbo.primas_imss.cvart168II ,
                @cvPat168II = dbo.primas_imss.cvpat168II
                + CASE WHEN @patronPagaIMSS = 'S'
                       THEN dbo.primas_imss.cvtra168ii
                       ELSE 0
                  END ,
                @cvTra168II = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                                   ELSE dbo.primas_imss.cvtra168ii
                              END
        FROM    dbo.primas_imss
        WHERE   YEAR(dbo.primas_imss.periodo) = @ayoEmpresa



        SET @eymArt25 = CASE WHEN @eymArt25 IS NULL THEN 0
                             ELSE @eymArt25
                        END
        SET @eymPat25 = CASE WHEN @eymPat25 IS NULL THEN 0
                             ELSE @eymPat25
                        END
        SET @eymTra25 = CASE WHEN @eymTra25 IS NULL THEN 0
                             ELSE @eymTra25
                        END
        SET @eymArt106I = CASE WHEN @eymArt106I IS NULL THEN 0
                               ELSE @eymArt106I
                          END
        SET @eymArt1062 = CASE WHEN @eymArt1062 IS NULL THEN 0
                               ELSE @eymArt1062
                          END
        SET @eymPat1062 = CASE WHEN @eymPat1062 IS NULL THEN 0
                               ELSE @eymPat1062
                          END
        SET @eymTra1062 = CASE WHEN @eymTra1062 IS NULL THEN 0
                               ELSE @eymTra1062
                          END
        SET @eymArt107 = CASE WHEN @eymArt107 IS NULL THEN 0
                              ELSE @eymArt107
                         END
        SET @eymPat107 = CASE WHEN @eymPat107 IS NULL THEN 0
                              ELSE @eymPat107
                         END
        SET @eymTra107 = CASE WHEN @eymTra107 IS NULL THEN 0
                              ELSE @eymTra107
                         END
        SET @ivArt147 = CASE WHEN @ivArt147 IS NULL THEN 0
                             ELSE @ivArt147
                        END
        SET @ivPat147 = CASE WHEN @ivPat147 IS NULL THEN 0
                             ELSE @ivPat147
                        END
        SET @ivTra147 = CASE WHEN @ivTra147 IS NULL THEN 0
                             ELSE @ivTra147
                        END
        SET @retiro = CASE WHEN @retiro IS NULL THEN 0
                           ELSE @retiro
                      END
        SET @cvArt168II = CASE WHEN @cvArt168II IS NULL THEN 0
                               ELSE @cvArt168II
                          END
        SET @cvPat168II = CASE WHEN @cvPat168II IS NULL THEN 0
                               ELSE @cvPat168II
                          END
        SET @cvTra168II = CASE WHEN @cvTra168II IS NULL THEN 0
                               ELSE @cvTra168II
                          END
        SET @patronPagaIMSS = CASE WHEN @patronPagaIMSS IS NULL THEN 'N'
                                   ELSE @patronPagaIMSS
                              END


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesEmpresa, @ayoEmpresa)

        SET @salarioDF = @salarioRegionA

        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END

        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion

        --SELECT @ayoOperacion = ISNULL(dbo.Periodos.ayo_operacion,0)
        --FROM dbo.Periodos
        --WHERE dbo.Periodos.empresa = @empresa
        --      AND dbo.Periodos.tiponom = @tipoNomina
        --      AND dbo.Periodos.estatus = 'A'

        SET @ayoOperacion = @ayoEjercicio


        IF @procesoName = 'NominaNoOrdinaria'
            BEGIN
-- Prepara tabla virtual
                INSERT  @kardex
                        ( empresa ,
                          codigoId ,
                          codigo ,
                          nombre ,
                          fechaAlta ,
                          numeroSeguridadSocial ,
                          digitoVerificador ,
                          curp ,
                          centro ,
                          nombreCentro ,
                          cuentaBanco ,
                          nombreBanco ,
                          ocupacion ,
                          categoria ,
                          tipoSalario ,
                          jornada ,
                          sueldoDiario ,
                          salarioBaseCotizacion ,
                          clase ,
                          nombreClase ,
                          supervisor ,
                          nombreSupervisor ,
                          renglon ,
                          grupo ,
                          rfcAlfa ,
                          rfcNum ,
                          rfcHomo ,
                          email ,
                          fechaAntiguedad ,
                          procesoName ,
                          nomina
                        )
                        SELECT DISTINCT
                                dbo.kardex.empresa ,
                                RIGHT(STR(100000000 + dbo.kardex.codigo), 8)
                                + RIGHT(STR(1000000000 + dbo.kardex.renglon),
                                        9) AS codigoId ,
                                dbo.kardex.codigo AS codigo ,
                                RTRIM(dbo.empleados.ap_paterno) + ' '
                                + RTRIM(dbo.empleados.ap_materno) + ' '
                                + RTRIM(dbo.empleados.nombre) AS nombre ,
                                dbo.empleados.fchalta ,
                                dbo.empleados.afiliacion ,
                                dbo.empleados.digvera ,
                                CASE WHEN LEN(dbo.empleados.curp) = 18
                                     THEN dbo.empleados.curp
                                     ELSE dbo.empleados.rfcalfa
                                          + dbo.empleados.rfcnum -- RIGHT(STR(dbo.empleados.rfcnum), 6)
                                          + dbo.empleados.rfchomo
                                END AS curp ,
                                dbo.Llaves.centro ,
                                dbo.centros.nomdepto ,
                                dbo.empleados.cta_bco_no ,
                                dbo.bancos.nombre AS nombreBanco ,
                                dbo.Llaves.ocupacion ,
                                dbo.tabulador.actividad ,
                                dbo.empleados.tiposal ,
                                dbo.empleados.jornada ,
                                dbo.empleados.sueldo ,
                                dbo.empleados.saldiaint ,
                                dbo.Llaves.clase ,
                                dbo.clases.nombre AS nombreClase ,
                                dbo.Llaves.supervisor ,
                                dbo.supervisores.nombre AS nombreSupervisor ,
                                dbo.kardex.renglon ,
                                CASE WHEN ( ( @ordenadoPor & 4 > 0
                                              OR @ordenadoPor & 8 > 0
                                            )
                                            OR ( ( @ordenadoPor & 1 > 0
                                                   OR @ordenadoPor & 2 > 0
                                                 )
                                                 AND @desglosadoPor & 2 > 0
                                               )
                                          )
                                     THEN SUBSTRING(dbo.Llaves.centro, 1, 15)
                                     WHEN ( @ordenadoPor & 16 > 0
                                            OR @ordenadopor & 32 > 0
                                          )
                                     THEN RTRIM(dbo.Llaves.centro)
                                          + RIGHT(STR(100000000
                                                      + dbo.Llaves.supervisor),
                                                  8)
                                     ELSE NULL
                                END ,
                                dbo.empleados.rfcalfa ,
                                dbo.empleados.rfcnum ,
                                dbo.empleados.rfchomo ,
                                dbo.datosemps.email ,
                                dbo.empleados.fchantigua ,
                                @procesoName ,
                                @nomina
                        FROM    dbo.kardex
                                INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                            AND dbo.kardex.codigo = dbo.empleados.codigo
                                INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                         AND dbo.empleados.codigo = dbo.Llaves.codigo
                                INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                          AND dbo.Llaves.empresa = dbo.centros.empresa
                                INNER JOIN dbo.tabulador ON dbo.centros.empresa = dbo.tabulador.empresa
                                                            AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
                                INNER JOIN dbo.bancos ON dbo.Llaves.banco = dbo.bancos.banco
                                INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa
                                                         AND dbo.Llaves.clase = dbo.clases.clase
                                INNER JOIN dbo.supervisores ON dbo.Llaves.empresa = dbo.supervisores.empresa
                                                              AND dbo.Llaves.supervisor = dbo.supervisores.supervisor
                                INNER JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                                            AND dbo.empleados.codigo = dbo.datosemps.codigo
                                INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.Llaves.codigo
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.codigo
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.procesoName
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN @procesoName
                                                              ELSE '1'
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.nomina
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.kardex.nomina
                                                              ELSE '1'
                                                              END
                        WHERE   dbo.kardex.empresa = CASE WHEN @desglosadoPor
                                                              & 1 > 0
                                                          THEN @empresa
                                                          ELSE 0
                                                     END
                                AND dbo.kardex.nomina = @nomina
                                AND ( ( ( dbo.kardex.num_conc >= @numeroConceptoPercepcionInicioKardex
                                          AND dbo.kardex.num_conc <= @numeroConceptoPercepcionTerminoKardex
                                        )
                                        OR ( dbo.kardex.num_conc >= @numeroConceptoContraPercepcionInicioKardex
                                             AND dbo.kardex.num_conc <= @numeroConceptoContraPercepcionTerminoKardex
                                           )
                                      )
                                      OR ( ( dbo.kardex.num_conc >= @numeroConceptoDeduccionInicioKardex
                                             AND dbo.kardex.num_conc <= @numeroConceptoDeduccionTerminoKardex
                                           )
                                           OR ( dbo.kardex.num_conc >= @numeroConceptoContraDeduccionInicioKardex
                                                AND dbo.kardex.num_conc <= @numeroConceptoContraDeduccionTerminoKardex
                                              )
                                         )
                                      OR ( dbo.kardex.num_conc >= @numeroConceptoProvisionInicioKardex
                                           AND dbo.kardex.num_conc <= @numeroConceptoProvisionTerminoKardex
                                         )
                                    )
                                --AND CASE WHEN LEN(@codigoSeleccionado) > 0
                                --         THEN dbo.SeleccionElementos.procesoName
                                --         ELSE '1'
                                --    END = CASE WHEN LEN(@codigoSeleccionado) > 0
                                --               THEN @procesoName
                                --               ELSE '1'
                                --          END

-- Carga Percepciones
                UPDATE  @kardex
                SET     marcaContraPercepcion = CASE WHEN dbo.kardex.num_conc >= 1101
                                                          AND dbo.kardex.num_conc <= 1199
                                                     THEN 'C'
                                                     ELSE NULL
                                                END ,
                        numeroConceptoPercepcion = dbo.kardex.num_conc ,
                        nombreConceptoPercepcion = dbo.kardex.concepto ,
                        importeConceptoPercepcion = dbo.kardex.importe ,
                        gravablePercepcion = dbo.kardex.igravable ,
                        exentoPercepcion = dbo.kardex.iexento ,
                        saldoPercepcion = CASE WHEN dbo.kardex.saldo > 0
                                               THEN dbo.kardex.saldo
                                               ELSE NULL
                                          END ,
                        anexoConceptoPercepcion = CASE
                                      -- Detalle Sueldo
                                                       WHEN dbo.kardex.num_conc >= 1
                                                            AND dbo.kardex.num_conc <= 8
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.impor_base))
                                                            + ' * '
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                            + ' Das'

                                      -- Detalle Horas Extras
                                                       WHEN dbo.kardex.num_conc >= 10
                                                            AND dbo.kardex.num_conc <= 13
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.horas))
                                                            + ' Horas'

                                      -- Detalle Aguinaldo
                                                       WHEN dbo.kardex.num_conc = 16
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.impor_base))
                                                            + ' * ' +
                                                            CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                            + ' Das'

                                      -- Detalle Prima Vacacional
                                                       WHEN dbo.kardex.num_conc = 17
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                            + ' Das'

                                      -- Detalle Vacaciones
                                                       WHEN dbo.kardex.num_conc = 30
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.impor_base))
                                                            + ' * ' + '('
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                            + 'H' + ' '
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                            + 'D' + ' '
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                            + 'F' + ')'

                                      -- Detalle Subsidio para el Empleo
                                                       WHEN dbo.kardex.num_conc = 36
                                                       THEN CASE
                                                              WHEN dbo.kardex.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoEmpresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoEmpresa < 2014
                                                                        THEN 'Art 8vo Trans$'
                                                                        ELSE 'Art 10 Trans$'
                                                                   END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              ELSE ''
                                                              END
                                                            END

                                      -- Detalle Concepto 53 Por Registro Patronal
                                                       WHEN dbo.kardex.num_conc = 53
                                                            AND ( @registroPatronal = 'R131234638'
                                                              OR @registroPatronal = 'C166197810'
                                                              OR @registroPatronal = 'C166939010'
                                                              OR @registroPatronal = 'E647730310'
                                                              OR @registroPatronal = 'E648122510'
                                                              )
                                                       THEN SUBSTRING(dbo.kardex.referencia,
                                                              01, 06)
                                                            + RIGHT(RTRIM(dbo.kardex.referencia),
                                                              02) + ' (M'
                                                            + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.unidades))
                                                            + ')'

                                      -- Detalle Sueldo Neto
                                                       WHEN dbo.kardex.num_conc = 99
                                                       THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                            + ' Das'

                                      -- Detalle de conceptos de Contras del 1107 al 1111
                                                       WHEN dbo.kardex.num_conc >= 1107
                                                            AND dbo.kardex.num_conc <= 1111
                                                       THEN CASE
                                                              WHEN dbo.kardex.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'
                                                              ELSE ''
                                                            END

                                      -- Detalle Conceptos con Valor Variable
                                                       ELSE CASE
                                                              WHEN dbo.kardex.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                            END
                                                  END ,
                        mov = CASE WHEN dbo.kardex.num_conc <= 6
                                   THEN RTRIM(dbo.kardex.referencia)
                                   ELSE NULL
                              END
                FROM    @kardex
                        INNER JOIN dbo.kardex ON [@kardex].empresa = dbo.kardex.empresa
                                                 AND [@kardex].codigo = dbo.kardex.codigo
                                                 AND [@kardex].renglon = dbo.kardex.renglon
                                                 AND @nomina = dbo.kardex.nomina
                WHERE   [@kardex].empresa = @empresa
                        AND ( ( dbo.kardex.num_conc >= 1
                                AND dbo.kardex.num_conc <= 99
                              )
                              OR ( dbo.kardex.num_conc >= 1101
                                   AND dbo.kardex.num_conc <= 1199
                                 )
                            )
                        AND dbo.kardex.nomina = @nomina

                -- Percepciones. Actualiza el subtotal y total de resumen de centro de costos
                --UPDATE  @kardex
                --SET     [@kardex].numeroConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].numeroConcepto ,
                --        [@kardex].nombreConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].nombreConcepto ,
                --        [@kardex].importeConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].importe ,
                --        [@kardex].gravablePercepcion = [dbo].[ResumenPorCentroRecibo].gravable ,
                --        [@kardex].exentoPercepcion = [dbo].[ResumenPorCentroRecibo].exento ,
                --        [@kardex].saldoPercepcion = [dbo].[ResumenPorCentroRecibo].saldoPercepcion ,
                --        [@kardex].anexoConceptoPercepcion = [dbo].[ResumenPorCentroRecibo].anexoConceptoPercepcion
                --FROM    @kardex
                --        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa, @nomina,
                --                                            @incluirProvisiones,
                --                                            'S', @tipoNomina,
                --                                            'P', @ordenadoPor,
                --                                            0, 0, 0, 0, 0, 0,
                --                                            0, @desglosadoPor,
                --                                            @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                --                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroRecibo].centro))
                --                                              AND CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [@kardex].supervisor
                --                                              ELSE 1
                --                                              END = CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                --                                              ELSE 1
                --                                              END
                --                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroRecibo].renglon
                --WHERE   ( ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 1
                --            AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 99
                --          )
                --          OR ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 1101
                --               AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 1199
                --             )
                --        )


-- Carga Deducciones
                UPDATE  @kardex
                SET     marcaContraDeduccion = CASE WHEN dbo.kardex.num_conc >= 1001
                                                         AND dbo.kardex.num_conc <= 1099
                                                    THEN 'C'
                                                    ELSE NULL
                                               END ,
                        numeroConceptoDeduccion = dbo.kardex.num_conc ,
                        nombreConceptoDeduccion = dbo.kardex.concepto ,
                        importeConceptoDeduccion = dbo.kardex.importe ,
                        gravableDeduccion = dbo.kardex.igravable ,
                        exentoDeduccion = dbo.kardex.iexento ,
                        saldoDeduccion = CASE WHEN dbo.kardex.saldo > 0
                                              THEN CASE WHEN dbo.kardex.num_conc = 126
                                                        THEN dbo.kardex.importe
                                                             + dbo.kardex.saldo
                                                        WHEN dbo.kardex.num_conc = 127
                                                        THEN dbo.kardex.importe
                                                             + dbo.kardex.saldo
                                                        ELSE dbo.kardex.saldo
                                                   END
                                              ELSE NULL
                                         END ,
                        anexoConceptoDeduccion = CASE
                                      -- Detalle Cuotas IMSS
                                                      WHEN dbo.kardex.num_conc >= 101
                                                           AND dbo.kardex.num_conc <= 105
                                                      THEN CONVERT(VARCHAR(15), CASE
                                                              WHEN dbo.kardex.num_conc = 102
                                                              THEN CASE
                                                              WHEN dbo.kardex.saldiaint > ( @salarioDF
                                                              * 3 )
                                                              THEN dbo.ChecaDecimales(dbo.kardex.saldiaint
                                                              - ( @salarioDF
                                                              * 3 ))
                                                              ELSE dbo.ChecaDecimales(dbo.kardex.saldiaint)
                                                              END
                                                              ELSE dbo.ChecaDecimales(dbo.kardex.saldiaint)
                                                              END) + ' * '
                                                           + CASE
                                                              WHEN dbo.kardex.num_conc = 101
                                                              THEN CONVERT(VARCHAR(15), @eymTra25)
                                                              WHEN dbo.kardex.num_conc = 102
                                                              THEN CONVERT(VARCHAR(15), @eymTra1062)
                                                              WHEN dbo.kardex.num_conc = 103
                                                              THEN CONVERT(VARCHAR(15), @eymTra107)
                                                              WHEN dbo.kardex.num_conc = 104
                                                              THEN CONVERT(VARCHAR(15), @ivTra147)
                                                              WHEN dbo.kardex.num_conc = 105
                                                              THEN CONVERT(VARCHAR(15), @cvTra168II)
                                                              ELSE ''
                                                             END + ' * '
                                                           + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias_imss))

                                      -- Detalle Retencion IMSS por Faltas
                                                      WHEN dbo.kardex.num_conc = 106
                                                           OR dbo.kardex.num_conc = 107
                                                           OR dbo.kardex.num_conc = 109
                                                           OR dbo.kardex.num_conc = 110
                                                           OR dbo.kardex.num_conc = 111
                                                           OR dbo.kardex.num_conc = 130
                                                      THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                           + ' Da(s)'

                                      -- Detalle Faltas
                                                      WHEN dbo.kardex.num_conc = 108
                                                      THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                           + ' Da(s)' + ' + '
                                                           + CONVERT(VARCHAR(15), dbo.ChecaDecimales(ABS(dbo.kardex.descuento
                                                              - 100))) + '%'

                                      -- Detalle Creditos INFONAVIT
                                                      WHEN dbo.kardex.num_conc = 112 AND dbo.kardex.dias > 0
                                                      THEN CASE
                                                              WHEN dbo.kardex.descuento > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.saldiaint))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.descuento))
                                                              + '%'
                                                              ELSE CONVERT(VARCHAR(15), CONVERT(NUMERIC(15,
                                                              2), dbo.ChecaDecimales(ROUND(dbo.kardex.importe
                                                              / dbo.kardex.dias,
                                                              2)))) + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + 'DS'
                                                           END

                                      -- Detalle Fondo de Ahorro
                                                      WHEN dbo.kardex.num_conc = 126
                                                           OR dbo.kardex.num_conc = 127
                                                      THEN 'Saldo $ '
                                                           + CONVERT(VARCHAR(15), dbo.kardex.saldo
                                                           + dbo.kardex.importe)

                                      -- Detalle ISR
                                                      WHEN dbo.kardex.num_conc = 136
                                                      THEN CASE
                                                              WHEN dbo.kardex.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoEmpresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoEmpresa < 2014
                                                                        THEN 'Art 8vo Trans$'
                                                                        ELSE 'Art 10 Trans$'
                                                                   END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              ELSE ''
                                                              END
                                                           END

                                      -- Contra Sueldo
                                                      WHEN dbo.kardex.num_conc >= 1001
                                                           AND dbo.kardex.num_conc <= 1007
                                                      THEN CASE
                                                              WHEN dbo.kardex.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Da(s)'
                                                              ELSE ''
                                                           END

                                      -- Detalle los demas conceptos
                                                      ELSE CASE
                                                              WHEN dbo.kardex.saldo > 0
                                                              THEN 'Saldo $ '
                                                              + CONVERT(VARCHAR(15), dbo.kardex.saldo
                                                              + CASE
                                                              WHEN dbo.conceptos.marca2 = 'H'
                                                              OR --'A'
                                                              dbo.conceptos.num_conc IN (
                                                              125, 126, 127 )
                                                              THEN 1
                                                              ELSE -1
                                                              END
                                                              * dbo.kardex.descuento)
                                                -- Detalle de conceptos con valores variable
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                              END
                                                           END
                                                 END
                FROM    @kardex
                        INNER JOIN dbo.kardex ON [@kardex].empresa = dbo.kardex.empresa
                                                 AND [@kardex].codigo = dbo.kardex.codigo
                                                 AND [@kardex].renglon = dbo.kardex.renglon
                                                 AND @nomina = dbo.kardex.nomina
                        INNER JOIN dbo.conceptos ON dbo.kardex.empresa = dbo.conceptos.empresa
                                                    AND dbo.kardex.num_conc = dbo.conceptos.num_conc
                                                    AND dbo.kardex.clase = dbo.conceptos.clase
                                                    AND dbo.kardex.centro = dbo.conceptos.centro
                WHERE   [@kardex].empresa = @empresa
                        AND ( ( dbo.kardex.num_conc >= 101
                                AND dbo.kardex.num_conc <= 199
                              )
                              OR ( dbo.kardex.num_conc >= 1001
                                   AND dbo.kardex.num_conc <= 1099
                                 )
                            )
                        AND dbo.kardex.nomina = @nomina

                -- Deducciones. Actualiza el subtotal y total de resumen de centro de costos
                --UPDATE  @kardex
                --SET     [@kardex].numeroConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].numeroConcepto ,
                --        [@kardex].nombreConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].nombreConcepto ,
                --        [@kardex].importeConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].importe ,
                --        [@kardex].gravableDeduccion = [dbo].[ResumenPorCentroRecibo].gravable ,
                --        [@kardex].exentoDeduccion = [dbo].[ResumenPorCentroRecibo].exento ,
                --        [@kardex].anexoConceptoDeduccion = [dbo].[ResumenPorCentroRecibo].anexoConceptoDeduccion
                --FROM    @kardex
                --        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa, @nomina,
                --                                            @incluirProvisiones,
                --                                            'S', @tipoNomina,
                --                                            'D', @ordenadoPor,
                --                                            0, 0, 0, 0, 0, 0,
                --                                            0, @desglosadoPor,
                --                                            @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                --                                              AND [@kardex].centro = [dbo].[ResumenPorCentroRecibo].centro
                --                                              AND CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [@kardex].supervisor
                --                                              ELSE 1
                --                                              END = CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                --                                              ELSE 1
                --                                              END
                --                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroRecibo].renglon
                --WHERE   ( ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 101
                --            AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 199
                --          )
                --          OR ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 1001
                --               AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 1099
                --             )
                --        )

-- Carga Provisiones
                --IF @incluirProvisiones = 'S'
                --    BEGIN
                --        UPDATE  @kardex
                --        SET     numeroConceptoProvision = dbo.recibos.num_conc ,
                --                nombreConceptoProvision = dbo.recibos.concepto ,
                --                importeConceptoProvision = dbo.recibos.importe
                --        FROM    @kardex
                --                INNER JOIN dbo.recibos ON [@kardex].empresa = dbo.recibos.empresa
                --                                         AND [@kardex].codigo = dbo.recibos.codigo
                --                                         AND [@kardex].renglon = dbo.recibos.renglon
                --                                         AND @nomina = dbo.recibos.nomina
                --        WHERE   [@kardex].empresa = @empresa
                --                AND ( dbo.recibos.num_conc >= 201
                --                      AND dbo.recibos.num_conc <= 299
                --                    )
                --                AND dbo.recibos.nomina = @nomina

                -- Provision. Actualiza el subtotal y total de resumen de centro de costos
                --        UPDATE  @kardex
                --        SET     [@kardex].numeroConceptoProvision = [dbo].[ResumenPorCentroRecibo].numeroConcepto ,
                --                [@kardex].nombreConceptoProvision = [dbo].[ResumenPorCentroRecibo].nombreConcepto ,
                --                [@kardex].importeConceptoProvision = [dbo].[ResumenPorCentroRecibo].importe
                --        FROM    @kardex
                --                INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa,
                --                                              @nomina,
                --                                              @incluirProvisiones,
                --                                              'S', @tipoNomina,
                --                                              'I',
                --                                              @ordenadoPor, 0,
                --                                              0, 0, 0, 0, 0, 0,
                --                                              @desglosadoPor,
                --                                              @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                --                                              AND [@kardex].centro = [dbo].[ResumenPorCentroRecibo].centro
                --                                              AND CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [@kardex].supervisor
                --                                              ELSE 1
                --                                              END = CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                --                                              ELSE 1
                --                                              END
                --                                              AND [@kardex].renglon = [dbo].[ResumenPorCentroRecibo].renglon
                --        WHERE   ( [dbo].[ResumenPorCentroRecibo].numeroConcepto >= 201
                --                  AND [dbo].[ResumenPorCentroRecibo].numeroConcepto <= 299
                --                )
                --    END


                -- Registro Totales
                --UPDATE  @kardex
                --SET     [@kardex].empleados = [dbo].[ResumenPorCentroRecibo].empleados ,
                --        [@kardex].provisionIMSS = [dbo].[ResumenPorCentroRecibo].provisionIMSS ,
                --        [@kardex].provisionRCV = [dbo].[ResumenPorCentroRecibo].provisionRCV ,
                --        [@kardex].provisionINFONAVIT = [dbo].[ResumenPorCentroRecibo].provisionINFONAVIT ,
                --        [@kardex].retencionIMSS = [dbo].[ResumenPorCentroRecibo].retencionIMSS ,
                --        [@kardex].retencionRCV = [dbo].[ResumenPorCentroRecibo].retencionRCV ,
                --        [@kardex].retencionINFONAVIT = [dbo].[ResumenPorCentroRecibo].retencionINFONAVIT ,
                --        [@kardex].empleadosConCuentaBancaria = [dbo].[ResumenPorCentroRecibo].empleadosConCuentaBancaria ,
                --        [@kardex].empleadosSinCuentaBancaria = [dbo].[ResumenPorCentroRecibo].empleadosSinCuentaBancaria ,
                --        [@kardex].percepcionesConCuentaBancaria = [dbo].[ResumenPorCentroRecibo].percepcionesConCuentaBancaria ,
                --        [@kardex].deduccionesConCuentaBancaria = [dbo].[ResumenPorCentroRecibo].deduccionesConCuentaBancaria ,
                --        [@kardex].percepcionesSinCuentaBancaria = [dbo].[ResumenPorCentroRecibo].percepcionesSinCuentaBancaria ,
                --        [@kardex].deduccionesSinCuentaBancaria = [dbo].[ResumenPorCentroRecibo].deduccionesSinCuentaBancaria ,
                --        [@kardex].basePorcientoSobreNomina = [dbo].[ResumenPorCentroRecibo].basePorcientoSobreNomina ,
                --        [@kardex].porcientoSobreNomina = [dbo].[ResumenPorCentroRecibo].porcientoSobreNomina ,
                --        [@kardex].fondoAhorroAportacionEmpleado = [dbo].[ResumenPorCentroRecibo].fondoAhorroAportacionEmpleado ,
                --        [@kardex].fondoAhorroAportacionPatron = [dbo].[ResumenPorCentroRecibo].fondoAhorroAportacionPatron ,
                --        [@kardex].sueldoNetoGeneral = [dbo].[ResumenPorCentroRecibo].sueldoNetoGeneral
                --FROM    @kardex
                --        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa, @nomina,
                --                                            @incluirProvisiones,
                --                                            'T', @tipoNomina,
                --                                            '', @ordenadoPor,
                --                                            @salarioDF,
                --                                            @salarioRegion,
                --                                            @eymArt25,
                --                                            @eymArt1062,
                --                                            @eymArt107,
                --                                            @ivArt147,
                --                                            @cvArt168II,
                --                                            @desglosadoPor,
                --                                            @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                --                                              AND RTRIM(LTRIM([@kardex].centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroRecibo].centro))
                --                                              AND CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [@kardex].supervisor
                --                                              ELSE 1
                --                                              END = CASE
                --                                              WHEN ( ( @ordenadoPor
                --                                              & 16 > 0
                --                                              OR @ordenadoPor
                --                                              & 32 > 0
                --                                              )
                --                                              AND @desglosadoPor
                --                                              & 4 = 0
                --                                              )
                --                                              THEN [dbo].[ResumenPorCentroRecibo].supervisor
                --                                              ELSE 1
                --                                              END
                --WHERE   [dbo].[ResumenPorCentroRecibo].numeroConcepto = 9996


                --UPDATE  @kardex
                --SET     [@kardex].ejercicio = [dbo].[ResumenPorCentroRecibo].ejercicio ,
                --        [@kardex].diarioOficialDia = [dbo].[ResumenPorCentroRecibo].diarioOficialDia ,
                --        [@kardex].diarioOficialMes = [dbo].[ResumenPorCentroRecibo].diarioOficialMes ,
                --        [@kardex].diarioOficialAyo = [dbo].[ResumenPorCentroRecibo].diarioOficialAyo ,
                --        [@kardex].salarioMinimoDF = [dbo].[ResumenPorCentroRecibo].salarioMinimoDF ,
                --        [@kardex].salarioMinimoRegion = [dbo].[ResumenPorCentroRecibo].salarioMinimoRegion ,
                --        [@kardex].eymArt25 = [dbo].[ResumenPorCentroRecibo].eymArt25 ,
                --        [@kardex].eymArt106ii = [dbo].[ResumenPorCentroRecibo].eymArt106ii ,
                --        [@kardex].eymArt107 = [dbo].[ResumenPorCentroRecibo].eymArt107 ,
                --        [@kardex].ivArt147 = [dbo].[ResumenPorCentroRecibo].ivArt147 ,
                --        [@kardex].cvArt168ii = [dbo].[ResumenPorCentroRecibo].cvArt168ii ,
                --        [@kardex].baseCalculo = [dbo].[ResumenPorCentroRecibo].baseCalculo
                --FROM    @kardex
                --        INNER JOIN [dbo].[ResumenPorCentroRecibo](@empresa, @nomina,
                --                                            @incluirProvisiones,
                --                                            'T', @tipoNomina,
                --                                            '', @ordenadoPor,
                --                                            @salarioDF,
                --                                            @salarioRegion,
                --                                            @eymArt25,
                --                                            @eymArt1062,
                --                                            @eymArt107,
                --                                            @ivArt147,
                --                                            @cvArt168II,
                --                                            @desglosadoPor,
                --                                            @porCentro) ON [@kardex].codigo = [dbo].[ResumenPorCentroRecibo].codigo
                --                                              AND [@kardex].centro = [dbo].[ResumenPorCentroRecibo].centro
                --WHERE   [dbo].[ResumenPorCentroRecibo].numeroConcepto = 9996
                --        AND [@kardex].codigo = 999999996
                --        AND [@kardex].centro = '99999999999997'

            END

        --IF @esRecibo = 0
        --    BEGIN
        --        DELETE  @kardex
        --        WHERE   [@kardex].empresa = @empresa
        --                AND [@kardex].codigo = 999999995
        --                AND [@kardex].numeroConceptoPercepcion IS NULL
        --                AND [@kardex].numeroConceptoDeduccion IS NULL
        --                AND [@kardex].numeroConceptoProvision IS NULL
        --    END
        --ELSE
        --    BEGIN

        INSERT  @codigoBase
                ( codigo ,
                  renglon ,
                  centro ,
                  supervisor ,
                  nombre

                )
                SELECT DISTINCT
                        [@kardex].codigo ,
                        [@tablaBaseRenglon].renglon ,
                        [@kardex].centro ,
                        [@kardex].supervisor ,
                        [@kardex].nombre
                FROM    @kardex ,
                        @tablaBaseRenglon
                WHERE   [@tablaBaseRenglon].renglon <= CASE WHEN [@kardex].renglon > 20
                                                            THEN 40
                                                            ELSE 20
                                                       END


        SET @codigoAnterior = 0
        SET @numeroRecibo = 0
        SET @nombreAnterior = ''

                -- Ordenado por Cdigo
        IF @ordenadoPor & 1 > 0
            BEGIN
                INSERT  @tablaNumeroRecibo
                        ( codigo ,
                          renglon

                        )
                        SELECT DISTINCT
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon
                        FROM    @kardex ,
                                @tablaBaseRenglon
                        WHERE   [@tablaBaseRenglon].renglon <= CASE
                                                              WHEN [@kardex].renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                        ORDER BY [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon

                UPDATE  @tablaNumeroRecibo
                SET     @numeroRecibo = @numeroRecibo
                        + CASE WHEN [@tablaNumeroRecibo].codigo <> @codigoAnterior
                               THEN 1
                               ELSE 0
                          END ,
                        [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                        @codigoAnterior = [@tablaNumeroRecibo].codigo
            END

                -- Ordenado por Nombre
        IF @ordenadoPor & 2 > 0
            BEGIN
                INSERT  @tablaNumeroRecibo
                        ( codigo ,
                          renglon ,
                          nombre

                        )
                        SELECT DISTINCT
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon ,
                                [@kardex].nombre
                        FROM    @kardex ,
                                @tablaBaseRenglon
                        WHERE   [@tablaBaseRenglon].renglon <= CASE
                                                              WHEN [@kardex].renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                        ORDER BY [@kardex].nombre ,
                                [@tablaBaseRenglon].renglon

                UPDATE  @tablaNumeroRecibo
                SET     @numeroRecibo = @numeroRecibo
                        + CASE WHEN [@tablaNumeroRecibo].nombre <> @nombreAnterior
                               THEN 1
                               ELSE 0
                          END ,
                        [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                        @nombreAnterior = [@tablaNumeroRecibo].nombre
            END

                -- Ordenado por Centro y Nombre
        IF @ordenadoPor & 4 > 0
            BEGIN
                INSERT  @tablaNumeroRecibo
                        ( codigo ,
                          renglon ,
                          nombre ,
                          centro

                        )
                        SELECT DISTINCT
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon ,
                                [@kardex].nombre ,
                                [@kardex].centro
                        FROM    @kardex ,
                                @tablaBaseRenglon
                        WHERE   [@tablaBaseRenglon].renglon <= CASE
                                                              WHEN [@kardex].renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                        ORDER BY [@kardex].centro ,
                                [@kardex].nombre ,
                                [@tablaBaseRenglon].renglon

                UPDATE  @tablaNumeroRecibo
                SET     @numeroRecibo = @numeroRecibo
                        + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                    + [@tablaNumeroRecibo].nombre <> @nombreAnterior
                               THEN 1
                               ELSE 0
                          END ,
                        [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                        @nombreAnterior = [@tablaNumeroRecibo].centro + ' '
                        + [@tablaNumeroRecibo].nombre
            END

                -- Ordenado por Centro y Cdigo
        IF @ordenadoPor & 8 > 0
            BEGIN
                INSERT  @tablaNumeroRecibo
                        ( codigo ,
                          renglon ,
                          centro

                        )
                        SELECT DISTINCT
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon ,
                                [@kardex].centro
                        FROM    @kardex ,
                                @tablaBaseRenglon
                        WHERE   [@tablaBaseRenglon].renglon <= CASE
                                                              WHEN [@kardex].renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                        ORDER BY [@kardex].centro ,
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon

                UPDATE  @tablaNumeroRecibo
                SET     @numeroRecibo = @numeroRecibo
                        + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                    + STR([@tablaNumeroRecibo].codigo) <> @nombreAnterior
                               THEN 1
                               ELSE 0
                          END ,
                        [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                        @nombreAnterior = [@tablaNumeroRecibo].centro + ' '
                        + STR([@tablaNumeroRecibo].codigo)
            END

                -- Ordenado por Centro, Supervisor y Nombre
        IF @ordenadoPor & 16 > 0
            BEGIN
                INSERT  @tablaNumeroRecibo
                        ( codigo ,
                          renglon ,
                          centro ,
                          nombre ,
                          supervisor

                        )
                        SELECT DISTINCT
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon ,
                                [@kardex].centro ,
                                [@kardex].nombre ,
                                [@kardex].supervisor
                        FROM    @kardex ,
                                @tablaBaseRenglon
                        WHERE   [@tablaBaseRenglon].renglon <= CASE
                                                              WHEN [@kardex].renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                        ORDER BY [@kardex].centro ,
                                [@kardex].supervisor ,
                                [@kardex].nombre ,
                                [@tablaBaseRenglon].renglon

                UPDATE  @tablaNumeroRecibo
                SET     @numeroRecibo = @numeroRecibo
                        + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                    + STR([@tablaNumeroRecibo].supervisor)
                                    + ' ' + [@tablaNumeroRecibo].nombre <> @nombreAnterior
                               THEN 1
                               ELSE 0
                          END ,
                        [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                        @nombreAnterior = [@tablaNumeroRecibo].centro + ' '
                        + STR([@tablaNumeroRecibo].supervisor) + ' '
                        + [@tablaNumeroRecibo].nombre
            END

                -- Ordenado por Centro, Supervisor y Cdigo
        IF @ordenadoPor & 32 > 0
            BEGIN
                INSERT  @tablaNumeroRecibo
                        ( codigo ,
                          renglon ,
                          centro ,
                          supervisor

                        )
                        SELECT DISTINCT
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon ,
                                [@kardex].centro ,
                                [@kardex].supervisor
                        FROM    @kardex ,
                                @tablaBaseRenglon
                        WHERE   [@tablaBaseRenglon].renglon <= CASE
                                                              WHEN [@kardex].renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                        ORDER BY [@kardex].centro ,
                                [@kardex].supervisor ,
                                [@kardex].codigo ,
                                [@tablaBaseRenglon].renglon

                UPDATE  @tablaNumeroRecibo
                SET     @numeroRecibo = @numeroRecibo
                        + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                    + STR([@tablaNumeroRecibo].supervisor)
                                    + ' ' + STR([@tablaNumeroRecibo].codigo) <> @nombreAnterior
                               THEN 1
                               ELSE 0
                          END ,
                        [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                        @nombreAnterior = [@tablaNumeroRecibo].centro + ' '
                        + STR([@tablaNumeroRecibo].supervisor) + ' '
                        + STR([@tablaNumeroRecibo].codigo)
            END

        SET @cuantosRecibos = 0
        SET @codigoAnterior = 0
        SET @numeroRecibo = 0

        UPDATE  @codigoBase
        SET     @cuantosRecibos = CASE WHEN codigoBase.renglon <= 20 THEN 1
                                       ELSE 2
                                  END ,
                [@codigoBase].cuantosRecibos = @cuantosRecibos ,
                [@codigoBase].recibo = CASE WHEN [@codigoBase].renglon <= 20
                                            THEN 1
                                            ELSE 2
                                       END ,
                @numeroRecibo = @numeroRecibo
                + CASE WHEN [@codigoBase].codigo <> @codigoAnterior THEN 1
                       ELSE 0
                  END ,
                @codigoAnterior = [@codigoBase].codigo ,
                [@codigoBase].numeroRecibo = [@tablaNumeroRecibo].numeroRecibo
                        --, [@codigoBase].numeroRecibo = @numeroRecibo
        FROM    @codigoBase
                INNER JOIN ( SELECT [@codigoBase].codigo ,
                                    MAX([@codigoBase].renglon) AS renglon
                             FROM   @codigoBase
                             GROUP BY [@codigoBase].codigo
                           ) AS codigoBase ON [@codigoBase].codigo = codigoBase.codigo
                INNER JOIN @tablaNumeroRecibo ON [@codigoBase].codigo = [@tablaNumeroRecibo].codigo
                                                 AND [@codigoBase].renglon = [@tablaNumeroRecibo].renglon

        INSERT  @kardex
                ( empresa ,
                  codigo ,
                  renglon ,
                  codigoId ,
                  nombre ,
                  centro ,
                  supervisor ,
                  procesoName ,
                  nomina

                )
                SELECT  @empresa ,
                        [@codigoBase].codigo ,
                        [@codigoBase].renglon ,
                        RIGHT(STR(100000000 + [@codigoBase].codigo), 8)
                        + RIGHT(STR(1000000000 + [@codigoBase].renglon), 9) ,
                        [@codigoBase].nombre ,
                        [@codigoBase].centro ,
                        [@codigoBase].supervisor ,
                        @procesoName ,
                        @nomina
                FROM    @kardex
                        RIGHT JOIN @codigoBase ON [@kardex].codigo = [@codigoBase].codigo
                                                  AND [@kardex].renglon = [@codigoBase].renglon
                WHERE   [@kardex].renglon IS NULL


        UPDATE  @kardex
        SET     [@kardex].cuantosRecibos = [@codigoBase].cuantosRecibos ,
                [@kardex].recibo = [@codigoBase].recibo ,
                [@kardex].numeroRecibo = [@codigoBase].numeroRecibo ,
                [@kardex].grupoRecibo = RIGHT(STR(100000000
                                                  + [@codigoBase].codigo), 8)
                + RIGHT(STR(100 + [@codigoBase].recibo), 2)
        FROM    @kardex
                INNER JOIN @codigoBase ON [@kardex].codigo = [@codigoBase].codigo
                                          AND [@kardex].renglon = [@codigoBase].renglon


        IF @nomina = 'AGI'
            BEGIN
                UPDATE  [@kardex]
                SET     [@kardex].percepcionesEmpleado = ISNULL(dbo.aguinaldos.tpercepcion,
                                                              0) ,
                        [@kardex].deduccionesEmpleado = ISNULL(dbo.aguinaldos.tdeduccion,
                                                              0) ,
                        [@kardex].netoPagarEmpleado = ISNULL(dbo.aguinaldos.neto,
                                                             0) ,
                        [@kardex].acumuladoPercepcion = ISNULL(dbo.acum_emps.acu_percep,
                                                              0) ,
                        [@kardex].acumuladoPercepcionGravable = ISNULL(dbo.acum_emps.gravable,
                                                              0) ,
                        [@kardex].acumuladoIsr = ISNULL(dbo.acum_emps.ispt, 0) ,
                        [@kardex].acumuladoInfonavit = ISNULL(dbo.acum_emps.acu_info,
                                                              0) ,
                        [@kardex].acumuladoSar = ISNULL(dbo.acum_emps.acu_sar,
                                                        0) ,
                        [@kardex].acumuladoCv = ISNULL(dbo.acum_emps.acu_cv, 0)
                FROM    @kardex
                        INNER JOIN dbo.aguinaldos ON [@kardex].empresa = dbo.aguinaldos.empresa
                                                     AND [@kardex].codigo = dbo.aguinaldos.codigo
                        LEFT JOIN dbo.acum_emps ON [@kardex].empresa = dbo.acum_emps.empresa
                                                   AND [@kardex].codigo = dbo.acum_emps.codigo
                                                   AND @ayoOperacion = dbo.acum_emps.ejercicio
                WHERE   ( ( [@kardex].cuantosRecibos = 1
                            AND [@kardex].renglon = 20
                          )
                          OR ( [@kardex].cuantosRecibos = 2
                               AND [@kardex].renglon = 40
                             )
                        )
            END
        ELSE
            BEGIN
                IF @nomina = 'PTU'
                    OR @nomina = 'DES'
                    OR @nomina = 'VAC'
                    BEGIN
                        UPDATE  [@kardex]
                        SET     [@kardex].percepcionesEmpleado = ISNULL(kardexTotal.importePercepcion,
                                                              0) ,
                                [@kardex].deduccionesEmpleado = ISNULL(kardexTotal.importeDeduccion,
                                                              0) ,
                                [@kardex].netoPagarEmpleado = ISNULL(kardexTotal.netoPagar,
                                                              0) ,
                                [@kardex].acumuladoPercepcion = ISNULL(dbo.acum_emps.acu_percep,
                                                              0) ,
                                [@kardex].acumuladoPercepcionGravable = ISNULL(dbo.acum_emps.gravable,
                                                              0) ,
                                [@kardex].acumuladoIsr = ISNULL(dbo.acum_emps.ispt,
                                                              0) ,
                                [@kardex].acumuladoInfonavit = ISNULL(dbo.acum_emps.acu_info,
                                                              0) ,
                                [@kardex].acumuladoSar = ISNULL(dbo.acum_emps.acu_sar,
                                                              0) ,
                                [@kardex].acumuladoCv = ISNULL(dbo.acum_emps.acu_cv,
                                                              0)
                        FROM    @kardex
                                LEFT JOIN dbo.acum_emps ON [@kardex].empresa = dbo.acum_emps.empresa
                                                           AND [@kardex].codigo = dbo.acum_emps.codigo
                                                           AND @ayoOperacion = dbo.acum_emps.ejercicio
                                INNER JOIN ( SELECT kardex.empresa ,
                                                    kardex.codigo ,
                                                    SUM(ISNULL(kardex.importeConceptoPercepcion,
                                                              0)
                                                        - ISNULL(kardex.importeConceptoDeduccion,
                                                              0)) AS netoPagar ,
                                                    SUM(ISNULL(kardex.importeConceptoPercepcion,
                                                              0)) AS importePercepcion ,
                                                    SUM(ISNULL(kardex.importeConceptoDeduccion,
                                                              0)) AS importeDeduccion
                                             FROM   @kardex AS kardex
                                             GROUP BY kardex.empresa ,
                                                    kardex.codigo
                                           ) AS kardexTotal ON [@kardex].empresa = kardexTotal.empresa
                                                              AND [@kardex].codigo = kardexTotal.codigo
                        WHERE   ( ( [@kardex].cuantosRecibos = 1
                                    AND [@kardex].renglon = 20
                                  )
                                  OR ( [@kardex].cuantosRecibos = 2
                                       AND [@kardex].renglon = 40
                                     )
                                )
                    END
                ELSE
                    BEGIN
                        UPDATE  [@kardex]
                        SET     [@kardex].percepcionesEmpleado = ISNULL(dbo.otranomina.percepcion,
                                                              0) ,
                                [@kardex].deduccionesEmpleado = ISNULL(dbo.otranomina.deduccion,
                                                              0) ,
                                [@kardex].netoPagarEmpleado = ISNULL(dbo.otranomina.neto,
                                                              0) ,
                                [@kardex].acumuladoPercepcion = ISNULL(dbo.acum_emps.acu_percep,
                                                              0) ,
                                [@kardex].acumuladoPercepcionGravable = ISNULL(dbo.acum_emps.gravable,
                                                              0) ,
                                [@kardex].acumuladoIsr = ISNULL(dbo.acum_emps.ispt,
                                                              0) ,
                                [@kardex].acumuladoInfonavit = ISNULL(dbo.acum_emps.acu_info,
                                                              0) ,
                                [@kardex].acumuladoSar = ISNULL(dbo.acum_emps.acu_sar,
                                                              0) ,
                                [@kardex].acumuladoCv = ISNULL(dbo.acum_emps.acu_cv,
                                                              0)
                        FROM    @kardex
                                INNER JOIN dbo.otranomina ON [@kardex].empresa = dbo.otranomina.empresa
                                                             AND [@kardex].codigo = dbo.otranomina.codigo
                                LEFT JOIN dbo.acum_emps ON [@kardex].empresa = dbo.acum_emps.empresa
                                                           AND [@kardex].codigo = dbo.acum_emps.codigo
                                                           AND @ayoOperacion = dbo.acum_emps.ejercicio
                        WHERE   ( ( [@kardex].cuantosRecibos = 1
                                    AND [@kardex].renglon = 20
                                  )
                                  OR ( [@kardex].cuantosRecibos = 2
                                       AND [@kardex].renglon = 40
                                     )
                                )
                    END
            END


                --- Para cuando se va a imprimir mas de una copia de recibo
        SELECT  @copiasRecibo = ISNULL(dbo.Parametros_Empresas.Copias_Recibo,
                                       0)
        FROM    dbo.Parametros_Empresas
        WHERE   dbo.Parametros_Empresas.Empresa = @empresa

        IF @copiasRecibo > 1
            BEGIN
                WHILE @cuentaCopia <= @copiasRecibo
                    BEGIN
                        INSERT  @kardex
                                ( empresa ,
                                  codigoId ,
                                  codigo ,
                                  nombre ,
                                  fechaAlta ,
                                  numeroSeguridadSocial ,
                                  digitoVerificador ,
                                  curp ,
                                  centro ,
                                  nombreCentro ,
                                  cuentaBanco ,
                                  nombreBanco ,
                                  ocupacion ,
                                  categoria ,
                                  tipoSalario ,
                                  renglon ,
                                  jornada ,
                                  sueldoDiario ,
                                  salarioBaseCotizacion ,
                                  clase ,
                                  nombreClase ,
                                  supervisor ,
                                  nombreSupervisor ,
                                  marcaContraPercepcion ,
                                  numeroConceptoPercepcion ,
                                  nombreConceptoPercepcion ,
                                  importeConceptoPercepcion ,
                                  gravablePercepcion ,
                                  exentoPercepcion ,
                                  saldoPercepcion ,
                                  anexoConceptoPercepcion ,
                                  marcaContraDeduccion ,
                                  numeroConceptoDeduccion ,
                                  nombreConceptoDeduccion ,
                                  importeConceptoDeduccion ,
                                  gravableDeduccion ,
                                  exentoDeduccion ,
                                  saldoDeduccion ,
                                  anexoConceptoDeduccion ,
                                  numeroConceptoProvision ,
                                  nombreConceptoProvision ,
                                  importeConceptoProvision ,
                                  empleados ,
                                  provisionIMSS ,
                                  provisionRCV ,
                                  provisionINFONAVIT ,
                                  retencionIMSS ,
                                  retencionRCV ,
                                  retencionINFONAVIT ,
                                  empleadosConCuentaBancaria ,
                                  empleadosSinCuentaBancaria ,
                                  percepcionesConCuentaBancaria ,
                                  deduccionesConCuentaBancaria ,
                                  percepcionesSinCuentaBancaria ,
                                  deduccionesSinCuentaBancaria ,
                                  basePorcientoSobreNomina ,
                                  porcientoSobreNomina ,
                                  fondoAhorroAportacionEmpleado ,
                                  fondoAhorroAportacionPatron ,
                                  sueldoNetoGeneral ,
                                  ejercicio ,
                                  diarioOficialDia ,
                                  diarioOficialMes ,
                                  diarioOficialAyo ,
                                  salarioMinimoDF ,
                                  salarioMinimoRegion ,
                                  eymArt25 ,
                                  eymArt106ii ,
                                  eymArt107 ,
                                  ivArt147 ,
                                  cvArt168ii ,
                                  baseCalculo ,
                                  grupo ,
                                  cuantosRecibos ,
                                  numeroRecibo ,
                                  recibo ,
                                  percepcionesEmpleado ,
                                  deduccionesEmpleado ,
                                  netoPagarEmpleado ,
                                  grupoRecibo ,
                                  rfcAlfa ,
                                  rfcNum ,
                                  rfcHomo ,
                                  acumuladoPercepcion ,
                                  acumuladoPercepcionGravable ,
                                  acumuladoIsr ,
                                  acumuladoInfonavit ,
                                  acumuladoSar ,
                                  acumuladoCv ,
                                  email ,
                                  fechaAntiguedad ,
                                  procesoName ,
                                  nomina

                                )
                                SELECT  empresa ,
                                        codigoId ,
                                        codigo ,
                                        nombre ,
                                        fechaAlta ,
                                        numeroSeguridadSocial ,
                                        digitoVerificador ,
                                        curp ,
                                        centro ,
                                        nombreCentro ,
                                        cuentaBanco ,
                                        nombreBanco ,
                                        ocupacion ,
                                        categoria ,
                                        tipoSalario ,
                                        renglon ,
                                        jornada ,
                                        sueldoDiario ,
                                        salarioBaseCotizacion ,
                                        clase ,
                                        nombreClase ,
                                        supervisor ,
                                        nombreSupervisor ,
                                        marcaContraPercepcion ,
                                        numeroConceptoPercepcion ,
                                        nombreConceptoPercepcion ,
                                        importeConceptoPercepcion ,
                                        gravablePercepcion ,
                                        exentoPercepcion ,
                                        saldoPercepcion ,
                                        anexoConceptoPercepcion ,
                                        marcaContraDeduccion ,
                                        numeroConceptoDeduccion ,
                                        nombreConceptoDeduccion ,
                                        importeConceptoDeduccion ,
                                        gravableDeduccion ,
                                        exentoDeduccion ,
                                        saldoDeduccion ,
                                        anexoConceptoDeduccion ,
                                        numeroConceptoProvision ,
                                        nombreConceptoProvision ,
                                        importeConceptoProvision ,
                                        empleados ,
                                        provisionIMSS ,
                                        provisionRCV ,
                                        provisionINFONAVIT ,
                                        retencionIMSS ,
                                        retencionRCV ,
                                        retencionINFONAVIT ,
                                        empleadosConCuentaBancaria ,
                                        empleadosSinCuentaBancaria ,
                                        percepcionesConCuentaBancaria ,
                                        deduccionesConCuentaBancaria ,
                                        percepcionesSinCuentaBancaria ,
                                        deduccionesSinCuentaBancaria ,
                                        basePorcientoSobreNomina ,
                                        porcientoSobreNomina ,
                                        fondoAhorroAportacionEmpleado ,
                                        fondoAhorroAportacionPatron ,
                                        sueldoNetoGeneral ,
                                        ejercicio ,
                                        diarioOficialDia ,
                                        diarioOficialMes ,
                                        diarioOficialAyo ,
                                        salarioMinimoDF ,
                                        salarioMinimoRegion ,
                                        eymArt25 ,
                                        eymArt106ii ,
                                        eymArt107 ,
                                        ivArt147 ,
                                        cvArt168ii ,
                                        baseCalculo ,
                                        grupo ,
                                        cuantosRecibos ,
                                        numeroRecibo ,
                                        recibo ,
                                        percepcionesEmpleado ,
                                        deduccionesEmpleado ,
                                        netoPagarEmpleado ,
                                        SUBSTRING(grupoRecibo, 1, 8)
                                        + RIGHT(STR(100 + @cuentaCopia), 2)
                                        + SUBSTRING(grupoRecibo, 11, 50) ,
                                        rfcAlfa ,
                                        rfcNum ,
                                        rfcHomo ,
                                        acumuladoPercepcion ,
                                        acumuladoPercepcionGravable ,
                                        acumuladoIsr ,
                                        acumuladoInfonavit ,
                                        acumuladoSar ,
                                        acumuladoCv ,
                                        email ,
                                        fechaAntiguedad ,
                                        procesoName ,
                                        nomina
                                FROM    @kardex
                                WHERE   SUBSTRING(grupoRecibo, 1, 10) = RIGHT(STR(100000000
                                                              + codigo), 8)
                                        + '01'
                        SET @cuentaCopia = @cuentaCopia + 1
                    END
            END


        --    END

        IF @procesoName = 'NominaNoOrdinaria'
            BEGIN
                --DECLARE @fechaCierreNomina DATETIME
                DECLARE @tFechaAltaEmpleado TABLE
                    (
                      codigo INT ,
                      fechaAltaEmpleado DATETIME
                    )

                --SELECT  @fechaCierreNomina = dbo.Periodos.cierre
                --FROM    dbo.Periodos
                --WHERE   dbo.Periodos.empresa = @empresa
                --        AND dbo.Periodos.tiponom = @tipoNomina
                --        AND dbo.Periodos.estatus = 'A'

                INSERT  @tFechaAltaEmpleado
                        ( codigo ,
                          fechaAltaEmpleado
                        )
                        SELECT  dbo.empleados.codigo ,
                                ISNULL(( SELECT TOP 1
                                                dbo.avisos_imss.fch_mov
                                         FROM   dbo.avisos_imss
                                         WHERE  dbo.avisos_imss.empresa = dbo.empleados.empresa
                                                AND dbo.avisos_imss.codigo = dbo.empleados.codigo
                                                AND ( dbo.avisos_imss.mov = 'A'
                                                      OR dbo.avisos_imss.mov = 'RI'
                                                    )
                                                AND dbo.avisos_imss.fch_mov <= dbo.Periodos.cierre --@fechaCierreNomina
                                         ORDER BY dbo.avisos_imss.fch_mov DESC
                                       ), dbo.empleados.fchalta) AS fechaAlta
                        FROM    dbo.empleados
                                INNER JOIN @kardex AS tablaKardex ON dbo.empleados.empresa = tablaKardex.empresa
                                                              AND dbo.empleados.codigo = tablaKardex.codigo
                                INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa AND dbo.empleados.codigo = dbo.Llaves.codigo
                                LEFT JOIN dbo.Periodos ON dbo.Llaves.empresa = dbo.Periodos.empresa AND dbo.Llaves.tiponom = dbo.Periodos.tiponom AND dbo.Periodos.estatus = 'A'
                        WHERE dbo.empleados.empresa = @empresa

                UPDATE  tablaKardex
                SET     tablaKardex.fechaAlta = tFechaAltaEmpleado.fechaAltaEmpleado
                FROM    @kardex AS tablaKardex
                        INNER JOIN @tFechaAltaEmpleado AS tFechaAltaEmpleado ON tFechaAltaEmpleado.codigo = tablaKardex.codigo
            END

        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaInfonavitBimestre
 * Project       : APSI Nomina
 * Description   : Llena tabla con aportacin INFONAVIT Con o Sin Credito
 * Table name    : empresa, primas_imss, empleados, deducciones, infonavit
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'TF'
--                    AND name = 'LlenaInfonavitBimestre' ) 
--    BEGIN
--        DROP  FUNCTION [dbo].[LlenaInfonavitBimestre]
--    END
IF OBJECT_ID('dbo.LlenaInfonavitBimestre') IS NOT NULL
   DROP  FUNCTION [dbo].[LlenaInfonavitBimestre]
GO
CREATE FUNCTION [dbo].[LlenaInfonavitBimestre]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT,
	  @filtroInfonavit INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
    )

-- @porRenglon = 0.- Es un registro por cada prima IMSS
--               1.- Es un solo registro y en cada columna su cuota IMSS correspondiente

RETURNS @cedulaBimestral TABLE
    (
      --empresa INT NOT NULL
      --            DEFAULT 0 ,
      --diastr INT NOT NULL
      --           DEFAULT 0 ,
      --incap INT NOT NULL
      --          DEFAULT 0 ,
      --ausen FLOAT NOT NULL
      --            DEFAULT 0 ,
      --retiro FLOAT NOT NULL
      --             DEFAULT 0 ,
      --cesantiaVejez FLOAT NOT NULL
      --                    DEFAULT 0 ,
      --cesantiaVejezPatron FLOAT NOT NULL
      --                          DEFAULT 0 ,
      --cesantiaVejezTrabajador FLOAT NOT NULL
      --                              DEFAULT 0 ,
      --aportacionInfonavit FLOAT NOT NULL
      --                          DEFAULT 0 ,
      --amortizacion FLOAT NOT NULL
      --                   DEFAULT 0 ,
      --seguroVivienda FLOAT NOT NULL
      --                     DEFAULT 0 ,
      infonavitSinCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      infonavitConCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      --clase VARCHAR(2),
      --baseCotizacionRetiro FLOAT,
      --baseCotizacionCV FLOAT,
      --baseCotizacionAportacionSinCredito FLOAT,
      --baseCotizacionAportacionConCredito FLOAT,
      --casos INT,
      --casosSinCredito INT,
      --casosConCredito INT,
      --articulo168I FLOAT,
      --articulo168II FLOAT ,
      --articulo29 FLOAT ,
      campo VARCHAR(50) COLLATE database_default,
      valor FLOAT
    )
AS 
    BEGIN
        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        --DECLARE @retiro FLOAT
        --DECLARE @cvArt168II FLOAT
        --DECLARE @cvPat168II FLOAT
        --DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        --DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        --DECLARE @retiroCuota FLOAT
        --DECLARE @cesantiaVejez FLOAT
        --DECLARE @aportacionInfonavit FLOAT 
        --DECLARE @amortizacion FLOAT
        --DECLARE @seguroViviendaCuota FLOAT
        DECLARE @infonavitSinCredito FLOAT
        DECLARE @infonavitConCredito FLOAT
        DECLARE @FechaFinita DATETIME

        SET @FechaFinita = '29991231'

        
        --SET @infonavit = 5
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar 
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE 
            BEGIN
                SET @esBimestre = 'N'
            END
    
    
-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                --@patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion    
    

-- Obtiene Primas IMSS
        SELECT  --@retiro = dbo.primas_imss.retiro ,
                --@cvArt168II = dbo.primas_imss.cvart168II ,
                --@cvPat168II = dbo.primas_imss.cvpat168II
                --+ CASE WHEN @patronPagaIMSS = 'S'
                --       THEN dbo.primas_imss.cvtra168ii
                --       ELSE 0
                --  END ,
                --@cvTra168II = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                --                   ELSE dbo.primas_imss.cvtra168ii
                --              END ,
                @infonavit = primasImss.infonavitPorciento
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss
        --WHERE   YEAR(dbo.primas_imss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END    
                                                
                                                
                                                
-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = variable1
        FROM    conceptos
        WHERE   empresa = @empresa
                AND num_conc = 112                                                
    

        --SET @seguroVivienda = CASE WHEN YEAR(@fiNon) >= 2006
        --                                AND YEAR(@fiNon) <= 2008 THEN 8
        --                           WHEN YEAR(@fiNon) >= 2009 THEN 13
        --                           ELSE 0
        --                      END

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END

    
-- Registro Avisos
        INSERT  @cedulaBimestral
                ( --empresa ,
                  --clase,
                  --diastr ,
                  --incap ,
                  --ausen ,
                  --retiro ,
                  --cesantiaVejez ,
                  --cesantiaVejezPatron ,
                  --cesantiaVejezTrabajador ,
                  --aportacionInfonavit 
                  infonavitSinCredito ,
                  infonavitConCredito 
                  --amortizacion,
                  --seguroVivienda
                  --baseCotizacionRetiro ,
                  --baseCotizacionCV ,
                  --baseCotizacionAportacionSinCredito ,
                  --baseCotizacionAportacionConCredito,
                  --casos ,
                  --casosSinCredito ,
                  --casosConCredito ,
                )
                SELECT  --dbo.empleados.empresa ,
                        --dbo.Llaves.clase,
                        --SUM(dbo.avisos_imss.diastr) AS diasTr ,
                        --SUM(dbo.avisos_imss.incap) AS incap ,
                        --SUM(dbo.avisos_imss.ausen) AS ausen ,
                        --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,0,dbo.avisos_imss.ausen,@retiro, 'N', 0)),2) AS retiro ,
                        --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@cvArt168II,'N',0)),2) AS cesantiaVejez ,
                        --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@cvPat168II,'N',0)),2) AS cesantiaVejezPatron ,
                        --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@cvTra168II,'N',0)),2) AS cesantiaVejez ,
                        --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,0,dbo.avisos_imss.ausen,@infonavit,'N',0)),2) AS aportacionInfonavit
                        ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion IS NULL THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitSinCredito,
                        ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion >= 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitConCredito
                        --0,
                        --0,
                        --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen)),2) AS baseCotizacionRetiro,
                        --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen - dbo.avisos_imss.incap)),2) AS baseCotizacionCV,
                        --ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion IS NULL THEN [dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen) ELSE 0 END),2) AS baseCotizacionAportacionSinCredito,
                        --ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion >= 0 THEN [dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen) ELSE 0 END),2) AS baseCotizacionAportacionConCredito,
                        --0,
                        --0,
                        --0
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        --INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa AND dbo.empleados.codigo = dbo.Llaves.codigo
                        --INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                            AND dbo.empleados.codigo = aItc.codigo
                        LEFT JOIN dbo.TemporalAmortizacion ON aItc.empresa = dbo.TemporalAmortizacion.empresa 
                                                              AND aItc.codigo = dbo.TemporalAmortizacion.codigo

                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = dbo.empleados.empresa
				                           AND i.codigo = dbo.empleados.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                WHERE   aItc.mes_operacion >= @mesNon 
                        AND aItc.mes_operacion <= @mesPar 
                        AND aItc.ayo_operacion = @ayo 
                        AND dbo.empleados.cotiza_imss = 'S' 
                        AND dbo.empleados.borrado = 'N' 
                        AND aItc.empresa >= CASE WHEN @empresa = 0 
                                                 THEN 0 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.empresa <= CASE WHEN @empresa = 0 
                                                 THEN 9999 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.codigo >= CASE WHEN @codigo = 0 
                                                THEN 0 
                                                ELSE @codigo 
                                           END 
                        AND aItc.codigo <= CASE WHEN @codigo = 0 
                                                THEN 99999999 
                                                ELSE @codigo 
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

                GROUP BY dbo.empleados.empresa --, dbo.Llaves.clase
                
                
                /*
                UPDATE cedulaBimestre 
                SET cedulaBimestre.amortizacion = ISNULL((SELECT SUM(dbo.TemporalAmortizacion.amortizacion)
                                                   FROM dbo.TemporalAmortizacion
                                                   WHERE dbo.TemporalAmortizacion.empresa = @empresa),0),
                                                         --AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase),0),
                                                         
                    cedulaBimestre.seguroVivienda = @seguroVivienda * ISNULL((SELECT COUNT(*)
                                                                       FROM dbo.TemporalAmortizacion
                                                                       WHERE dbo.TemporalAmortizacion.empresa = @empresa),0)
                                                                             --AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase),0)
                FROM @cedulaBimestral AS cedulaBimestre
                */
                
                /*
                UPDATE cedulaBimestre
                SET cedulaBimestre.casos = (SELECT COUNT(DISTINCT dbo.Llaves.codigo)
                                            FROM dbo.Llaves
                                            INNER JOIN dbo.avisos_imss ON dbo.Llaves.empresa = dbo.avisos_imss.empresa AND dbo.Llaves.codigo = dbo.avisos_imss.codigo
                                            INNER JOIN dbo.empleados ON dbo.avisos_imss.empresa = dbo.empleados.empresa AND dbo.avisos_imss.codigo = dbo.empleados.codigo
                                            WHERE   dbo.avisos_imss.mes_operacion >= @mesNon 
                                                    AND dbo.avisos_imss.mes_operacion <= @mesPar 
                                                    AND dbo.avisos_imss.ayo_operacion = @ayo 
                                                    AND dbo.empleados.cotiza_imss = 'S' 
                                                    AND dbo.empleados.borrado = 'N' 
                                                    AND dbo.avisos_imss.empresa >= CASE WHEN @empresa = 0 
                                                                                           THEN 0 
                                                                                           ELSE @empresa 
                                                                                   END 
                                                    AND dbo.avisos_imss.empresa <= CASE WHEN @empresa = 0 
                                                                                           THEN 9999 
                                                                                           ELSE @empresa 
                                                                                   END 
                                                    AND dbo.avisos_imss.codigo >= CASE WHEN @codigo = 0 
                                                                                          THEN 0 
                                                                                          ELSE @codigo 
                                                                                  END 
                                                    AND dbo.avisos_imss.codigo <= CASE WHEN @codigo = 0 
                                                                                          THEN 99999999 
                                                                                          ELSE @codigo 
                                                                                  END
                                                    AND dbo.Llaves.clase = cedulaBimestre.clase),
                    cedulaBimestre.casosConCredito = (SELECT COUNT(*)
                                                      FROM dbo.TemporalAmortizacion
                                                      WHERE dbo.TemporalAmortizacion.empresa = cedulaBimestre.empresa
                                                            AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase)
                                                           
                FROM @cedulaBimestral AS cedulaBimestre
                WHERE cedulaBimestre.empresa = @empresa
                
                UPDATE cedulaBimestre 
                SET cedulaBimestre.casosSinCredito = cedulaBimestre.casos - cedulaBimestre.casosConCredito
                FROM @cedulaBimestral AS cedulaBimestre
                WHERE cedulaBimestre.empresa = @empresa
                

                UPDATE cedulaBimestre
                SET [cedulaBimestre].articulo168I = @retiro,
                    [cedulaBimestre].articulo168II = @cvArt168II,
                    [cedulaBimestre].articulo29 = @infonavit
                FROM @cedulaBimestral AS cedulaBimestre
                WHERE [cedulaBimestre].clase = (SELECT TOP 1 [cedulaBimestre].clase 
                                               FROM @cedulaBimestral AS cedulaBimestre)
                */
                
        IF @porRenglon = 0
            BEGIN
              SELECT @infonavitSinCredito = cedulaBimestre.infonavitSinCredito ,
                     @infonavitConCredito = cedulaBimestre.infonavitConCredito
              FROM @cedulaBimestral AS cedulaBimestre

              INSERT @cedulaBimestral (campo, valor) VALUES ('Sin Credito', @infonavitSinCredito)
              INSERT @cedulaBimestral (campo, valor) VALUES ('Con Credito', @infonavitConCredito)
            
              DELETE cedulaBimestre FROM @cedulaBimestral AS cedulaBimestre WHERE cedulaBimestre.campo IS NULL
          END
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaInfonavitMensual
 * Project       : APSI Nomina
 * Description   : Llena tabla con aportacin INFONAVIT Con o Sin Credito
 * Table name    : empresa, primas_imss, empleados, deducciones, infonavit
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'TF'
--                    AND name = 'LlenaInfonavitBimestre' ) 
--    BEGIN
--        DROP  FUNCTION [dbo].[LlenaInfonavitBimestre]
--    END
IF OBJECT_ID('dbo.LlenaInfonavitMensual') IS NOT NULL
   DROP  FUNCTION [dbo].[LlenaInfonavitMensual]
GO
CREATE FUNCTION [dbo].[LlenaInfonavitMensual]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT
    )

-- @porRenglon = 0.- Es un registro por cada prima IMSS
--               1.- Es un solo registro y en cada columna su cuota IMSS correspondiente

RETURNS @cedulaMensual TABLE
    (
      infonavitSinCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      infonavitConCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      campo VARCHAR(50) COLLATE database_default,
      valor FLOAT
    )
AS 
    BEGIN
        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        --DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @infonavitSinCredito FLOAT
        DECLARE @infonavitConCredito FLOAT

        
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        --        SET @esBimestre = 'N'
    
    
-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesNon, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion    
    

-- Obtiene Primas IMSS
        SELECT  @infonavit = primasImss.infonavitPorciento
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
                                                
                                                
-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = variable1
        FROM    conceptos
        WHERE   empresa = @empresa
                AND num_conc = 112                                                
    

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffNon <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffNon <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END

    
-- Registro Avisos
        INSERT  @cedulaMensual
                ( infonavitSinCredito ,
                  infonavitConCredito 
                )
                SELECT  ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion IS NULL THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitSinCredito,
                        ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion >= 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitConCredito
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                            AND dbo.empleados.codigo = aItc.codigo
                        LEFT JOIN dbo.TemporalAmortizacion ON aItc.empresa = dbo.TemporalAmortizacion.empresa 
                                                              AND aItc.codigo = dbo.TemporalAmortizacion.codigo
                WHERE   aItc.mes_operacion = @mesNon 
                        AND aItc.ayo_operacion = @ayo 
                        AND dbo.empleados.cotiza_imss = 'S' 
                        AND dbo.empleados.borrado = 'N' 
                        AND aItc.empresa >= CASE WHEN @empresa = 0 
                                                 THEN 0 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.empresa <= CASE WHEN @empresa = 0 
                                                 THEN 9999 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.codigo >= CASE WHEN @codigo = 0 
                                                THEN 0 
                                                ELSE @codigo 
                                           END 
                        AND aItc.codigo <= CASE WHEN @codigo = 0 
                                                THEN 99999999 
                                                ELSE @codigo 
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                GROUP BY dbo.empleados.empresa
                
                
        IF @porRenglon = 0
            BEGIN
              SELECT @infonavitSinCredito = cedulaMensual.infonavitSinCredito ,
                     @infonavitConCredito = cedulaMensual.infonavitConCredito
              FROM @cedulaMensual AS cedulaMensual

              INSERT @cedulaMensual (campo, valor) VALUES ('Sin Crdito', @infonavitSinCredito)
              INSERT @cedulaMensual (campo, valor) VALUES ('Con Crdito', @infonavitConCredito)
            
              DELETE cedulaMensual FROM @cedulaMensual AS cedulaMensual WHERE cedulaMensual.campo IS NULL
          END
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaResumenClase
 * Project       : APSI Nomina
 * Description   : Prepara el resumen por clase de empleado
 * Table name    : avisos_imss, llaves
 * Return        : tabla con el resumen
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Agosto 19, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.LlenaResumenClase') IS NOT NULL
   DROP FUNCTION dbo.LlenaResumenClase
GO

CREATE FUNCTION dbo.LlenaResumenClase(
@empresa NUMERIC(5),
@codigo NUMERIC(8, 0),
@ayo INT,
@mes INT,
@proceso VARCHAR(250),
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8) ,
@simulaReforma INT
    )

RETURNS @cedulaMensual TABLE
    (
      salario FLOAT NULL ,
      diastr INT NULL ,
      incap INT NULL ,
      ausen FLOAT NULL ,
      cuotaFija FLOAT NULL ,
      excedente FLOAT NULL ,
      excedentePatron FLOAT NULL ,
      exccedenteTrabajador FLOAT NULL ,
      prestacionesDinero FLOAT NULL ,
      prestacionesPatron FLOAT NULL ,
      prestacionesTrabajador FLOAT NULL ,
      gmp FLOAT NULL ,
      gmpPatron FLOAT NULL ,
      gmpTrabajador FLOAT NULL ,
      rt FLOAT NULL ,
      invalidezVida FLOAT NULL ,
      invalidezVidaPatron FLOAT NULL ,
      invalidezVidaTrabajador FLOAT NULL ,
      guarderias FLOAT NULL ,
      cesantiaVejez FLOAT NULL ,
      cesantiaVejezPatron FLOAT NULL ,
      cesantiaVejezTrabajador FLOAT NULL,
      clase VARCHAR(2) COLLATE database_default NULL,
      registroPorClase INT NULL,
      registroExc INT NULL,
      baseCotizacionCuotaFija FLOAT,
      baseCotizacionExc FLOAT,
      baseCotizacionPD FLOAT,
      baseCotizacionGMP FLOAT,
      baseCotizacionRT FLOAT,
      baseCotizacionIV FLOAT,
      baseCotizacionGPS FLOAT,
      baseCotizacionCV FLOAT,
      nombreClase VARCHAR(20) COLLATE database_default,
      articulo106I FLOAT,
      articulo106II FLOAT,
      articulo107 FLOAT,
      articulo25 FLOAT,
      articulo71 FLOAT,
      articulo147 FLOAT,
      articulo211 FLOAT ,
      infonavit FLOAT,
	  lic INT
    )
    
AS 
    BEGIN

        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @fi DATETIME
        DECLARE @ff DATETIME
        DECLARE @prima_rt FLOAT
        DECLARE @ayoEmpresa INT
        DECLARE @diasFaltaTope INT
        --DECLARE @infonavit FLOAT
        DECLARE @art211 FLOAT
        DECLARE @mesPago CHAR(6)
        DECLARE @mesAplicaUMA CHAR(6)
        
        SET @mesPago = RIGHT(STR(@ayo),4) + RIGHT(STR(100 + @mes),2)
        SET @mesAplicaUMA = '201701'

        SET @diasFaltaTope = 7
        SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
        SET @ff = dbo.fin_mes(@mes, @ayo)


-- Obtiene Area Geografica
        SELECT  @areaGeografica = empresa.zona_geografica ,
                @patronPagaIMSS = empresa.patron_paga_cuotas_imss ,
                @ayoEmpresa = empresa.ayo_operacion
        FROM    dbo.empresas AS empresa
        WHERE   empresa.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion
                    

-- Obtiene Primas IMSS
        SELECT  @eymArt25 = primasImss.eymart25 ,
                @eymPat25 = primasImss.eympat25 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra25 ELSE 0 END ,
                @eymTra25 = primasImss.eymtra25 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra25 END ,
                @eymArt106I = primasImss.eymart106I ,
                @eymArt1062 = primasImss.eymart1062 ,
                @eymPat1062 = primasImss.eympat1062 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra1062 ELSE 0 END ,
                @eymTra1062 = primasImss.eymtra1062 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra1062 END ,
                @eymArt107 = primasImss.eymart107 ,
                @eymPat107 = primasImss.eympat107 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra107 ELSE 0 END ,
                @eymTra107 = primasImss.eymtra107 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra107 END ,
                @ivArt147 = primasImss.ivart147 ,
                @ivPat147 = primasImss.ivpat147 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.ivtra147 ELSE 0 END ,
                @ivTra147 = primasImss.ivtra147 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.ivtra147 END ,
                @retiro = primasImss.cvArt168I ,
                @cvArt168II = primasImss.cvart168II ,
                @cvPat168II = primasImss.cvpat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
                @cvTra168II = primasImss.cvtra168ii , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
                --@infonavit = primasImss.infonavit ,
                @art211 = primasImss.art211
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss AS primasImss
        --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END


-- Obtiene Prima RT
        SELECT  @prima_rt = primaRt.prima_rt
        FROM    dbo.primas_rt AS primaRt
        WHERE   primaRt.empresa = @empresa
                AND primaRt.fecha_inicial <= @fi
                AND primaRt.fecha_final >= @ff


-- Prima Guarderias
        --SET @primaGuarderia = 1

        INSERT  @cedulaMensual
                ( salario ,
                  diastr ,
                  incap ,
                  ausen ,
                  cuotaFija ,
                  excedente ,
                  excedentePatron ,
                  exccedenteTrabajador ,
                  prestacionesDinero ,
                  prestacionesPatron ,
                  prestacionesTrabajador ,
                  gmp ,
                  gmpPatron ,
                  gmpTrabajador ,
                  rt ,
                  invalidezVida ,
                  invalidezVidaPatron ,
                  invalidezVidaTrabajador ,
                  guarderias ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  clase,
                  baseCotizacionCuotaFija ,
                  baseCotizacionExc ,
                  baseCotizacionPD ,
                  baseCotizacionGMP ,
                  baseCotizacionRT ,
                  baseCotizacionIV ,
                  baseCotizacionGPS ,
                  baseCotizacionCV,
                  nombreClase,
				  lic
                )
                SELECT  ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint, CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, @topeRegion, dbo.empleados.art39, aItc.mov)),2) AS salario ,
                        SUM(aItc.diastr) ,
                        SUM(aItc.incap - aItc.lic) AS incap ,
                        SUM(aItc.ausen) ,
                        ROUND(SUM([dbo].[CalculaCuotaImss](CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END,aItc.diastr,aItc.incap,0,@eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymArt106I, 0)),2) AS cuotaFija ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat1062, @eymTra1062)),2) AS excedente ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymPat1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @eymPat1062, @eymTra1062)),2) AS excedentePatron ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymTra1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @eymPat1062, @eymTra1062)),2) AS exccedenteTrabajador ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat107, @eymTra107)),2) AS prestacionesDinero ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymPat107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @eymPat107, @eymTra107)),2) AS prestacionesPatron ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymTra107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @eymPat107, @eymTra107)),2) AS prestacionesTrabajador ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat25, @eymTra25) END),2) AS gmp ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymPat25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @eymPat25, @eymTra25) END),2) AS gmpPatron ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymTra25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @eymPat25, @eymTra25) END),2) AS gmpTrabajador ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @prima_rt, 0)),2) AS rt ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivArt147,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @ivPat147, @ivTra147) END),2) AS invalidezVida ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivPat147,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @ivPat147, @ivTra147) END),2) AS invalidezVidaPatron ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivTra147,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @ivPat147, @ivTra147) END),2) AS invalidezVidaTrabajador ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @art211, 0)),2) AS guarderias ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,0                  ,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvPat168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezPatron ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvTra168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezTrabajador,
                        dbo.Llaves.clase,
                        ROUND(SUM(@salarioDF * (aItc.diastr - aItc.incap)),2),   -- baseCotizacionCuotaFija ,
                        ROUND(SUM(CASE WHEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) > ROUND(CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END * 3,2) THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) - ROUND(CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END * 3,2) ELSE 0 END * (aItc.diastr - aItc.incap)),2),    --baseCotizacionExc ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap)),2) ,  --baseCotizacionPD ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap)),2) ,  --baseCotizacionGMP ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionRT ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionIV ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionGPS 
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionCV 
                        dbo.clases.nombre,
						SUM(aItc.lic) AS lic
                FROM    ( ( dbo.empresas
                            INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                          )
                          LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                              AND conceptomarca.num_conc = 101
                        )
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa AND dbo.Llaves.clase = dbo.clases.clase
                WHERE   MONTH(aItc.fch_mov) = @mes
                        AND YEAR(aItc.fch_mov) = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND conceptomarca.num_conc = 101
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        
                GROUP BY dbo.empresas.empresa, dbo.Llaves.clase, dbo.clases.nombre
                ORDER BY dbo.Llaves.clase
                
                
                UPDATE cedulaMensual 
                SET cedulaMensual.registroPorClase = ISNULL((SELECT COUNT(DISTINCT dbo.Llaves.codigo) 
                                                             FROM dbo.Llaves 
                                                                  INNER JOIN dbo.empleados ON dbo.Llaves.empresa = dbo.empleados.empresa 
                                                                                              AND dbo.Llaves.codigo = dbo.empleados.codigo
                                                                  INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                                                                      AND dbo.empleados.codigo = aItc.codigo
                                                             WHERE dbo.Llaves.clase = cedulaMensual.clase
                                                                   AND MONTH(aItc.fch_mov) = @mes
                                                                   AND YEAR(aItc.fch_mov) = @ayo
                                                                   AND dbo.Llaves.empresa >= CASE WHEN @empresa = 0
                                                                                                  THEN 0
                                                                                                  ELSE @empresa
                                                                                             END
                                                                   AND dbo.Llaves.empresa <= CASE WHEN @empresa = 0
                                                                                                  THEN 9999
                                                                                                  ELSE @empresa
                                                                                             END
                                                                   AND dbo.empleados.cotiza_imss = 'S'
                                                                   AND dbo.empleados.borrado = 'N'
                                                                   AND dbo.Llaves.codigo >= CASE WHEN @codigo = 0
                                                                                                 THEN 0
                                                                                                 ELSE @codigo
                                                                                            END
                                                                   AND dbo.Llaves.codigo <= CASE WHEN @codigo = 0
                                                                                                 THEN 99999999
                                                                                                 ELSE @codigo
                                                                                            END
                                                                   AND aItc.horaProceso = @horaProceso
                                                                   AND aItc.fechaProceso = @fechaProceso
                                                                   AND aItc.proceso = @proceso
                                                             GROUP BY dbo.Llaves.clase),0),
                                                             
                    cedulaMensual.registroExc = ISNULL((SELECT COUNT(DISTINCT dbo.Llaves.codigo) 
                                                        FROM dbo.Llaves 
                                                             INNER JOIN dbo.empleados ON dbo.Llaves.empresa = dbo.empleados.empresa 
                                                                                         AND dbo.Llaves.codigo = dbo.empleados.codigo
                                                             INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                                                                 AND dbo.empleados.codigo = aItc.codigo
                                                        WHERE dbo.Llaves.clase = cedulaMensual.clase
                                                              AND MONTH(aItc.fch_mov) = @mes
                                                              AND YEAR(aItc.fch_mov) = @ayo
                                                              AND dbo.Llaves.empresa >= CASE WHEN @empresa = 0
                                                                                             THEN 0
                                                                                             ELSE @empresa
                                                                                        END
                                                              AND dbo.Llaves.empresa <= CASE WHEN @empresa = 0
                                                                                             THEN 9999
                                                                                             ELSE @empresa
                                                                                        END
                                                              AND dbo.empleados.cotiza_imss = 'S'
                                                              AND dbo.empleados.borrado = 'N'
                                                              AND dbo.Llaves.codigo >= CASE WHEN @codigo = 0
                                                                                            THEN 0
                                                                                            ELSE @codigo
                                                                                       END
                                                              AND dbo.Llaves.codigo <= CASE WHEN @codigo = 0
                                                                                            THEN 99999999
                                                                                            ELSE @codigo
                                                                                       END
                                                              AND aItc.saldiaint >= ROUND(CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END * 3,2)
                                                              AND aItc.horaProceso = @horaProceso
                                                              AND aItc.fechaProceso = @fechaProceso
                                                              AND aItc.proceso = @proceso
                                                        GROUP BY dbo.Llaves.clase),0)

                FROM @cedulaMensual AS cedulaMensual
                
                
                
      UPDATE cedulaMensual
      SET cedulaMensual.articulo106I = @eymArt106I,
          cedulaMensual.articulo106II = @eymArt1062,
          cedulaMensual.articulo107 = @eymArt107,
          cedulaMensual.articulo25 = @eymArt25,
          cedulaMensual.articulo71 = @prima_rt,
          cedulaMensual.articulo147 = @ivArt147,
          cedulaMensual.articulo211 = @art211 
          --cedulaMensual.infonavit = @infonavit
     FROM @cedulaMensual AS cedulaMensual
     WHERE cedulaMensual.clase = (SELECT TOP 1 cedulaMensual2.clase 
                                    FROM @cedulaMensual AS cedulaMensual2)
RETURN
END
-- Cuota Fija   106 I
-- Exec.        106 II
-- Pd.          107
-- Gmp          25
-- RT           71
-- Iv           147
-- Gps          211
GO

/**************************************************************************************************
 * Name          : LlenaResumenClaseBimestre
 * Project       : APSI Nomina
 * Description   : Llena tabla con los resumen de cuotas obrero-patron del bimestre
 * Table name    : empresa, empleados, deducciones
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'LlenaResumenClaseBimestre' ) 
    BEGIN
        DROP  FUNCTION [dbo].[LlenaResumenClaseBimestre]
    END
GO

CREATE FUNCTION [dbo].[LlenaResumenClaseBimestre]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250) ,
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT,
	  @filtroInfonavit INT  -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
    )
RETURNS @cedulaBimestral TABLE
    (
      empresa INT NOT NULL
                  DEFAULT 0 ,
      diastr INT NOT NULL
                 DEFAULT 0 ,
      incap INT NOT NULL
                DEFAULT 0 ,
      ausen FLOAT NOT NULL
                  DEFAULT 0 ,
      retiro FLOAT NOT NULL
                   DEFAULT 0 ,
      cesantiaVejez FLOAT NOT NULL
                          DEFAULT 0 ,
      cesantiaVejezPatron FLOAT NOT NULL
                                DEFAULT 0 ,
      cesantiaVejezTrabajador FLOAT NOT NULL
                                    DEFAULT 0 ,
      aportacionInfonavit FLOAT NOT NULL
                                DEFAULT 0 ,
      amortizacion FLOAT NOT NULL
                         DEFAULT 0 ,
      seguroVivienda FLOAT NOT NULL
                           DEFAULT 0 ,
      infonavitSinCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      infonavitConCredito FLOAT NOT NULL
                                DEFAULT 0 ,
      clase VARCHAR(2) COLLATE database_default,
      baseCotizacionRetiro FLOAT,
      baseCotizacionCV FLOAT,
      baseCotizacionAportacionSinCredito FLOAT,
      baseCotizacionAportacionConCredito FLOAT,
      casos INT,
      casosSinCredito INT,
      casosConCredito INT,
      articulo168I FLOAT,
      articulo168II FLOAT ,
      articulo29 FLOAT ,
      seguroDesempleoPorciento FLOAT ,
      seguroDesempleoCuota FLOAT,
      nombreClase VARCHAR(20),
      lic INT NOT NULL
                DEFAULT 0 
    )
AS 
    BEGIN
        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @seguroDesempleoPorciento FLOAT
        DECLARE @fechaAplicaUMA DATETIME
        DECLARE @FechaFinita DATETIME

        SET @FechaFinita = '29991231'
        
        SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
        
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar 
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE 
            BEGIN
                SET @esBimestre = 'N'
            END
    
    
-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion    
    

-- Obtiene Primas IMSS
        SELECT  @retiro = primasImss.cvArt168I , --dbo.primas_imss.retiro ,
                @cvArt168II = primasImss.cvArt168II ,
                @cvPat168II = primasImss.cvPat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.cvtra168ii ELSE 0 END ,
                @cvTra168II = primasImss.cvTra168II , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE dbo.primas_imss.cvtra168ii END ,
                @infonavit = primasImss.infonavitPorciento , --dbo.primas_imss.infonavit ,
                @seguroDesempleoPorciento = primasImss.seguroDesempleoPorciento  --dbo.primas_imss.seguroDesempleo
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss
        --WHERE   YEAR(dbo.primas_imss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END    
                                                
                                                
                                                
-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = variable1
        FROM    conceptos
        WHERE   empresa = @empresa
                AND num_conc = 112                                                
    

        --SET @seguroVivienda = CASE WHEN YEAR(@fiNon) >= 2006
        --                                AND YEAR(@fiNon) <= 2008 THEN 8
        --                           WHEN YEAR(@fiNon) >= 2009 THEN 13
        --                           ELSE 0
        --                      END
        
        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END
        

    
-- Registro Avisos
        INSERT  @cedulaBimestral
                ( empresa ,
                  clase,
                  diastr ,
                  incap ,
                  ausen ,
                  retiro ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  aportacionInfonavit ,
                  infonavitSinCredito ,
                  infonavitConCredito ,
                  amortizacion,
                  seguroVivienda,
                  baseCotizacionRetiro ,
                  baseCotizacionCV ,
                  baseCotizacionAportacionSinCredito ,
                  baseCotizacionAportacionConCredito,
                  casos,
                  casosSinCredito,
                  casosConCredito ,
                  seguroDesempleoCuota,
                  nombreClase,
				  lic
                )
                SELECT  dbo.empleados.empresa ,
                        dbo.Llaves.clase,
                        SUM(aItc.diastr) AS diasTr ,
                        SUM(aItc.incap - aItc.lic) AS incap ,
                        SUM(aItc.ausen) AS ausen ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @retiro, 0)),2) AS retiro ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvPat168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezPatron ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvTra168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0)),2) AS aportacionInfonavit,
                        ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion IS NULL THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitSinCredito,
                        ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion >= 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitConCredito,
                        0,
                        0,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.ausen)),2) AS baseCotizacionRetiro,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV,
                        ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion IS NULL THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.ausen) ELSE 0 END),2) AS baseCotizacionAportacionSinCredito,
                        ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion >= 0 THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.ausen) ELSE 0 END),2) AS baseCotizacionAportacionConCredito,
                        0,
                        0,
                        0,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@seguroDesempleoPorciento, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @seguroDesempleoPorciento, 0)),2) AS seguroDesempleo,
                        clase.nombre,
						SUM(aItc.lic) AS lic 
                FROM    dbo.empresas
                        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                            AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa 
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro 
                                                  AND dbo.Llaves.empresa = dbo.centros.empresa
                        LEFT JOIN dbo.TemporalAmortizacion ON aItc.empresa = dbo.TemporalAmortizacion.empresa 
                                                              AND aItc.codigo = dbo.TemporalAmortizacion.codigo
                        INNER JOIN dbo.clases AS clase ON LTRIM(RTRIM(dbo.Llaves.clase)) = LTRIM(RTRIM(clase.clase))
                                                          AND dbo.Llaves.empresa = clase.empresa

                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = dbo.empleados.empresa
				                           AND i.codigo = dbo.empleados.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                WHERE   aItc.mes_operacion >= @mesNon 
                        AND aItc.mes_operacion <= @mesPar 
                        AND aItc.ayo_operacion = @ayo 
                        AND dbo.empleados.cotiza_imss = 'S' 
                        AND dbo.empleados.borrado = 'N' 
                        AND aItc.empresa >= CASE WHEN @empresa = 0 
                                                 THEN 0 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.empresa <= CASE WHEN @empresa = 0 
                                                 THEN 9999 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.codigo >= CASE WHEN @codigo = 0 
                                                THEN 0 
                                                ELSE @codigo 
                                           END 
                        AND aItc.codigo <= CASE WHEN @codigo = 0 
                                                THEN 99999999 
                                                ELSE @codigo 
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

                GROUP BY dbo.empleados.empresa, 
                        dbo.Llaves.clase,
                        clase.nombre
                
                
                
                UPDATE cedulaBimestre 
                SET cedulaBimestre.amortizacion = ISNULL((SELECT SUM(dbo.TemporalAmortizacion.amortizacion)
                                                          FROM dbo.TemporalAmortizacion
                                                          WHERE dbo.TemporalAmortizacion.empresa = @empresa
                                                                AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase),0),
                                                         
                    cedulaBimestre.seguroVivienda = @seguroVivienda * ISNULL((SELECT COUNT(*)
                                                                              FROM dbo.TemporalAmortizacion
                                                                              WHERE dbo.TemporalAmortizacion.empresa = @empresa
                                                                                    AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase
                                                                                    AND dbo.TemporalAmortizacion.amortizacion > 0),0)
                FROM @cedulaBimestral AS cedulaBimestre
                
                UPDATE cedulaBimestre
                SET cedulaBimestre.casos = (SELECT COUNT(DISTINCT dbo.Llaves.codigo)
                                            FROM dbo.Llaves
                                                 INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.Llaves.empresa = aItc.empresa 
                                                                                                     AND dbo.Llaves.codigo = aItc.codigo
                                                 INNER JOIN dbo.empleados ON aItc.empresa = dbo.empleados.empresa 
                                                                             AND aItc.codigo = dbo.empleados.codigo

                                                 OUTER APPLY (SELECT TOP 1
                                                                     'Si' AS TieneCredito
                                                              FROM dbo.infonavit AS i
                                                              WHERE i.empresa = dbo.empleados.empresa
                                                                    AND i.codigo = dbo.empleados.codigo
                                                                    AND i.fecha <= @ffPar
                                                                    AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
                                                                    AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                                            WHERE   aItc.mes_operacion >= @mesNon 
                                                    AND aItc.mes_operacion <= @mesPar 
                                                    AND aItc.ayo_operacion = @ayo 
                                                    AND dbo.empleados.cotiza_imss = 'S' 
                                                    AND dbo.empleados.borrado = 'N' 
                                                    AND aItc.empresa >= CASE WHEN @empresa = 0 
                                                                             THEN 0 
                                                                             ELSE @empresa 
                                                                        END 
                                                    AND aItc.empresa <= CASE WHEN @empresa = 0 
                                                                             THEN 9999 
                                                                             ELSE @empresa 
                                                                        END 
                                                    AND aItc.codigo >= CASE WHEN @codigo = 0 
                                                                            THEN 0 
                                                                            ELSE @codigo 
                                                                       END 
                                                    AND aItc.codigo <= CASE WHEN @codigo = 0 
                                                                            THEN 99999999 
                                                                            ELSE @codigo 
                                                                       END
                                                    AND dbo.Llaves.clase = cedulaBimestre.clase
                                                    AND aItc.horaProceso = @horaProceso
                                                    AND aItc.fechaProceso = @fechaProceso
                                                    AND aItc.proceso = @proceso

                                                    AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                                              WHEN 2 THEN 'Si'
                                                                              WHEN 3 THEN 'No'
                                                                              ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

								           ) ,
                                                    
                    cedulaBimestre.casosConCredito = (SELECT COUNT(*)
                                                      FROM dbo.TemporalAmortizacion
                                                      WHERE dbo.TemporalAmortizacion.empresa = cedulaBimestre.empresa
                                                            AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase)
                                                           
                FROM @cedulaBimestral AS cedulaBimestre
                WHERE cedulaBimestre.empresa = @empresa
                
                UPDATE cedulaBimestre 
                SET cedulaBimestre.casosSinCredito = cedulaBimestre.casos - cedulaBimestre.casosConCredito
                FROM @cedulaBimestral AS cedulaBimestre
                WHERE cedulaBimestre.empresa = @empresa
                

                UPDATE cedulaBimestre
                SET [cedulaBimestre].articulo168I = @retiro,
                    [cedulaBimestre].articulo168II = @cvArt168II,
                    [cedulaBimestre].articulo29 = @infonavit ,
                    [cedulaBimestre].seguroDesempleoPorciento = @seguroDesempleoPorciento
                FROM @cedulaBimestral AS cedulaBimestre
                WHERE [cedulaBimestre].clase = (SELECT TOP 1 [cedulaBimestre].clase 
                                               FROM @cedulaBimestral AS cedulaBimestre)
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaResumenClaseInfonavit
 * Project       : APSI Nomina
 * Description   : Prepara el resumen por clase de empleado
 * Table name    : avisos_imss, llaves
 * Return        : tabla con el resumen
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Agosto 19, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.LlenaResumenClaseInfonavit') IS NOT NULL
   DROP FUNCTION dbo.LlenaResumenClaseInfonavit
GO

CREATE FUNCTION dbo.LlenaResumenClaseInfonavit(
@empresa NUMERIC(5),
@codigo NUMERIC(8, 0),
@ayo INT,
@mes INT,
@proceso VARCHAR(250),
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8) ,
@simulaReforma INT
    )

RETURNS @cedulaMensual TABLE
    (
      salario FLOAT NULL ,
      diastr INT NULL ,
      incap INT NULL ,
      ausen FLOAT NULL ,
      cuotaFija FLOAT NULL ,
      excedente FLOAT NULL ,
      excedentePatron FLOAT NULL ,
      exccedenteTrabajador FLOAT NULL ,
      prestacionesDinero FLOAT NULL ,
      prestacionesPatron FLOAT NULL ,
      prestacionesTrabajador FLOAT NULL ,
      gmp FLOAT NULL ,
      gmpPatron FLOAT NULL ,
      gmpTrabajador FLOAT NULL ,
      rt FLOAT NULL ,
      invalidezVida FLOAT NULL ,
      invalidezVidaPatron FLOAT NULL ,
      invalidezVidaTrabajador FLOAT NULL ,
      guarderias FLOAT NULL ,
      cesantiaVejez FLOAT NULL ,
      cesantiaVejezPatron FLOAT NULL ,
      cesantiaVejezTrabajador FLOAT NULL,
      clase VARCHAR(2) COLLATE database_default NULL,
      registroPorClase INT NULL,
      registroExc INT NULL,
      baseCotizacionCuotaFija FLOAT,
      baseCotizacionExc FLOAT,
      baseCotizacionPD FLOAT,
      baseCotizacionGMP FLOAT,
      baseCotizacionRT FLOAT,
      baseCotizacionIV FLOAT,
      baseCotizacionGPS FLOAT,
      baseCotizacionCV FLOAT,
      nombreClase VARCHAR(20) COLLATE database_default,
      articulo106I FLOAT,
      articulo106II FLOAT,
      articulo107 FLOAT,
      articulo25 FLOAT,
      articulo71 FLOAT,
      articulo147 FLOAT,
      articulo211 FLOAT,
      infonavit FLOAT,
      infonavitSinCredito FLOAT,
      infonavitConCredito FLOAT,
      sinCreditado INT,
      conCreditado INT,
      seguroVivienda FLOAT,
      amortizacion FLOAT,
      baseCotizacionInfonavitSin FLOAT,
      baseCotizacionInfonavitCon FLOAT,
      articulo168II FLOAT,
      diasCotizadosSin INT,
      diasCotizadosCon INT
    )
    
AS 
    BEGIN

        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @fi DATETIME
        DECLARE @ff DATETIME
        DECLARE @prima_rt FLOAT
        DECLARE @ayoEmpresa INT
        DECLARE @diasFaltaTope INT
        DECLARE @infonavit FLOAT
        DECLARE @art211 FLOAT
        DECLARE @seguroVivienda INT

        SET @diasFaltaTope = 7
        SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
        SET @ff = dbo.fin_mes(@mes, @ayo)


-- Obtiene Area Geografica
        SELECT  @areaGeografica = empresa.zona_geografica ,
                @patronPagaIMSS = empresa.patron_paga_cuotas_imss ,
                @ayoEmpresa = empresa.ayo_operacion
        FROM    dbo.empresas AS empresa
        WHERE   empresa.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion
                    

-- Obtiene Primas IMSS
        SELECT  @eymArt25 = primasImss.eymart25 ,
                @eymPat25 = primasImss.eympat25 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra25 ELSE 0 END ,
                @eymTra25 = primasImss.eymtra25 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra25 END ,
                @eymArt106I = primasImss.eymart106I ,
                @eymArt1062 = primasImss.eymart1062 ,
                @eymPat1062 = primasImss.eympat1062 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra1062 ELSE 0 END ,
                @eymTra1062 = primasImss.eymtra1062 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra1062 END ,
                @eymArt107 = primasImss.eymart107 ,
                @eymPat107 = primasImss.eympat107 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.eymtra107 ELSE 0 END ,
                @eymTra107 = primasImss.eymtra107 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.eymtra107 END ,
                @ivArt147 = primasImss.ivart147 ,
                @ivPat147 = primasImss.ivpat147 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.ivtra147 ELSE 0 END ,
                @ivTra147 = primasImss.ivtra147 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.ivtra147 END ,
                @retiro = primasImss.cvArt168I ,
                @cvArt168II = primasImss.cvart168II ,
                @cvPat168II = primasImss.cvpat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
                @cvTra168II = primasImss.cvtra168ii , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
                @infonavit = primasImss.infonavit ,
                @art211 = primasImss.art211
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss AS primasImss
        --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END

-- Obtiene Prima RT
        SELECT  @prima_rt = primaRt.prima_rt
        FROM    dbo.primas_rt AS primaRt
        WHERE   primaRt.empresa = @empresa
                AND primaRt.fecha_inicial <= @fi
                AND primaRt.fecha_final >= @ff

-- Seguro vivienda                
        SET @seguroVivienda = CASE WHEN @fi >= CONVERT(DATETIME, '20060101') AND @ff <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fi >= CONVERT(DATETIME, '20090101') AND @ff <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fi >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END

-- Prima Guarderias
        --SET @primaGuarderia = 1

        INSERT  @cedulaMensual
                ( salario ,
                  diastr ,
                  incap ,
                  ausen ,
                  cuotaFija ,
                  excedente ,
                  excedentePatron ,
                  exccedenteTrabajador ,
                  prestacionesDinero ,
                  prestacionesPatron ,
                  prestacionesTrabajador ,
                  gmp ,
                  gmpPatron ,
                  gmpTrabajador ,
                  rt ,
                  invalidezVida ,
                  invalidezVidaPatron ,
                  invalidezVidaTrabajador ,
                  guarderias ,
                  cesantiaVejez ,
                  cesantiaVejezPatron ,
                  cesantiaVejezTrabajador ,
                  clase,
                  baseCotizacionCuotaFija ,
                  baseCotizacionExc ,
                  baseCotizacionPD ,
                  baseCotizacionGMP ,
                  baseCotizacionRT ,
                  baseCotizacionIV ,
                  baseCotizacionGPS ,
                  baseCotizacionCV,
                  nombreClase,
                  infonavitSinCredito,
                  infonavitConCredito,
                  sinCreditado,
                  conCreditado,
                  seguroVivienda,
                  amortizacion,
                  baseCotizacionInfonavitSin,
                  baseCotizacionInfonavitCon,
                  diasCotizadosSin,
                  diasCotizadosCon
                )
                SELECT  ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint, @topeDF, @topeRegion, dbo.empleados.art39, aItc.mov)),2) AS salario ,
                        SUM(aItc.diastr) ,
                        SUM(aItc.incap) ,
                        SUM(aItc.ausen) ,
                        ROUND(SUM([dbo].[CalculaCuotaImss](@salarioDF,aItc.diastr,aItc.incap,0,@eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymArt106I, 0)),2) AS cuotaFija ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat1062, @eymTra1062)),2) AS excedente ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymPat1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @eymPat1062, @eymTra1062)),2) AS excedentePatron ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymTra1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @eymPat1062, @eymTra1062)),2) AS exccedenteTrabajador ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat107, @eymTra107)),2) AS prestacionesDinero ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymPat107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @eymPat107, @eymTra107)),2) AS prestacionesPatron ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymTra107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @eymPat107, @eymTra107)),2) AS prestacionesTrabajador ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat25, @eymTra25) END),2) AS gmp ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymPat25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @eymPat25, @eymTra25) END),2) AS gmpPatron ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymTra25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @eymPat25, @eymTra25) END),2) AS gmpTrabajador ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @prima_rt, 0)),2) AS rt ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivArt147,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @ivPat147, @ivTra147) END),2) AS invalidezVida ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivPat147,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @ivPat147, @ivTra147) END),2) AS invalidezVidaPatron ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivTra147,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @ivPat147, @ivTra147) END),2) AS invalidezVidaTrabajador ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @art211, 0)),2) AS guarderias ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0                  ,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0                  ,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvPat168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezPatron ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0                  ,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvTra168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezTrabajador,
                        dbo.Llaves.clase,
                        ROUND(SUM(@salarioDF * (aItc.diastr - aItc.incap)),2),   -- baseCotizacionCuotaFija ,
                        ROUND(SUM(CASE WHEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov) > ROUND(@salarioDF * 3,2) THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov) - ROUND(@salarioDF * 3,2) ELSE 0 END * (aItc.diastr - aItc.incap)),2),    --baseCotizacionExc ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap)),2) ,  --baseCotizacionPD ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap)),2) ,  --baseCotizacionGMP ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionRT ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionIV ,
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionGPS 
                        ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0                  ,aItc.mov) * (aItc.diastr - aItc.incap - aItc.ausen)),2) ,  --baseCotizacionCV 
                        dbo.clases.nombre,
                        ROUND(SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0,aItc.sueldo,aItc.fch_mov,@simulaReforma,@salarioRegion,0,@infonavit,0) ELSE 0 END),2) AS infonavitSinCredito,
                        ROUND(SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF, @topeRegion, 0, aItc.mov), aItc.diastr, 0, aItc.ausen, @infonavit , 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit , 0) END),2) AS infonavitConCredito,
                        SUM(CASE WHEN aItc.serial = 1 THEN CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 1 ELSE 0 END ELSE 0 END) AS sinCreditado,
                        SUM(CASE WHEN aItc.serial = 1 THEN CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 0 ELSE 1 END ELSE 0 END) AS conCreditado,
                        SUM(CASE WHEN aItc.serial = 1 THEN CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 0 ELSE @seguroVivienda END ELSE 0 END) AS seguroVivienda,
                        SUM(CASE WHEN aItc.serial = 1 THEN ISNULL(ta.amortizacion,0) ELSE 0 END) AS amortizacion,
                        ROUND(SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0,aItc.mov) * (aItc.diastr - 0 - aItc.ausen) ELSE 0 END),2), --baseCotizacionInfonavitSin
                        ROUND(SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 0 Else [dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0,aItc.mov) * (aItc.diastr - 0 - aItc.ausen) END),2), --baseCotizacionInfonavitCon
                        SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN (aItc.diastr - 0 - aItc.ausen) ELSE 0 END),
                        SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 0 Else (aItc.diastr - 0 - aItc.ausen) END)
                FROM    ( ( dbo.empresas
                            INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                          )
                          LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                              AND conceptomarca.num_conc = 101
                        )
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo
                        INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                 AND dbo.empleados.codigo = dbo.Llaves.codigo
                        INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa AND dbo.Llaves.clase = dbo.clases.clase
                        LEFT JOIN dbo.TemporalAmortizacion AS ta ON dbo.Llaves.clase = ta.clase AND aItc.codigo = ta.codigo AND aItc.empresa = ta.empresa
                WHERE   MONTH(aItc.fch_mov) = @mes
                        AND YEAR(aItc.fch_mov) = @ayo
                        AND aItc.empresa >= CASE WHEN @empresa = 0
                                                 THEN 0
                                                 ELSE @empresa
                                            END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND conceptomarca.num_conc = 101
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.codigo >= CASE WHEN @codigo = 0
                                                THEN 0
                                                ELSE @codigo
                                           END
                        AND aItc.codigo <= CASE WHEN @codigo = 0
                                                THEN 99999999
                                                ELSE @codigo
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        
                GROUP BY dbo.empresas.empresa, dbo.Llaves.clase, dbo.clases.nombre
                ORDER BY dbo.Llaves.clase
                
                
                UPDATE cedulaMensual 
                SET cedulaMensual.registroPorClase = ISNULL((SELECT COUNT(DISTINCT dbo.Llaves.codigo) 
                                                             FROM dbo.Llaves 
                                                                  INNER JOIN dbo.empleados ON dbo.Llaves.empresa = dbo.empleados.empresa 
                                                                                              AND dbo.Llaves.codigo = dbo.empleados.codigo
                                                                  INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                                                                      AND dbo.empleados.codigo = aItc.codigo
                                                             WHERE dbo.Llaves.clase = cedulaMensual.clase
                                                                   AND MONTH(aItc.fch_mov) = @mes
                                                                   AND YEAR(aItc.fch_mov) = @ayo
                                                                   AND dbo.Llaves.empresa >= CASE WHEN @empresa = 0
                                                                                                  THEN 0
                                                                                                  ELSE @empresa
                                                                                             END
                                                                   AND dbo.Llaves.empresa <= CASE WHEN @empresa = 0
                                                                                                  THEN 9999
                                                                                                  ELSE @empresa
                                                                                             END
                                                                   AND dbo.empleados.cotiza_imss = 'S'
                                                                   AND dbo.empleados.borrado = 'N'
                                                                   AND dbo.Llaves.codigo >= CASE WHEN @codigo = 0
                                                                                                 THEN 0
                                                                                                 ELSE @codigo
                                                                                            END
                                                                   AND dbo.Llaves.codigo <= CASE WHEN @codigo = 0
                                                                                                 THEN 99999999
                                                                                                 ELSE @codigo
                                                                                            END
                                                                   AND aItc.horaProceso = @horaProceso
                                                                   AND aItc.fechaProceso = @fechaProceso
                                                                   AND aItc.proceso = @proceso
                                                             GROUP BY dbo.Llaves.clase),0),
                                                             
                    cedulaMensual.registroExc = ISNULL((SELECT COUNT(DISTINCT dbo.Llaves.codigo) 
                                                        FROM dbo.Llaves 
                                                             INNER JOIN dbo.empleados ON dbo.Llaves.empresa = dbo.empleados.empresa 
                                                                                         AND dbo.Llaves.codigo = dbo.empleados.codigo
                                                             INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa 
                                                                                                                 AND dbo.empleados.codigo = aItc.codigo
                                                        WHERE dbo.Llaves.clase = cedulaMensual.clase
                                                              AND MONTH(aItc.fch_mov) = @mes
                                                              AND YEAR(aItc.fch_mov) = @ayo
                                                              AND dbo.Llaves.empresa >= CASE WHEN @empresa = 0
                                                                                             THEN 0
                                                                                             ELSE @empresa
                                                                                        END
                                                              AND dbo.Llaves.empresa <= CASE WHEN @empresa = 0
                                                                                             THEN 9999
                                                                                             ELSE @empresa
                                                                                        END
                                                              AND dbo.empleados.cotiza_imss = 'S'
                                                              AND dbo.empleados.borrado = 'N'
                                                              AND dbo.Llaves.codigo >= CASE WHEN @codigo = 0
                                                                                            THEN 0
                                                                                            ELSE @codigo
                                                                                       END
                                                              AND dbo.Llaves.codigo <= CASE WHEN @codigo = 0
                                                                                            THEN 99999999
                                                                                            ELSE @codigo
                                                                                       END
                                                              AND aItc.saldiaint >= ROUND(@salarioDF * 3,2)
                                                              AND aItc.horaProceso = @horaProceso
                                                              AND aItc.fechaProceso = @fechaProceso
                                                              AND aItc.proceso = @proceso
                                                        GROUP BY dbo.Llaves.clase),0)

                FROM @cedulaMensual AS cedulaMensual
                
                
                
      UPDATE cedulaMensual
      SET cedulaMensual.articulo106I = @eymArt106I,
          cedulaMensual.articulo106II = @eymArt1062,
          cedulaMensual.articulo107 = @eymArt107,
          cedulaMensual.articulo25 = @eymArt25,
          cedulaMensual.articulo71 = @prima_rt,
          cedulaMensual.articulo147 = @ivArt147,
          cedulaMensual.articulo211 = @art211, 
          cedulaMensual.infonavit = @infonavit,
          cedulaMensual.articulo168II = @cvArt168II
     FROM @cedulaMensual AS cedulaMensual
     WHERE cedulaMensual.clase = (SELECT TOP 1 cedulaMensual2.clase 
                                    FROM @cedulaMensual AS cedulaMensual2)
RETURN
END
-- Cuota Fija   106 I
-- Exec.        106 II
-- Pd.          107
-- Gmp          25
-- RT           71
-- Iv           147
-- Gps          211
GO

/**************************************************************************************************
 * Name          : LlenaTotalCuotaImss
 * Project       : APSI Nomina
 * Description   : Prepara el resumen por clase de empleado
 * Table name    : avisos_imss, llaves
 * Return        : tabla con el total cuotas imss
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Septiembre 14, 2010
 **************************************************************************************************/

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'TF'
--                    AND name = 'LlenaTotalCuotaImss' ) 
--    BEGIN
--        DROP  FUNCTION [dbo].[LlenaTotalCuotaImss]
--    END
IF OBJECT_ID('dbo.LlenaTotalCuotaImss') IS NOT NULL
   DROP FUNCTION dbo.LlenaTotalCuotaImss
GO

CREATE FUNCTION [dbo].[LlenaTotalCuotaImss](
@empresa NUMERIC(5) ,
@codigo NUMERIC(8, 0) ,
@ayo INT ,
@mes INT ,
@porRenglon INT ,
@proceso VARCHAR(250),
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8) ,
@simulaReforma INT
)

-- @porRenglon = 0.- Es un registro por cada prima IMSS
--               1.- Es un solo registro y en cada columna su cuota IMSS correspondiente

RETURNS @cedulaMensual TABLE
    (
      salario FLOAT NULL ,
      diastr INT NULL ,
      incap INT NULL ,
      ausen DECIMAL(5, 2) NULL ,
      cuotaFija FLOAT NULL ,
      excedente FLOAT NULL ,
      excedentePatron FLOAT NULL ,
      exccedenteTrabajador FLOAT NULL ,
      prestacionesDinero FLOAT NULL ,
      prestacionesPatron FLOAT NULL ,
      prestacionesTrabajador FLOAT NULL ,
      gmp FLOAT NULL ,
      gmpPatron FLOAT NULL ,
      gmpTrabajador FLOAT NULL ,
      rt FLOAT NULL ,
      invalidezVida FLOAT NULL ,
      invalidezVidaPatron FLOAT NULL ,
      invalidezVidaTrabajador FLOAT NULL ,
      guarderias FLOAT NULL ,
      cesantiaVejez FLOAT NULL ,
      cesantiaVejezPatron FLOAT NULL ,
      cesantiaVejezTrabajador FLOAT NULL,
      clase VARCHAR(2) COLLATE database_default,
      registroPorClase INT NULL,
      registroExc INT NULL,
      baseCotizacionCuotaFija FLOAT,
      baseCotizacionExc FLOAT,
      baseCotizacionPD FLOAT,
      baseCotizacionGMP FLOAT,
      baseCotizacionRT FLOAT,
      baseCotizacionIV FLOAT,
      baseCotizacionGPS FLOAT,
      baseCotizacionCV FLOAT,
      nombreClase VARCHAR(20) COLLATE database_default,
      articulo106I FLOAT,
      articulo106II FLOAT,
      articulo107 FLOAT,
      articulo25 FLOAT,
      articulo71 FLOAT,
      articulo147 FLOAT,
      articulo211 FLOAT,
      nombrePrimaImss VARCHAR(50) COLLATE database_default,
      cuotaPrimaImss FLOAT
    )
    
AS 
    BEGIN
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @fi DATETIME
        DECLARE @ff DATETIME
        DECLARE @prima_rt FLOAT
        DECLARE @ayoEmpresa INT
        --DECLARE @primaGuarderia FLOAT
        DECLARE @diasFaltaTope INT
        DECLARE @cuotaFija FLOAT
        DECLARE @excedente FLOAT
        DECLARE @prestacionesDinero FLOAT
        DECLARE @gmp FLOAT
        DECLARE @rt FLOAT
        DECLARE @invalidezVida FLOAT
        DECLARE @guarderias FLOAT
        DECLARE @cesantiaVejez FLOAT
        DECLARE @art211 FLOAT
        DECLARE @mesPago CHAR(6)
        DECLARE @mesAplicaUMA CHAR(6)
        
        SET @mesPago = RIGHT(STR(@ayo),4) + RIGHT(STR(100 + @mes),2)
        SET @mesAplicaUMA = '201701'

        SET @diasFaltaTope = 7


        SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
        SET @ff = dbo.fin_mes(@mes, @ayo)


-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion
                    

-- Obtiene Primas IMSS
        SELECT  @eymArt25 = primasImss.eymArt25 ,
                @eymPat25 = primasImss.eymPat25 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.eymtra25 ELSE 0 END ,
                @eymTra25 = primasImss.eymTra25 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE dbo.primas_imss.eymtra25 END ,
                @eymArt106I = primasImss.eymArt106I ,
                @eymArt1062 = primasImss.eymArt1062 ,
                @eymPat1062 = primasImss.eymPat1062 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.eymtra1062 ELSE 0 END ,
                @eymTra1062 = primasImss.eymTra1062 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE dbo.primas_imss.eymtra1062 END ,
                @eymArt107 = primasImss.eymArt107 ,
                @eymPat107 = primasImss.eymPat107 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.eymtra107 ELSE 0 END ,
                @eymTra107 = primasImss.eymTra107 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE dbo.primas_imss.eymtra107 END ,
                @ivArt147 = primasImss.ivArt147 ,
                @ivPat147 = primasImss.ivPat147 , --+ CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.ivtra147 ELSE 0 END ,
                @ivTra147 = primasImss.ivTra147 , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE dbo.primas_imss.ivtra147 END ,
                @retiro = primasImss.cvArt168I ,
                @cvArt168II = primasImss.cvArt168II ,
                @cvPat168II = primasImss.cvPat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.cvtra168ii ELSE 0 END ,
                @cvTra168II = primasImss.cvTra168ii , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE dbo.primas_imss.cvtra168ii END ,
                @art211 = primasImss.art211
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss
        --WHERE   YEAR(dbo.primas_imss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END


-- Obtiene Prima RT
        SELECT  @prima_rt = dbo.primas_rt.prima_rt
        FROM    dbo.primas_rt
        WHERE   dbo.primas_rt.empresa = @empresa
                AND dbo.primas_rt.fecha_inicial <= @fi
                AND dbo.primas_rt.fecha_final >= @ff


-- Prima Guarderias
        --SET @primaGuarderia = 1

        --IF @porRenglon = 1
        --   BEGIN
             INSERT  @cedulaMensual
                     ( --salario ,
                       --diastr ,
                       --incap ,
                       --ausen ,
                       cuotaFija ,
                       excedente ,
                       --excedentePatron ,
                       --exccedenteTrabajador ,
                       prestacionesDinero ,
                       --prestacionesPatron ,
                       --prestacionesTrabajador ,
                       gmp ,
                       --gmpPatron ,
                       --gmpTrabajador ,
                       rt ,
                       invalidezVida ,
                       --invalidezVidaPatron ,
                       --invalidezVidaTrabajador ,
                       guarderias ,
                       cesantiaVejez --,
                       --cesantiaVejezPatron ,
                       --cesantiaVejezTrabajador ,
                       --clase,
                       --baseCotizacionCuotaFija ,
                       --baseCotizacionExc ,
                       --baseCotizacionPD ,
                       --baseCotizacionGMP ,
                       --baseCotizacionRT ,
                       --baseCotizacionIV ,
                       --baseCotizacionGPS ,
                       --baseCotizacionCV,
                       --nombreClase
                     )
                     SELECT  --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint, @topeDF, @topeRegion, dbo.empleados.art39, dbo.avisos_imss.mov)),2) AS salario ,
                             --SUM(dbo.avisos_imss.diastr) ,
                             --SUM(dbo.avisos_imss.incap) ,
                             --SUM(dbo.avisos_imss.ausen) ,
                             ROUND(SUM([dbo].[CalculaCuotaImss](CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END,aItc.diastr,aItc.incap,0,@eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymArt106I, 0)),2) AS cuotaFija ,
                             ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat1062, @eymTra1062)),2) AS excedente ,
                             --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,0,@eymPat1062, 'S', @salarioDF)),2) AS excedentePatron ,
                             --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,0,@eymTra1062, 'S', @salarioDF)),2) AS exccedenteTrabajador ,
                             ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat107, @eymTra107)),2) AS prestacionesDinero ,
                             --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,0,@eymPat107, 'N', 0)),2) AS prestacionesPatron ,
                             --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,0,@eymTra107, 'N', 0)),2) AS prestacionesTrabajador ,
                             ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat25, @eymTra25) END),2) AS gmp ,
                             --ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,0,@eymPat25, 'N',0) END),2) AS gmpPatron ,
                             --ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,0,@eymTra25, 'N',0) END),2) AS gmpTrabajador ,
                             ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @prima_rt, 0)),2) AS rt ,
                             ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivArt147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @ivPat147, @ivTra147) END),2) AS invalidezVida ,
                             --ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@ivPat147,'N',0) END),2) AS invalidezVidaPatron ,
                             --ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@ivTra147,'N',0) END),2) AS invalidezVidaTrabajador ,
                             ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @art211, 0)),2) AS guarderias ,
                             ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,0,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez --,
                             --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@cvPat168II,'N',0)),2) AS cesantiaVejezPatron ,
                             --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@cvTra168II,'N',0)),2) AS cesantiaVejezTrabajador,
                             --dbo.Llaves.clase,
                             --ROUND(SUM(@salarioDF * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap)),2),   -- baseCotizacionCuotaFija ,
                             --ROUND(SUM(CASE WHEN [dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) > ROUND(@salarioDF * 3,2) THEN [dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) - ROUND(@salarioDF * 3,2) ELSE 0 END * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap)),2),    --baseCotizacionExc ,
                             --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap)),2) ,  --baseCotizacionPD ,
                             --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap)),2) ,  --baseCotizacionGMP ,
                             --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap - dbo.avisos_imss.ausen)),2) ,  --baseCotizacionRT ,
                             --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap - dbo.avisos_imss.ausen)),2) ,  --baseCotizacionIV ,
                             --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap - dbo.avisos_imss.ausen)),2) ,  --baseCotizacionGPS 
                             --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.incap - dbo.avisos_imss.ausen)),2) ,  --baseCotizacionCV 
                             --dbo.clases.nombre
                     FROM    ( ( dbo.empresas
                               INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                                )
                               LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                                           AND conceptomarca.num_conc = 101
                             )
                             INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                           AND dbo.empleados.codigo = aItc.codigo
                             --INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                             --                         AND dbo.empleados.codigo = dbo.Llaves.codigo
                             --INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa AND dbo.Llaves.clase = dbo.clases.clase
                     WHERE   MONTH(aItc.fch_mov) = @mes
                            AND YEAR(aItc.fch_mov) = @ayo
                            AND aItc.empresa >= CASE WHEN @empresa = 0
                                                     THEN 0
                                                     ELSE @empresa
                                                END
                            AND aItc.empresa <= CASE WHEN @empresa = 0
                                                     THEN 9999
                                                     ELSE @empresa
                                                END
                            AND dbo.empleados.cotiza_imss = 'S'
                            AND conceptomarca.num_conc = 101
                            AND dbo.empleados.borrado = 'N'
                            AND aItc.codigo >= CASE WHEN @codigo = 0
                                                    THEN 0
                                                    ELSE @codigo
                                               END
                            AND aItc.codigo <= CASE WHEN @codigo = 0
                                                    THEN 99999999
                                                    ELSE @codigo
                                               END
                            AND aItc.horaProceso = @horaProceso
                            AND aItc.fechaProceso = @fechaProceso
                            AND aItc.proceso = @proceso
                     GROUP BY dbo.empresas.empresa --, dbo.Llaves.clase, dbo.clases.nombre
                     --ORDER BY dbo.Llaves.clase
       --    END
       
       
       IF @porRenglon = 0
          BEGIN
            SELECT @cuotaFija = cedulaMes.cuotaFija ,
                   @excedente = cedulaMes.excedente ,
                   @prestacionesDinero = cedulaMes.prestacionesDinero ,
                   @gmp = cedulaMes.gmp ,
                   @rt = cedulaMes.rt ,
                   @invalidezVida = cedulaMes.invalidezVida ,
                   @guarderias = cedulaMes.guarderias ,
                   @cesantiaVejez = cedulaMes.cesantiaVejez
            FROM @cedulaMensual AS cedulaMes

            INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Cuota Fija', @cuotaFija)
            INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Exc. 3 SMGDF', @excedente)
            INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Prest. Dinero', @prestacionesDinero)
            INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('G.M.P.', @gmp)
            INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('R.T.', @rt)
            INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('I.V.', @invalidezVida)
            INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('G.P.S.', @guarderias)
            
            DELETE cedulaMes FROM @cedulaMensual AS cedulaMes WHERE cedulaMes.nombrePrimaImss IS NULL
          END
        RETURN
    END
-- Cuota Fija   106 I
-- Exec.        106 II
-- Pd.          107
-- Gmp          25
-- RT           71
-- Iv           147
-- Gps          211
GO

/**************************************************************************************************
 * Name          : LlenaTotalCuotaImssInfonavit
 * Project       : APSI Nomina
 * Description   : Prepara el resumen por clase de empleado
 * Table name    : avisos_imss, llaves
 * Return        : tabla con el total cuotas imss
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Septiembre 14, 2010
 **************************************************************************************************/
IF OBJECT_ID('dbo.LlenaTotalCuotaImssInfonavit') IS NOT NULL
   DROP FUNCTION dbo.LlenaTotalCuotaImssInfonavit
GO

CREATE FUNCTION [dbo].[LlenaTotalCuotaImssInfonavit](
@empresa NUMERIC(5) ,
@codigo NUMERIC(8, 0) ,
@ayo INT ,
@mes INT ,
@porRenglon INT ,
@proceso VARCHAR(250),
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8) ,
@simulaReforma INT
)

-- @porRenglon = 0.- Es un registro por cada prima IMSS
--               1.- Es un solo registro y en cada columna su cuota IMSS correspondiente

RETURNS @cedulaMensual TABLE
    (
      salario FLOAT NULL ,
      diastr INT NULL ,
      incap INT NULL ,
      ausen DECIMAL(5, 2) NULL ,
      cuotaFija FLOAT NULL ,
      excedente FLOAT NULL ,
      excedentePatron FLOAT NULL ,
      exccedenteTrabajador FLOAT NULL ,
      prestacionesDinero FLOAT NULL ,
      prestacionesPatron FLOAT NULL ,
      prestacionesTrabajador FLOAT NULL ,
      gmp FLOAT NULL ,
      gmpPatron FLOAT NULL ,
      gmpTrabajador FLOAT NULL ,
      rt FLOAT NULL ,
      invalidezVida FLOAT NULL ,
      invalidezVidaPatron FLOAT NULL ,
      invalidezVidaTrabajador FLOAT NULL ,
      guarderias FLOAT NULL ,
      cesantiaVejez FLOAT NULL ,
      cesantiaVejezPatron FLOAT NULL ,
      cesantiaVejezTrabajador FLOAT NULL,
      clase VARCHAR(2) COLLATE database_default,
      registroPorClase INT NULL,
      registroExc INT NULL,
      baseCotizacionCuotaFija FLOAT,
      baseCotizacionExc FLOAT,
      baseCotizacionPD FLOAT,
      baseCotizacionGMP FLOAT,
      baseCotizacionRT FLOAT,
      baseCotizacionIV FLOAT,
      baseCotizacionGPS FLOAT,
      baseCotizacionCV FLOAT,
      nombreClase VARCHAR(20) COLLATE database_default,
      articulo106I FLOAT,
      articulo106II FLOAT,
      articulo107 FLOAT,
      articulo25 FLOAT,
      articulo71 FLOAT,
      articulo147 FLOAT,
      articulo211 FLOAT,
      nombrePrimaImss VARCHAR(50) COLLATE database_default,
      cuotaPrimaImss FLOAT,
      infonavitSinCredito FLOAT,
      infonavitConCredito FLOAT,
      seguroVivienda FLOAT,
      amortizacion FLOAT
    )
    
AS 
    BEGIN
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @eymArt25 FLOAT
        DECLARE @eymPat25 FLOAT
        DECLARE @eymTra25 FLOAT
        DECLARE @eymArt106I FLOAT
        DECLARE @eymArt1062 FLOAT
        DECLARE @eymPat1062 FLOAT
        DECLARE @eymTra1062 FLOAT
        DECLARE @eymArt107 FLOAT
        DECLARE @eymPat107 FLOAT
        DECLARE @eymTra107 FLOAT
        DECLARE @ivArt147 FLOAT
        DECLARE @ivPat147 FLOAT
        DECLARE @ivTra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @fi DATETIME
        DECLARE @ff DATETIME
        DECLARE @prima_rt FLOAT
        DECLARE @ayoEmpresa INT
        DECLARE @diasFaltaTope INT
        DECLARE @cuotaFija FLOAT
        DECLARE @excedente FLOAT
        DECLARE @prestacionesDinero FLOAT
        DECLARE @gmp FLOAT
        DECLARE @rt FLOAT
        DECLARE @invalidezVida FLOAT
        DECLARE @guarderias FLOAT
        DECLARE @cesantiaVejez FLOAT
        DECLARE @art211 FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @seguroVivienda INT
        DECLARE @infonavitSinCredito FLOAT
        DECLARE @infonavitConCredito FLOAT
        DECLARE @seguroViviendaCuota FLOAT
        DECLARE @amortizacionCuota FLOAT

        SET @diasFaltaTope = 7


        SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
        SET @ff = dbo.fin_mes(@mes, @ayo)


-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion
                    

-- Obtiene Primas IMSS
        SELECT  @eymArt25 = primasImss.eymArt25 ,
                @eymPat25 = primasImss.eymPat25 ,
                @eymTra25 = primasImss.eymTra25 ,
                @eymArt106I = primasImss.eymArt106I ,
                @eymArt1062 = primasImss.eymArt1062 ,
                @eymPat1062 = primasImss.eymPat1062 ,
                @eymTra1062 = primasImss.eymTra1062 ,
                @eymArt107 = primasImss.eymArt107 ,
                @eymPat107 = primasImss.eymPat107 ,
                @eymTra107 = primasImss.eymTra107 ,
                @ivArt147 = primasImss.ivArt147 ,
                @ivPat147 = primasImss.ivPat147 ,
                @ivTra147 = primasImss.ivTra147 ,
                @retiro = primasImss.cvArt168I ,
                @cvArt168II = primasImss.cvArt168II ,
                @cvPat168II = primasImss.cvPat168II ,
                @cvTra168II = primasImss.cvTra168ii ,
                @art211 = primasImss.art211,
                @infonavit = primasImss.infonavit
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss


-- Obtiene Prima RT
        SELECT  @prima_rt = dbo.primas_rt.prima_rt
        FROM    dbo.primas_rt
        WHERE   dbo.primas_rt.empresa = @empresa
                AND dbo.primas_rt.fecha_inicial <= @fi
                AND dbo.primas_rt.fecha_final >= @ff
                
-- Seguro vivienda                
        SET @seguroVivienda = CASE WHEN @fi >= CONVERT(DATETIME, '20060101') AND @ff <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fi >= CONVERT(DATETIME, '20090101') AND @ff <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fi >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END


        INSERT  @cedulaMensual
                ( cuotaFija ,
                  excedente ,
                  prestacionesDinero ,
                  gmp ,
                  rt ,
                  invalidezVida ,
                  guarderias ,
                  cesantiaVejez,
                  infonavitSinCredito,
                  infonavitConCredito,
                  seguroVivienda,
                  amortizacion
                )
                SELECT  ROUND(SUM([dbo].[CalculaCuotaImss](@salarioDF,aItc.diastr,aItc.incap,0,@eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymArt106I, 0)),2) AS cuotaFija ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt1062, 'S', @salarioDF, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat1062, @eymTra1062)),2) AS excedente ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat107, @eymTra107)),2) AS prestacionesDinero ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,0,@eymArt25,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @eymPat25, @eymTra25) END),2) AS gmp ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @prima_rt, 0)),2) AS rt ,
                        ROUND(SUM(CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@ivArt147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @ivPat147, @ivTra147) END),2) AS invalidezVida ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @art211, 0)),2) AS guarderias ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez,
                        ROUND(SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,0,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0,aItc.sueldo,aItc.fch_mov,@simulaReforma,@salarioRegion,0,@infonavit,0) ELSE 0 END),2) AS infonavitSinCredito,
                        ROUND(SUM(CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 0 ELSE [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF, @topeRegion, 0, aItc.mov), aItc.diastr, 0, aItc.ausen, @infonavit , 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit , 0) END),2) AS infonavitConCredito,
                        SUM(CASE WHEN aItc.serial = 1 THEN CASE WHEN ISNULL(ta.amortizacion,0) = 0 THEN 0 ELSE @seguroVivienda END ELSE 0 END) AS seguroVivienda,
                        SUM(CASE WHEN aItc.serial = 1 THEN ISNULL(ta.amortizacion,0) ELSE 0 END) AS amortizacion
                FROM ( ( dbo.empresas
                         INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
                       )
                       LEFT JOIN dbo.conceptos AS conceptomarca ON dbo.empresas.empresa = conceptomarca.empresa
                                                                   AND conceptomarca.num_conc = 101
                     )
                     INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                         AND dbo.empleados.codigo = aItc.codigo
                     LEFT JOIN dbo.TemporalAmortizacion AS ta ON aItc.codigo = ta.codigo AND aItc.empresa = ta.empresa
                WHERE MONTH(aItc.fch_mov) = @mes
                      AND YEAR(aItc.fch_mov) = @ayo
                      AND aItc.empresa >= CASE WHEN @empresa = 0 THEN 0 ELSE @empresa END
                      AND aItc.empresa <= CASE WHEN @empresa = 0 THEN 9999 ELSE @empresa END
                      AND dbo.empleados.cotiza_imss = 'S'
                      AND conceptomarca.num_conc = 101
                      AND dbo.empleados.borrado = 'N'
                      AND aItc.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END
                      AND aItc.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END
                      AND aItc.horaProceso = @horaProceso
                      AND aItc.fechaProceso = @fechaProceso
                      AND aItc.proceso = @proceso
                GROUP BY dbo.empresas.empresa 
       
       
        IF @porRenglon = 0
           BEGIN
             SELECT @cuotaFija = cedulaMes.cuotaFija ,
                    @excedente = cedulaMes.excedente ,
                    @prestacionesDinero = cedulaMes.prestacionesDinero ,
                    @gmp = cedulaMes.gmp ,
                    @rt = cedulaMes.rt ,
                    @invalidezVida = cedulaMes.invalidezVida ,
                    @guarderias = cedulaMes.guarderias ,
                    @cesantiaVejez = cedulaMes.cesantiaVejez,
                    @infonavitSinCredito = cedulaMes.infonavitSinCredito,
                    @infonavitConCredito = cedulaMes.infonavitConCredito,
                    @seguroViviendaCuota = cedulaMes.seguroVivienda,
                    @amortizacionCuota = cedulaMes.amortizacion
             FROM @cedulaMensual AS cedulaMes

             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Cuota Fija', @cuotaFija)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Exc. 3 SMGDF', @excedente)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Prest. Dinero', @prestacionesDinero)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('G.M.P.', @gmp)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('R.T.', @rt)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('I.V.', @invalidezVida)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('G.P.S.', @cesantiaVejez)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Aportacin Sin Crdito', @infonavitSinCredito)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Aportacin Con Crdito', @infonavitConCredito)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Seguro Vivienda', @seguroViviendaCuota)
             INSERT @cedulaMensual (nombrePrimaImss, cuotaPrimaImss) VALUES ('Amortizacin', @amortizacionCuota)
             
             DELETE cedulaMes FROM @cedulaMensual AS cedulaMes WHERE cedulaMes.nombrePrimaImss IS NULL
           END
        RETURN
    END
-- Cuota Fija   106 I
-- Exec.        106 II
-- Pd.          107
-- Gmp          25
-- RT           71
-- Iv           147
-- Gps          211
GO

/**************************************************************************************************
 * Name          : LlenaTotalCuotasBimestre
 * Project       : APSI Nomina
 * Description   : Calcula y llena la tabla de salida del resumen por calse de la cedula bimestral
 * Table name    : empresa, primas_imss, empleados, deducciones, infonavit
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'TF'
--                    AND name = 'LlenaTotalCuotasBimestre' ) 
--    BEGIN
--        DROP  FUNCTION [dbo].[LlenaTotalCuotasBimestre]
--    END
IF OBJECT_ID('dbo.LlenaTotalCuotasBimestre') IS NOT NULL
   DROP  FUNCTION [dbo].[LlenaTotalCuotasBimestre]
GO
CREATE FUNCTION [dbo].[LlenaTotalCuotasBimestre]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT,
	  @filtroInfonavit INT    -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
    )

-- @porRenglon = 0.- Es un registro por cada prima IMSS
--               1.- Es un solo registro y en cada columna su cuota IMSS correspondiente

RETURNS @cedulaBimestral TABLE
    (
      --empresa INT NOT NULL
      --            DEFAULT 0 ,
      --diastr INT NOT NULL
      --           DEFAULT 0 ,
      --incap INT NOT NULL
      --          DEFAULT 0 ,
      --ausen FLOAT NOT NULL
      --            DEFAULT 0 ,
      retiro FLOAT NOT NULL
                   DEFAULT 0 ,
      cesantiaVejez FLOAT NOT NULL
                          DEFAULT 0 ,
      --cesantiaVejezPatron FLOAT NOT NULL
      --                          DEFAULT 0 ,
      --cesantiaVejezTrabajador FLOAT NOT NULL
      --                              DEFAULT 0 ,
      aportacionInfonavit FLOAT NOT NULL
                                DEFAULT 0 ,
      amortizacion FLOAT NOT NULL
                         DEFAULT 0 ,
      seguroVivienda FLOAT NOT NULL
                           DEFAULT 0 ,
      --infonavitSinCredito FLOAT NOT NULL
      --                          DEFAULT 0 ,
      --infonavitConCredito FLOAT NOT NULL
      --                          DEFAULT 0 ,
      --clase VARCHAR(2),
      --baseCotizacionRetiro FLOAT,
      --baseCotizacionCV FLOAT,
      --baseCotizacionAportacionSinCredito FLOAT,
      --baseCotizacionAportacionConCredito FLOAT,
      --casos INT,
      --casosSinCredito INT,
      --casosConCredito INT,
      --articulo168I FLOAT,
      --articulo168II FLOAT ,
      --articulo29 FLOAT ,
      nombrePrimaImss VARCHAR(50) COLLATE database_default,
      cuotaPrimaImss FLOAT ,
      seguroDesempleo FLOAT
    )
AS 
    BEGIN
        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        --DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @retiroCuota FLOAT
        DECLARE @cesantiaVejez FLOAT
        DECLARE @aportacionInfonavit FLOAT 
        DECLARE @amortizacion FLOAT
        DECLARE @seguroViviendaCuota FLOAT
        DECLARE @seguroDesempleo FLOAT
        DECLARE @fechaAplicaUMA DATETIME
		        DECLARE @FechaFinita DATETIME

        SET @FechaFinita = '29991231'

        
        SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
        
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar 
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE 
            BEGIN
                SET @esBimestre = 'N'
            END
    
    
-- Obtiene Area Geografica
        SELECT  @areaGeografica = empresa.zona_geografica ,
                --@patronPagaIMSS = empresa.patron_paga_cuotas_imss ,
                @ayoEmpresa = empresa.ayo_operacion
        FROM    dbo.empresas AS empresa
        WHERE   empresa.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
                @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
                @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion    
    

-- Obtiene Primas IMSS
        SELECT @retiro = primasImss.cvArt168I , --primasImss.retiro ,
               @cvArt168II = primasImss.cvArt168II ,
               @cvPat168II = primasImss.cvPat168II , --+ CASE WHEN @patronPagaIMSS = 'S' THEN primasImss.cvtra168ii ELSE 0 END ,
               @cvTra168II = primasImss.cvTra168ii , --CASE WHEN @patronPagaIMSS = 'S' THEN 0 ELSE primasImss.cvtra168ii END ,
               @infonavit = primasImss.infonavitPorciento ,
               @seguroDesempleo = primasImss.seguroDesempleoPorciento
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
        --FROM    dbo.primas_imss AS primasImss
        --WHERE   YEAR(primasImss.periodo) = CASE WHEN @ayo > @ayoEmpresa THEN @ayoEmpresa ELSE @ayo END    
                                                
                                                
                                                
-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN concepto.hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN concepto.marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = concepto.variable1
        FROM    dbo.conceptos AS concepto
        WHERE   concepto.empresa = @empresa
                AND concepto.num_conc = 112                                                
    

        --SET @seguroVivienda = CASE WHEN YEAR(@fiNon) >= 2006
        --                                AND YEAR(@fiNon) <= 2008 THEN 8
        --                           WHEN YEAR(@fiNon) >= 2009 THEN 13
        --                           ELSE 0
        --                      END
        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END
        

    
-- Registro Avisos
        INSERT  @cedulaBimestral
                ( --empresa ,
                  --clase,
                  --diastr ,
                  --incap ,
                  --ausen ,
                  retiro ,
                  cesantiaVejez ,
                  --cesantiaVejezPatron ,
                  --cesantiaVejezTrabajador ,
                  aportacionInfonavit ,
                  --infonavitSinCredito ,
                  --infonavitConCredito ,
                  --amortizacion,
                  --seguroVivienda
                  --baseCotizacionRetiro ,
                  --baseCotizacionCV ,
                  --baseCotizacionAportacionSinCredito ,
                  --baseCotizacionAportacionConCredito,
                  --casos ,
                  --casosSinCredito ,
                  --casosConCredito ,
                  seguroDesempleo
                )
                SELECT  --dbo.empleados.empresa ,
                        --dbo.Llaves.clase,
                        --SUM(dbo.avisos_imss.diastr) AS diasTr ,
                        --SUM(dbo.avisos_imss.incap) AS incap ,
                        --SUM(dbo.avisos_imss.ausen) AS ausen ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @retiro, 0)),2) AS retiro ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvArt168II, 0)),2) AS cesantiaVejez ,
                        --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@cvPat168II,'N',0)),2) AS cesantiaVejezPatron ,
                        --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,dbo.avisos_imss.incap,dbo.avisos_imss.ausen,@cvTra168II,'N',0)),2) AS cesantiaVejez ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0)),2) AS aportacionInfonavit ,
                        --ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion IS NULL THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,0,dbo.avisos_imss.ausen,@infonavit,'N',0) ELSE 0 END),2) AS infonavitSinCredito,
                        --ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion >= 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov),dbo.avisos_imss.diastr,0,dbo.avisos_imss.ausen,@infonavit,'N',0) ELSE 0 END),2) AS infonavitConCredito,
                        --0,
                        --0,
                        --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen)),2) AS baseCotizacionRetiro,
                        --ROUND(SUM([dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen - dbo.avisos_imss.incap)),2) AS baseCotizacionCV,
                        --ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion IS NULL THEN [dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen) ELSE 0 END),2) AS baseCotizacionAportacionSinCredito,
                        --ROUND(SUM(CASE WHEN dbo.TemporalAmortizacion.amortizacion >= 0 THEN [dbo].[AjustaSaldiaInt](dbo.avisos_imss.saldiaint,@topeDF,@topeRegion,dbo.empleados.art39,dbo.avisos_imss.mov) * (dbo.avisos_imss.diastr - dbo.avisos_imss.ausen) ELSE 0 END),2) AS baseCotizacionAportacionConCredito,
                        --0,
                        --0,
                        --0
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@seguroDesempleo, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @seguroDesempleo, 0)),2) AS seguroDesempleo
                FROM    dbo.empresas AS empresa
                        INNER JOIN dbo.empleados AS empleado ON empresa.empresa = empleado.empresa
                        --INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa AND dbo.empleados.codigo = dbo.Llaves.codigo
                        --INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro AND dbo.Llaves.empresa = dbo.centros.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON empleado.empresa = aItc.empresa 
                                                                            AND empleado.codigo = aItc.codigo
                        --LEFT JOIN dbo.TemporalAmortizacion ON dbo.avisos_imss.empresa = dbo.TemporalAmortizacion.empresa AND dbo.avisos_imss.codigo = dbo.TemporalAmortizacion.codigo
                
                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = empleado.empresa
				                           AND i.codigo = empleado.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

				WHERE   aItc.mes_operacion >= @mesNon 
                        AND aItc.mes_operacion <= @mesPar 
                        AND aItc.ayo_operacion = @ayo 
                        AND empleado.cotiza_imss = 'S' 
                        AND empleado.borrado = 'N' 
                        AND aItc.empresa >= CASE WHEN @empresa = 0 
                                                 THEN 0 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.empresa <= CASE WHEN @empresa = 0 
                                                 THEN 9999 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.codigo >= CASE WHEN @codigo = 0 
                                                THEN 0 
                                                ELSE @codigo 
                                           END 
                        AND aItc.codigo <= CASE WHEN @codigo = 0 
                                                THEN 99999999 
                                                ELSE @codigo 
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso

                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

                GROUP BY empleado.empresa --, dbo.Llaves.clase
                
                
                
                UPDATE cedulaBimestre 
                SET cedulaBimestre.amortizacion = ISNULL((SELECT SUM(dbo.TemporalAmortizacion.amortizacion)
                                                          FROM dbo.TemporalAmortizacion
                                                          WHERE dbo.TemporalAmortizacion.empresa = @empresa),0),
                                                                --AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase),0),
                                                         
                    cedulaBimestre.seguroVivienda = @seguroVivienda * ISNULL((SELECT COUNT(*)
                                                                              FROM dbo.TemporalAmortizacion
                                                                              WHERE dbo.TemporalAmortizacion.empresa = @empresa
                                                                                    AND dbo.TemporalAmortizacion.amortizacion > 0),0)
                                                                                    --AND dbo.TemporalAmortizacion.clase = cedulaBimestre.clase),0)
                FROM @cedulaBimestral AS cedulaBimestre
                
        IF @porRenglon = 0
            BEGIN
            
              SELECT @retiroCuota = cedulaBimestre.retiro ,
                     @cesantiaVejez = cedulaBimestre.cesantiaVejez ,
                     @aportacionInfonavit = cedulaBimestre.aportacionInfonavit ,
                     @amortizacion = cedulaBimestre.amortizacion ,
                     @seguroViviendaCuota = cedulaBimestre.seguroVivienda ,
                     @seguroDesempleo = cedulaBimestre.seguroDesempleo
              FROM @cedulaBimestral AS cedulaBimestre

              INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Retiro', @retiroCuota)
              INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Cesantia y Vejez', @cesantiaVejez)
              INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Aportacin INFONAVIT', @aportacionInfonavit)
              INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Amortizacion', @amortizacion)
              INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Seguro Vivienda', @seguroViviendaCuota)
              --INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Seguro Desempleo', @seguroDesempleo)
            
              DELETE cedulaBimestre FROM @cedulaBimestral AS cedulaBimestre WHERE cedulaBimestre.nombrePrimaImss IS NULL
          END
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : LlenaTotalCuotasBimestre
 * Project       : APSI Nomina
 * Description   : Calcula y llena la tabla de salida del resumen por calse de la cedula bimestral
 * Table name    : empresa, primas_imss, empleados, deducciones, infonavit
 *               : avisos_imss, coneptos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/
IF OBJECT_ID('dbo.LlenaTotalCuotasBimestreSinInfonavit') IS NOT NULL
   DROP  FUNCTION [dbo].[LlenaTotalCuotasBimestreSinInfonavit]
GO
CREATE FUNCTION [dbo].[LlenaTotalCuotasBimestreSinInfonavit]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8) ,
      @simulaReforma INT
    )

-- @porRenglon = 0.- Es un registro por cada prima IMSS
--               1.- Es un solo registro y en cada columna su cuota IMSS correspondiente

RETURNS @cedulaBimestral TABLE
    ( retiro FLOAT NOT NULL
                   DEFAULT 0 ,
      cesantiaVejez FLOAT NOT NULL
                          DEFAULT 0 ,
      aportacionInfonavit FLOAT NOT NULL
                                DEFAULT 0 ,
      amortizacion FLOAT NOT NULL
                         DEFAULT 0 ,
      seguroVivienda FLOAT NOT NULL
                           DEFAULT 0 ,
      nombrePrimaImss VARCHAR(50) COLLATE database_default,
      cuotaPrimaImss FLOAT ,
      seguroDesempleo FLOAT
    )
AS 
    BEGIN
        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @retiroCuota FLOAT
        DECLARE @cesantiaVejez FLOAT
        DECLARE @aportacionInfonavit FLOAT 
        DECLARE @amortizacion FLOAT
        DECLARE @seguroViviendaCuota FLOAT
        DECLARE @seguroDesempleo FLOAT
        
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar 
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE 
            BEGIN
                SET @esBimestre = 'N'
            END
    
    
-- Obtiene Area Geografica
        SELECT  @areaGeografica = empresa.zona_geografica ,
                @ayoEmpresa = empresa.ayo_operacion
        FROM    dbo.empresas AS empresa
        WHERE   empresa.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
                @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
                @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion    
    

-- Obtiene Primas IMSS
        SELECT @retiro = primasImss.cvArt168I ,
               @cvArt168II = primasImss.cvArt168II ,
               @cvPat168II = primasImss.cvPat168II ,
               @cvTra168II = primasImss.cvTra168ii ,
               @infonavit = primasImss.infonavitPorciento ,
               @seguroDesempleo = primasImss.seguroDesempleoPorciento
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
                                                
                                                
-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN concepto.hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN concepto.marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = concepto.variable1
        FROM    dbo.conceptos AS concepto
        WHERE   concepto.empresa = @empresa
                AND concepto.num_conc = 112                                                
    

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END
        
    
-- Registro Avisos
        INSERT  @cedulaBimestral
                ( retiro ,
                  cesantiaVejez 
                )
                SELECT  ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @retiro, 0)),2) AS retiro ,
                        ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,@topeDF,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvArt168II, 0)),2) AS cesantiaVejez
                FROM    dbo.empresas AS empresa
                        INNER JOIN dbo.empleados AS empleado ON empresa.empresa = empleado.empresa
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON empleado.empresa = aItc.empresa 
                                                                            AND empleado.codigo = aItc.codigo
                WHERE   aItc.mes_operacion >= @mesNon 
                        AND aItc.mes_operacion <= @mesPar 
                        AND aItc.ayo_operacion = @ayo 
                        AND empleado.cotiza_imss = 'S' 
                        AND empleado.borrado = 'N' 
                        AND aItc.empresa >= CASE WHEN @empresa = 0 
                                                 THEN 0 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.empresa <= CASE WHEN @empresa = 0 
                                                 THEN 9999 
                                                 ELSE @empresa 
                                            END 
                        AND aItc.codigo >= CASE WHEN @codigo = 0 
                                                THEN 0 
                                                ELSE @codigo 
                                           END 
                        AND aItc.codigo <= CASE WHEN @codigo = 0 
                                                THEN 99999999 
                                                ELSE @codigo 
                                           END
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                GROUP BY empleado.empresa --, dbo.Llaves.clase
                
                
        IF @porRenglon = 0
            BEGIN
            
              SELECT @retiroCuota = cedulaBimestre.retiro ,
                     @cesantiaVejez = cedulaBimestre.cesantiaVejez
              FROM @cedulaBimestral AS cedulaBimestre

              INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Retiro', @retiroCuota)
              INSERT @cedulaBimestral (nombrePrimaImss, cuotaPrimaImss) VALUES ('Cesantia y Vejez', @cesantiaVejez)
            
              DELETE cedulaBimestre FROM @cedulaBimestral AS cedulaBimestre WHERE cedulaBimestre.nombrePrimaImss IS NULL
          END
        RETURN
    END
GO

IF OBJECT_ID('dbo.NOM_FUN_FiltraEmpresa') IS NOT NULL 
    DROP FUNCTION dbo.NOM_FUN_FiltraEmpresa
GO
CREATE FUNCTION dbo.NOM_FUN_FiltraEmpresa
    (@empresa INT
     , @proceso VARCHAR(500))
RETURNS @tblEmpresa TABLE
    (
      empresa INT
    )
AS 
    BEGIN
      DECLARE @listaEmpresas VARCHAR(400)
      DECLARE @pdelimiter CHAR(1)
      DECLARE @posicionMultiple INT

      SET @posicionMultiple = CHARINDEX('"', @proceso, 1)
      SET @pdelimiter = ','

      IF @posicionMultiple > 0
         BEGIN
           SET @listaEmpresas = SUBSTRING(@proceso, @posicionMultiple + 1, 500)
	       SET @listaEmpresas = SUBSTRING(@listaEmpresas, 1, LEN(RTRIM(@listaEmpresas)) - 1)

           INSERT @TblEmpresa (empresa)
                  SELECT empresa.empresa
                  FROM dbo.empresas AS empresa
	                   INNER JOIN (SELECT valor 
                                   FROM [dbo].[CadenaATabla](@listaEmpresas, @pdelimiter)) AS listaEmpresas ON listaEmpresas.valor = empresa.empresa
         END
      ELSE
         BEGIN
           INSERT @TblEmpresa (empresa) VALUES (@empresa)
         END

      RETURN
    END
GO

/**************************************************************************************************
 * Name          : NOM_FUN_ObtieneDescripcionIncidencia
 * Project       : APSI Nomina
 * Description   : Calcula cuota Imss
 * Table name    : 
 * Copyright     : (c) Apsi 2009 - 2030. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Noviembre 21, 2019
 **************************************************************************************************/

IF OBJECT_ID('dbo.NOM_FUN_ObtieneDescripcionIncidencia') IS NOT NULL 
    DROP FUNCTION dbo.NOM_FUN_ObtieneDescripcionIncidencia
GO
CREATE FUNCTION [dbo].[NOM_FUN_ObtieneDescripcionIncidencia]
    (
      @EmpresaParam INT ,
	  @Num_ConcParam INT ,
      @TipoParam CHAR(1) ,
      @RamoParam CHAR(1) ,
	  @ClaseParam VARCHAR(2),
	  @CentroParam VARCHAR(15)
    )
RETURNS VARCHAR(30)
AS 
    BEGIN
	    DECLARE @DescripcionRegresa VARCHAR(30)

		IF @Num_ConcParam = 109 AND @RamoParam = '4'
		   SET @DescripcionRegresa = 'LICENCIA 140 BIS'
		ELSE IF @Num_ConcParam = 108 AND @TipoParam = 'P'
		   SET @DescripcionRegresa = ISNULL((SELECT TOP 1 c.variable2 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = 108 AND LTRIM(RTRIM(c.clase)) = '' AND LTRIM(RTRIM(c.centro)) = ''), 'PERMISO SIN GOCE DE SUELDO')
		ELSE IF @Num_ConcParam = 108 AND @TipoParam = 'S'
		   SET @DescripcionRegresa = ISNULL((SELECT TOP 1 c.variable3 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = 108 AND LTRIM(RTRIM(c.clase)) = '' AND LTRIM(RTRIM(c.centro)) = ''), 'SUSPENSION DISCIPLINARIA')
		ELSE IF @Num_ConcParam = 108 AND @TipoParam = 'T'
		   SET @DescripcionRegresa = ISNULL((SELECT TOP 1 c.variable4 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = 108 AND LTRIM(RTRIM(c.clase)) = '' AND LTRIM(RTRIM(c.centro)) = ''), 'PARO TECNICO')
		ELSE
		   IF EXISTS (SELECT 1 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(c.clase)) = @ClaseParam AND LTRIM(RTRIM(c.centro)) = @CentroParam)
		      SET @DescripcionRegresa = (SELECT c.concepto FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(c.clase)) = @ClaseParam AND LTRIM(RTRIM(c.centro)) = @CentroParam)
		   ELSE
		      IF EXISTS (SELECT 1 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(c.clase)) = @ClaseParam AND LTRIM(RTRIM(ISNULL(c.centro,''))) = '')
			     SET @DescripcionRegresa = (SELECT 1 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(c.clase)) = @ClaseParam AND LTRIM(RTRIM(ISNULL(c.centro,''))) = '')
		      ELSE
		         IF EXISTS (SELECT 1 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(ISNULL(c.clase,''))) = '' AND LTRIM(RTRIM(ISNULL(c.centro,''))) = ISNULL(@CentroParam,''))
			        SET @DescripcionRegresa = (SELECT c.concepto FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(ISNULL(c.clase,''))) = '' AND LTRIM(RTRIM(ISNULL(c.centro,''))) = ISNULL(@CentroParam,''))
                 ELSE
		            IF EXISTS (SELECT 1 FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(ISNULL(c.clase,''))) = '' AND LTRIM(RTRIM(ISNULL(c.centro,''))) = '')
			           SET @DescripcionRegresa = (SELECT c.concepto FROM dbo.conceptos AS c WHERE c.empresa = @EmpresaParam AND c.num_conc = @Num_ConcParam AND LTRIM(RTRIM(ISNULL(c.clase,''))) = '' AND LTRIM(RTRIM(ISNULL(c.centro,''))) = '')

        RETURN @DescripcionRegresa
    END
GO

/**************************************************************************************************
 * Name          : NOM_FUN_ObtienePrimaCVPatron2023
 * Project       : APSI Nomina
 * Description   : Calcula cuota Imss
 * Table name    : 
 * Copyright     : (c) Apsi 2009 - 2030. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Mircoles, Septimbre 21, 2022
 **************************************************************************************************/
IF OBJECT_ID('dbo.NOM_FUN_ObtienePrimaCVPatron2023') IS NOT NULL 
    DROP FUNCTION dbo.NOM_FUN_ObtienePrimaCVPatron2023
GO
CREATE FUNCTION dbo.NOM_FUN_ObtienePrimaCVPatron2023
( @empresa INT
  , @fecha DATETIME 
  , @ayo INT
  , @sbc NUMERIC(12,2)
  , @cvArt168II NUMERIC(8,4)
  , @cvPat168II NUMERIC(8,4)
  , @cvTra168II NUMERIC(8,4)
)

RETURNS @tblCV TABLE
       (rango INT
	    , cvArt168II NUMERIC(8,4)
        , cvPat168II NUMERIC(8,4)
        , cvTra168II NUMERIC(8,4)
       )   

AS
  
  BEGIN

    DECLARE @ayoAplicaTablaCVPatron INT
    SET @ayoAplicaTablaCVPatron = 2023

    IF  @ayo >= @ayoAplicaTablaCVPatron
	   BEGIN
	     IF @ayo > 2030
	        SET @ayo = 2030

         --DECLARE @nCiclo INT
		 --SET @nCiclo = 1

         --WHILE @nCiclo <= 250
         --  BEGIN
             INSERT @tblCV (rango, cvArt168II, cvPat168II, cvTra168II)
                    SELECT TOP 1
					       rango
                           , cvPatron.primaCVPatron + @cvTra168II AS cvArt168II
			               , cvPatron.primaCVPatron AS cvPat168II
				           , @cvTra168II AS cvTra168II
                    FROM dbo.NOM_TBL_PrimaCVPatron AS cvPatron
                         --CROSS APPLY (SELECT TOP 1
                         --                    e.zona_geografica AS zg
			             --             FROM dbo.empresas AS e
				         --             WHERE e.empresa = @empresa) AS e
                         --OUTER APPLY (SELECT TOP 1 
                         --                    CASE WHEN e.zg = 'B' 
			      	     --                         THEN zona_b
					     --                         ELSE zona_a
						 --                    END AS salarioMinimo
				         --             FROM dbo.salarios_minimos AS sm
				         --             WHERE @fecha >= sm.fecha_ini 
				         --                   AND @fecha <= sm.fecha_fin) AS sm
	                     OUTER APPLY (SELECT TOP 1
	                                         uma.umaDiario
                                      FROM dbo.TblUMA AS uma
				                      WHERE uma.fecha <= @fecha
				                      ORDER BY uma.fecha DESC) AS uma

	                     --CROSS APPLY (SELECT ROUND(CASE WHEN cvPatron.claveInferior = 'SM' THEN sm.salarioMinimo ELSE uma.umaDiario END * cvPatron.limiteInferior,2) AS inferior
	                     --                    , ROUND(CASE WHEN cvPatron.claveSuperior = 'SM' THEN sm.salarioMinimo ELSE uma.umaDiario END * cvPatron.limiteSuperior,2) AS superior) AS limite

						 CROSS APPLY (SELECT ROUND(@sbc / uma.umaDiario,2,2) AS sbc) AS vecesUma

                    WHERE cvPatron.ayo = @ayo
                          --AND @sbc >= limite.inferior
	                      --AND @sbc <= limite.superior
						  AND vecesUma.sbc >= limiteInferior
						  AND vecesUma.sbc <= limiteSuperior
                    ORDER BY cvPatron.limiteInferior ASC
                             , cvPatron.limiteSuperior ASC

       --      IF NOT EXISTS (SELECT TOP 1 1 FROM @tblCV)
       --         BEGIN
       --           SET @nCiclo = @nCiclo + 1
	   --           SET @sbc = @sbc + 0.01
       --         END
       --      ELSE
       --         BEGIN
       --           BREAK
       --         END
       --   END
	   END
	ELSE
	   BEGIN
         INSERT @tblCV (rango, cvArt168II, cvPat168II, cvTra168II) VALUES (0, @cvArt168II, @cvPat168II, @cvTra168II)
	   END

	RETURN
  END
GO

/**************************************************************************************************
 * Name          : ResumenAvisosImss
 * Project       : APSI Nomina
 * Description   : Obtiene resumen avisos imss
 * Table name    : avisos_imss
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 11, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'ResumenAvisosImss' ) 
    BEGIN
        DROP  FUNCTION [dbo].[ResumenAvisosImss]
    END
GO

CREATE FUNCTION [dbo].[ResumenAvisosImss]
    (
      @empresa INT ,
      @ayo INT ,
      @mes INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8)
    )

-- @porRenglon = 0.- Es un registro por cada aviso afiliatorio
--               1.- Es un solo registro y en cada columna su valor correspondiente
--               2.- Es un registro por cada aviso afiliatorio PERO solo las altas y bajas
    
RETURNS @resumenAvisosImss TABLE
    (
      registros INT NOT NULL
                    DEFAULT 0 ,
      altas INT NOT NULL
                DEFAULT 0 ,
      bajas INT NOT NULL
                DEFAULT 0 ,
      modificacionSalario INT NOT NULL
                              DEFAULT 0,
      campo VARCHAR(50),
      valor INT
    )
    
AS 
    BEGIN
    
        DECLARE @registros INT 
        DECLARE @altas INT 
        DECLARE @bajas INT 
        DECLARE @modificacionSalario INT 
        DECLARE @fi DATETIME
        DECLARE @ayoEmpresa INT
        DECLARE @mesEmpresa INT
        DECLARE @fechaOperacion DATETIME

        SET @registros = 0
        SET @altas = 0
        SET @bajas = 0
        SET @modificacionSalario = 0    
        
        SELECT  @ayoEmpresa = dbo.empresas.ayo_operacion ,
                @mesEmpresa = dbo.empresas.mes_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa

        SET @fechaOperacion = CONVERT(DATETIME, LTRIM(STR(@ayoEmpresa)) + RIGHT(100 + @mesEmpresa,2) + '01')

            
    -- Obtiene el total de empleados
        SET @registros = ISNULL(( SELECT    COUNT(*)
                                  FROM      dbo.empleados
                                            INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                                                AND dbo.empleados.codigo = aItc.codigo
                                  WHERE     aItc.empresa >= CASE WHEN @empresa = 0
                                                                 THEN 0
                                                                 ELSE @empresa
                                                            END
                                            AND aItc.empresa <= CASE WHEN @empresa = 0
                                                                     THEN 9999
                                                                     ELSE @empresa
                                                                END
                                            AND dbo.empleados.cotiza_imss = 'S'
                                            AND dbo.empleados.borrado = 'N'
                                            AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                                            AND YEAR(aItc.fch_mov) = @ayo
                                            AND MONTH(aItc.fch_mov) = @mes
                                            AND aItc.serial = 1
                                            AND aItc.horaProceso = @horaProceso
                                            AND aItc.fechaProceso = @fechaProceso
                                            AND aItc.proceso = @proceso
                                ), 0)
    

    -- Obtiene el total de altas
        SET @altas = ISNULL(( SELECT    COUNT(*)
                              FROM      dbo.empleados
                                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                                            AND dbo.empleados.codigo = aItc.codigo
                              WHERE     aItc.empresa >= CASE WHEN @empresa = 0
                                                             THEN 0
                                                             ELSE @empresa
                                                        END
                                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                                 THEN 9999
                                                                 ELSE @empresa
                                                            END
                                        AND dbo.empleados.cotiza_imss = 'S'
                                        AND dbo.empleados.borrado = 'N'
                                        AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                                        AND YEAR(aItc.fch_mov) = @ayo
                                        AND MONTH(aItc.fch_mov) = @mes
                                        AND ( aItc.mov = 'A'
                                              OR aItc.mov = 'RI'
                                            )
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                            ), 0)            
                        
                        
    -- Obtiene el total de bajas
        SET @bajas = ISNULL(( SELECT    COUNT(*)
                              FROM      dbo.empleados
                                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                                            AND dbo.empleados.codigo = aItc.codigo
                              WHERE     aItc.empresa >= CASE WHEN @empresa = 0
                                                             THEN 0
                                                             ELSE @empresa
                                                        END
                                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                                 THEN 9999
                                                                 ELSE @empresa
                                                            END
                                        AND dbo.empleados.cotiza_imss = 'S'
                                        AND dbo.empleados.borrado = 'N'
                                        AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                                        AND YEAR(aItc.fch_mov) = @ayo
                                        AND MONTH(aItc.fch_mov) = @mes
                                        AND aItc.mov = 'B'
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                            ), 0)                                    


    -- Obtiene el total de modificaciones de salario
        SET @modificacionSalario = ISNULL(( SELECT  COUNT(*)
                                            FROM    dbo.empleados
                                                    INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                                                        AND dbo.empleados.codigo = aItc.codigo
                                            WHERE   aItc.empresa >= CASE WHEN @empresa = 0
                                                                         THEN 0
                                                                         ELSE @empresa
                                                                    END
                                                    AND aItc.empresa <= CASE WHEN @empresa = 0
                                                                             THEN 9999
                                                                             ELSE @empresa
                                                                        END
                                                    AND dbo.empleados.cotiza_imss = 'S'
                                                    AND dbo.empleados.borrado = 'N'
                                                    AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                                                    AND YEAR(aItc.fch_mov) = @ayo
                                                    AND MONTH(aItc.fch_mov) = @mes
                                                    AND aItc.mov = 'MS'
                                                    AND aItc.horaProceso = @horaProceso
                                                    AND aItc.fechaProceso = @fechaProceso
                                                    AND aItc.proceso = @proceso
                                          ), 0)
                                      

        IF @porRenglon = 1
           BEGIN
              INSERT  INTO @resumenAvisosImss
                           ( registros ,
                             altas ,
                             bajas ,
                             modificacionSalario 
                           )
              VALUES  ( @registros ,
                        @altas ,
                        @bajas ,
                        @modificacionSalario
                      )
           END
        ELSE
           IF @porRenglon = 0
              BEGIN
                INSERT @resumenAvisosImss (campo, valor) VALUES ('Altas', @altas)
                INSERT @resumenAvisosImss (campo, valor) VALUES ('Bajas', @bajas)
                INSERT @resumenAvisosImss (campo, valor) VALUES ('Modificacin Salario', @modificacionSalario)
              END
           ELSE 
              IF @porRenglon = 2
                 BEGIN
                   INSERT @resumenAvisosImss (campo, valor) VALUES ('Altas', @altas)
                   INSERT @resumenAvisosImss (campo, valor) VALUES ('Bajas', @bajas)
                 END
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : ResumenAvisosImssBimestre
 * Project       : APSI Nomina
 * Description   : Obtiene resumen avisos imss
 * Table name    : avisos_imss
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 11, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'ResumenAvisosImssBimestre' ) 
    BEGIN
        DROP  FUNCTION [dbo].[ResumenAvisosImssBimestre]
    END
GO

CREATE FUNCTION [dbo].[ResumenAvisosImssBimestre]
    (
      @empresa INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT ,
      @porRenglon INT ,
      @proceso VARCHAR(250),
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8),
	  @filtroInfonavit INT    -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
    )

-- @porRenglon = 0.- Es un registro por cada aviso afiliatorio
--               1.- Es un solo registro y en cada columna su valor correspondiente
--               2.- Es un registro por cada aviso afiliatorio PERO solo las altas y bajas
    
RETURNS @ResumenAvisosImss TABLE
    (
      registros INT NOT NULL
                    DEFAULT 0 ,
      altas INT NOT NULL
                DEFAULT 0 ,
      bajas INT NOT NULL
                DEFAULT 0 ,
      modificacionSalario INT NOT NULL
                              DEFAULT 0,
      campo VARCHAR(50),
      valor INT
    )
    
AS 
    BEGIN
    
        DECLARE @registros INT 
        DECLARE @altas INT 
        DECLARE @bajas INT 
        DECLARE @modificacionSalario INT 
        DECLARE @codigoTemporal TABLE ( codigo INT )
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @FechaFinita DATETIME

        SET @FechaFinita = '29991231'
        SET @registros = 0
        SET @altas = 0
        SET @bajas = 0
        SET @modificacionSalario = 0   
        
        SET @FechaFinita = '29991231'
        
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

    -- Obtiene el total de empleados
        INSERT  @codigoTemporal
                ( codigo 
                )
                SELECT  dbo.empleados.codigo
                FROM    dbo.empleados
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                      AND dbo.empleados.codigo = aItc.codigo

                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = dbo.empleados.empresa
				                           AND i.codigo = dbo.empleados.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                WHERE   aItc.empresa >= CASE WHEN @empresa = 0
                                             THEN 0
                                             ELSE @empresa
                                        END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.mes_operacion = @mesNon
                        AND aItc.serial = 1
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND NOT EXISTS ( SELECT codigoTemporal.codigo
                                         FROM   @codigoTemporal AS codigoTemporal
                                         WHERE  codigo = dbo.empleados.codigo )

                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END


        INSERT  @codigoTemporal
                ( codigo 
                )
                SELECT  dbo.empleados.codigo
                FROM    dbo.empleados
                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                            AND dbo.empleados.codigo = aItc.codigo
                        OUTER APPLY (SELECT TOP 1
                                            'Si' AS TieneCredito
                                     FROM dbo.infonavit AS i
                                     WHERE i.empresa = dbo.empleados.empresa
				                           AND i.codigo = dbo.empleados.codigo
                                           AND i.fecha <= @ffPar
	                                       AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                       AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                WHERE   aItc.empresa >= CASE WHEN @empresa = 0
                                             THEN 0
                                             ELSE @empresa
                                        END
                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                 THEN 9999
                                                 ELSE @empresa
                                            END
                        AND dbo.empleados.cotiza_imss = 'S'
                        AND dbo.empleados.borrado = 'N'
                        AND aItc.ayo_operacion = @ayo
                        AND aItc.mes_operacion = @mesPar
                        AND aItc.serial = 1
                        AND aItc.horaProceso = @horaProceso
                        AND aItc.fechaProceso = @fechaProceso
                        AND aItc.proceso = @proceso
                        AND NOT EXISTS ( SELECT codigoTemporal.codigo
                                         FROM   @codigoTemporal AS codigoTemporal
                                         WHERE  codigo = dbo.empleados.codigo )
                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                  WHEN 2 THEN 'Si'
                                                  WHEN 3 THEN 'No'
                                                         ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END
                
                
        SET @registros = ISNULL(( SELECT    COUNT(*)
                                  FROM      @codigoTemporal
                                ), 0)                

        
    -- Obtiene el total de altas
        SET @altas = ISNULL(( SELECT    COUNT(*)
                              FROM      dbo.empleados
                                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                                            AND dbo.empleados.codigo = aItc.codigo

                                        OUTER APPLY (SELECT TOP 1
                                                            'Si' AS TieneCredito
                                                    FROM dbo.infonavit AS i
                                                    WHERE i.empresa = dbo.empleados.empresa
				                                          AND i.codigo = dbo.empleados.codigo
                                                          AND i.fecha <= @ffPar
	                                                      AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                                      AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                              WHERE     aItc.empresa >= CASE WHEN @empresa = 0
                                                             THEN 0
                                                             ELSE @empresa
                                                        END
                                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                                 THEN 9999
                                                                 ELSE @empresa
                                                            END
                                        AND dbo.empleados.cotiza_imss = 'S'
                                        AND dbo.empleados.borrado = 'N'
                                        AND aItc.ayo_operacion = @ayo
                                        AND ( aItc.mes_operacion = @mesNon
                                              OR aItc.mes_operacion = @mesPar
                                            )
                                        AND ( aItc.mov = 'A'
                                              OR aItc.mov = 'RI'
                                            )
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                                  WHEN 2 THEN 'Si'
                                                                  WHEN 3 THEN 'No'
                                                                  ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END
                            ), 0)            
                        
                        
    -- Obtiene el total de bajas
        SET @bajas = ISNULL(( SELECT    COUNT(*)
                              FROM      dbo.empleados
                                        INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                                            AND dbo.empleados.codigo = aItc.codigo
                                        OUTER APPLY (SELECT TOP 1
                                                            'Si' AS TieneCredito
                                                    FROM dbo.infonavit AS i
                                                    WHERE i.empresa = dbo.empleados.empresa
				                                          AND i.codigo = dbo.empleados.codigo
                                                          AND i.fecha <= @ffPar
	                                                      AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                                      AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                              WHERE     aItc.empresa >= CASE WHEN @empresa = 0
                                                             THEN 0
                                                             ELSE @empresa
                                                        END
                                        AND aItc.empresa <= CASE WHEN @empresa = 0
                                                                 THEN 9999
                                                                 ELSE @empresa
                                                            END
                                        AND dbo.empleados.cotiza_imss = 'S'
                                        AND dbo.empleados.borrado = 'N'
                                        AND aItc.ayo_operacion = @ayo
                                        AND ( aItc.mes_operacion = @mesNon
                                              OR aItc.mes_operacion = @mesPar
                                            )
                                        AND aItc.mov = 'B'
                                        AND aItc.horaProceso = @horaProceso
                                        AND aItc.fechaProceso = @fechaProceso
                                        AND aItc.proceso = @proceso
                                        AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                                  WHEN 2 THEN 'Si'
                                                                  WHEN 3 THEN 'No'
                                                                  ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END
                            ), 0)                                    


    -- Obtiene el total de modificaciones de salario
        SET @modificacionSalario = ISNULL(( SELECT  COUNT(*)
                                            FROM    dbo.empleados
                                                    INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                                                        AND dbo.empleados.codigo = aItc.codigo
                                                    OUTER APPLY (SELECT TOP 1
                                                                        'Si' AS TieneCredito
                                                                 FROM dbo.infonavit AS i
                                                                 WHERE i.empresa = dbo.empleados.empresa
				                                                       AND i.codigo = dbo.empleados.codigo
                                                                       AND i.fecha <= @ffPar
	                                                                   AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                                                   AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

                                            WHERE   aItc.empresa >= CASE WHEN @empresa = 0
                                                                         THEN 0
                                                                         ELSE @empresa
                                                                    END
                                                    AND aItc.empresa <= CASE WHEN @empresa = 0
                                                                             THEN 9999
                                                                             ELSE @empresa
                                                                        END
                                                    AND dbo.empleados.cotiza_imss = 'S'
                                                    AND dbo.empleados.borrado = 'N'
                                                    AND aItc.ayo_operacion = @ayo
                                                    AND ( aItc.mes_operacion = @mesNon
                                                          OR aItc.mes_operacion = @mesPar
                                                        )
                                                    AND aItc.mov = 'MS'
                                                    AND aItc.horaProceso = @horaProceso
                                                    AND aItc.fechaProceso = @fechaProceso
                                                    AND aItc.proceso = @proceso
                                                    AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                                                              WHEN 2 THEN 'Si'
                                                                              WHEN 3 THEN 'No'
                                                                              ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END
                                          ), 0)
                                      
        IF @porRenglon = 1
           BEGIN
              INSERT  INTO @resumenAvisosImss
                           ( registros ,
                             altas ,
                             bajas ,
                             modificacionSalario 
                           )
              VALUES  ( @registros ,
                        @altas ,
                        @bajas ,
                        @modificacionSalario
                      )
           END
        ELSE
           IF @porRenglon = 0
              BEGIN
                INSERT @resumenAvisosImss (campo, valor) VALUES ('Altas', @altas)
                INSERT @resumenAvisosImss (campo, valor) VALUES ('Bajas', @bajas)
                INSERT @resumenAvisosImss (campo, valor) VALUES ('Modificacin Salario', @modificacionSalario)
              END
           ELSE 
              IF @porRenglon = 2
                 BEGIN
                   INSERT @resumenAvisosImss (campo, valor) VALUES ('Altas', @altas)
                   INSERT @resumenAvisosImss (campo, valor) VALUES ('Bajas', @bajas)
                 END


        RETURN
    END
GO

/**************************************************************************************************
 * Name          : ResumenPorCentroRecibo
 * Project       : APSI Nomina
 * Description   : Genera el resumen de la tabla 
 * Table name    : Kardex, Centros
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Julio 14, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'TF'
                    AND name = 'ResumenPorCentroRecibo' ) 
    BEGIN
        DROP  FUNCTION [dbo].[ResumenPorCentroRecibo]
    END
GO

CREATE FUNCTION [dbo].[ResumenPorCentroRecibo]
    (
      @empresa INT ,
      @nomina VARCHAR(15) ,
      @incluirProvisiones CHAR(1) ,
      @porDetalle CHAR(1) ,
      @tipoNomina INT ,
      @queConcepto CHAR(1) ,
      @ordenadoPor INT ,
      @salarioDF FLOAT ,
      @salarioRegion FLOAT ,
      @eymArt25 FLOAT ,
      @eymArt1062 FLOAT ,
      @eymArt107 FLOAT ,
      @ivArt147 FLOAT ,
      @cvArt168II FLOAT ,
      @desglosadoPor INT ,
      @porCentro INT
    )
RETURNS @resumenPorCentro TABLE
    (
      centro VARCHAR(50) ,
      supervisor INT ,
      codigo INT ,
      numeroConcepto INT ,
      nombreConcepto VARCHAR(50) ,
      importe FLOAT ,
      gravable FLOAT ,
      exento FLOAT ,
      centroGrupo VARCHAR(50) ,
      conceptoGrupo INT ,
      renglon INT ,
      tipoPago INT ,
      saldoPercepcion FLOAT ,
      anexoConceptoPercepcion VARCHAR(150) ,
      anexoConceptoDeduccion VARCHAR(150) ,
      empleados INT ,
      provisionIMSS FLOAT ,
      provisionRCV FLOAT ,
      provisionINFONAVIT FLOAT ,
      retencionIMSS FLOAT ,
      retencionRCV FLOAT ,
      retencionINFONAVIT FLOAT ,
      empleadosConCuentaBancaria INT ,
      empleadosSinCuentaBancaria INT ,
      percepcionesConCuentaBancaria FLOAT ,
      deduccionesConCuentaBancaria FLOAT ,
      percepcionesSinCuentaBancaria FLOAT ,
      deduccionesSinCuentaBancaria FLOAT ,
      basePorcientoSobreNomina FLOAT ,
      porcientoSobreNomina FLOAT ,
      fondoAhorroAportacionEmpleado FLOAT ,
      fondoAhorroAportacionPatron FLOAT ,
      sueldoNetoGeneral FLOAT ,
      ejercicio INT ,
      diarioOficialDia INT ,
      diarioOficialMes INT ,
      diarioOficialAyo INT ,
      salarioMinimoDF FLOAT ,
      salarioMinimoRegion FLOAT ,
      eymArt25 FLOAT ,
      eymArt106ii FLOAT ,
      eymArt107 FLOAT ,
      ivArt147 FLOAT ,
      cvArt168ii FLOAT ,
      baseCalculo INT ,
      grupo VARCHAR(500) ,
      supervisorGrupo INT
    )
AS 
    BEGIN
        DECLARE @nombreEmpresa VARCHAR(250)
        DECLARE @centroAnterior VARCHAR(50)
        DECLARE @supervisorAnterior INT
        DECLARE @tipoPagoAnterior VARCHAR(50)
        DECLARE @renglon INT
        DECLARE @numeroConceptoPercepcionInicio INT
        DECLARE @numeroConceptoPercepcionTermino INT
        DECLARE @numeroConceptoContraPercepcionInicio INT
        DECLARE @numeroConceptoContraPercepcionTermino INT
        DECLARE @numeroConceptoDeduccionInicio INT
        DECLARE @numeroConceptoDeduccionTermino INT
        DECLARE @numeroConceptoContraDeduccionInicio INT
        DECLARE @numeroConceptoContraDeduccionTermino INT
        DECLARE @numeroConceptoProvisionInicio INT
        DECLARE @numeroConceptoProvisionTermino INT
        DECLARE @conceptosBaseImpuestoSobreNomina VARCHAR(2000)
        DECLARE @importeBaseImpuestoSobreNomina FLOAT
        DECLARE @contador INT
        DECLARE @caracter CHAR(1)
        DECLARE @cadena VARCHAR(15)
        DECLARE @resumenPorCentroTemporal TABLE
            (
              centro VARCHAR(50) ,
              supervisor INT ,
              codigo INT ,
              numeroConcepto INT ,
              nombreConcepto VARCHAR(50) ,
              importe FLOAT ,
              gravable FLOAT ,
              exento FLOAT ,
              centroGrupo VARCHAR(50) ,
              conceptoGrupo INT ,
              renglon INT ,
              tipoPago CHAR(1) ,
              saldoPercepcion FLOAT ,
              anexoConceptoPercepcion VARCHAR(150) ,
              anexoConceptoDeduccion VARCHAR(150) ,
              empleados INT ,
              provisionIMSS FLOAT ,
              provisionRCV FLOAT ,
              provisionINFONAVIT FLOAT ,
              retencionIMSS FLOAT ,
              retencionRCV FLOAT ,
              retencionINFONAVIT FLOAT ,
              empleadosConCuentaBancaria INT ,
              empleadosSinCuentaBancaria INT ,
              percepcionesConCuentaBancaria FLOAT ,
              deduccionesConCuentaBancaria FLOAT ,
              percepcionesSinCuentaBancaria FLOAT ,
              deduccionesSinCuentaBancaria FLOAT ,
              basePorcientoSobreNomina FLOAT ,
              porcientoSobreNomina FLOAT ,
              fondoAhorroAportacionEmpleado FLOAT ,
              fondoAhorroAportacionPatron FLOAT ,
              sueldoNetoGeneral FLOAT ,
              ejercicio INT ,
              diarioOficialDia INT ,
              diarioOficialMes INT ,
              diarioOficialAyo INT ,
              salarioMinimoDF FLOAT ,
              salarioMinimoRegion FLOAT ,
              eymArt25 FLOAT ,
              eymArt106ii FLOAT ,
              eymArt107 FLOAT ,
              ivArt147 FLOAT ,
              cvArt168ii FLOAT ,
              baseCalculo INT ,
              grupo VARCHAR(500) ,
              supervisorGrupo INT
            )    
        DECLARE @tablaConceptoBaseImpuestoSobreNomina TABLE ( numeroConcepto
                                                              INT )
        DECLARE @ejercicio INT
        DECLARE @diarioOficial DATETIME
        DECLARE @baseCalculo VARCHAR(25)
        DECLARE @porSupervisor INT
        DECLARE @empleados INT
        DECLARE @provisionIMSS FLOAT
        DECLARE @provisionRCV FLOAT
        DECLARE @provisionINFONAVIT FLOAT
        DECLARE @retencionIMSS FLOAT
        DECLARE @retencionRCV FLOAT
        DECLARE @retencionINFONAVIT FLOAT
        DECLARE @empleadosConCuentaBancaria INT
        DECLARE @empleadosSinCuentaBancaria INT
        DECLARE @percepcionesConCuentaBancaria FLOAT
        DECLARE @deduccionesConCuentaBancaria FLOAT
        DECLARE @percepcionesSinCuentaBancaria FLOAT
        DECLARE @deduccionesSinCuentaBancaria FLOAT
        DECLARE @porcientoSobreNomina FLOAT
        DECLARE @fondoAhorroAportacionEmpleado FLOAT
        DECLARE @fondoAhorroAportacionPatron FLOAT
        DECLARE @sueldoNetoGeneral FLOAT

        DECLARE @empleadosCentro INT
        DECLARE @provisionIMSSCentro FLOAT
        DECLARE @provisionRCVCentro FLOAT
        DECLARE @provisionINFONAVITCentro FLOAT
        DECLARE @retencionIMSSCentro FLOAT
        DECLARE @retencionRCVCentro FLOAT
        DECLARE @retencionINFONAVITCentro FLOAT
        DECLARE @empleadosConCuentaBancariaCentro INT
        DECLARE @empleadosSinCuentaBancariaCentro INT
        DECLARE @percepcionesConCuentaBancariaCentro FLOAT
        DECLARE @deduccionesConCuentaBancariaCentro FLOAT
        DECLARE @percepcionesSinCuentaBancariaCentro FLOAT
        DECLARE @deduccionesSinCuentaBancariaCentro FLOAT
        DECLARE @porcientoSobreNominaCentro FLOAT
        DECLARE @fondoAhorroAportacionEmpleadoCentro FLOAT
        DECLARE @fondoAhorroAportacionPatronCentro FLOAT
        DECLARE @sueldoNetoGeneralCentro FLOAT
        
        DECLARE @regimenSeguridadSocial INT

        
        SET @numeroConceptoPercepcionInicio = 1
        SET @numeroConceptoPercepcionTermino = 99
        SET @numeroConceptoContraPercepcionInicio = 1101
        SET @numeroConceptoContraPercepcionTermino = 1199
        SET @numeroConceptoDeduccionInicio = 101
        SET @numeroConceptoDeduccionTermino = 199
        SET @numeroConceptoContraDeduccionInicio = 1001
        SET @numeroConceptoContraDeduccionTermino = 1099
        SET @numeroConceptoProvisionInicio = CASE WHEN @incluirProvisiones = 'S'
                                                  THEN 201
                                                  ELSE 0
                                             END
        SET @numeroConceptoProvisionTermino = CASE WHEN @incluirProvisiones = 'S'
                                                   THEN 299
                                                   ELSE 0
                                              END
    
        SET @nombreEmpresa = ISNULL(( SELECT    dbo.empresas.nombre_empresa
                                      FROM      dbo.empresas
                                      WHERE     dbo.empresas.empresa = @empresa
                                    ), 'SIN RAZON SOCIAL REGISTRADA')
                                    
        SET @regimenSeguridadSocial = ISNULL((SELECT dbo.empresas.Regimen_Seguridad_Social
                                              FROM dbo.empresas
                                              WHERE dbo.empresas.empresa = @empresa),1)
        
        IF @ordenadoPor & 16 > 0
            OR @ordenadoPor & 32 > 0 
            SET @porSupervisor = 1
                                    
        -- Cuando el reporte es General el order de hace cero
        IF @desglosadoPor & 4 > 0 
            SET @ordenadopor = 0


        -- @porDetalle = 'S' agrega los valores de kardex
        IF @porDetalle = 'S' 
            BEGIN
            
                -- si el orden es 1 o 2 y el desglose es 1 
                -- quiere decir que se van a incluir los empleados           
                IF ( ( @ordenadoPor & 1 > 0
                       OR @ordenadoPor & 2 > 0
                     )
                     AND @desglosadoPor & 1 > 0
                   ) 
                    BEGIN
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  --supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  importe ,
                                  gravable ,
                                  exento ,
                                  tipoPago ,
                                  saldoPercepcion
                                )
                                SELECT  '99999999999997' AS centro ,
                                        --NULL, --999999995 AS supervisor ,
                                        999999995 AS codigo ,
                                        dbo.recibos.num_conc AS numeroConcepto ,
                                        dbo.recibos.concepto AS nombreConcepto ,
                                        SUM(dbo.recibos.importe) AS importePercepciones ,
                                        SUM(dbo.recibos.igravable) AS gravablePercepciones ,
                                        SUM(dbo.recibos.iexento) AS exentoPercepciones ,
                                        CASE WHEN dbo.recibos.num_conc >= 1
                                                  AND dbo.recibos.num_conc <= 99
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 1101
                                                  AND dbo.recibos.num_conc <= 1199
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 101
                                                  AND dbo.recibos.num_conc <= 199
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 1001
                                                  AND dbo.recibos.num_conc <= 1099
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 201
                                                  AND dbo.recibos.num_conc <= 299
                                             THEN 3
                                             ELSE 0
                                        END ,
                                        SUM(CASE WHEN ( ( dbo.recibos.num_conc >= 1
                                                          AND dbo.recibos.num_conc <= 99
                                                        )
                                                        OR ( dbo.recibos.num_conc >= 1101
                                                             AND dbo.recibos.num_conc <= 1199
                                                           )
                                                      )
                                                      AND dbo.recibos.saldo > 0
                                                 THEN CASE WHEN dbo.recibos.saldo IS NULL
                                                           THEN 0
                                                           ELSE dbo.recibos.saldo
                                                      END
                                                 ELSE 0
                                            END) AS saldoPercepcion
                                FROM    dbo.recibos
                                WHERE   dbo.recibos.empresa = @empresa
                                        AND dbo.recibos.nomina = @nomina
                                        AND ( ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                  AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                )
                                                OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                              )
                                              OR ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                                   OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                        AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                      )
                                                 )
                                              OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                   AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                 )
                                            )
                                GROUP BY dbo.recibos.num_conc ,
                                        dbo.recibos.concepto
                    END
                    
                
                -- Si el orden es 4 u 8 o el desglose es 2
                -- Quiere decir que solo se va a incluir 
                -- los centros de costos sin empleados
                IF ( ( @ordenadoPor & 4 > 0
                       OR @ordenadoPor & 8 > 0
                     )
                     OR ( ( @ordenadoPor & 1 > 0
                            OR @ordenadoPor & 2 > 0
                          )
                          AND @desglosadoPor & 2 > 0
                        )
                   ) 
                    BEGIN
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  --supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  importe ,
                                  gravable ,
                                  exento ,
                                  centroGrupo ,
                                  conceptoGrupo ,
                                  tipoPago ,
                                  saldoPercepcion
                                )
                                SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                             THEN '99999999999997'
                                             ELSE dbo.Llaves.centro
                                        END AS centroGrupo ,
                                        --NULL, --999999995 AS supervisor ,
                                        999999995 AS codigo ,
                                        CASE WHEN dbo.recibos.num_conc IS NULL
                                             THEN 9995
                                             ELSE dbo.recibos.num_conc
                                        END AS numeroConcepto ,
                                        CASE WHEN dbo.recibos.concepto IS NULL
                                             THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                             ELSE dbo.recibos.concepto
                                        END AS nombreConcepto ,
                                        SUM(dbo.recibos.importe) AS importePercepciones ,
                                        SUM(dbo.recibos.igravable) AS gravablePercepciones ,
                                        SUM(dbo.recibos.iexento) AS exentoPercepciones ,
                                        CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                             THEN '99999999999997'
                                             ELSE ''
                                        END AS centroGrupo ,
                                        CASE WHEN GROUPING(dbo.recibos.num_conc) = 1
                                             THEN 999999995
                                             ELSE 0
                                        END AS ConceptoGrupo ,
                                        CASE WHEN dbo.recibos.num_conc >= 1
                                                  AND dbo.recibos.num_conc <= 99
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 1101
                                                  AND dbo.recibos.num_conc <= 1199
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 101
                                                  AND dbo.recibos.num_conc <= 199
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 1001
                                                  AND dbo.recibos.num_conc <= 1099
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 201
                                                  AND dbo.recibos.num_conc <= 299
                                             THEN 3
                                             ELSE 0
                                        END ,
                                        SUM(CASE WHEN ( ( dbo.recibos.num_conc >= 1
                                                          AND dbo.recibos.num_conc <= 99
                                                        )
                                                        OR ( dbo.recibos.num_conc >= 1101
                                                             AND dbo.recibos.num_conc <= 1199
                                                           )
                                                      )
                                                      AND dbo.recibos.saldo > 0
                                                 THEN CASE WHEN dbo.recibos.saldo IS NULL
                                                           THEN 0
                                                           ELSE dbo.recibos.saldo
                                                      END
                                                 ELSE 0
                                            END) AS saldoPercepcion
                                FROM    dbo.recibos
                                        INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                        /*INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN RTRIM(LTRIM(dbo.Llaves.centro))
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN RTRIM(LTRIM(dbo.SeleccionElementos.centro))
                                                              ELSE '1'
                                                              END*/
                                WHERE   dbo.recibos.empresa = @empresa
                                        AND dbo.recibos.nomina = @nomina
                                        --AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                        --AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                        --AND dbo.SeleccionElementos.nomina = @nomina
                                        AND ( ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                  AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                )
                                                OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                              )
                                              OR ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                                   OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                        AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                      )
                                                 )
                                              OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                   AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                 )
                                            )
                                GROUP BY dbo.Llaves.centro ,
                                        dbo.recibos.num_conc ,
                                        dbo.recibos.concepto
                                        WITH CUBE

                                     
                        IF @porCentro = 1 
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                  --supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          importe ,
                                          gravable ,
                                          exento ,
                                          tipoPago ,
                                          saldoPercepcion
                                        )
                                        SELECT  '99999999999996' AS centro ,
                                        --NULL, --999999995 AS supervisor ,
                                                999999995 AS codigo ,
                                                dbo.recibos.num_conc AS numeroConcepto ,
                                                CASE WHEN dbo.recibos.concepto IS NULL
                                                     THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                     ELSE dbo.recibos.concepto
                                                END AS nombreConcepto ,
                                                SUM(dbo.recibos.importe) AS importePercepciones ,
                                                SUM(dbo.recibos.igravable) AS gravablePercepciones ,
                                                SUM(dbo.recibos.iexento) AS exentoPercepciones ,
                                                CASE WHEN dbo.recibos.num_conc >= 1
                                                          AND dbo.recibos.num_conc <= 99
                                                     THEN 1
                                                     WHEN dbo.recibos.num_conc >= 1101
                                                          AND dbo.recibos.num_conc <= 1199
                                                     THEN 1
                                                     WHEN dbo.recibos.num_conc >= 101
                                                          AND dbo.recibos.num_conc <= 199
                                                     THEN 2
                                                     WHEN dbo.recibos.num_conc >= 1001
                                                          AND dbo.recibos.num_conc <= 1099
                                                     THEN 2
                                                     WHEN dbo.recibos.num_conc >= 201
                                                          AND dbo.recibos.num_conc <= 299
                                                     THEN 3
                                                     ELSE 0
                                                END ,
                                                SUM(CASE WHEN ( ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.recibos.saldo > 0
                                                         THEN CASE
                                                              WHEN dbo.recibos.saldo IS NULL
                                                              THEN 0
                                                              ELSE dbo.recibos.saldo
                                                              END
                                                         ELSE 0
                                                    END) AS saldoPercepcion
                                        FROM    dbo.recibos
                                                INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                        WHERE   dbo.recibos.empresa = @empresa
                                                AND dbo.recibos.nomina = @nomina
                                                AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                AND dbo.SeleccionElementos.nomina = @nomina
                                                AND ( ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                          AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                        )
                                                        OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                      )
                                                      OR ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                           OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                              AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                              )
                                                         )
                                                      OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                           AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                         )
                                                    )
                                        GROUP BY --dbo.Llaves.centro ,
                                                dbo.recibos.num_conc ,
                                                dbo.recibos.concepto
                            END
                           
                    END
                    
                -- Ordenado por Centro, Supervisor y Nombre o Codigo
                IF ( ( @ordenadoPor & 16 > 0
                       OR @ordenadoPor & 32 > 0
                     )
                     AND ( @desglosadoPor & 1 > 0
                           OR @desglosadoPor & 2 > 0
                         )
                   ) 
                    BEGIN
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  importe ,
                                  gravable ,
                                  exento ,
                                  centroGrupo ,
                                  conceptoGrupo ,
                                  tipoPago ,
                                  supervisorGrupo ,
                                  saldoPercepcion
                                    
                                )
                                SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                             THEN '99999999999997'
                                             ELSE dbo.Llaves.centro
                                        END AS centro ,
                                        CASE WHEN dbo.Llaves.supervisor IS NULL
                                             THEN 999999995
                                             ELSE dbo.Llaves.supervisor
                                        END ,
                                        999999995 AS codigo ,
                                        CASE WHEN dbo.recibos.num_conc IS NULL
                                             THEN 9995
                                             ELSE dbo.recibos.num_conc
                                        END AS numeroConcepto ,
                                        CASE WHEN dbo.recibos.concepto IS NULL
                                             THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                             ELSE dbo.recibos.concepto
                                        END AS nombreConcepto ,
                                        SUM(dbo.recibos.importe) AS importePercepciones ,
                                        SUM(dbo.recibos.igravable) AS gravablePercepciones ,
                                        SUM(dbo.recibos.iexento) AS exentoPercepciones ,
                                        CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                             THEN '99999999999997'
                                             ELSE ''
                                        END AS centroGrupo ,
                                        CASE WHEN GROUPING(dbo.recibos.num_conc) = 1
                                             THEN 999999995
                                             ELSE 0
                                        END AS ConceptoGrupo ,
                                        CASE WHEN dbo.recibos.num_conc >= 1
                                                  AND dbo.recibos.num_conc <= 99
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 1101
                                                  AND dbo.recibos.num_conc <= 1199
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 101
                                                  AND dbo.recibos.num_conc <= 199
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 1001
                                                  AND dbo.recibos.num_conc <= 1099
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 201
                                                  AND dbo.recibos.num_conc <= 299
                                             THEN 3
                                             ELSE 0
                                        END AS tipoPago ,
                                        CASE WHEN GROUPING(dbo.Llaves.supervisor) = 1
                                             THEN 99995
                                             ELSE 0
                                        END AS supervisorGrupo ,
                                        SUM(CASE WHEN ( ( dbo.recibos.num_conc >= 1
                                                          AND dbo.recibos.num_conc <= 99
                                                        )
                                                        OR ( dbo.recibos.num_conc >= 1101
                                                             AND dbo.recibos.num_conc <= 1199
                                                           )
                                                      )
                                                      AND dbo.recibos.saldo > 0
                                                 THEN CASE WHEN dbo.recibos.saldo IS NULL
                                                           THEN 0
                                                           ELSE dbo.recibos.saldo
                                                      END
                                                 ELSE 0
                                            END) AS saldoPercepcion
                                FROM    dbo.recibos
                                        INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                WHERE   dbo.recibos.empresa = @empresa
                                        AND dbo.recibos.nomina = @nomina
                                        AND ( ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                  AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                )
                                                OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                              )
                                              OR ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                                   OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                        AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                      )
                                                 )
                                              OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                   AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                 )
                                            )
                                GROUP BY dbo.Llaves.centro ,
                                        dbo.Llaves.supervisor ,
                                        dbo.recibos.num_conc ,
                                        dbo.recibos.concepto
                                        WITH CUBE
                                ORDER BY dbo.Llaves.centro ,
                                        dbo.Llaves.supervisor ,
                                        dbo.recibos.num_conc ASC
                    
                        IF @porCentro = 1 
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          importe ,
                                          gravable ,
                                          exento ,
                                          tipoPago ,
                                          saldoPercepcion
                                        )
                                        SELECT  '99999999999996' AS centro ,
                                                999999995 AS supervisor ,
                                                999999995 AS codigo ,
                                                dbo.recibos.num_conc AS numeroConcepto ,
                                                dbo.recibos.concepto AS nombreConcepto ,
                                                SUM(dbo.recibos.importe) AS importePercepciones ,
                                                SUM(dbo.recibos.igravable) AS gravablePercepciones ,
                                                SUM(dbo.recibos.iexento) AS exentoPercepciones ,
                                                CASE WHEN dbo.recibos.num_conc >= 1
                                                          AND dbo.recibos.num_conc <= 99
                                                     THEN 1
                                                     WHEN dbo.recibos.num_conc >= 1101
                                                          AND dbo.recibos.num_conc <= 1199
                                                     THEN 1
                                                     WHEN dbo.recibos.num_conc >= 101
                                                          AND dbo.recibos.num_conc <= 199
                                                     THEN 2
                                                     WHEN dbo.recibos.num_conc >= 1001
                                                          AND dbo.recibos.num_conc <= 1099
                                                     THEN 2
                                                     WHEN dbo.recibos.num_conc >= 201
                                                          AND dbo.recibos.num_conc <= 299
                                                     THEN 3
                                                     ELSE 0
                                                END AS tipoPago ,
                                                SUM(CASE WHEN ( ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              )
                                                              )
                                                              AND dbo.recibos.saldo > 0
                                                         THEN CASE
                                                              WHEN dbo.recibos.saldo IS NULL
                                                              THEN 0
                                                              ELSE dbo.recibos.saldo
                                                              END
                                                         ELSE 0
                                                    END) AS saldoPercepcion
                                        FROM    dbo.recibos
                                                INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                        WHERE   dbo.recibos.empresa = @empresa
                                                AND dbo.recibos.nomina = @nomina
                                                AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                AND dbo.SeleccionElementos.nomina = @nomina
                                                AND ( ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                          AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                        )
                                                        OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                      )
                                                      OR ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                             AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                           )
                                                           OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                              AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                              )
                                                         )
                                                      OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                           AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                         )
                                                    )
                                        GROUP BY --dbo.Llaves.centro ,
                                        --dbo.Llaves.supervisor ,
                                                dbo.recibos.num_conc ,
                                                dbo.recibos.concepto
                                        --WITH CUBE
                                        ORDER BY --dbo.Llaves.centro ,
                                        --dbo.Llaves.supervisor ,
                                                dbo.recibos.num_conc ASC
                            END
                        
                    END


                -- desglosadoPor = 4 
                -- quiere decir que solo se va imprimir el total general
                IF @ordenadoPor = 0
                    AND @desglosadoPor & 4 > 0 
                    BEGIN
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  --supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  importe ,
                                  gravable ,
                                  exento ,
                                  tipoPago ,
                                  saldoPercepcion
                                )
                                SELECT  '99999999999997' AS centro ,
                                        --NULL, --999999995 AS supervisor ,
                                        999999995 AS codigo ,
                                        dbo.recibos.num_conc AS numeroConcepto ,
                                        dbo.recibos.concepto AS nombreConcepto ,
                                        SUM(dbo.recibos.importe) AS importePercepciones ,
                                        SUM(dbo.recibos.igravable) AS gravablePercepciones ,
                                        SUM(dbo.recibos.iexento) AS exentoPercepciones ,
                                        CASE WHEN dbo.recibos.num_conc >= 1
                                                  AND dbo.recibos.num_conc <= 99
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 1101
                                                  AND dbo.recibos.num_conc <= 1199
                                             THEN 1
                                             WHEN dbo.recibos.num_conc >= 101
                                                  AND dbo.recibos.num_conc <= 199
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 1001
                                                  AND dbo.recibos.num_conc <= 1099
                                             THEN 2
                                             WHEN dbo.recibos.num_conc >= 201
                                                  AND dbo.recibos.num_conc <= 299
                                             THEN 3
                                             ELSE 0
                                        END ,
                                        SUM(CASE WHEN ( ( dbo.recibos.num_conc >= 1
                                                          AND dbo.recibos.num_conc <= 99
                                                        )
                                                        OR ( dbo.recibos.num_conc >= 1101
                                                             AND dbo.recibos.num_conc <= 1199
                                                           )
                                                      )
                                                      AND dbo.recibos.saldo > 0
                                                 THEN CASE WHEN dbo.recibos.saldo IS NULL
                                                           THEN 0
                                                           ELSE dbo.recibos.saldo
                                                      END
                                                 ELSE 0
                                            END) AS saldoPercepcion
                                FROM    dbo.recibos
                                WHERE   dbo.recibos.empresa = @empresa
                                        AND dbo.recibos.nomina = @nomina
                                        AND ( ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionInicio
                                                              ELSE 0
                                                              END
                                                  AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoPercepcionTermino
                                                              ELSE 0
                                                              END
                                                )
                                                OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'P'
                                                              THEN @numeroConceptoContraPercepcionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                              )
                                              OR ( ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionInicio
                                                              ELSE 0
                                                              END
                                                     AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoDeduccionTermino
                                                              ELSE 0
                                                              END
                                                   )
                                                   OR ( dbo.recibos.num_conc >= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionInicio
                                                              ELSE 0
                                                              END
                                                        AND dbo.recibos.num_conc <= CASE
                                                              WHEN @queConcepto = 'D'
                                                              THEN @numeroConceptoContraDeduccionTermino
                                                              ELSE 0
                                                              END
                                                      )
                                                 )
                                              OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                   AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                 )
                                            )
                                GROUP BY dbo.recibos.num_conc ,
                                        dbo.recibos.concepto
                    END                    
                    

                -- Anexo Concepto Percepcion por Centro
                -- Llena el campo anexoConceptoPercepcion 
                -- con desglose por departamento
                IF @queConcepto = 'P' 
                    BEGIN
                        IF ( ( @ordenadoPor & 4 > 0
                               OR @ordenadoPor & 8 > 0
                             )
                             OR ( ( @ordenadoPor & 1 > 0
                                    OR @ordenadoPor & 2 > 0
                                  )
                                  AND @desglosadoPor & 2 > 0
                                )
                           ) 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.horas)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )
                            END
                            
                            
                        IF ( ( @ordenadoPor & 16 > 0
                               OR @ordenadoPor & 32 > 0
                             )
                             AND ( @desglosadoPor & 1 > 0
                                   OR @desglosadoPor & 2 > 0
                                 )
                           ) 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.horas)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )                           
                            END                             
                            
-- Anexo Concepto Percepcion Total Centro
                        -- Llena el campo anexoConceptoPercepcion 
                        -- solo el total General
                        UPDATE  [@resumenPorCentroTemporal]
                        SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.horas)
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                        FROM    @resumenPorCentroTemporal
                        WHERE   [@resumenPorCentroTemporal].centro = '99999999999997'
                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                      )
                                      OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                           AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                         )
                                      OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                    )
                                    
                                    
                        IF @porCentro = 1 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoPercepcion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.horas)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              )) + ' Horas'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 36
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro = '99999999999996'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                            )
                            END            
                    END
                                                              
                                                              

-- Anexo Concepto Deduccion por Centro
                -- Llena el campo anexoConceptoDeduccion
                -- con desglose por departamento
                IF @queConcepto = 'D' 
                    BEGIN
                        IF ( ( @ordenadoPor & 4 > 0
                               OR @ordenadoPor & 8 > 0
                             )
                             OR ( ( @ordenadoPor & 1 > 0
                                    OR @ordenadoPor & 2 > 0
                                  )
                                  AND @desglosadoPor & 2 > 0
                                )
                           ) 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.dias)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )
                            END


                        IF ( ( @ordenadoPor & 16 > 0
                               OR @ordenadoPor & 32 > 0
                             )
                             AND ( @desglosadoPor & 1 > 0
                                   OR @desglosadoPor & 2 > 0
                                 )
                           ) 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.dias)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.Llaves.centro = [@resumenPorCentroTemporal].centro
                                                              AND CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE dbo.Llaves.supervisor
                                                              END = CASE
                                                              WHEN [@resumenPorCentroTemporal].supervisor = 999999995
                                                              THEN 1
                                                              ELSE [@resumenPorCentroTemporal].supervisor
                                                              END
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro <> '99999999999997'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 1
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 7
                                              )
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 10
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 13
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 36
                                              OR ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                   AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                 )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )                           
                            END

                            

-- Anexo Concepto Deduccion Total Centro
                        -- Llena el campo anexoConceptoDeduccion
                        -- solo el total General
                        UPDATE  [@resumenPorCentroTemporal]
                        SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.dias)
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                        FROM    @resumenPorCentroTemporal
                        WHERE   [@resumenPorCentroTemporal].centro = '99999999999997'
                                AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                        AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                      )
                                      OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                      OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                    )
                                    
                        IF @porCentro = 1 
                            BEGIN
                                UPDATE  [@resumenPorCentroTemporal]
                                SET     [@resumenPorCentroTemporal].anexoConceptoDeduccion = CASE
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                              AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                                              THEN CONVERT(VARCHAR(50), ( SELECT
                                                              SUM(dbo.recibos.dias)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              )) + ' Das'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 112
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              WHEN [@resumenPorCentroTemporal].numeroConcepto = 136
                                                              THEN CONVERT(VARCHAR(50), ( SELECT DISTINCT
                                                              COUNT(dbo.recibos.num_conc)
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.num_conc = [@resumenPorCentroTemporal].numeroConcepto
                                                              AND LTRIM(RTRIM(dbo.recibos.concepto)) = LTRIM(RTRIM([@resumenPorCentroTemporal].nombreConcepto))
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              ))
                                                              + ' Empleados'
                                                              ELSE NULL
                                                              END
                                FROM    @resumenPorCentroTemporal
                                WHERE   [@resumenPorCentroTemporal].centro = '99999999999996'
                                        AND ( ( [@resumenPorCentroTemporal].numeroConcepto >= 108
                                                AND [@resumenPorCentroTemporal].numeroConcepto <= 111
                                              )
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 112
                                              OR [@resumenPorCentroTemporal].numeroConcepto = 136
                                            )
                            END           
                    END
            END
        ELSE 
            IF @porDetalle = 'N' 
                BEGIN
                    -- Genera un registro por trabajador y renglon
                    IF ( @ordenadoPor & 1 > 0
                         OR @ordenadoPor & 2 > 0
                       )
                        AND @desglosadoPor & 1 > 0 
                        BEGIN
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      --supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      nombreConcepto ,
                                      tipoPago
                                    )
                                    SELECT  '99999999999997' ,
                                            --NULL, --999999995 AS supervisor ,
                                            999999995 AS codigo ,
                                            dbo.recibos.num_conc AS numeroConcepto ,
                                            dbo.recibos.concepto ,
                                            CASE WHEN dbo.recibos.num_conc >= 1
                                                      AND dbo.recibos.num_conc <= 99
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 1101
                                                      AND dbo.recibos.num_conc <= 1199
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 101
                                                      AND dbo.recibos.num_conc <= 199
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 1001
                                                      AND dbo.recibos.num_conc <= 1099
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 201
                                                      AND dbo.recibos.num_conc <= 299
                                                 THEN 3
                                                 ELSE 0
                                            END AS tipoPago
                                    FROM    dbo.recibos
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                                    GROUP BY dbo.recibos.num_conc ,
                                            dbo.recibos.concepto
                        END             
            
             
                    IF ( ( @ordenadoPor & 4 > 0
                           OR @ordenadoPor & 8 > 0
                         )
                         OR ( ( @ordenadoPor & 1 > 0
                                OR @ordenadoPor & 2 > 0
                              )
                              AND @desglosadoPor & 2 > 0
                            )
                       ) 
                        -- Gernera un registro por centro y renglon
                        BEGIN
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      --supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      nombreConcepto ,
                                      centroGrupo ,
                                      conceptoGrupo ,
                                      tipoPago
                                    )
                                    SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                                 THEN '99999999999997'
                                                 ELSE dbo.Llaves.centro
                                            END AS centroGrupo ,
                                            --NULL, --999999995 AS supervisor ,
                                            999999995 AS codigo ,
                                            CASE WHEN dbo.recibos.num_conc IS NULL
                                                 THEN 9995
                                                 ELSE dbo.recibos.num_conc
                                            END AS numeroConcepto ,
                                            CASE WHEN dbo.recibos.concepto IS NULL
                                                 THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                 ELSE dbo.recibos.concepto
                                            END AS nombreConcepto ,
                                            CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                                 THEN '99999999999997'
                                                 ELSE ''
                                            END AS centroGrupo ,
                                            CASE WHEN GROUPING(dbo.recibos.num_conc) = 1
                                                 THEN 999999995
                                                 ELSE 0
                                            END AS ConceptoGrupo ,
                                            CASE WHEN dbo.recibos.num_conc >= 1
                                                      AND dbo.recibos.num_conc <= 99
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 1101
                                                      AND dbo.recibos.num_conc <= 1199
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 101
                                                      AND dbo.recibos.num_conc <= 199
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 1001
                                                      AND dbo.recibos.num_conc <= 1099
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 201
                                                      AND dbo.recibos.num_conc <= 299
                                                 THEN 3
                                                 ELSE 0
                                            END
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                            INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.centro
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                            AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                            AND dbo.SeleccionElementos.nomina = @nomina
                                            AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                                    GROUP BY dbo.Llaves.centro ,
                                            dbo.recibos.num_conc ,
                                            dbo.recibos.concepto
                                            WITH CUBE
                                            
                        
                            -- Agrega el registro de total por cada centro
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      --supervisor ,
                                      codigo ,
                                      tipoPago ,
                                      renglon
                                    )
                                    SELECT  DISTINCT
                                            dbo.Llaves.centro ,
                                            --NULL, --999999996 AS supervisor ,
                                            999999996 AS codigo ,
                                            4 ,
                                            1
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                            INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.Llaves.centro
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porCentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                            AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                            AND dbo.SeleccionElementos.nomina = @nomina
                                            AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )

                                                
                            IF @porCentro = 1 
                                BEGIN
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                      --supervisor ,
                                              codigo ,
                                              numeroConcepto ,
                                              nombreConcepto ,
                                              tipoPago
                                            )
                                            SELECT  DISTINCT
                                                    '99999999999996' AS centro ,
                                            --NULL, --999999995 AS supervisor ,
                                                    999999995 AS codigo ,
                                                    dbo.recibos.num_conc ,
                                                    RTRIM(LTRIM(dbo.recibos.concepto)) ,
                                                    CASE WHEN dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                         THEN 1
                                                         WHEN dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                         THEN 1
                                                         WHEN dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                         THEN 2
                                                         WHEN dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                         THEN 2
                                                         WHEN dbo.recibos.num_conc >= 201
                                                              AND dbo.recibos.num_conc <= 299
                                                         THEN 3
                                                         ELSE 0
                                                    END
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                            GROUP BY dbo.recibos.num_conc ,
                                                    RTRIM(LTRIM(dbo.recibos.concepto))
                                END
                              
                        END   
                        
                        
                    -- Por centro, supervisor y nombre o codigo
                    IF ( ( @ordenadoPor & 16 > 0
                           OR @ordenadoPor & 32 > 0
                         )
                         AND ( @desglosadoPor & 1 > 0
                               OR @desglosadoPor & 2 > 0
                             )
                       ) 
                        BEGIN
                        
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      nombreConcepto ,
                                      centroGrupo ,
                                      conceptoGrupo ,
                                      tipoPago ,
                                      supervisorGrupo
                                    )
                                    SELECT  CASE WHEN dbo.Llaves.centro IS NULL
                                                 THEN '99999999999997'
                                                 ELSE dbo.Llaves.centro
                                            END AS centro ,
                                            CASE WHEN dbo.Llaves.supervisor IS NULL
                                                 THEN 999999995
                                                 ELSE dbo.Llaves.supervisor
                                            END ,
                                            999999995 AS codigo ,
                                            CASE WHEN dbo.recibos.num_conc IS NULL
                                                 THEN 9995
                                                 ELSE dbo.recibos.num_conc
                                            END AS numeroConcepto ,
                                            CASE WHEN dbo.recibos.concepto IS NULL
                                                 THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                                                 ELSE dbo.recibos.concepto
                                            END AS nombreConcepto ,
                                            CASE WHEN GROUPING(dbo.Llaves.centro) = 1
                                                 THEN '99999999999997'
                                                 ELSE ''
                                            END AS centroGrupo ,
                                            CASE WHEN GROUPING(dbo.recibos.num_conc) = 1
                                                 THEN 999999995
                                                 ELSE 0
                                            END AS ConceptoGrupo ,
                                            CASE WHEN dbo.recibos.num_conc >= 1
                                                      AND dbo.recibos.num_conc <= 99
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 1101
                                                      AND dbo.recibos.num_conc <= 1199
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 101
                                                      AND dbo.recibos.num_conc <= 199
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 1001
                                                      AND dbo.recibos.num_conc <= 1099
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 201
                                                      AND dbo.recibos.num_conc <= 299
                                                 THEN 3
                                                 ELSE 0
                                            END AS tipoPago ,
                                            CASE WHEN GROUPING(dbo.Llaves.supervisor) = 1
                                                 THEN 99995
                                                 ELSE 0
                                            END AS supervisorGrupo
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                                    GROUP BY dbo.Llaves.centro ,
                                            dbo.Llaves.supervisor ,
                                            dbo.recibos.num_conc ,
                                            dbo.recibos.concepto
                                            WITH CUBE
                                    ORDER BY dbo.Llaves.centro ,
                                            dbo.Llaves.supervisor ,
                                            dbo.recibos.num_conc ASC
                                            
                            
                                            
                            -- Agrega el registro de total por cada centro
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      tipoPago ,
                                      renglon
                                    )
                                    SELECT  DISTINCT
                                            dbo.Llaves.centro ,
                                            dbo.Llaves.supervisor ,
                                            999999996 AS codigo ,
                                            4 ,
                                            1
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                         
                                                
                            IF @porCentro = 1 --AND (@desglosadoPor & 2 > 0 OR @desglosadoPor & 4 > 0)
                                BEGIN
                                    INSERT  @resumenPorCentroTemporal
                                            ( centro ,
                                              supervisor ,
                                              codigo ,
                                              numeroConcepto ,
                                              nombreConcepto ,
                                              tipoPago ,
                                              supervisorGrupo
                                            )
                                            SELECT  DISTINCT
                                                    '99999999999996' AS centro ,
                                                    999999995 AS supervisor ,
                                                    999999995 AS codigo ,
                                                    dbo.recibos.num_conc ,
                                                    dbo.recibos.concepto ,
                                                    CASE WHEN dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                         THEN 1
                                                         WHEN dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                         THEN 1
                                                         WHEN dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                         THEN 2
                                                         WHEN dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                         THEN 2
                                                         WHEN dbo.recibos.num_conc >= 201
                                                              AND dbo.recibos.num_conc <= 299
                                                         THEN 3
                                                         ELSE 0
                                                    END ,
                                                    99995
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                            )
                                                            OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                              )
                                                          )
                                                          OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                              )
                                                              OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                              )
                                                             )
                                                          OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                              AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                             )
                                                        )
                                            GROUP BY dbo.recibos.num_conc ,
                                                    dbo.recibos.concepto
                                END                                                
                            
                        END
                        
                       
                        
                    IF @ordenadoPor = 0
                        AND @desglosadoPor & 4 > 0 
                        -- Agrega un registro por cada renglon 
                        -- solo total general
                        BEGIN
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      nombreConcepto ,
                                      tipoPago
                                    )
                                    SELECT  '99999999999997' AS centro ,
                                            CASE WHEN @porSupervisor = 1
                                                 THEN 999999996
                                                 ELSE NULL
                                            END , --NULL, --999999995 AS supervisor ,
                                            999999995 AS codigo ,
                                            dbo.recibos.num_conc ,
                                            dbo.recibos.concepto ,
                                            CASE WHEN dbo.recibos.num_conc >= 1
                                                      AND dbo.recibos.num_conc <= 99
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 1101
                                                      AND dbo.recibos.num_conc <= 1199
                                                 THEN 1
                                                 WHEN dbo.recibos.num_conc >= 101
                                                      AND dbo.recibos.num_conc <= 199
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 1001
                                                      AND dbo.recibos.num_conc <= 1099
                                                 THEN 2
                                                 WHEN dbo.recibos.num_conc >= 201
                                                      AND dbo.recibos.num_conc <= 299
                                                 THEN 3
                                                 ELSE 0
                                            END
                                    FROM    dbo.recibos
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND nomina = @nomina
                                            AND ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicio
                                                      AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTermino
                                                    )
                                                    OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTermino
                                                       )
                                                  )
                                                  OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicio
                                                         AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTermino
                                                       )
                                                       OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicio
                                                            AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTermino
                                                          )
                                                     )
                                                  OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicio
                                                       AND dbo.recibos.num_conc <= @numeroConceptoProvisionTermino
                                                     )
                                                )
                                    GROUP BY dbo.recibos.num_conc ,
                                            dbo.recibos.concepto
                        END


                    IF @porCentro = 1
                        AND ( @desglosadoPor & 1 > 0
                              OR @desglosadoPor & 2 > 0
                            ) 
                        BEGIN
                         -- Agrega registro de Total General para los centros seleccionados
                            INSERT  @resumenPorCentroTemporal
                                    ( centro ,
                                      supervisor ,
                                      codigo ,
                                      numeroConcepto ,
                                      tipoPago ,
                                      renglon
                                    )
                            VALUES  ( '99999999999996' ,
                                      CASE WHEN @porSupervisor = 1
                                           THEN 999999996
                                           ELSE NULL
                                      END ,
                                      999999996 ,
                                      9996 ,
                                      4 ,
                                      1
                                    )
                        END
                      

                    -- Agrega registro de Total General
                    INSERT  @resumenPorCentroTemporal
                            ( centro ,
                              supervisor ,
                              codigo ,
                              numeroConcepto ,
                              tipoPago ,
                              renglon
                            )
                    VALUES  ( '99999999999997 ' ,
                              CASE WHEN @porSupervisor = 1 THEN 999999996
                                   ELSE NULL
                              END ,
                              999999996 ,
                              9996 ,
                              4 ,
                              1
                            )
                                  
                END
            
            ELSE 
                IF @porDetalle = 'T' 
                    BEGIN
                    
                        SET @conceptosBaseImpuestoSobreNomina = ISNULL(( SELECT
                                                              dbo.conceptos.totales
                                                              FROM
                                                              dbo.conceptos
                                                              WHERE
                                                              dbo.conceptos.empresa = @empresa
                                                              AND dbo.conceptos.centro = ''
                                                              AND dbo.conceptos.clase = ''
                                                              AND num_conc = 216
                                                              ), '')
                                                              
                                                              
                        SET @conceptosBaseImpuestoSobreNomina = CASE
                                                              WHEN LEN(@conceptosBaseImpuestoSobreNomina) > 0
                                                              THEN LTRIM(RTRIM(SUBSTRING(@conceptosBaseImpuestoSobreNomina,
                                                              2,
                                                              LEN(@conceptosBaseImpuestoSobreNomina)
                                                              - 4)))
                                                              ELSE ''
                                                              END
                        SET @conceptosBaseImpuestoSobreNomina = @conceptosBaseImpuestoSobreNomina
                            + CASE WHEN SUBSTRING(@conceptosBaseImpuestoSobreNomina,
                                                  LEN(@conceptosBaseImpuestoSobreNomina),
                                                  1) <> ',' THEN ','
                                   ELSE ''
                              END
                                        
                        SET @contador = 1
                        SET @cadena = ''

                        WHILE @contador <= LEN(@conceptosBaseImpuestoSobreNomina) 
                            BEGIN
                                SET @caracter = SUBSTRING(@conceptosBaseImpuestoSobreNomina,
                                                          @contador, 1)
        
                                IF @caracter IN ( '1', '2', '3', '4', '5', '6',
                                                  '7', '8', '9', '0' ) 
                                    SET @cadena = @cadena + @caracter
                                ELSE 
                                    IF @caracter = ',' 
                                        BEGIN
                                            INSERT  @tablaConceptoBaseImpuestoSobreNomina
                                                    ( numeroConcepto )
                                            VALUES  ( CONVERT(INT, @cadena)  -- codigo - int
                                                      )
                                            SET @cadena = ''
                                        END
                                SET @contador = @contador + 1
                            END
                        
                        SET @importeBaseImpuestoSobreNomina = ISNULL(( SELECT SUM(CASE WHEN dbo.recibos.num_conc >= 1
                                                                                            AND dbo.recibos.num_conc <= 99 THEN 1
                                                                                       WHEN dbo.recibos.num_conc >= 1101
                                                                                            AND dbo.recibos.num_conc <= 1199 THEN 1
                                                                                       WHEN dbo.recibos.num_conc >= 101
                                                                                            AND dbo.recibos.num_conc <= 199 THEN -1
                                                                                       WHEN dbo.recibos.num_conc >= 1001
                                                                                            AND dbo.recibos.num_conc <= 1099 THEN -1
                                                                                       ELSE 1
                                                                                  END * importe)
                                                                       FROM dbo.recibos
                                                                       WHERE dbo.recibos.empresa = @empresa
                                                                             AND dbo.recibos.nomina = @nomina
                                                                             AND dbo.recibos.num_conc IN ( SELECT [@tablaConceptoBaseImpuestoSobreNomina].numeroConcepto
                                                                                                           FROM @tablaConceptoBaseImpuestoSobreNomina 
                                                                                                         )
                                                                     ), 0)
                                                              
                                                              
                        SELECT TOP 1
                                @ejercicio = SUBSTRING(CONVERT(VARCHAR(15), dbo.apsiispt.trimestre),
                                                       1, 4) ,
                                @diarioOficial = dbo.apsiispt.diario_of ,
                                @baseCalculo = CASE WHEN dbo.apsiispt.base_calc = 'P'
                                                    THEN 1
                                                    WHEN dbo.apsiispt.base_calc = 'M'
                                                    THEN 2
                                                    ELSE 0
                                               END
                        FROM    dbo.apsiispt
                        WHERE   dbo.apsiispt.empresa = @empresa
                                AND dbo.apsiispt.mca_ultimo = 'U'
                                
                                
                        SET @empleados = ISNULL(( SELECT DISTINCT
                                                         COUNT(dbo.recibos.num_conc)
                                                  FROM     dbo.recibos
                                                  WHERE    dbo.recibos.empresa = @empresa
                                                           AND dbo.recibos.nomina = @nomina
                                                           AND dbo.recibos.num_conc = @tipoNomina
                                                ),0)
                                                              
                        SET @provisionIMSS = CASE WHEN @regimenSeguridadSocial = 1
                                                  THEN ISNULL((SELECT  SUM(dbo.recibos.importe)
                                                               FROM    dbo.recibos
                                                               WHERE   dbo.recibos.empresa = @empresa
                                                                       AND dbo.recibos.nomina = @nomina
                                                                       AND ( dbo.recibos.num_conc = 201
                                                                             OR dbo.recibos.num_conc = 202
                                                                             OR dbo.recibos.num_conc = 203
                                                                             OR dbo.recibos.num_conc = 204
                                                                             OR dbo.recibos.num_conc = 205
                                                                             OR dbo.recibos.num_conc = 208
                                                                             OR dbo.recibos.num_conc = 209
                                                                           )
                                                             ),0)
                                                  ELSE ISNULL((SELECT  SUM(dbo.kardex.importe)
                                                               FROM    dbo.kardex
                                                               WHERE   dbo.kardex.empresa = @empresa
                                                                       AND dbo.kardex.nomina = @nomina
                                                                       AND ( dbo.kardex.num_conc = 201
                                                                             OR dbo.kardex.num_conc = 202
                                                                             OR dbo.kardex.num_conc = 203
                                                                             OR dbo.kardex.num_conc = 204
                                                                             OR dbo.kardex.num_conc = 205
                                                                             OR dbo.kardex.num_conc = 206
                                                                           )
                                                             ),0)
                                             END
                    
                        SET @provisionRCV = CASE WHEN @regimenSeguridadSocial = 1
                                                 THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                                               FROM    dbo.recibos
                                                               WHERE   dbo.recibos.empresa = @empresa
                                                                       AND dbo.recibos.nomina = @nomina
                                                                       AND ( dbo.recibos.num_conc = 206
                                                                             OR dbo.recibos.num_conc = 207
                                                                           )
                                                             ),0)
                                                 ELSE 0
                                            END                    
                                  
                        SET @provisionINFONAVIT = CASE WHEN @regimenSeguridadSocial = 1
                                                       THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                                                     FROM    dbo.recibos
                                                                     WHERE   dbo.recibos.empresa = @empresa
                                                                             AND dbo.recibos.nomina = @nomina
                                                                             AND dbo.recibos.num_conc = 210
                                                                   ),0)
                                                       ELSE ISNULL(( SELECT  ISNULL(SUM(dbo.kardex.importe), 0)
                                                                     FROM    dbo.kardex
                                                                     WHERE   dbo.kardex.empresa = @empresa
                                                                             AND dbo.kardex.nomina = @nomina
                                                                             AND dbo.kardex.num_conc = 207
                                                                   ),0)
                                                  END
                                  
                        SET @retencionIMSS = CASE WHEN @regimenSeguridadSocial = 1
                                                  THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                                                FROM    dbo.recibos
                                                                WHERE   dbo.recibos.empresa = @empresa
                                                                        AND dbo.recibos.nomina = @nomina
                                                                        AND ( dbo.recibos.num_conc = 101
                                                                              OR dbo.recibos.num_conc = 102
                                                                              OR dbo.recibos.num_conc = 103
                                                                              OR dbo.recibos.num_conc = 104
                                                                              OR dbo.recibos.num_conc = 106
                                                                            )
                                                              ),0)
                                                  ELSE 0
                                             END        
                                  
                        SET @retencionRCV = CASE WHEN @regimenSeguridadSocial = 1
                                                 THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                                               FROM    dbo.recibos
                                                               WHERE   dbo.recibos.empresa = @empresa
                                                                       AND dbo.recibos.nomina = @nomina
                                                                       AND dbo.recibos.num_conc = 105
                                                             ),0)
                                                 ELSE 0
                                            END
                                  
                        SET @retencionINFONAVIT = CASE WHEN @regimenSeguridadSocial = 1
                                                       THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                                                     FROM    dbo.recibos
                                                                     WHERE   dbo.recibos.empresa = @empresa
                                                                             AND dbo.recibos.nomina = @nomina
                                                                             AND (dbo.recibos.num_conc = 112
                                                                                  OR dbo.recibos.num_conc = 113
                                                                                 )
                                                                   ),0)
                                                       ELSE 0
                                                  END
                                                    
                        SET @empleadosConCuentaBancaria = ISNULL(( SELECT DISTINCT
                                            ISNULL(COUNT(dbo.empleados.codigo),
                                                   0)
                                    FROM    dbo.empleados
                                    WHERE   dbo.empleados.empresa = @empresa
                                            AND dbo.empleados.cta_bco_no <> ''
                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              )
                                  ),0)
                                  
                        SET @empleadosSinCuentaBancaria = ISNULL(( SELECT DISTINCT
                                            ISNULL(COUNT(dbo.empleados.codigo),
                                                   0)
                                    FROM    dbo.empleados
                                    WHERE   dbo.empleados.empresa = @empresa
                                            AND dbo.empleados.cta_bco_no = ''
                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              )
                                  ),0)
                                  
                        SET @percepcionesConCuentaBancaria = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND ( ( dbo.recibos.num_conc >= 1
                                                    AND dbo.recibos.num_conc <= 99
                                                  )
                                                  OR ( dbo.recibos.num_conc >= 1101
                                                       AND dbo.recibos.num_conc <= 1199
                                                     )
                                                )
                                            AND dbo.empleados.cta_bco_no <> ''
                                  ),0)
                                  
                        SET @deduccionesConCuentaBancaria = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND ( ( dbo.recibos.num_conc >= 101
                                                    AND dbo.recibos.num_conc <= 199
                                                  )
                                                  OR ( dbo.recibos.num_conc >= 1001
                                                       AND dbo.recibos.num_conc <= 1099
                                                     )
                                                )
                                            AND dbo.empleados.cta_bco_no <> ''
                                  ),0)
                                  
                        SET @percepcionesSinCuentaBancaria = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND ( ( dbo.recibos.num_conc >= 1
                                                    AND dbo.recibos.num_conc <= 99
                                                  )
                                                  OR ( dbo.recibos.num_conc >= 1101
                                                       AND dbo.recibos.num_conc <= 1199
                                                     )
                                                )
                                            AND dbo.empleados.cta_bco_no = ''
                                  ),0)
                                  
                        SET @deduccionesSinCuentaBancaria = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                    FROM    dbo.recibos
                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND ( ( dbo.recibos.num_conc >= 101
                                                    AND dbo.recibos.num_conc <= 199
                                                  )
                                                  OR ( dbo.recibos.num_conc >= 1001
                                                       AND dbo.recibos.num_conc <= 1099
                                                     )
                                                )
                                            AND dbo.empleados.cta_bco_no = ''
                                  ),0)
                                  
                        SET @porcientoSobreNomina = ISNULL(( SELECT TOP 1
                                            ISNULL(dbo.recibos.unidades, 0)
                                    FROM    dbo.recibos
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND dbo.recibos.num_conc = 216
                                            AND dbo.recibos.unidades > 0
                                  ),0)
                                  
                        SET @fondoAhorroAportacionEmpleado = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                    FROM    dbo.recibos
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND dbo.recibos.num_conc = 126
                                  ),0)
                                  
                        SET @fondoAhorroAportacionPatron = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe), 0)
                                    FROM    dbo.recibos
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                            AND dbo.recibos.num_conc = 127
                                  ),0)
                                  
                        SET @sueldoNetoGeneral = ISNULL(( SELECT  ISNULL(SUM(CASE WHEN ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 7
                                                              ) THEN 1
                                                            WHEN dbo.recibos.num_conc = 30
                                                            THEN 1
                                                            WHEN ( dbo.recibos.num_conc >= 1108
                                                              AND dbo.recibos.num_conc <= 1111
                                                              ) THEN 1
                                                            WHEN ( dbo.recibos.num_conc >= 108
                                                              AND dbo.recibos.num_conc <= 111
                                                              ) THEN -1
                                                            WHEN ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1007
                                                              ) THEN -1
                                                            WHEN dbo.recibos.num_conc = 1030
                                                            THEN -1
                                                            ELSE 0
                                                       END
                                                       * dbo.recibos.importe),
                                                   0)
                                    FROM    dbo.recibos
                                    WHERE   dbo.recibos.empresa = @empresa
                                            AND dbo.recibos.nomina = @nomina
                                  ),0)

                                  
                    
              -- Agrega Registro de Totales
                        -- Llena el registro de total General
                        -- un solo registro
                        INSERT  @resumenPorCentroTemporal
                                ( centro ,
                                  supervisor ,
                                  codigo ,
                                  numeroConcepto ,
                                  nombreConcepto ,
                                  empleados ,
                                  provisionIMSS ,
                                  provisionRCV ,
                                  provisionINFONAVIT ,
                                  retencionIMSS ,
                                  retencionRCV ,
                                  retencionINFONAVIT ,
                                  empleadosConCuentaBancaria ,
                                  empleadosSinCuentaBancaria ,
                                  percepcionesConCuentaBancaria ,
                                  deduccionesConCuentaBancaria ,
                                  percepcionesSinCuentaBancaria ,
                                  deduccionesSinCuentaBancaria ,
                                  basePorcientoSobreNomina ,
                                  porcientoSobreNomina ,
                                  fondoAhorroAportacionEmpleado ,
                                  fondoAhorroAportacionPatron ,
                                  sueldoNetoGeneral ,
                                  renglon ,
                                  tipoPago ,
                                  ejercicio ,
                                  diarioOficialDia ,
                                  diarioOficialMes ,
                                  diarioOficialAyo ,
                                  salarioMinimoDF ,
                                  salarioMinimoRegion ,
                                  eymArt25 ,
                                  eymArt106ii ,
                                  eymArt107 ,
                                  ivArt147 ,
                                  cvArt168ii ,
                                  baseCalculo 
                                    
                                )
                        VALUES  ( '99999999999997' ,
                                  CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                OR @ordenadoPor & 32 > 0
                                              )
                                              AND ( @desglosadoPor & 1 > 0
                                                    OR @desglosadoPor & 2 > 0
                                                  )
                                            ) THEN 999999996
                                       ELSE NULL
                                  END ,
                                  999999996 ,
                                  9996 ,
                                  'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                  @empleados , --empleados ,
                                  @provisionIMSS  ,   --provisionIMSS ,
                                  @provisionRCV ,  --provisionRCV ,
                                  @provisionINFONAVIT ,
                                  @retencionIMSS ,
                                  @retencionRCV ,
                                  @retencionINFONAVIT ,
                                  @empleadosConCuentaBancaria ,
                                  @empleadosSinCuentaBancaria ,
                                  @percepcionesConCuentaBancaria ,
                                  @deduccionesConCuentaBancaria ,
                                  @percepcionesSinCuentaBancaria ,
                                  @deduccionesSinCuentaBancaria ,
                                  @importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                  @porcientoSobreNomina ,
                                  @fondoAhorroAportacionEmpleado ,
                                  @fondoAhorroAportacionPatron ,
                                  @sueldoNetoGeneral ,
                                  1 , -- AS renglon ,
                                  4 ,--AS tipoPago
                                  @ejercicio ,
                                  DAY(@diarioOficial) ,
                                  MONTH(@diarioOficial) ,
                                  YEAR(@diarioOficial) ,
                                  @salarioDF ,
                                  @salarioRegion ,
                                  @eymArt25 ,
                                  @eymArt1062 ,
                                  @eymArt107 ,
                                  @ivArt147 ,
                                  @cvArt168II ,
                                  @baseCalculo
                                )
                                
                                
                        IF @porCentro = 1 
                            BEGIN
                              SET @empleadosCentro = ISNULL(( SELECT DISTINCT
                                                    ISNULL(COUNT(dbo.recibos.num_conc),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.recibos.num_conc = @tipoNomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                          ),0)
                                          
                              set @provisionIMSSCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                              THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                            FROM    dbo.recibos
                                                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                             AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                         AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                            WHERE   dbo.recibos.empresa = @empresa
                                                                                    AND dbo.recibos.nomina = @nomina
                                                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                                                    AND ( dbo.recibos.num_conc = 201
                                                                                          OR dbo.recibos.num_conc = 202
                                                                                          OR dbo.recibos.num_conc = 203
                                                                                          OR dbo.recibos.num_conc = 204
                                                                                          OR dbo.recibos.num_conc = 205
                                                                                          OR dbo.recibos.num_conc = 208
                                                                                          OR dbo.recibos.num_conc = 209
                                                                                        )
                                                                          ),0)
                                                              ELSE ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                            FROM    dbo.recibos
                                                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                             AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                         AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                            WHERE   dbo.recibos.empresa = @empresa
                                                                                    AND dbo.recibos.nomina = @nomina
                                                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                                                    AND ( dbo.recibos.num_conc = 201
                                                                                          OR dbo.recibos.num_conc = 202
                                                                                          OR dbo.recibos.num_conc = 203
                                                                                          OR dbo.recibos.num_conc = 204
                                                                                          OR dbo.recibos.num_conc = 205
                                                                                          OR dbo.recibos.num_conc = 206
                                                                                        )
                                                                          ),0)
                                                         END
                              
                              set @provisionRCVCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                           FROM    dbo.recibos
                                                                                   INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                            AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                   INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                        AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                           WHERE   dbo.recibos.empresa = @empresa
                                                                                   AND dbo.recibos.nomina = @nomina
                                                                                   AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                   AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                   AND dbo.SeleccionElementos.nomina = @nomina
                                                                                   AND ( dbo.recibos.num_conc = 206
                                                                                         OR dbo.recibos.num_conc = 207
                                                                                       )
                                                                         ),0)
                                                             ELSE 0
                                                        END
                              
                              set @provisionINFONAVITCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                                   THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                                 FROM    dbo.recibos
                                                                                         INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                                  AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                         INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                 WHERE   dbo.recibos.empresa = @empresa
                                                                                         AND dbo.recibos.nomina = @nomina
                                                                                         AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                         AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                         AND dbo.SeleccionElementos.nomina = @nomina
                                                                                         AND dbo.recibos.num_conc = 210
                                                                               ),0)
                                                                   ELSE ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                                 FROM    dbo.recibos
                                                                                         INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                                  AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                         INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                 WHERE   dbo.recibos.empresa = @empresa
                                                                                         AND dbo.recibos.nomina = @nomina
                                                                                         AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                         AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                         AND dbo.SeleccionElementos.nomina = @nomina
                                                                                         AND dbo.recibos.num_conc = 207
                                                                               ),0)
                                                              END
                                                               
                              
                              set @retencionIMSSCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                              THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                            FROM    dbo.recibos
                                                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                             AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                         AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                            WHERE   dbo.recibos.empresa = @empresa
                                                                                    AND dbo.recibos.nomina = @nomina
                                                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                                                    AND ( dbo.recibos.num_conc = 101
                                                                                          OR dbo.recibos.num_conc = 102
                                                                                          OR dbo.recibos.num_conc = 103
                                                                                          OR dbo.recibos.num_conc = 104
                                                                                          OR dbo.recibos.num_conc = 106
                                                                                        )
                                                                          ),0)
                                                              ELSE 0
                                                         END
                                                         
                              
                              set @retencionRCVCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                             THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                           FROM    dbo.recibos
                                                                                   INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                            AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                   INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                        AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                           WHERE   dbo.recibos.empresa = @empresa
                                                                                   AND dbo.recibos.nomina = @nomina
                                                                                   AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                   AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                   AND dbo.SeleccionElementos.nomina = @nomina
                                                                                   AND dbo.recibos.num_conc = 105
                                                                         ),0)
                                                             ELSE 0
                                                        END
                              
                              set @retencionINFONAVITCentro = CASE WHEN @regimenSeguridadSocial = 1
                                                                   THEN ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),0)
                                                                                 FROM    dbo.recibos
                                                                                         INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                                                                                  AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                                                         INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                                                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                                                 WHERE   dbo.recibos.empresa = @empresa
                                                                                         AND dbo.recibos.nomina = @nomina
                                                                                         AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                                                         AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                                                         AND dbo.SeleccionElementos.nomina = @nomina
                                                                                         AND (dbo.recibos.num_conc = 112
                                                                                              OR dbo.recibos.num_conc = 113
                                                                                             )
                                                                               ),0)
                                                                   ELSE 0
                                                              END
                              
                              set @empleadosConCuentaBancariaCentro = ISNULL(( SELECT DISTINCT
                                                    ISNULL(COUNT(dbo.empleados.codigo),
                                                           0)
                                            FROM    dbo.empleados
                                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.empleados.empresa = @empresa
                                                    AND dbo.empleados.cta_bco_no <> ''
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              )
                                          ),0)
                              
                              set @empleadosSinCuentaBancariaCentro = ISNULL(( SELECT DISTINCT
                                                    ISNULL(COUNT(dbo.empleados.codigo),
                                                           0)
                                            FROM    dbo.empleados
                                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.empleados.empresa = @empresa
                                                    AND dbo.empleados.cta_bco_no = ''
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                              INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                              AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                              AND dbo.SeleccionElementos.nomina = @nomina
                                                              )
                                          ),0)
                              
                              set @percepcionesConCuentaBancariaCentro = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( dbo.recibos.num_conc >= 1
                                                            AND dbo.recibos.num_conc <= 99
                                                          )
                                                          OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                             )
                                                        )
                                                    AND dbo.empleados.cta_bco_no <> ''
                                          ),0)
                              
                              set @deduccionesConCuentaBancariaCentro = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( dbo.recibos.num_conc >= 101
                                                            AND dbo.recibos.num_conc <= 199
                                                          )
                                                          OR ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                             )
                                                        )
                                                    AND dbo.empleados.cta_bco_no <> ''
                                          ),0)
                              
                              set @percepcionesSinCuentaBancariaCentro = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( dbo.recibos.num_conc >= 1
                                                            AND dbo.recibos.num_conc <= 99
                                                          )
                                                          OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                             )
                                                        )
                                                    AND dbo.empleados.cta_bco_no = ''
                                          ),0)
                              
                              set @deduccionesSinCuentaBancariaCentro = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                              AND dbo.empleados.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND ( ( dbo.recibos.num_conc >= 101
                                                            AND dbo.recibos.num_conc <= 199
                                                          )
                                                          OR ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                             )
                                                        )
                                                    AND dbo.empleados.cta_bco_no = ''
                                          ),0)
                              
                              set @porcientoSobreNominaCentro = ISNULL(( SELECT TOP 1
                                                    ISNULL(dbo.recibos.unidades,
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND dbo.recibos.num_conc = 216
                                                    AND dbo.recibos.unidades > 0
                                          ),0)
                              
                              set @fondoAhorroAportacionEmpleadoCentro = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND dbo.recibos.num_conc = 126
                                          ),0)
                              
                              set @fondoAhorroAportacionPatronCentro = ISNULL(( SELECT  ISNULL(SUM(dbo.recibos.importe),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                                    AND dbo.recibos.num_conc = 127
                                          ),0)
                              
                              set @sueldoNetoGeneralCentro = ISNULL(( SELECT  ISNULL(SUM(CASE
                                                              WHEN ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN dbo.recibos.num_conc = 30
                                                              THEN 1
                                                              WHEN ( dbo.recibos.num_conc >= 1108
                                                              AND dbo.recibos.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( dbo.recibos.num_conc >= 108
                                                              AND dbo.recibos.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN dbo.recibos.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * dbo.recibos.importe),
                                                           0)
                                            FROM    dbo.recibos
                                                    INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                                    INNER JOIN dbo.SeleccionElementos ON dbo.Llaves.empresa = dbo.SeleccionElementos.empresa
                                                              AND dbo.Llaves.centro = dbo.SeleccionElementos.centro
                                            WHERE   dbo.recibos.empresa = @empresa
                                                    AND dbo.recibos.nomina = @nomina
                                                    AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                                    AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                                    AND dbo.SeleccionElementos.nomina = @nomina
                                          ),0)
                              
                            
                            
                            
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          empleados ,
                                          provisionIMSS ,
                                          provisionRCV ,
                                          provisionINFONAVIT ,
                                          retencionIMSS ,
                                          retencionRCV ,
                                          retencionINFONAVIT ,
                                          empleadosConCuentaBancaria ,
                                          empleadosSinCuentaBancaria ,
                                          percepcionesConCuentaBancaria ,
                                          deduccionesConCuentaBancaria ,
                                          percepcionesSinCuentaBancaria ,
                                          deduccionesSinCuentaBancaria ,
                                          basePorcientoSobreNomina ,
                                          porcientoSobreNomina ,
                                          fondoAhorroAportacionEmpleado ,
                                          fondoAhorroAportacionPatron ,
                                          sueldoNetoGeneral ,
                                          renglon ,
                                          tipoPago ,
                                          ejercicio ,
                                          diarioOficialDia ,
                                          diarioOficialMes ,
                                          diarioOficialAyo ,
                                          salarioMinimoDF ,
                                          salarioMinimoRegion ,
                                          eymArt25 ,
                                          eymArt106ii ,
                                          eymArt107 ,
                                          ivArt147 ,
                                          cvArt168ii ,
                                          baseCalculo 
                                        )
                                VALUES  ( '99999999999996' ,
                                          CASE WHEN ( ( @ordenadoPor & 16 > 0
                                                        OR @ordenadoPor & 32 > 0
                                                      )
                                                      AND ( @desglosadoPor & 1 > 0
                                                            OR @desglosadoPor
                                                            & 2 > 0
                                                          )
                                                    ) THEN 999999996
                                               ELSE NULL
                                          END ,
                                          999999996 ,
                                          9996 ,
                                          'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                          @empleadosCentro ,
                                          @provisionIMSSCentro ,
                                          @provisionRCVCentro ,
                                          @provisionINFONAVITCentro ,
                                          @retencionIMSSCentro ,
                                          @retencionRCVCentro ,
                                          @retencionINFONAVITCentro ,
                                          @empleadosConCuentaBancariaCentro ,
                                          @empleadosSinCuentaBancariaCentro ,
                                          @percepcionesConCuentaBancariaCentro ,
                                          @deduccionesConCuentaBancariaCentro ,
                                          @percepcionesSinCuentaBancariaCentro ,
                                          @deduccionesSinCuentaBancariaCentro ,
                                          @importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                          @porcientoSobreNominaCentro ,
                                          @fondoAhorroAportacionEmpleadoCentro ,
                                          @fondoAhorroAportacionPatronCentro ,
                                          @sueldoNetoGeneral,
                                          1 , -- AS renglon ,
                                          4 ,--AS tipoPago
                                          @ejercicio ,
                                          DAY(@diarioOficial) ,
                                          MONTH(@diarioOficial) ,
                                          YEAR(@diarioOficial) ,
                                          @salarioDF ,
                                          @salarioRegion ,
                                          @eymArt25 ,
                                          @eymArt1062 ,
                                          @eymArt107 ,
                                          @ivArt147 ,
                                          @cvArt168II ,
                                          @baseCalculo
                                        )
                            END
                                
                                
                        IF ( ( @ordenadoPor & 4 > 0
                               OR @ordenadoPor & 8 > 0
                             )
                             OR ( ( @ordenadoPor & 1 > 0
                                    OR @ordenadoPor & 2 > 0
                                  )
                                  AND @desglosadoPor & 2 > 0
                                )
                             OR ( ( @ordenadoPor & 16 > 0
                                    OR @ordenadoPor & 32 > 0
                                  )
                                  AND ( @desglosadoPor & 1 > 0
                                        OR @desglosadoPor & 2 > 0
                                      )
                                )
                           )
                            
                            -- Llena el registro de total
                            -- uno por cada centro de costos
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          renglon ,
                                          empleados ,
                                          provisionIMSS ,
                                          provisionRCV ,
                                          provisionINFONAVIT ,
                                          retencionIMSS ,
                                          retencionRCV ,
                                          retencionINFONAVIT ,
                                          empleadosConCuentaBancaria ,
                                          empleadosSinCuentaBancaria ,
                                          percepcionesConCuentaBancaria ,
                                          deduccionesConCuentaBancaria ,
                                          percepcionesSinCuentaBancaria ,
                                          deduccionesSinCuentaBancaria ,
                                          basePorcientoSobreNomina ,
                                          porcientoSobreNomina ,
                                          fondoAhorroAportacionEmpleado ,
                                          fondoAhorroAportacionPatron ,
                                          sueldoNetoGeneral ,
                                          tipoPago ,
                                          ejercicio ,
                                          diarioOficialDia ,
                                          diarioOficialMes ,
                                          diarioOficialAyo ,
                                          salarioMinimoDF ,
                                          salarioMinimoRegion ,
                                          eymArt25 ,
                                          eymArt106ii ,
                                          eymArt107 ,
                                          ivArt147 ,
                                          cvArt168ii ,
                                          baseCalculo
                                            
                                        )
                                        SELECT DISTINCT
                                                dbo.Llaves.centro ,
                                                CASE WHEN ( ( @ordenadoPor
                                                              & 16 > 0
                                                              OR @ordenadoPor
                                                              & 32 > 0
                                                            )
                                                            AND ( @desglosadoPor
                                                              & 1 > 0
                                                              OR @desglosadoPor
                                                              & 2 > 0
                                                              )
                                                          ) THEN 999999996
                                                     ELSE NULL
                                                END ,
                                                999999996 ,
                                                9996 ,
                                                'XZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                                1 ,
                                                ( SELECT DISTINCT
                                                            ISNULL(COUNT(dbo.recibos.num_conc),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = @tipoNomina
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) , -- empleados ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( dbo.recibos.num_conc = 201
                                                              OR dbo.recibos.num_conc = 202
                                                              OR dbo.recibos.num_conc = 203
                                                              OR dbo.recibos.num_conc = 204
                                                              OR dbo.recibos.num_conc = 205
                                                              OR dbo.recibos.num_conc = 208
                                                              OR dbo.recibos.num_conc = 209
                                                              )
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) , --provisionIMSS ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( dbo.recibos.num_conc = 206
                                                              OR dbo.recibos.num_conc = 207
                                                              )
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --provisionRCV ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 210
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --provisionINFONAVIT ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( dbo.recibos.num_conc = 101
                                                              OR dbo.recibos.num_conc = 102
                                                              OR dbo.recibos.num_conc = 103
                                                              OR dbo.recibos.num_conc = 104
                                                              OR dbo.recibos.num_conc = 106
                                                              )
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --retencionIMSS ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 105
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --retencionRCV ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 112
                                                            AND llaveCentro.centro = llaveCentro.centro
                                                ) ,  --retencionINFONAVIT ,
                                                ( SELECT DISTINCT
                                                            ISNULL(COUNT(dbo.empleados.codigo),
                                                              0)
                                                  FROM      dbo.empleados
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.empleados.empresa = @empresa
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                              )
                                                ) ,  --empleadosConCuentaBancaria ,
                                                ( SELECT DISTINCT
                                                            ISNULL(COUNT(dbo.empleados.codigo),
                                                              0)
                                                  FROM      dbo.empleados
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.empleados.empresa = @empresa
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                            AND dbo.empleados.cta_bco_no = ''
                                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              AND llaveCentro.centro = dbo.Llaves.centro
                                                              )
                                                ) ,  --empleadosSinCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --percepcionesConCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --deduccionesConCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no = ''
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --percepcionesSinCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no = ''
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --deduccionesSinCuentaBancaria ,
                                                ( SELECT    SUM(CASE
                                                              WHEN dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              THEN 1
                                                              WHEN dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              THEN 1
                                                              WHEN dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                              THEN -1
                                                              WHEN dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                              THEN -1
                                                              ELSE 1
                                                              END * importe)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                            AND dbo.recibos.num_conc IN (
                                                            SELECT
                                                              [@tablaConceptoBaseImpuestoSobreNomina].numeroConcepto
                                                            FROM
                                                              @tablaConceptoBaseImpuestoSobreNomina )
                                                ) , --@importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                                ( SELECT TOP 1
                                                            ISNULL(dbo.recibos.unidades,
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 216
                                                            AND dbo.recibos.unidades > 0
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --porcientoSobreNomina ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 126
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --fondoAhorroAportacionEmpleado ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 127
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --fondoAhorroAportacionPatron ,
                                                ( SELECT    ISNULL(SUM(CASE
                                                              WHEN ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN dbo.recibos.num_conc = 30
                                                              THEN 1
                                                              WHEN ( dbo.recibos.num_conc >= 1108
                                                              AND dbo.recibos.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( dbo.recibos.num_conc >= 108
                                                              AND dbo.recibos.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN dbo.recibos.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND llaveCentro.centro = dbo.Llaves.centro
                                                ) ,  --sueldoNetoGeneral
                                                4 ,--AS tipoPago
                                                @ejercicio ,
                                                DAY(@diarioOficial) ,
                                                MONTH(@diarioOficial) ,
                                                YEAR(@diarioOficial) ,
                                                @salarioDF ,
                                                @salarioRegion ,
                                                @eymArt25 ,
                                                @eymArt1062 ,
                                                @eymArt107 ,
                                                @ivArt147 ,
                                                @cvArt168II ,
                                                @baseCalculo
                                        FROM    dbo.recibos
                                                INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                        WHERE   dbo.recibos.empresa = @empresa
                                                AND dbo.recibos.nomina = @nomina
                                        GROUP BY dbo.Llaves.centro
                                   --END
                            END
                            
                        IF ( ( @ordenadoPor & 16 > 0
                               OR @ordenadoPor & 32 > 0
                             )
                             AND ( @desglosadoPor & 1 > 0
                                   OR @desglosadoPor & 2 > 0
                                 )
                           ) 
                            -- Llena el registro de total
                            -- uno por cada centro de costos y supervisor
                            BEGIN
                                INSERT  @resumenPorCentroTemporal
                                        ( centro ,
                                          supervisor ,
                                          codigo ,
                                          numeroConcepto ,
                                          nombreConcepto ,
                                          renglon ,
                                          empleados ,
                                          provisionIMSS ,
                                          provisionRCV ,
                                          provisionINFONAVIT ,
                                          retencionIMSS ,
                                          retencionRCV ,
                                          retencionINFONAVIT ,
                                          empleadosConCuentaBancaria ,
                                          empleadosSinCuentaBancaria ,
                                          percepcionesConCuentaBancaria ,
                                          deduccionesConCuentaBancaria ,
                                          percepcionesSinCuentaBancaria ,
                                          deduccionesSinCuentaBancaria ,
                                          basePorcientoSobreNomina ,
                                          porcientoSobreNomina ,
                                          fondoAhorroAportacionEmpleado ,
                                          fondoAhorroAportacionPatron ,
                                          sueldoNetoGeneral ,
                                          tipoPago ,
                                          ejercicio ,
                                          diarioOficialDia ,
                                          diarioOficialMes ,
                                          diarioOficialAyo ,
                                          salarioMinimoDF ,
                                          salarioMinimoRegion ,
                                          eymArt25 ,
                                          eymArt106ii ,
                                          eymArt107 ,
                                          ivArt147 ,
                                          cvArt168ii ,
                                          baseCalculo
                                        )
                                        SELECT DISTINCT
                                                dbo.Llaves.centro ,
                                                dbo.Llaves.supervisor ,
                                                999999996 ,
                                                9996 ,
                                                'XZZZZZZZZZZZZZZZZZZZZZZZZZZZZX' ,
                                                1 ,
                                                ( SELECT DISTINCT
                                                            ISNULL(COUNT(dbo.recibos.num_conc),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = @tipoNomina
                                                ) , -- empleados ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( dbo.recibos.num_conc = 201
                                                              OR dbo.recibos.num_conc = 202
                                                              OR dbo.recibos.num_conc = 203
                                                              OR dbo.recibos.num_conc = 204
                                                              OR dbo.recibos.num_conc = 205
                                                              OR dbo.recibos.num_conc = 208
                                                              OR dbo.recibos.num_conc = 209
                                                              )
                                                ) , --provisionIMSS ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( dbo.recibos.num_conc = 206
                                                              OR dbo.recibos.num_conc = 207
                                                              )
                                                ) ,  --provisionRCV ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 210
                                                ) ,  --provisionINFONAVIT ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( dbo.recibos.num_conc = 101
                                                              OR dbo.recibos.num_conc = 102
                                                              OR dbo.recibos.num_conc = 103
                                                              OR dbo.recibos.num_conc = 104
                                                              OR dbo.recibos.num_conc = 106
                                                              )
                                                ) ,  --retencionIMSS ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 105
                                                ) ,  --retencionRCV ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 112
                                                ) ,  --retencionINFONAVIT ,
                                                ( SELECT DISTINCT
                                                            ISNULL(COUNT(dbo.empleados.codigo),
                                                              0)
                                                  FROM      dbo.empleados
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.empleados.empresa = @empresa
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              )
                                                ) ,  --empleadosConCuentaBancaria ,
                                                ( SELECT DISTINCT
                                                            ISNULL(COUNT(dbo.empleados.codigo),
                                                              0)
                                                  FROM      dbo.empleados
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.empleados.empresa = @empresa
                                                            AND dbo.empleados.cta_bco_no = ''
                                                            AND dbo.empleados.codigo = ( SELECT DISTINCT
                                                              dbo.recibos.codigo
                                                              FROM
                                                              dbo.recibos
                                                              INNER JOIN dbo.Llaves
                                                              AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                              WHERE
                                                              dbo.recibos.empresa = @empresa
                                                              AND dbo.recibos.nomina = @nomina
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                              )
                                                ) ,  --empleadosSinCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                ) ,  --percepcionesConCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no <> ''
                                                ) ,  --deduccionesConCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no = ''
                                                ) ,  --percepcionesSinCuentaBancaria ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.empleados.empresa = llaveCentro.empresa
                                                              AND dbo.empleados.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND ( ( dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                              )
                                                              OR ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                              )
                                                              )
                                                            AND dbo.empleados.cta_bco_no = ''
                                                ) ,  --deduccionesSinCuentaBancaria ,
                                                ( SELECT    SUM(CASE
                                                              WHEN dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 99
                                                              THEN 1
                                                              WHEN dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              THEN 1
                                                              WHEN dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 199
                                                              THEN -1
                                                              WHEN dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                              THEN -1
                                                              ELSE 1
                                                              END * importe)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc IN (
                                                            SELECT
                                                              [@tablaConceptoBaseImpuestoSobreNomina].numeroConcepto
                                                            FROM
                                                              @tablaConceptoBaseImpuestoSobreNomina )
                                                ) , --@importeBaseImpuestoSobreNomina , --basePorcientoSobreNomina ,
                                                ( SELECT TOP 1
                                                            ISNULL(dbo.recibos.unidades,
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 216
                                                            AND dbo.recibos.unidades > 0
                                                ) ,  --porcientoSobreNomina ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 126
                                                ) ,  --fondoAhorroAportacionEmpleado ,
                                                ( SELECT    ISNULL(SUM(dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                            AND dbo.recibos.num_conc = 127
                                                ) ,  --fondoAhorroAportacionPatron ,
                                                ( SELECT    ISNULL(SUM(CASE
                                                              WHEN ( dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 7
                                                              ) THEN 1
                                                              WHEN dbo.recibos.num_conc = 30
                                                              THEN 1
                                                              WHEN ( dbo.recibos.num_conc >= 1108
                                                              AND dbo.recibos.num_conc <= 1111
                                                              ) THEN 1
                                                              WHEN ( dbo.recibos.num_conc >= 108
                                                              AND dbo.recibos.num_conc <= 111
                                                              ) THEN -1
                                                              WHEN ( dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1007
                                                              ) THEN -1
                                                              WHEN dbo.recibos.num_conc = 1030
                                                              THEN -1
                                                              ELSE 0
                                                              END
                                                              * dbo.recibos.importe),
                                                              0)
                                                  FROM      dbo.recibos
                                                            INNER JOIN dbo.Llaves
                                                            AS llaveCentro ON dbo.recibos.empresa = llaveCentro.empresa
                                                              AND dbo.recibos.codigo = llaveCentro.codigo
                                                              AND dbo.Llaves.centro = llaveCentro.centro
                                                              AND dbo.Llaves.supervisor = llaveCentro.supervisor
                                                  WHERE     dbo.recibos.empresa = @empresa
                                                            AND dbo.recibos.nomina = @nomina
                                                ) ,  --sueldoNetoGeneral
                                                4 ,--AS tipoPago
                                                @ejercicio ,
                                                DAY(@diarioOficial) ,
                                                MONTH(@diarioOficial) ,
                                                YEAR(@diarioOficial) ,
                                                @salarioDF ,
                                                @salarioRegion ,
                                                @eymArt25 ,
                                                @eymArt1062 ,
                                                @eymArt107 ,
                                                @ivArt147 ,
                                                @cvArt168II ,
                                                @baseCalculo
                                        FROM    dbo.recibos
                                                INNER JOIN dbo.Llaves ON dbo.recibos.empresa = dbo.Llaves.empresa
                                                              AND dbo.recibos.codigo = dbo.Llaves.codigo
                                        WHERE   dbo.recibos.empresa = @empresa
                                                AND dbo.recibos.nomina = @nomina
                                        GROUP BY dbo.Llaves.centro ,
                                                dbo.Llaves.supervisor
                            END                            
                    END
            
            

        -- Borra los registros que no son necesarios
        -- generados por la funcion Grouping
        DELETE  @resumenPorCentroTemporal
        WHERE   [@resumenPorCentroTemporal].nombreConcepto = 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZXX'
                OR ( [@resumenPorCentroTemporal].centro = '99999999999997'
                     AND [@resumenPorCentroTemporal].codigo = 999999995
                     AND [@resumenPorCentroTemporal].numeroConcepto = 9995
                     --AND [@resumenPorCentroTemporal].supervisor = 99995
                     
                   )
                OR ( [@resumenPorCentroTemporal].codigo = 999999995
                     AND [@resumenPorCentroTemporal].numeroConcepto = 9995
                     AND [@resumenPorCentroTemporal].centro <> '99999999999996'
                     --AND [@resumenPorCentroTemporal].supervisor = 99995
                     
                   )
                OR ( [@resumenPorCentroTemporal].numeroConcepto = 9995
                     AND [@resumenPorCentroTemporal].conceptoGrupo = 999999995
                     AND [@resumenPorCentroTemporal].supervisorGrupo = 0
                   )
                OR ( [@resumenPorCentroTemporal].centro = '99999999999997'
                     AND [@resumenPorCentroTemporal].codigo = 999999995
                     AND [@resumenPorCentroTemporal].supervisorGrupo = 0
                   )
                   

        -- Pasa de la temporal a la tabla que regresa la funcion
        -- se hace esto para darle la salida en el orden que se 
        -- requiere
        INSERT  @resumenPorCentro
                ( centro ,
                  supervisor ,
                  codigo ,
                  numeroConcepto ,
                  nombreConcepto ,
                  importe ,
                  gravable ,
                  exento ,
                  renglon ,
                  tipoPago ,
                  anexoConceptoPercepcion ,
                  anexoConceptoDeduccion ,
                  empleados ,
                  provisionIMSS ,
                  provisionRCV ,
                  provisionINFONAVIT ,
                  retencionIMSS ,
                  retencionRCV ,
                  retencionINFONAVIT ,
                  empleadosConCuentaBancaria ,
                  empleadosSinCuentaBancaria ,
                  percepcionesConCuentaBancaria ,
                  deduccionesConCuentaBancaria ,
                  percepcionesSinCuentaBancaria ,
                  deduccionesSinCuentaBancaria ,
                  basePorcientoSobreNomina ,
                  porcientoSobreNomina ,
                  fondoAhorroAportacionEmpleado ,
                  fondoAhorroAportacionPatron ,
                  sueldoNetoGeneral ,
                  ejercicio ,
                  diarioOficialDia ,
                  diarioOficialMes ,
                  diarioOficialAyo ,
                  salarioMinimoDF ,
                  salarioMinimoRegion ,
                  eymArt25 ,
                  eymArt106ii ,
                  eymArt107 ,
                  ivArt147 ,
                  cvArt168ii ,
                  baseCalculo 
                )
                SELECT  [@resumenPorCentroTemporal].centro ,
                        [@resumenPorCentroTemporal].supervisor ,
                        [@resumenPorCentroTemporal].codigo ,
                        [@resumenPorCentroTemporal].numeroConcepto ,
                        [@resumenPorCentroTemporal].nombreConcepto ,
                        [@resumenPorCentroTemporal].importe ,
                        [@resumenPorCentroTemporal].gravable ,
                        [@resumenPorCentroTemporal].exento ,
                        [@resumenPorCentroTemporal].renglon ,
                        [@resumenPorCentroTemporal].tipoPago ,
                        [@resumenPorCentroTemporal].anexoConceptoPercepcion ,
                        [@resumenPorCentroTemporal].anexoConceptoDeduccion ,
                        [@resumenPorCentroTemporal].empleados ,
                        [@resumenPorCentroTemporal].provisionIMSS ,
                        [@resumenPorCentroTemporal].provisionRCV ,
                        [@resumenPorCentroTemporal].provisionINFONAVIT ,
                        [@resumenPorCentroTemporal].retencionIMSS ,
                        [@resumenPorCentroTemporal].retencionRCV ,
                        [@resumenPorCentroTemporal].retencionINFONAVIT ,
                        [@resumenPorCentroTemporal].empleadosConCuentaBancaria ,
                        [@resumenPorCentroTemporal].empleadosSinCuentaBancaria ,
                        [@resumenPorCentroTemporal].percepcionesConCuentaBancaria ,
                        [@resumenPorCentroTemporal].deduccionesConCuentaBancaria ,
                        [@resumenPorCentroTemporal].percepcionesSinCuentaBancaria ,
                        [@resumenPorCentroTemporal].deduccionesSinCuentaBancaria ,
                        [@resumenPorCentroTemporal].basePorcientoSobreNomina ,
                        [@resumenPorCentroTemporal].porcientoSobreNomina ,
                        [@resumenPorCentroTemporal].fondoAhorroAportacionEmpleado ,
                        [@resumenPorCentroTemporal].fondoAhorroAportacionPatron ,
                        [@resumenPorCentroTemporal].sueldoNetoGeneral ,
                        [@resumenPorCentroTemporal].ejercicio ,
                        [@resumenPorCentroTemporal].diarioOficialDia ,
                        [@resumenPorCentroTemporal].diarioOficialMes ,
                        [@resumenPorCentroTemporal].diarioOficialAyo ,
                        [@resumenPorCentroTemporal].salarioMinimoDF ,
                        [@resumenPorCentroTemporal].salarioMinimoRegion ,
                        [@resumenPorCentroTemporal].eymArt25 ,
                        [@resumenPorCentroTemporal].eymArt106ii ,
                        [@resumenPorCentroTemporal].eymArt107 ,
                        [@resumenPorCentroTemporal].ivArt147 ,
                        [@resumenPorCentroTemporal].cvArt168ii ,
                        [@resumenPorCentroTemporal].baseCalculo
                FROM    @resumenPorCentroTemporal
                ORDER BY [@resumenPorCentroTemporal].centro ,
                        CASE WHEN @ordenadoPor & 16 > 0
                                  OR @ordenadoPor & 32 > 0
                                  OR @porSupervisor = 1
                             THEN [@resumenPorCentroTemporal].supervisor
                             ELSE ''
                        END ,
                        [@resumenPorCentroTemporal].tipoPago ,
                        [@resumenPorCentroTemporal].numeroConcepto ASC ,
                        [@resumenPorCentroTemporal].nombreConcepto
                        

        IF @porDetalle = 'S'
            OR @porDetalle = 'T' 
            -- Renumera los renglones
            BEGIN
                SET @tipoPagoAnterior = ''
                SET @supervisorAnterior = -1
                SET @renglon = 0

                UPDATE  @resumenPorCentro
                SET     @renglon = CASE WHEN @tipoPagoAnterior <> LTRIM([@resumenPorCentro].centro)
                                             + CASE WHEN @ordenadoPor & 16 > 0
                                                         OR @ordenadoPor & 32 > 0
                                                         OR @porSupervisor = 1
                                                    THEN LTRIM(STR([@resumenPorCentro].supervisor))
                                                    ELSE ''
                                               END
                                             + STR([@resumenPorCentro].tipoPago)
                                        THEN 0
                                        ELSE @renglon
                                   END ,
                        @renglon = @renglon + 1 ,
                        [@resumenPorCentro].renglon = @renglon ,
                        @tipoPagoAnterior = LTRIM([@resumenPorCentro].centro)
                        + CASE WHEN @ordenadoPor & 16 > 0
                                    OR @ordenadoPor & 32 > 0
                                    OR @porSupervisor = 1
                               THEN LTRIM(STR([@resumenPorCentro].supervisor))
                               ELSE ''
                          END + STR([@resumenPorCentro].tipoPago)
            END
        ELSE 
            -- Renumera los renglones
            BEGIN
                SET @centroAnterior = ''
                SET @supervisorAnterior = -1
                SET @renglon = 0

                UPDATE  @resumenPorCentro
                SET     @renglon = CASE WHEN @centroAnterior <> LTRIM([@resumenPorCentro].centro)
                                             + CASE WHEN @ordenadoPor & 16 > 0
                                                         OR @ordenadoPor & 32 > 0
                                                         OR @porSupervisor = 1
                                                    THEN LTRIM(STR([@resumenPorCentro].supervisor))
                                                    ELSE ''
                                               END
                                             + LTRIM(STR([@resumenPorCentro].tipoPago))
                                        THEN 0
                                        ELSE @renglon
                                   END ,
                        @renglon = @renglon + 1 ,
                        [@resumenPorCentro].renglon = @renglon ,
                        @centroAnterior = LTRIM([@resumenPorCentro].centro)
                        + CASE WHEN @ordenadoPor & 16 > 0
                                    OR @ordenadoPor & 32 > 0
                                    OR @porSupervisor = 1
                               THEN LTRIM(STR([@resumenPorCentro].supervisor))
                               ELSE ''
                          END + LTRIM(STR([@resumenPorCentro].tipoPago))
            END                  
        RETURN
    END
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtienePrimaRtRpu') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ObtienePrimaRtRpu
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtienePrimaRtRpu
@Empresa INT,
@Rpu CHAR(3)

AS 

  SET NOCOUNT ON

  SELECT id
         , rp.fecha
         , rp.primaRt
  FROM dbo.Rpu_PrimaRT AS rp
  WHERE empresa = @Empresa
        AND rpu = @Rpu
GO

IF OBJECT_ID('dbo.ActualizaEstadoEmpresasValidaV4') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaEstadoEmpresasValidaV4
GO
CREATE PROCEDURE dbo.ActualizaEstadoEmpresasValidaV4
@usuario VARCHAR(20)
, @empresa INT
, @seleccionada INT

AS

  BEGIN
    SET NOCOUNT ON
    SET XACT_ABORT ON	
    BEGIN TRANSACTION
      BEGIN TRY

	    IF EXISTS (SELECT 1 
		           FROM dbo.Tbl_EmpresasSeleccionadasV4 AS tes
                   WHERE tes.usuarioApsi = @usuario
                         AND tes.empresa = @empresa)
           UPDATE tes
           SET tes.seleccionada = @seleccionada
           FROM dbo.Tbl_EmpresasSeleccionadasV4 AS tes
           WHERE tes.usuarioApsi = @usuario
                 AND tes.empresa = @empresa
        ELSE
		   INSERT dbo.Tbl_EmpresasSeleccionadasV4 
                  (usuarioApsi
                   , empresa
                   , seleccionada)
             VALUES
                  (@usuario
                   , @empresa
                   , @seleccionada)

        SELECT 0 AS ErrorNumber
               , 0 AS ErrorSeverity
               , 0 AS ErrorState 
               , '' AS ErrorProcedure 
               , 0 AS ErrorLine 
               , '' AS ErrorMessage

      END TRY

      BEGIN CATCH
        IF XACT_STATE() = -1
           OR @@TRANCOUNT > 0
           ROLLBACK TRANSACTION

        SELECT ERROR_NUMBER() AS ErrorNumber ,
               ERROR_SEVERITY() AS ErrorSeverity ,
               ERROR_STATE() AS ErrorState ,
               ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
               ERROR_LINE() AS ErrorLine ,
               ERROR_MESSAGE() AS ErrorMessage
      END CATCH

      IF @@TRANCOUNT > 0
         COMMIT TRANSACTION
  END 
GO

DECLARE @schema_name NVARCHAR(256)
DECLARE @table_name NVARCHAR(256)
DECLARE @col_name NVARCHAR(256)
DECLARE @Command  NVARCHAR(1000)

SET @schema_name = N'dbo'
SET @table_name = N'accesos'

SET @col_name = N'empresa'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

Print '1'

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

Print '2'

/*
SET @col_name = N'usuario'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

Print '2'

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

SET @col_name = N'idNomTblEquipo'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

Print '3'

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END
*/

SET @Command = NULL
SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + name
FROM sys.key_constraints
WHERE [type] = 'PK'
      AND [parent_object_id] = OBJECT_ID(@schema_name + '.' + @table_name)

IF @Command IS NOT NULL    
   BEGIN
     EXECUTE (@Command)
   END

Print '3'

IF EXISTS (SELECT 1
           FROM sys.indexes
           WHERE name='PK1' 
           AND OBJECT_ID = OBJECT_ID('[dbo].[accesos]'))
   BEGIN
     DROP INDEX [PK1] ON [dbo].[accesos]
   END

Print '4'

SET @col_name = N'empresa'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[accesos] ADD DEFAULT 0 FOR [empresa]
   END

Print '5'

SET @col_name = N'usuario'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[accesos] ADD DEFAULT '' FOR [usuario]
   END

Print '6'

SET @col_name = N'idNomTblEquipo'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[accesos] ADD DEFAULT 0 FOR [idNomTblEquipo]
   END

Print '7'

SET @col_name = N'sesion'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[accesos] ADD DEFAULT '' FOR [sesion]
   END

Print '8'

IF EXISTS (SELECT * 
           FROM sys.foreign_keys 
           WHERE object_id = OBJECT_ID(N'dbo.Refempresas373')
           AND parent_object_id = OBJECT_ID(N'dbo.accesos'))
   BEGIN
     ALTER TABLE dbo.accesos DROP CONSTRAINT Refempresas373
   END

Print '9'

IF  NOT EXISTS (SELECT name
                FROM sys.objects 
                WHERE object_id = OBJECT_ID(N'PK1') 
                      AND type in (N'U'))
    BEGIN
      ALTER TABLE dbo.accesos ADD CONSTRAINT PK1 PRIMARY KEY CLUSTERED (empresa,usuario,idNomTblEquipo,sesion)
            WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON)
            ON [PRIMARY]         
    END

Print '10'

--GO

IF (OBJECT_ID('Refempresas373', 'F') IS NULL)
   BEGIN
     ALTER TABLE [dbo].[accesos] WITH CHECK ADD CONSTRAINT [Refempresas373] FOREIGN KEY([empresa])
     REFERENCES [dbo].[empresas] ([empresa])

     ALTER TABLE [dbo].[accesos] CHECK CONSTRAINT [Refempresas373]
   END

Print '11'

--GO

--IF (OBJECT_ID('Refusuarios373', 'F') IS NULL)
--   BEGIN
--     ALTER TABLE [dbo].[accesos] WITH CHECK ADD CONSTRAINT [Refusuarios373] FOREIGN KEY([idNomTblEquipo])
--     REFERENCES [dbo].[NOM_TBL_Equipo] ([idNomTblEquipo])
--
--     ALTER TABLE [dbo].[accesos] CHECK CONSTRAINT [Refusuarios373]
--   END
--GO

GO

DECLARE @schema_name NVARCHAR(256)
DECLARE @table_name NVARCHAR(256)
DECLARE @col_name NVARCHAR(256)
DECLARE @Command  NVARCHAR(1000)

SET @schema_name = N'dbo'
SET @table_name = N'auditoria'
SET @col_name = N'mov'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

SET @col_name = N'fch_mov'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name
      
IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

SET @col_name = N'obs_auto'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name
      
IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

SET @col_name = N'fchalta'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name
      
IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

SET @col_name = N'rpu'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name
      

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END
   
SET @col_name = N'ip'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name
      

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END
   
SET @col_name = N'mac'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name
      

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END
   
SET @col_name = N'nombreEquipo'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name
      

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END
   
SET @col_name = N'origen'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END

SET @col_name = N'usuario'

SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + d.name
FROM sys.tables t
     JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
     JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
WHERE t.name = @table_name
      AND t.schema_id = schema_id(@schema_name)
      AND c.name = @col_name

IF @Command IS NOT NULL
   BEGIN
     EXECUTE (@Command)
   END
   
   

SET @Command = NULL
SELECT @Command = 'ALTER TABLE ' + @schema_name + '.' + @table_name + ' DROP CONSTRAINT ' + name
FROM sys.key_constraints
WHERE [type] = 'PK'
      AND [parent_object_id] = OBJECT_ID(@schema_name + '.' + @table_name)

IF @Command IS NOT NULL    
   BEGIN
     EXECUTE (@Command)
   END

--IF (OBJECT_ID('Refempresas453', 'F') IS NOT NULL)
--   BEGIN
--     ALTER TABLE dbo.Historico DROP CONSTRAINT Refempresas453
--   END

--IF (OBJECT_ID('Refempleados454', 'F') IS NOT NULL)
--   BEGIN
--     ALTER TABLE dbo.Historico DROP CONSTRAINT Refempleados454
--   END
--GO

IF EXISTS (SELECT 1
           FROM sys.indexes
           WHERE name='PK545' 
           AND OBJECT_ID = OBJECT_ID('[dbo].[auditoria]'))
   BEGIN
     DROP INDEX [PK545] ON [dbo].[auditoria]
   END
   


SET @col_name = N'empresa'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[auditoria] ADD DEFAULT 0 FOR [empresa]
   END

SET @col_name = N'codigo'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[auditoria] ADD DEFAULT 0 FOR [codigo]
   END


SET @col_name = N'ip'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[auditoria] ADD DEFAULT '' FOR [ip]
   END

SET @col_name = N'mac'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[auditoria] ADD DEFAULT '' FOR [mac]
   END

SET @col_name = N'nombreEquipo'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[auditoria] ADD DEFAULT '' FOR [nombreEquipo]
   END
   

SET @col_name = N'origen'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[auditoria] ADD DEFAULT '' FOR [origen]
   END
   
SET @col_name = N'usuario'
IF NOT EXISTS (SELECT t.name
               FROM sys.tables t
                    JOIN sys.default_constraints d ON d.parent_object_id = t.object_id
                    JOIN sys.columns c ON c.object_id = t.object_id AND c.column_id = d.parent_column_id
               WHERE t.name = @table_name
                     AND t.schema_id = schema_id(@schema_name)
                     AND c.name = @col_name)
   BEGIN
     ALTER TABLE [dbo].[auditoria] ADD DEFAULT '' FOR [usuario]
   END
   
GO

--IF (OBJECT_ID('Refempresas453', 'F') IS NULL)
--   BEGIN
--     ALTER TABLE [dbo].[Historico] WITH CHECK ADD CONSTRAINT [Refempresas453] FOREIGN KEY([empresa])
--     REFERENCES [dbo].[empresas] ([empresa])
--
--     ALTER TABLE [dbo].[Historico] CHECK CONSTRAINT [Refempresas453]
--     ALTER TABLE [dbo].[Historico] ADD DEFAULT (0) FOR [empresa]
--   END
--GO

--IF (OBJECT_ID('Refempleados454', 'F') IS NULL)
--   BEGIN
--     ALTER TABLE [dbo].[Historico] WITH CHECK ADD CONSTRAINT [Refempleados454] FOREIGN KEY([empresa], [codigo])
--     REFERENCES [dbo].[empleados] ([empresa], [codigo])

--     ALTER TABLE [dbo].[Historico] CHECK CONSTRAINT [Refempleados454]
--     ALTER TABLE [dbo].[Historico] ADD DEFAULT (0) FOR [codigo]
--   END
--GO

UPDATE dbo.auditoria SET ip = '' WHERE ip IS NULL
UPDATE dbo.auditoria SET mac = '' WHERE mac IS NULL
UPDATE dbo.auditoria SET nombreEquipo = '' WHERE nombreEquipo IS NULL
UPDATE dbo.auditoria SET origen = '' WHERE origen IS NULL
UPDATE dbo.auditoria SET usuario = '' WHERE usuario IS NULL

--ALTER TABLE dbo.auditoria DROP COLUMN ip 
--ALTER TABLE dbo.auditoria DROP COLUMN mac 
--ALTER TABLE dbo.auditoria DROP COLUMN nombreEquipo 


GO

--ALTER TABLE [dbo].[Historico] ALTER COLUMN fecha_captura DATETIME NOT NULL 
--GO

IF EXISTS (SELECT * 
           FROM sys.foreign_keys 
           WHERE object_id = OBJECT_ID(N'dbo.Refempleados667')
           AND parent_object_id = OBJECT_ID(N'dbo.auditoria'))
   BEGIN
     ALTER TABLE auditoria DROP CONSTRAINT Refempleados667
   END

IF  NOT EXISTS (SELECT name
                FROM sys.objects 
                WHERE object_id = OBJECT_ID(N'PK545') 
                      AND type in (N'U'))
    BEGIN
      ALTER TABLE dbo.auditoria ADD CONSTRAINT PK545 PRIMARY KEY CLUSTERED (empresa,codigo,usuario,ip,mac,nombreEquipo,origen,id)
            WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON)
            ON [PRIMARY]         
    END
GO

--UPDATE  dbo.primas_imss
--SET     dbo.primas_imss.infonavit = 5
--WHERE   dbo.primas_imss.periodo < '20140101'
        
--UPDATE  dbo.primas_imss
--SET     dbo.primas_imss.infonavit = 2
--WHERE   dbo.primas_imss.periodo >= '20140101'

--UPDATE  dbo.primas_imss
--SET     dbo.primas_imss.art211 = 1

--UPDATE  dbo.primas_imss
--SET     dbo.primas_imss.seguroDesempleo = 0
--WHERE   dbo.primas_imss.periodo < '20140101'
        
--UPDATE  dbo.primas_imss
--SET     dbo.primas_imss.seguroDesempleo = 3
--WHERE   dbo.primas_imss.periodo >= '20140101'

UPDATE  dbo.primas_imss
SET     dbo.primas_imss.infonavit = 5
WHERE   dbo.primas_imss.periodo >= '20140101'
        AND dbo.primas_imss.infonavit = 2
GO

IF OBJECT_ID('dbo.NOM_PRO_ActualizaClasePercepcionesDeducciones') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ActualizaClasePercepcionesDeducciones
GO
CREATE PROCEDURE dbo.NOM_PRO_ActualizaClasePercepcionesDeducciones
@empresa INT,
@idNomTblEquipo BIGINT

AS 

  SET NOCOUNT ON

  DECLARE @Tipo VARCHAR(15)
  DECLARE @conceptos TABLE (
                             empresa INT
                             ,codigo INT
                             ,tipo VARCHAR(15)
                             ,folio INT
                             ,num_conc INT
							 ,concepto VARCHAR(30)
                             ,mes_operacion INT
                             ,ayo_operacion INT
                             ,clase VARCHAR(2)
                             ,centro VARCHAR(15)
                             ,periodo INT
                             ,tiponom INT
                             ,siempre CHAR(1)
                             ,origen CHAR(1)
                             ,nomina NUMERIC(12,2)
                             ,claseNueva VARCHAR(2)
                             ,centroNuevo VARCHAR(15)
                           )

  SET @tipo = 'Percepciones'
  INSERT INTO @conceptos (empresa, codigo, tipo, folio, num_conc, concepto, mes_operacion, ayo_operacion, clase, centro, periodo, tiponom, siempre, origen, nomina, claseNueva, centroNuevo)
         SELECT p.empresa, p.codigo, @tipo, p.folio, p.num_conc, c.concepto, p.mes_operacion, p.ayo_operacion, p.clase, p.centro, p.periodo, p.tiponom, p.siempre, p.origen, p.nomina, CASE WHEN LTRIM(RTRIM(p.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END AS claseNueva, CASE WHEN LTRIM(RTRIM(p.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END AS centroNuevo
         FROM dbo.NOM_TBL_Tmp_Listado AS tl
		      INNER JOIN dbo.percepciones AS p ON tl.empresa = p.empresa
			                                      AND tl.codigo = p.codigo
              INNER JOIN dbo.Llaves AS ll ON p.empresa = ll.empresa
	                                         AND p.codigo = ll.codigo
              INNER JOIN dbo.periodos AS Per ON p.empresa = per.empresa
                                                AND p.tiponom = per.tiponom
                                                AND p.periodo = per.periodo
                                                AND p.ayo_operacion = per.ayo_operacion
                                                AND per.estatus = 'A'
              INNER JOIN dbo.conceptos AS c ON p.empresa = c.empresa
                                               AND p.num_conc = c.num_conc
                                               AND LTRIM(RTRIM(p.clase)) = LTRIM(RTRIM(c.clase))
                                               AND LTRIM(RTRIM(p.centro)) = LTRIM(RTRIM(c.centro))
         WHERE tl.empresa = @empresa
		       AND tl.idNomTblEquipo = @idNomTblEquipo
		       AND LTRIM(RTRIM(p.clase)) + LTRIM(RTRIM(p.centro)) <> CASE WHEN LTRIM(RTRIM(p.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(p.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
               AND NOT EXISTS (
	                            SELECT 1
                                FROM dbo.conceptos AS c
                                WHERE c.empresa = p.empresa
                                      AND c.num_conc = p.num_conc
                                      AND LTRIM(RTRIM(c.clase)) + LTRIM(RTRIM(c.centro)) = CASE WHEN LTRIM(RTRIM(p.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(p.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
                              )

  UPDATE p
  SET p.clase = CASE WHEN LTRIM(RTRIM(p.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END,
      p.centro = CASE WHEN LTRIM(RTRIM(p.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
  FROM dbo.NOM_TBL_Tmp_Listado AS tl
       INNER JOIN dbo.percepciones AS p ON tl.empresa = p.empresa
                                           AND tl.codigo = p.codigo
       INNER JOIN dbo.Llaves AS ll ON p.empresa = ll.empresa
                                      AND p.codigo = ll.codigo
       INNER JOIN dbo.periodos AS Per ON p.empresa = per.empresa
                                         AND p.tiponom = per.tiponom
                                         AND p.periodo = per.periodo
                                         AND p.ayo_operacion = per.ayo_operacion
                                         AND per.estatus = 'A'
       INNER JOIN dbo.conceptos AS c ON p.empresa = c.empresa
                                        AND p.num_conc = c.num_conc
                                        AND LTRIM(RTRIM(p.clase)) = LTRIM(RTRIM(c.clase))
                                        AND LTRIM(RTRIM(p.centro)) = LTRIM(RTRIM(c.centro))
  WHERE tl.empresa = @empresa
        AND tl.idNomTblEquipo = @idNomTblEquipo
        AND LTRIM(RTRIM(p.clase)) + LTRIM(RTRIM(p.centro)) <> CASE WHEN LTRIM(RTRIM(p.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(p.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
        AND EXISTS (
                     SELECT 1
                     FROM dbo.conceptos AS c
                     WHERE c.empresa = p.empresa
                           AND c.num_conc = p.num_conc
                           AND LTRIM(RTRIM(c.clase)) + LTRIM(RTRIM(p.centro)) = CASE WHEN LTRIM(RTRIM(p.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(p.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
                   )

  DELETE p
  FROM dbo.NOM_TBL_Tmp_Listado AS tl
       INNER JOIN dbo.percepciones AS p ON tl.empresa = p.empresa
                                           AND tl.codigo = p.codigo
       INNER JOIN @conceptos AS c ON c.empresa           = p.empresa
                                     AND c.codigo        = p.codigo
                                     AND c.folio         = p.folio
                                     AND c.num_conc      = p.num_conc
                                     AND c.mes_operacion = p.mes_operacion
                                     AND c.ayo_operacion = p.ayo_operacion
                                     AND c.clase         = p.clase
                                     AND c.centro        = p.centro
                                     AND c.periodo       = p.periodo
                                     AND c.tiponom       = p.tiponom
                                     AND c.siempre       = p.siempre
                                     AND c.origen        = p.origen
  WHERE tl.empresa = @empresa
        AND tl.idNomTblEquipo = @idNomTblEquipo
        AND c.tipo = @tipo



  SET @tipo = 'Deducciones'
  INSERT INTO @conceptos (empresa, codigo, tipo, folio, num_conc, concepto, mes_operacion, ayo_operacion, clase, centro, periodo, tiponom, siempre, origen, nomina, claseNueva, centroNuevo)
         SELECT d.empresa, d.codigo, @tipo, d.folio, d.num_conc, c.concepto, d.mes_operacion, d.ayo_operacion, d.clase, d.centro, d.periodo, d.tiponom, d.siempre, d.origen, d.descuento AS nomina, CASE WHEN LTRIM(RTRIM(d.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END AS claseNueva, CASE WHEN LTRIM(RTRIM(d.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END AS centroNuevo
         FROM dbo.NOM_TBL_Tmp_Listado AS tl
		      INNER JOIN dbo.deducciones AS d ON tl.empresa = d.empresa
			                                     AND tl.codigo = d.codigo
              INNER JOIN dbo.Llaves AS ll ON d.empresa = ll.empresa
                                             AND d.codigo = ll.codigo
              INNER JOIN dbo.periodos AS Per ON d.empresa = per.empresa
                                                AND d.tiponom = per.tiponom
                                                AND d.periodo = per.periodo
                                                AND d.ayo_operacion = per.ayo_operacion
                                                AND Per.estatus = 'A'
              INNER JOIN dbo.conceptos AS c ON d.empresa = c.empresa
                                               AND d.num_conc = c.num_conc
                                               AND LTRIM(RTRIM(d.clase)) = LTRIM(RTRIM(c.clase))
                                               AND LTRIM(RTRIM(d.centro)) = LTRIM(RTRIM(c.centro))
  WHERE tl.empresa = @empresa
        AND tl.idNomTblEquipo = @idNomTblEquipo
        AND LTRIM(RTRIM(d.clase)) + LTRIM(RTRIM(d.centro)) <> CASE WHEN LTRIM(RTRIM(d.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(d.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
        AND NOT EXISTS (
	                     SELECT 1
                         FROM dbo.conceptos AS c
                         WHERE c.empresa = d.empresa
                               AND c.num_conc = d.num_conc 
                               AND LTRIM(RTRIM(c.clase)) + LTRIM(RTRIM(d.centro)) = CASE WHEN LTRIM(RTRIM(d.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(d.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
                       )

  UPDATE d
  SET d.clase = CASE WHEN LTRIM(RTRIM(d.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END,
      d.centro = CASE WHEN LTRIM(RTRIM(d.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
  FROM dbo.NOM_TBL_Tmp_Listado AS tl
       INNER JOIN dbo.deducciones AS d ON tl.empresa = d.empresa
                                          AND tl.codigo = d.codigo
       INNER JOIN dbo.Llaves AS ll ON d.empresa = ll.empresa
                                      AND d.codigo = ll.codigo
       INNER JOIN dbo.periodos AS Per ON d.empresa = per.empresa
                                         AND d.tiponom = per.tiponom
                                         AND d.periodo = per.periodo
                                         AND d.ayo_operacion = per.ayo_operacion
                                         AND per.estatus = 'A'
       INNER JOIN dbo.conceptos AS c ON d.empresa = c.empresa
                                        AND d.num_conc = c.num_conc
                                        AND LTRIM(RTRIM(d.clase)) = LTRIM(RTRIM(c.clase))
                                        AND LTRIM(RTRIM(d.centro)) = LTRIM(RTRIM(c.centro))
  WHERE tl.empresa = @empresa
        AND tl.idNomTblEquipo = @idNomTblEquipo
        AND LTRIM(RTRIM(d.clase)) + LTRIM(RTRIM(d.centro)) <> CASE WHEN LTRIM(RTRIM(d.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(d.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
        AND EXISTS (
                   SELECT 1
                   FROM dbo.conceptos AS c
                   WHERE c.empresa = d.empresa
                         AND c.num_conc = d.num_conc
                         AND LTRIM(RTRIM(c.clase)) + LTRIM(RTRIM(d.centro)) = CASE WHEN LTRIM(RTRIM(d.clase)) <> '' THEN LTRIM(RTRIM(ll.clase)) ELSE '' END + CASE WHEN LTRIM(RTRIM(d.centro)) <> '' THEN LTRIM(RTRIM(ll.centro)) ELSE '' END
                 )

  DELETE d
  FROM dbo.NOM_TBL_Tmp_Listado AS tl
       INNER JOIN dbo.deducciones AS d ON tl.empresa = d.empresa
                                          AND tl.codigo = d.codigo
       INNER JOIN @conceptos AS c ON c.empresa           = d.empresa
                                     AND c.codigo        = d.codigo
                                     AND c.folio         = d.folio
                                     AND c.num_conc      = d.num_conc
                                     AND c.mes_operacion = d.mes_operacion
                                     AND c.ayo_operacion = d.ayo_operacion
                                     AND c.clase         = d.clase
                                     AND c.centro        = d.centro
                                     AND c.periodo       = d.periodo
                                     AND c.tiponom       = d.tiponom
                                     AND c.siempre       = d.siempre
                                     AND c.origen        = d.origen
  WHERE tl.empresa = @empresa
        AND tl.idNomTblEquipo = @idNomTblEquipo
        AND c.tipo = @tipo

  SELECT c.empresa
         ,c.codigo 
         ,c.tipo
         ,c.folio 
         ,c.num_conc
		 ,c.concepto
         ,c.mes_operacion
         ,c.ayo_operacion
         ,c.clase
         ,c.centro
         ,c.periodo
         ,c.tiponom
         ,c.siempre
         ,c.origen
         ,c.nomina
         ,c.claseNueva
         ,c.centroNuevo
  FROM @conceptos AS c
  ORDER BY c.empresa
           ,c.codigo 
	       ,c.tipo DESC
	       ,c.num_conc
	       ,c.clase
	       ,c.centro
GO   

IF OBJECT_ID('dbo.NOM_PRO_ActualizaNomTblTmpListado') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ActualizaNomTblTmpListado
GO
CREATE PROCEDURE dbo.NOM_PRO_ActualizaNomTblTmpListado
@empresa INT,
@codigo INT,
@idNomTblEquipo BIGINT

AS 

  SET NOCOUNT ON

  INSERT dbo.NOM_TBL_Tmp_Listado (empresa, codigo, idNomTblEquipo)
         SELECT @empresa, @codigo, @idNomTblEquipo
		 WHERE NOT EXISTS (SELECT 1
		                   FROM dbo.NOM_TBL_Tmp_Listado AS tl
						   WHERE tl.empresa = @empresa
						         AND tl.codigo = @codigo
								 AND tl.idNomTblEquipo = @idNomTblEquipo)
GO

IF OBJECT_ID('dbo.NOM_PRO_ActualizaPrimaRtRpu') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ActualizaPrimaRtRpu
GO
CREATE PROCEDURE dbo.NOM_PRO_ActualizaPrimaRtRpu
@Empresa INT
, @Rpu CHAR(3)
, @Fecha DATETIME
, @PrimaRt NUMERIC(7,5)
, @Id INT
, @Accion CHAR(1)

AS 

  SET NOCOUNT ON

  IF @Accion = 'A'
     INSERT dbo.Rpu_PrimaRT (empresa, rpu, fecha, primaRt) VALUES (@Empresa, @Rpu, @Fecha, @PrimaRt)
  ELSE If @Accion = 'M'
     UPDATE rpr 
     SET rpr.primaRt = @PrimaRt
     FROM dbo.Rpu_PrimaRt AS rpr
     WHERE rpr.id = @Id
  ELSE IF @Accion = 'B'
    DELETE dbo.Rpu_PrimaRt WHERE id = @Id
GO

IF OBJECT_ID('dbo.NOM_PRO_ActualizaSeleccionEmpresasCedula') IS NOT NULL 
   DROP PROCEDURE dbo.NOM_PRO_ActualizaSeleccionEmpresasCedula
GO
CREATE PROCEDURE dbo.NOM_PRO_ActualizaSeleccionEmpresasCedula
@usuario VARCHAR(50)
, @empresa INT
, @cedula INT

AS

  SET NOCOUNT ON

  INSERT dbo.NOM_TBL_SeleccionEmpresasCedula (usuario, empresa, cedula)
  SELECT @usuario, @empresa, @cedula
  WHERE NOT EXISTS (SELECT 1
                    FROM dbo.NOM_TBL_SeleccionEmpresasCedula
					WHERE usuario = @usuario
                          AND empresa = @empresa
                          AND cedula = @cedula)
GO

IF OBJECT_Id('dbo.NOM_PRO_ActualizaTblAccesos') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ActualizaTblAccesos
GO
CREATE PROCEDURE dbo.NOM_PRO_ActualizaTblAccesos
@UsuarioParam VARCHAR(25),
@EmpresaParam INT,
@FuncionParam CHAR(2),
@IdNomTblEquipoParam BIGINT,
@SesionParam CHAR(14),
@Accion VARCHAR(7)

AS 

  SET NOCOUNT ON

  IF @Accion = 'AGREGAR'
     BEGIN
       IF EXISTS (SELECT 1
	              FROM dbo.accesos AS a
                  WHERE a.empresa = @EmpresaParam
                        AND a.usuario = @UsuarioParam
                        AND a.idNomTblEquipo = @idNomTblEquipoParam)
          BEGIN
            DELETE dbo.accesos
            WHERE LTRIM(RTRIM(Usuario)) = @UsuarioParam
                  AND Empresa = @EmpresaParam
                  AND idNomTblEquipo = @idNomTblEquipoParam

            --UPDATE dbo.accesos
	        --SET Funcion = @FuncionParam,
            --    sesion = @sesionParam
            --WHERE LTRIM(RTRIM(Usuario)) = @UsuarioParam
            --      AND Empresa = @EmpresaParam
            --      AND idNomTblEquipo = @idNomTblEquipoParam
	      END
       
       INSERT dbo.accesos (Usuario, Empresa, Funcion, idNomTblEquipo, sesion)
              SELECT @UsuarioParam, @EmpresaParam, @FuncionParam, @idNomTblEquipoParam, @sesionParam
              WHERE NOT EXISTS (SELECT 1
                                FROM dbo.accesos AS a
                                WHERE LTRIM(RTRIM(Usuario)) = @UsuarioParam
                                      AND Empresa = @EmpresaParam
                                      AND idNomTblEquipo = @idNomTblEquipoParam
                                      AND sesion = @sesionParam)

       UPDATE dbo.accesos
	   SET Funcion = @FuncionParam
       WHERE LTRIM(RTRIM(Usuario)) = @UsuarioParam
             AND Empresa = @EmpresaParam
             AND idNomTblEquipo = @idNomTblEquipoParam
            AND sesion = @sesionParam
     END

  IF @Accion = 'BORRAR'
     BEGIN
       DELETE dbo.accesos
       WHERE LTRIM(RTRIM(Usuario)) = @UsuarioParam
             AND Empresa = @EmpresaParam
             AND idNomTblEquipo = @idNomTblEquipoParam
			 AND sesion = @sesionParam
     END
GO

IF OBJECT_Id('dbo.NOM_PRO_ActualizaTblEquipo') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ActualizaTblEquipo
GO
CREATE PROCEDURE dbo.NOM_PRO_ActualizaTblEquipo
@ip VARCHAR(15),
@direccionMac VARCHAR(17),
@nombreEquipo VARCHAR(50)

AS 

  SET NOCOUNT ON

  INSERT dbo.NOM_TBL_Equipo (ip, direccionMac, nombreEquipo)
  SELECT @ip, @direccionMac, @nombreEquipo 
  WHERE NOT EXISTS (SELECT 1
                    FROM dbo.NOM_TBL_Equipo AS te
					WHERE LTRIM(RTRIM(te.ip)) = LTRIM(RTRIM(@ip))
					      AND LTRIM(RTRIM(te.direccionMac)) = LTRIM(RTRIM(@direccionMac))
						  AND LTRIM(RTRIM(te.nombreEquipo)) = LTRIM(RTRIM(@nombreEquipo)))
  
  SELECT te.idNomTblEquipo
  FROM dbo.NOM_TBL_Equipo AS te
  WHERE LTRIM(RTRIM(te.ip)) = LTRIM(RTRIM(@ip))
        AND LTRIM(RTRIM(te.direccionMac)) = LTRIM(RTRIM(@direccionMac))
        AND LTRIM(RTRIM(te.nombreEquipo)) = LTRIM(RTRIM(@nombreEquipo))
GO

IF OBJECT_ID('dbo.NOM_PRO_BorraNomTblTmpListado') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_BorraNomTblTmpListado
GO
CREATE PROCEDURE dbo.NOM_PRO_BorraNomTblTmpListado
@empresa INT,
@idNomTblEquipo BIGINT

AS 

  SET NOCOUNT ON

  DELETE tl
  FROM dbo.NOM_TBL_Tmp_Listado AS tl
  WHERE tl.empresa = @empresa
        AND tl.idNomTblEquipo = @idNomTblEquipo
GO

IF OBJECT_ID('dbo.NOM_PRO_BorraSeleccionEmpresasCedula') IS NOT NULL 
   DROP PROCEDURE dbo.NOM_PRO_BorraSeleccionEmpresasCedula
GO
CREATE PROCEDURE dbo.NOM_PRO_BorraSeleccionEmpresasCedula
@usuario VARCHAR(50)
, @cedula INT

AS

  SET NOCOUNT ON

  DELETE dbo.NOM_TBL_SeleccionEmpresasCedula
  WHERE usuario = @usuario
		AND cedula = @cedula
GO

IF OBJECT_ID('dbo.NOM_PRO_BorraTablaTemporalAmortizacion') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_BorraTablaTemporalAmortizacion
GO
CREATE PROCEDURE dbo.NOM_PRO_BorraTablaTemporalAmortizacion

AS 

  SET NOCOUNT ON

  DELETE dbo.TemporalAmortizacion
GO

IF OBJECT_ID('dbo.NOM_PRO_Contingenciainfonvit2020') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_Contingenciainfonvit2020
GO
CREATE PROCEDURE dbo.NOM_PRO_Contingenciainfonvit2020
@empresa INT,
@Mes INT,
@Ayo INT

AS 

  SET NOCOUNT ON

  DECLARE @Fecha DATETIME
  DECLARE @FechaInicioMesNon DATETIME
  DECLARE @FechaFinMesNon DATETIME
  DECLARE @FechaInicioMesPar DATETIME
  DECLARE @FechaFinMesPar DATETIME
  DECLARE @FechaFinBimestreAnterior DATETIME
  DECLARE @FechaFinita DATETIME

  SET @Fecha = CONVERT(DATETIME, LTRIM(STR(@Ayo)) + RIGHT(100 + @Mes,2) + '01')
  SET @FechaFinita = '29991231'

  SELECT @FechaFinBimestreAnterior = f.fechaFin
  FROM [dbo].[ObtieneRangoFecha](@Fecha, 9) AS f

  SELECT @FechaInicioMesNon = f.fechaInicio
         , @FechaFinMesNon = f.fechaFin
  FROM [dbo].[ObtieneRangoFecha](@Fecha, 8) AS f

  SELECT @FechaInicioMesPar = f.fechaInicio
         , @FechaFinMesPar = f.fechaFin
  FROM [dbo].[ObtieneRangoFecha](@Fecha, 7) AS f

  SELECT e.codigo
         , e.ap_paterno
		 , e.ap_materno
		 , e.nombre
         , ISNULL(i.TieneCredito, 'No') AS TieneCredito
		 , @FechaFinBimestreAnterior AS FechaBajaContingencia
		 , e.afiliacion
		 , e.digvera
  FROM dbo.empleados AS e

	   CROSS APPLY (SELECT TOP 1
                           a.codigo
                    FROM dbo.avisos_imss AS a
                    WHERE a.empresa = e.empresa
                          AND a.codigo = e.codigo
                          AND a.fch_mov >= @FechaInicioMesNon
                          AND a.fch_mov <= @FechaFinMesPar) AS a
	  
	   OUTER APPLY (SELECT TOP 1
                           'Si' AS TieneCredito
                    FROM dbo.infonavit AS i
                    WHERE i.empresa = e.empresa
				          AND i.codigo = e.codigo
                          AND i.fecha <= @FechaFinMesPar
	                      AND ISNULL(i.fechaSuspension, @FechaFinita) >= @FechaInicioMesNon
	                      AND ISNULL(i.fch_termino, @FechaFinita) >= @FechaInicioMesNon) AS i

  WHERE e.empresa = @empresa
        AND e.borrado = 'N'
  ORDER BY i.TieneCredito DESC, e.codigo
GO

IF OBJECT_ID('dbo.NOM_PRO_GrabaExcepcionISSSTELEON') IS NOT NULL 
    DROP PROCEDURE dbo.NOM_PRO_GrabaExcepcionISSSTELEON
GO
CREATE PROCEDURE [dbo].[NOM_PRO_GrabaExcepcionISSSTELEON]
@ncodigo INTEGER,
@nempresa INTEGER,
@TransicionLey1983 CHAR(1)

AS 

  SET NOCOUNT ON
  DELETE e
  FROM dbo.excepciones AS e
  WHERE e.empresa = @nempresa AND 
        e.codigo = @ncodigo AND
		e.excepcion1 = 'LISSSTE83'
   
  SET @TransicionLey1983 = LTRIM(RTRIM(@TransicionLey1983))

  IF @TransicionLey1983 = 'S'
     BEGIN
       INSERT dbo.excepciones (empresa, codigo, excepcion1, excepcion2)
	          VALUES 
			                  (@nempresa, @ncodigo, 'LISSSTE83', 0)
     END
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneCentroEmpleado') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ObtieneCentroEmpleado
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneCentroEmpleado
@empresa INT,
@codigo INT

AS 

  SET NOCOUNT ON

  SELECT ll.centro
  FROM dbo.Llaves AS ll
  WHERE ll.empresa = @empresa
        AND ll.codigo = @codigo
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneClaseEmpleado') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ObtieneClaseEmpleado
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneClaseEmpleado
@empresa INT,
@codigo INT

AS 

  SET NOCOUNT ON

  SELECT ll.clase
  FROM dbo.Llaves AS ll
  WHERE ll.empresa = @empresa
        AND ll.codigo = @codigo
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneExcepcionISSSTELEON') IS NOT NULL 
    DROP PROCEDURE dbo.NOM_PRO_ObtieneExcepcionISSSTELEON
GO
CREATE PROCEDURE [dbo].[NOM_PRO_ObtieneExcepcionISSSTELEON]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 

AS 

  SET NOCOUNT ON

  DECLARE @TransicionLey1983 CHAR(1)

  SELECT @TransicionLey1983 = 'S'
  FROM dbo.excepciones 
  WHERE dbo.excepciones.empresa = @nempresa AND 
        dbo.excepciones.codigo = @ncodigo AND
		dbo.excepciones.excepcion1 = 'LISSSTE83'

  SELECT ISNULL(@TransicionLey1983, 'N') AS TransicionLey1983
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneIdEquipoUsuario') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ObtieneIdEquipoUsuario
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneIdEquipoUsuario
@usuario VARCHAR(25)

AS 

  SET NOCOUNT ON

  SELECT a.idNomTblEquipo
  FROM dbo.accesos AS a
  WHERE a.usuario = @usuario
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneSeleccionEmpresasCedula') IS NOT NULL 
   DROP PROCEDURE dbo.NOM_PRO_ObtieneSeleccionEmpresasCedula
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneSeleccionEmpresasCedula
@usuario VARCHAR(50)
, @cedula INT

AS

  SET NOCOUNT ON

  SELECT empresa
  FROM dbo.NOM_TBL_SeleccionEmpresasCedula
  WHERE usuario = @usuario
        AND cedula = @cedula
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneTablaPrimaCVPatron') IS NOT NULL 
   DROP PROCEDURE dbo.NOM_PRO_ObtieneTablaPrimaCVPatron
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneTablaPrimaCVPatron
@empresa INT
, @ayo INT
, @mes INT

AS 

  SET NOCOUNT ON

  DECLARE @fecha DATETIME
  SET @fecha = dbo.fin_mes(@mes, @ayo)

  SELECT cvPatron.rango 
         , cvPatron.limiteInferior
         , cvPatron.claveInferior
		 , limite.inferior AS importeInferior
         , cvPatron.limiteSuperior
         , cvPatron.claveSuperior
		 , CASE WHEN cvPatron.limiteSuperior = 999.99 THEN 999999.99 ELSE limite.superior END AS importeSuperior
         , cvPatron.primaCVPatron
  FROM dbo.NOM_TBL_PrimaCVPatron AS cvPatron
       CROSS APPLY (SELECT TOP 1
                           e.zona_geografica AS zg
                    FROM dbo.empresas AS e
                    WHERE e.empresa = @empresa) AS e
       OUTER APPLY (SELECT TOP 1 
                           CASE WHEN e.zg = 'B' 
                                THEN zona_b
                                ELSE zona_a
                           END AS salarioMinimo
                    FROM dbo.salarios_minimos AS sm
                    WHERE @fecha >= sm.fecha_ini 
                          AND @fecha <= sm.fecha_fin) AS sm
       OUTER APPLY (SELECT TOP 1
                           uma.umaDiario
                    FROM dbo.TblUMA AS uma
                    WHERE uma.fecha <= @fecha
                    ORDER BY uma.fecha DESC) AS uma

       CROSS APPLY (SELECT CONVERT(NUMERIC(12,2), ROUND(CASE WHEN cvPatron.claveInferior = 'SM' THEN sm.salarioMinimo ELSE uma.umaDiario END * cvPatron.limiteInferior,2)) AS inferior
                           , CONVERT(NUMERIC(12,2), ROUND(CASE WHEN cvPatron.claveSuperior = 'SM' THEN sm.salarioMinimo ELSE uma.umaDiario END * cvPatron.limiteSuperior,2)) AS superior) AS limite

  WHERE cvPatron.ayo = @ayo
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneTablaRpu') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ObtieneTablaRpu
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneTablaRpu
@Empresa INT

AS

  SET NOCOUNT ON

  SELECT r.rpu
         , r.reg_pat
         , r.nombre
         , r.referencia
         , r.direccion
         , r.colonia
         , r.poblacion
         , r.delegacion
         , r.subdelegacion
         , r.rfc
         , r.cod_postal
         , r.prima_rt
         , r.clase
         , r.zona_geografica
         , r.clave
         , r.guia 
  FROM dbo.rpu AS r
  WHERE r.empresa = @Empresa
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneTblAccesos') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ObtieneTblAccesos
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneTblAccesos
@EmpresaParam INT
AS 

  SET NOCOUNT ON

  SELECT a.empresa
         , a.usuario
         , a.funcion
         , a.idNomTblEquipo
         , a.sesion
         , ISNULL(e.ip,'') AS ip
         , ISNULL(e.direccionMac,'') AS direccionMac
         , ISNULL(e.nombreEquipo,'') AS nombreEquipo
		 , CASE WHEN PrimerRegistro.sesion = a.sesion 
		        THEN ISNULL((SELECT COUNT(*) AS sesiones
				      FROM dbo.accesos AS sesion
					  WHERE sesion.empresa = a.empresa
					        AND sesion.usuario = a.usuario),0)
		        ELSE NULL END AS sesiones

  FROM dbo.accesos AS a

       LEFT JOIN dbo.NOM_TBL_Equipo AS e ON a.idNomTblEquipo = e.idNomTblEquipo

	   CROSS APPLY (SELECT TOP 1
	                       a1.sesion
					FROM dbo.accesos AS a1
					WHERE a1.empresa = a.empresa
					      AND a1.usuario = a.usuario
					ORDER BY a1.sesion) AS PrimerRegistro
	                
  WHERE a.empresa = @EmpresaParam

  UNION

  SELECT a.empresa
         , a.usuario
         , a.funcion
         , a.idNomTblEquipo
         , a.sesion
         , ISNULL(e.ip,'') AS ip
         , ISNULL(e.direccionMac,'') AS direccionMac
         , ISNULL(e.nombreEquipo,'') AS nombreEquipo
		 , CASE WHEN PrimerRegistro.sesion = a.sesion 
		        THEN ISNULL((SELECT COUNT(*) AS sesiones
				      FROM dbo.accesos AS sesion
					  WHERE sesion.empresa = a.empresa
					        AND sesion.usuario = a.usuario),0)
		        ELSE NULL END AS sesiones

  FROM dbo.accesos AS a

       LEFT JOIN dbo.NOM_TBL_Equipo AS e ON a.idNomTblEquipo = e.idNomTblEquipo

	   CROSS APPLY (SELECT TOP 1
	                       a1.sesion
					FROM dbo.accesos AS a1
					WHERE a1.empresa = a.empresa
					      AND a1.usuario = a.usuario
					ORDER BY a1.sesion) AS PrimerRegistro
	                
  WHERE a.empresa <> @EmpresaParam
        AND a.funcion = 'R'

GO

IF OBJECT_ID('dbo.ObtieneCodigoPorEmpresaYRfcV4') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneCodigoPorEmpresaYRfcV4
GO
CREATE PROCEDURE dbo.ObtieneCodigoPorEmpresaYRfcV4
@stringEmpresas CHAR(3)
, @fechaInicio DATETIME
, @fechaFin DATETIME
, @rfc VARCHAR(13)

AS

  SET NOCOUNT ON

  DECLARE @empresa INT
  DECLARE @rfcalfa VARCHAR(4)
  DECLARE @rfcnum VARCHAR(6)
  DECLARE @rfchomo VARCHAR(3)

  SET @empresa = FLOOR(@stringEmpresas)
  SET @rfcalfa = SUBSTRING(@rfc,1,4)
  SET @rfcnum = SUBSTRING(@rfc,5,6)
  SET @rfchomo = SUBSTRING(@rfc,11,3)

  SELECT e.empresa
         , e.codigo
  FROM dbo.empleados AS e 
  WHERE e.empresa = @empresa 
        AND e.rfcalfa = @rfcalfa
        AND e.rfcnum = @rfcnum
        AND e.rfchomo = @rfchomo
GO

IF OBJECT_ID('dbo.ObtieneEmpleadosParaValidarV4') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEmpleadosParaValidarV4
GO
CREATE PROCEDURE dbo.ObtieneEmpleadosParaValidarV4
@empresa INT
, @fechaInicio DATETIME
, @fechaFin DATETIME

AS 

  SET NOCOUNT ON

  SELECT DISTINCT 
         a.codigo
         , e.nombre
         , e.ap_paterno
         , e.ap_materno
         , e.rfcalfa
         , e.rfcnum
         , e.rfchomo
         , de.codpostal
  FROM dbo.avisos_imss AS a
       INNER JOIN dbo.empleados AS e ON e.empresa = a.empresa 
                                        AND e.codigo = a.codigo
       INNER JOIN dbo.datosemps AS de ON de.empresa = a.empresa
                                         AND de.codigo = a.codigo
  WHERE a.empresa = @empresa
        AND a.fch_mov >= @fechaInicio
        AND a.fch_mov <= @fechaFin
        AND a.serial = 1
GO

INSERT  dbo.supervisores
        ( empresa ,
          supervisor ,
          nombre ,
          turno 
        )
        SELECT DISTINCT
                supervisor.empresa ,
                0 ,
                'GENERAL' ,
                1
        FROM    dbo.supervisores AS supervisor
        WHERE   NOT EXISTS ( SELECT DISTINCT
                                    supervisor2.empresa
                             FROM   dbo.supervisores AS supervisor2
                             WHERE  supervisor.empresa = supervisor2.empresa
                                    AND supervisor2.supervisor = 0 )
GO

--IF NOT EXISTS (SELECT name 
--           FROM sys.indexes
--           WHERE name = N'IX_avisos_imss_Resumen')
--   CREATE NONCLUSTERED INDEX IX_avisos_imss_Resumen ON dbo.avisos_imss (empresa,mes_operacion,ayo_operacion,mov)
--GO
--IF NOT EXISTS (SELECT name 
--           FROM sys.indexes
--           WHERE name = N'IX_deducciones_resumen')
--   CREATE NONCLUSTERED INDEX IX_deducciones_resumen ON dbo.deducciones (empresa,num_conc) INCLUDE (mes_operacion, ayo_operacion, dias)
--GO
IF EXISTS (SELECT name 
           FROM sys.indexes
           WHERE name = N'IX_avisos_imss_Resumen')
   DROP INDEX dbo.avisos_imss.IX_avisos_imss_Resumen
GO
IF EXISTS (SELECT name 
           FROM sys.indexes
           WHERE name = N'IX_deducciones_resumen')
   DROP INDEX dbo.deducciones.IX_deducciones_resumen
GO

IF OBJECT_ID('dbo.ActualizaAvisosApsiReloj') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaAvisosApsiReloj
GO
CREATE PROCEDURE dbo.ActualizaAvisosApsiReloj
@empresa NUMERIC(3,0), 
@codigo NUMERIC(8,0), 
@mov VARCHAR(2),
@fecha DATETIME,
@accionMovimiento VARCHAR(3),
@Enviar BIT,
@Enviado BIT,
@tipoActualizacion INT

AS

  SET NOCOUNT ON
  
  IF @Enviar = 1
     BEGIN
       IF @tipoActualizacion = 1
          BEGIN
            DELETE aa
            FROM dbo.AvisosApsiReloj AS aa
            WHERE aa.empresa = @empresa
                  AND aa.codigo = @codigo
                  AND LTRIM(RTRIM(aa.mov)) = LTRIM(RTRIM(@mov))
                  AND aa.fecha = @fecha
          END
    
       IF @tipoActualizacion = 2
          BEGIN
            IF @accionMovimiento = 'DEL'
               AND EXISTS (SELECT 1
                           FROM dbo.AvisosApsiReloj AS aa
                           WHERE aa.empresa = @empresa
                                 AND aa.codigo = @codigo
                                 AND aa.mov = @mov
                                 AND aa.fecha = @fecha
                                 AND aa.accion = 'Add')
               DELETE aa
               FROM dbo.AvisosApsiReloj AS aa
               WHERE aa.empresa = @empresa
                     AND aa.codigo = @codigo
                     AND LTRIM(RTRIM(aa.mov)) = LTRIM(RTRIM(@mov))
                     AND aa.fecha = @fecha
            ELSE
               IF NOT EXISTS (SELECT 1
                              FROM dbo.AvisosApsiReloj AS aa
                              WHERE aa.empresa = @empresa
                                    AND aa.codigo = @codigo
                                    AND aa.mov = @mov
                                    AND aa.fecha = @fecha)
                  BEGIN
                    INSERT dbo.AvisosApsiReloj (empresa, codigo, mov, fecha, accion)
                                        VALUES (@empresa, @codigo, @mov, @fecha, @accionMovimiento)
                  END
               ELSE
                  BEGIN
                    UPDATE aa
                    SET aa.accion = @accionMovimiento
                    FROM dbo.AvisosApsiReloj AS aa
                    WHERE aa.empresa = @empresa
                          AND aa.codigo = @codigo
                          AND aa.mov = @mov
                          AND aa.fecha = @fecha
                  END
          END
     END
     
     IF @accionMovimiento = 'Add'
        BEGIN
          UPDATE a
          SET a.Enviar = @Enviar,
              a.Enviado = @Enviado
          FROM dbo.avisos_imss AS a
          WHERE a.empresa = @empresa
                AND a.codigo = @codigo
                AND a.mov = @mov
                AND a.fch_mov = @fecha
        END
GO

IF OBJECT_ID('dbo.ActualizaCampoPagarNomina') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaCampoPagarNomina
GO
CREATE PROCEDURE dbo.ActualizaCampoPagarNomina
@empresa INT
, @codigo INT
, @pagarNomina CHAR(1)

AS 

  SET NOCOUNT ON

  UPDATE dbo.empleados 
  SET pagar_nomina = @pagarNomina 
  WHERE empresa = @empresa
        AND codigo = @codigo
GO

IF OBJECT_ID('dbo.ActualizaCatalogoHorario') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaCatalogoHorario
GO
CREATE PROCEDURE dbo.ActualizaCatalogoHorario
@empresa INT,
@horario INT,
@nombreHorario VARCHAR(30),
@accion INT

AS

  SET NOCOUNT ON
  
  DECLARE @jornada INT
  DECLARE @tolerancia INT
  DECLARE @tol_tpoextra INT
  DECLARE @rolar CHAR(1)
  DECLARE @turno INT
  DECLARE @descanso INT 
  DECLARE @dias_sem VARCHAR(6)
  DECLARE @semana_red CHAR(1)
  DECLARE @hrsturno DECIMAL(5,2)
  DECLARE @fac_aus_personal CHAR(1)
  DECLARE @JornadaSAT BIGINT
  
  SET @jornada = 0
  SET @tolerancia = 0
  SET @tol_tpoextra = 0
  SET @rolar = 'N'
  SET @turno = 1
  SET @descanso = 7
  SET @dias_sem = '123456'
  SET @semana_red = 'N'
  SET @hrsturno = 8
  SET @fac_aus_personal = 1
  SET @JornadaSAT = 1
  
  IF @accion = 1
     BEGIN
       INSERT dbo.horarios_catalogo (empresa, horario, nombre, jornada, tolerancia, tol_tpoextra, rolar, turno, descanso, dias_sem, semana_red, hrsturno, fac_aus_personal, JornadaSAT)
       SELECT @empresa, @horario, @nombreHorario, @jornada, @tolerancia, @tol_tpoextra, @rolar, @turno, @descanso, @dias_sem, @semana_red, @hrsturno, @fac_aus_personal, @JornadaSAT
       WHERE NOT EXISTS (SELECT 1
                         FROM dbo.horarios_catalogo AS hc
                         WHERE hc.horario = @horario
                               AND hc.empresa = @empresa)
                               
       INSERT dbo.detalle_horarios (empresa , horario , dia_Semana, nombre_dia, entra1, entra2, sale1 , sale2 , minutos, pausa, descanso, factor, factor_aus, turno_noc, sdoxhor) SELECT @empresa, @horario, 1         , 'LUN'     , '0900', '1500', '1300', '1900', 480    , 0    , 'F'     , 116.67, 116.67    , 'F'      , 8.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.detalle_horarios AS dh WHERE dh.dia_Semana = 1 AND dh.nombre_dia = 'LUN' AND dh.horario = @horario AND dh.empresa = @empresa)
       INSERT dbo.detalle_horarios (empresa , horario , dia_Semana, nombre_dia, entra1, entra2, sale1 , sale2 , minutos, pausa, descanso, factor, factor_aus, turno_noc, sdoxhor) SELECT @empresa, @horario, 2         , 'MAR'     , '0900', '1500', '1300', '1900', 480    , 0    , 'F'     , 116.67, 116.67    , 'F'      , 8.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.detalle_horarios AS dh WHERE dh.dia_Semana = 2 AND dh.nombre_dia = 'MAR' AND dh.horario = @horario AND dh.empresa = @empresa)
       INSERT dbo.detalle_horarios (empresa , horario , dia_Semana, nombre_dia, entra1, entra2, sale1 , sale2 , minutos, pausa, descanso, factor, factor_aus, turno_noc, sdoxhor) SELECT @empresa, @horario, 3         , 'MIE'     , '0900', '1500', '1300', '1900', 480    , 0    , 'F'     , 116.67, 116.67    , 'F'      , 8.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.detalle_horarios AS dh WHERE dh.dia_Semana = 3 AND dh.nombre_dia = 'MIE' AND dh.horario = @horario AND dh.empresa = @empresa)
       INSERT dbo.detalle_horarios (empresa , horario , dia_Semana, nombre_dia, entra1, entra2, sale1 , sale2 , minutos, pausa, descanso, factor, factor_aus, turno_noc, sdoxhor) SELECT @empresa, @horario, 4         , 'JUE'     , '0900', '1500', '1300', '1900', 480    , 0    , 'F'     , 116.67, 116.67    , 'F'      , 8.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.detalle_horarios AS dh WHERE dh.dia_Semana = 4 AND dh.nombre_dia = 'JUE' AND dh.horario = @horario AND dh.empresa = @empresa)
       INSERT dbo.detalle_horarios (empresa , horario , dia_Semana, nombre_dia, entra1, entra2, sale1 , sale2 , minutos, pausa, descanso, factor, factor_aus, turno_noc, sdoxhor) SELECT @empresa, @horario, 5         , 'VIE'     , '0900', '1500', '1300', '1900', 480    , 0    , 'F'     , 116.67, 116.67    , 'F'      , 8.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.detalle_horarios AS dh WHERE dh.dia_Semana = 5 AND dh.nombre_dia = 'VIE' AND dh.horario = @horario AND dh.empresa = @empresa)
       INSERT dbo.detalle_horarios (empresa , horario , dia_Semana, nombre_dia, entra1, entra2, sale1 , sale2 , minutos, pausa, descanso, factor, factor_aus, turno_noc, sdoxhor) SELECT @empresa, @horario, 6         , 'SAB'     , '0900', '1500', '1300', '1900', 480    , 0    , 'F'     , 116.67, 116.67    , 'F'      , 8.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.detalle_horarios AS dh WHERE dh.dia_Semana = 6 AND dh.nombre_dia = 'SAB' AND dh.horario = @horario AND dh.empresa = @empresa)
       INSERT dbo.detalle_horarios (empresa , horario , dia_Semana, nombre_dia, entra1, entra2, sale1 , sale2 , minutos, pausa, descanso, factor, factor_aus, turno_noc, sdoxhor) SELECT @empresa, @horario, 7         , 'DOM'     , ''    , ''    , ''    , ''    , 0      , 0    , 'T'     , 0.00  , 0.00      , 'F'      , 0.000 WHERE NOT EXISTS (SELECT 1 FROM dbo.detalle_horarios AS dh WHERE dh.dia_Semana = 7 AND dh.nombre_dia = 'DOM' AND dh.horario = @horario AND dh.empresa = @empresa)
     END
  ELSE
     IF @accion = 2
        BEGIN
          UPDATE hc
          SET hc.nombre = @nombreHorario
          FROM dbo.horarios_catalogo AS hc
          WHERE hc.horario = @horario
                AND hc.empresa = @empresa
        END
GO

IF OBJECT_ID('dbo.ActualizaConexionRelojAPSI') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaConexionRelojAPSI
GO
CREATE PROCEDURE dbo.ActualizaConexionRelojAPSI
@empresa INT,
@conexion NVARCHAR(1500)

AS 

  SET NOCOUNT ON
  
  UPDATE empresa
  SET empresa.conexionReloj = @conexion
  FROM dbo.empresas AS empresa
  WHERE empresa.empresa = @empresa
GO

IF OBJECT_ID('dbo.ActualizaDatosEmpleadoMasivo') IS NOT NULL 
    DROP PROCEDURE dbo.ActualizaDatosEmpleadoMasivo
GO
CREATE PROCEDURE dbo.ActualizaDatosEmpleadoMasivo
    @empresa INT ,
    @codigo INT ,
    @campo VARCHAR(100) ,
    @valorCaracter VARCHAR(250) ,
    @valorNumerico NUMERIC(15, 5) ,
    @valorEntero INT ,
    @valorFecha DATETIME ,
    @origen VARCHAR(25),
    @usuario VARCHAR(150)
AS 
    DECLARE @periodo INT
    DECLARE @mes CHAR(2)
    DECLARE @ayo CHAR(4)
    DECLARE @tipoNomina INT
    DECLARE @fecha DATETIME
    DECLARE @desde DATETIME
    DECLARE @valorCaracterOriginal VARCHAR(250)
    DECLARE @valorEnteroOriginal INT
    DECLARE @valorFechaOriginal DATETIME
    DECLARE @fechaDesde CHAR(10)
    DECLARE @fechaEnBlanco DATETIME
   
    SET @fechaDesde = RIGHT(10000 + YEAR(GETDATE()),4) + RIGHT(100 + MONTH(GETDATE()),2)  + RIGHT(100 + DAY(GETDATE()),2)
    SET @fecha = GETDATE()
    SET @desde = CONVERT(DATETIME, @fechaDesde)
    SET @fechaEnBlanco = CONVERT(DATETIME, '')
    
    SELECT  @tipoNomina = llaves.tiponom
    FROM    dbo.Llaves AS llaves
    WHERE   llaves.codigo = @codigo
            AND llaves.empresa = @empresa

    SELECT  @periodo = dbo.periodos.periodo ,
            @mes = RIGHT(100 + MONTH(dbo.periodos.pago), 2) ,
            @ayo = RIGHT(10000 + YEAR(dbo.periodos.pago), 4)
    FROM    dbo.periodos
    WHERE   dbo.periodos.empresa = @empresa
            AND dbo.periodos.tiponom = @tipoNomina
            AND dbo.periodos.estatus = 'A'

    IF @campo = 'CENTRO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(llaves.centro)),'')
            FROM   dbo.Llaves AS llaves
            WHERE  llaves.codigo = @codigo
                   AND llaves.empresa = @empresa
                   
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
                BEGIN
                    UPDATE  llaves
                    SET     llaves.centro = @valorCaracter
                    FROM    dbo.Llaves AS llaves
                    WHERE   llaves.codigo = @codigo
                            AND llaves.empresa = @empresa

                    INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                           VALUES  (@codigo,@empresa,'CENTRO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
                END      
        END

    IF @campo = 'TABULADOR' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(llaves.ocupacion,0)
            FROM   dbo.Llaves AS llaves
            WHERE  llaves.codigo = @codigo
                   AND llaves.empresa = @empresa
                   
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  llaves
                   SET     llaves.ocupacion = @valorEntero
                   FROM    dbo.Llaves AS llaves
                   WHERE   llaves.codigo = @codigo
                           AND llaves.empresa = @empresa

                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo,valor_original     ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'TABULADOR',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'CLASE' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(llaves.clase)),'')
            FROM   dbo.Llaves AS llaves
            WHERE  llaves.codigo = @codigo
                   AND llaves.empresa = @empresa
                   
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
                BEGIN
                    UPDATE  llaves
                    SET     llaves.clase = @valorCaracter
                    FROM    dbo.Llaves AS llaves
                    WHERE   llaves.codigo = @codigo
                            AND llaves.empresa = @empresa

                    INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                           VALUES  (@codigo,@empresa,'CLASE',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
                END             
        END

    IF @campo = 'SEXO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleado.sexo)),'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.sexo = @valorCaracter
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'SEXO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'ENTIDADNACIMIENTO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleado.edonac)),'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.edonac = @valorCaracter
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa

                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'ENT_NACI',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END        

    IF @campo = 'FECHANACIMIENTO' 
        BEGIN
            SELECT @valorFechaOriginal = ISNULL(LTRIM(RTRIM(empleado.fchnac)),@fechaEnBlanco)
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorFechaOriginal <> @valorFecha
               BEGIN
                   UPDATE  empleado
                   SET     empleado.fchnac = @valorFecha
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa

                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'FCH_NACI',@valorFecha,@valorFechaOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'RFC' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleado.rfcalfa)) + empleado.rfcnum + LTRIM(RTRIM(empleado.rfchomo)),'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.rfcalfa = SUBSTRING(@valorCaracter, 1, 4) ,
                           empleado.rfcnum = SUBSTRING(@valorCaracter, 5, 6) ,
                           empleado.rfchomo = SUBSTRING(@valorCaracter, 11, 3)
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa

                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'RFC',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'CURP' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(empleado.curp,'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.curp = @valorCaracter
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CURP',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'DIRECTOINDIRECTO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleado.manoobra)),'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.manoobra = @valorCaracter
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'MANO_OBRA',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'SUPERVISOR' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(llaves.supervisor,0)
            FROM   dbo.Llaves AS llaves
            WHERE  llaves.codigo = @codigo
                   AND llaves.empresa = @empresa
                   
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  llaves
                   SET     llaves.supervisor = @valorEntero
                   FROM    dbo.Llaves AS llaves
                   WHERE   llaves.codigo = @codigo
                           AND llaves.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo,valor_original     ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'SUPERVISOR',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'HORARIO' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(llaves.horario,0)
            FROM   dbo.Llaves AS llaves
            WHERE  llaves.codigo = @codigo
                   AND llaves.empresa = @empresa
                   
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  llaves
                   SET     llaves.horario = @valorEntero
                   FROM    dbo.Llaves AS llaves
                   WHERE   llaves.codigo = @codigo
                           AND llaves.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo,valor_original     ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'HORARIO',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'BANCO' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(llaves.banco,0)
            FROM   dbo.Llaves AS llaves
            WHERE  llaves.codigo = @codigo
                   AND llaves.empresa = @empresa
                   
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  llaves
                   SET     llaves.banco = @valorEntero
                   FROM    dbo.Llaves AS llaves
                   WHERE   llaves.codigo = @codigo
                           AND llaves.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo,valor_original     ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'NOM_BANCO',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'TIPODEPOSITO' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(empleado.tipo_deposito,0)
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
                   
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  empleado
                   SET     empleado.tipo_deposito = @valorEntero
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo,valor_original     ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'TIPOCTABCO',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'CUENTABANCARIA' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleado.cta_bco_no)),'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.cta_bco_no = @valorCaracter
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CTA_BANCO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'CLABE' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleadoAdicional.clabe)),'')
            FROM   dbo.EmpleadoAdicional AS empleadoAdicional
            WHERE  empleadoAdicional.codigo = @codigo
                   AND empleadoAdicional.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleadoAdicional
                   SET     empleadoAdicional.clabe = @valorCaracter
                   FROM    dbo.EmpleadoAdicional AS empleadoAdicional
                   WHERE   empleadoAdicional.codigo = @codigo
                           AND empleadoAdicional.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CLABE',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'CALLE' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.domicilio)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.domicilio = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CALLE',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'NUMEROEXTERIOR' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.numeroExterior)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.numeroExterior = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'NUMEROEXTERIOR',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'NUMEROINTERIOR' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.numeroInterior)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa

            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.numeroInterior = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'NUMEROINTERIOR',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'COLONIA' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.colonia)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.colonia = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'COLONIA',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'MUNICIPIO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.municipio)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.municipio = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'MUNICIPIO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'LOCALIDAD' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.localidad)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.localidad = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'LOCALIDAD',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'ENTIDADFEDERATIVA' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.poblacion)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.poblacion = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'POBLACION',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'CODIGOPOSTAL' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(RIGHT(100000 + datosemps.codpostal,5),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.codpostal = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CODPOSTAL',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'CUENTACONTABLE' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleado.cuenta)),'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.cuenta = @valorCaracter
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CUENTA',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'TIPOREGIMEN' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(empleadoAdicional.tipoRegimen,0)
            FROM   dbo.EmpleadoAdicional AS empleadoAdicional
            WHERE  empleadoAdicional.codigo = @codigo
                   AND empleadoAdicional.empresa = @empresa
        
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  empleadoAdicional
                   SET     empleadoAdicional.tipoRegimen = @valorEntero
                   FROM    dbo.EmpleadoAdicional AS empleadoAdicional
                   WHERE   empleadoAdicional.codigo = @codigo
                           AND empleadoAdicional.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'TIPOREGIMEN',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'TIPOCONTRATO' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(empleadoAdicional.tipoContrato,0)
            FROM   dbo.EmpleadoAdicional AS empleadoAdicional
            WHERE  empleadoAdicional.codigo = @codigo
                   AND empleadoAdicional.empresa = @empresa
        
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  empleadoAdicional
                   SET     empleadoAdicional.tipoContrato = @valorEntero
                   FROM    dbo.EmpleadoAdicional AS empleadoAdicional
                   WHERE   empleadoAdicional.codigo = @codigo
                           AND empleadoAdicional.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'TIPOCONTRATO',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'CORREOELECTRONICO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.email)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.email = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'MAILEMPLEADO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'CUENTAVALESDESPENSA' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.cta_vales)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.cta_vales = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CTAVALESDESP',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        

    IF @campo = 'CAMPOLIBRE1' OR
       @campo = 'CAMPOLIBRE2' OR
       @campo = 'CAMPOLIBRE3' OR
       @campo = 'CAMPOLIBRE4' OR
       @campo = 'CAMPOLIBRE5' OR
       @campo = 'CAMPOLIBRE6' OR
       @campo = 'CAMPOLIBRE7' OR
       @campo = 'CAMPOLIBRE8' OR
       @campo = 'CAMPOLIBRE9' OR
       @campo = 'CAMPOLIBRE10' OR
       @campo = 'CAMPOLIBRE11' OR
       @campo = 'CAMPOLIBRE12' OR
       @campo = 'CAMPOLIBRE13' OR
       @campo = 'CAMPOLIBRE14' OR
       @campo = 'CAMPOLIBRE15' 
	    BEGIN
          IF NOT EXISTS (SELECT clasifica.codigo
                         FROM dbo.clasificacion_empleados AS clasifica
                         WHERE clasifica.codigo = @codigo
                               AND clasifica.empresa = @empresa)
             INSERT dbo.clasificacion_empleados
                     ( empresa ,
                       codigo ,
                       campo_01 ,
                       campo_02 ,
                       campo_03 ,
                       campo_04 ,
                       campo_05 ,
                       campo_06 ,
                       campo_07 ,
                       campo_08 ,
                       campo_09 ,
                       campo_10 ,
                       campo_11 ,
                       campo_12 ,
					   campo__09,
					   campo__10,
					   campo__11,
					   campo__12,
					   campo__13,
					   campo__14,
					   campo__15
                     )
             VALUES  ( @empresa , -- empresa - numeric
                       @codigo , -- codigo - numeric
                       NULL , -- campo_01 - varchar(50)
                       NULL , -- campo_02 - varchar(50)
                       NULL , -- campo_03 - varchar(50)
                       NULL , -- campo_04 - numeric
                       NULL , -- campo_05 - numeric
                       NULL , -- campo_06 - numeric
                       NULL , -- campo_07 - int
                       NULL , -- campo_08 - int
                       NULL , -- campo_09 - int
                       NULL , -- campo_10 - datetime
                       NULL , -- campo_11 - datetime
                       NULL , -- campo_12 - datetime
					   NULL , -- campo_09 varchar(100)
					   NULL , -- campo_10 varchar(100)
					   NULL , -- campo_11 varchar(100)
					   NULL , -- campo_12 varchar(100)
					   NULL , -- campo_13 varchar(100)
					   NULL , -- campo_14 varchar(100)
					   NULL   -- campo_15 varchar(100)
                     )
       END



    IF @campo = 'CAMPOLIBRE1' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_02 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE2' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_03 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END

    IF @campo = 'CAMPOLIBRE3' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_04 = @valorNumerico
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE4' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_05 = @valorNumerico
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE5' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_07 = @valorEntero
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END

    IF @campo = 'CAMPOLIBRE6' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_08 = @valorEntero
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END        
        
    IF @campo = 'CAMPOLIBRE7' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_10 = @valorFecha
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE8' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo_11 = @valorFecha
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END

    IF @campo = 'CAMPOLIBRE9' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo__09 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE10' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo__10 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE11' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo__11 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE12' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo__12 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE13' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo__13 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE14' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo__14 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'CAMPOLIBRE15' 
        BEGIN
            UPDATE  clasificacionEmpleado
            SET     clasificacionEmpleado.campo__15 = @valorCaracter
            FROM    dbo.clasificacion_empleados AS clasificacionEmpleado
            WHERE   clasificacionEmpleado.codigo = @codigo
                    AND clasificacionEmpleado.empresa = @empresa
        END
        
    IF @campo = 'TIPOSALARIO' 
        BEGIN
            SELECT @valorEnteroOriginal = ISNULL(empleado.tiposal,0)
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorEnteroOriginal <> @valorEntero
               BEGIN
                   UPDATE  empleado
                   SET     empleado.tiposal = @valorEntero
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'TIPOSAL',@valorEntero,@valorEnteroOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'SINDICALIZADO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleado.sindicato)),'')
            FROM   dbo.empleados AS empleado
            WHERE  empleado.codigo = @codigo
                   AND empleado.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleado
                   SET     empleado.sindicato = @valorCaracter
                   FROM    dbo.empleados AS empleado
                   WHERE   empleado.codigo = @codigo
                           AND empleado.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'SINDICATO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'ESTADOCIVIL' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.edocivil)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.edocivil = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'EDO_CIVIL',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
        
    IF @campo = 'CLAVEENTIDADFEDERATIVA'
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(empleadoAdicional.claveEstado)),'')
            FROM   dbo.EmpleadoAdicional AS empleadoAdicional
            WHERE  empleadoAdicional.codigo = @codigo
                   AND empleadoAdicional.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  empleadoAdicional
                   SET     empleadoAdicional.claveEstado = @valorCaracter
                   FROM    dbo.EmpleadoAdicional AS empleadoAdicional
                   WHERE   empleadoAdicional.codigo = @codigo
                           AND empleadoAdicional.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'CLAVEESTADO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END

    IF @campo = 'TELEFONO' 
        BEGIN
            SELECT @valorCaracterOriginal = ISNULL(LTRIM(RTRIM(datosemps.telefono)),'')
            FROM   dbo.datosemps AS datosemps
            WHERE  datosemps.codigo = @codigo
                   AND datosemps.empresa = @empresa
        
            IF @valorCaracterOriginal <> @valorCaracter OR LEN(@valorCaracterOriginal) <> LEN(@valorCaracter)
               BEGIN
                   UPDATE  datosEmps
                   SET     datosEmps.telefono = @valorCaracter
                   FROM    dbo.datosemps AS datosEmps
                   WHERE   datosEmps.codigo = @codigo
                           AND datosEmps.empresa = @empresa
                           
                   INSERT dbo.Historico (codigo ,empresa ,campo   ,valor_nuevo   ,valor_original        ,periodo ,mes_operacion,ayo_operacion,capturo ,fecha_captura,desde ,origen)
                          VALUES  (@codigo,@empresa,'TELEFONO',@valorCaracter,@valorCaracterOriginal,@periodo,@mes         ,@ayo         ,@usuario,@fecha       ,@desde,@origen)
               END
        END
GO

IF OBJECT_ID('dbo.ActualizaEmpleadoApsiReloj') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaEmpleadoApsiReloj
GO
CREATE PROCEDURE dbo.ActualizaEmpleadoApsiReloj
@empresa NUMERIC(3,0), 
@Codigo NUMERIC(8,0), 
@Foto VARBINARY(MAX),
@Clave VARCHAR(200), 
@NoChecar VARCHAR(1), 
@ChecaLibre VARCHAR(1), 
@NoTiempoExtra VARCHAR(1),
@NoAusen VARCHAR(1), 
@Bloqueado VARCHAR(1), 
@NoExportar VARCHAR(1), 
@PremioPyA VARCHAR(1), 
@Comedor VARCHAR(1), 
@ExportaComedor VARCHAR(1), 
@FNomina VARCHAR(1), 
@Credencial VARCHAR(20),
@MailRetardos VARCHAR(2),
@MailTE VARCHAR(2),
@MailSalidaAntes VARCHAR(2),
@MailSupervisor VARCHAR(2),
@MailNomina VARCHAR(2),
@Enviar BIT,
@FechaUltimoEnvio DATETIME,
@ultimoMovimientoEnviado VARCHAR(2),
@Enviado BIT

AS 
  
  IF NOT EXISTS (SELECT 1
                 FROM dbo.EmpleadoApsiReloj AS ea
                 WHERE ea.codigo = @Codigo
                       AND ea.empresa = @empresa)
     BEGIN
       INSERT INTO dbo.EmpleadoApsiReloj (empresa,Codigo,Foto,Clave,NoChecar,ChecaLibre,NoTiempoExtra,NoAusen,Bloqueado,NoExportar,PremioPyA,Comedor,ExportaComedor,FNomina,Credencial,MailRetardos,MailTE,MailSalidaAntes,MailSupervisor,MailNomina,Enviar,FechaUltimoEnvio,ultimoMovimientoEnviado, Enviado)
                                  VALUES (@empresa,@Codigo,@Foto,@Clave,@NoChecar,@ChecaLibre,@NoTiempoExtra,@NoAusen,@Bloqueado,@NoExportar,@PremioPyA,@Comedor,@ExportaComedor,@FNomina,@Credencial,@MailRetardos,@MailTE,@MailSalidaAntes,@MailSupervisor,@MailNomina,@Enviar,@FechaUltimoEnvio,@ultimoMovimientoEnviado, @Enviado)
     END
  ELSE
     BEGIN
       UPDATE ea
       SET ea.Foto = @Foto,
           ea.Clave = @Clave,
           ea.NoChecar = @NoChecar,
           ea.ChecaLibre = @ChecaLibre,
           ea.NoTiempoExtra = @NoTiempoExtra,
           ea.NoAusen = @NoAusen,
           ea.Bloqueado = @Bloqueado,
           ea.NoExportar = @NoExportar,
           ea.PremioPyA = @PremioPyA,
           ea.Comedor = @Comedor,
           ea.ExportaComedor = @ExportaComedor,
           ea.FNomina = @FNomina,
           ea.Credencial = @Credencial,
           ea.MailRetardos = @MailRetardos,
           ea.MailTE = @MailTE,
           ea.MailSalidaAntes = @MailSalidaAntes,
           ea.MailSupervisor = @MailSupervisor,
           ea.MailNomina = @MailNomina,
           ea.Enviar = @Enviar,
           ea.FechaUltimoEnvio = @FechaUltimoEnvio,
           ea.ultimoMovimientoEnviado = @ultimoMovimientoEnviado,
           ea.Enviado = @Enviado
       FROM dbo.EmpleadoApsiReloj AS ea
       WHERE ea.codigo = @Codigo
             AND ea.empresa = @empresa
     END
GO

IF OBJECT_ID('dbo.ActualizaEspecialEnviaCorreo') IS NOT NULL 
    DROP PROCEDURE dbo.ActualizaEspecialEnviaCorreo
GO
CREATE PROCEDURE dbo.ActualizaEspecialEnviaCorreo
    @empresa INT ,
    @direccionDeCorreo VARCHAR(1000) ,
    @servidorDeCorreo VARCHAR(1000) ,
    @puertoDeCorreo INT ,
    @usuarioDeCorreo VARCHAR(1000) ,
    @passwordDeCorreo VARCHAR(1000) ,
    @mensajeDeCorreo VARCHAR(1000) ,
    @cAutentificacionCorreo CHAR(1) ,
    @cTipoAutentificacionCorreo VARCHAR(100) ,
    @cSSL CHAR(1) ,
    @cTLS CHAR(1) ,
    @correoDestino VARCHAR(1000) ,
    @asunto VARCHAR(250),
    @correoDestino2 VARCHAR(1000),
    @asunto2 VARCHAR(250),
    @mensajeDeCorreo2 VARCHAR(1000)
AS 
    IF NOT EXISTS ( SELECT  empresa
                    FROM    dbo.EspecialEnviaCorreo
                    WHERE   empresa = @empresa )
        BEGIN
            INSERT  dbo.EspecialEnviaCorreo
                    ( empresa ,
                      direccionDeCorreo ,
                      servidorDeCorreo ,
                      puertoDeCorreo ,
                      usuarioDeCorreo ,
                      passwordDeCorreo ,
                      AutentificacionCorreo ,
                      TipoAutentificacionCorreo ,
                      SSL ,
                      TLS,
                      MensajeDeCorreo ,
                      correoDestino ,
                      asunto,
                      correoDestino2,
                      asunto2,
                      MensajeDeCorreo2
                    )
            VALUES  ( @empresa ,
                      @direccionDeCorreo ,
                      @servidorDeCorreo ,
                      @puertoDeCorreo ,
                      @usuarioDeCorreo ,
                      @passwordDeCorreo ,
                      @cAutentificacionCorreo ,
                      @cTipoAutentificacionCorreo ,
                      @cSSL ,
                      @cTLS ,
                      @mensajeDeCorreo ,
                      @correoDestino ,
                      @asunto,
                      @correoDestino2,
                      @asunto2,
                      @mensajeDeCorreo2
                    )
        END
    ELSE 
        BEGIN
            UPDATE dbo.EspecialEnviaCorreo
            SET empresa = @empresa ,
                direccionDeCorreo = @direccionDeCorreo,
                servidorDeCorreo = @servidorDeCorreo,
                puertoDeCorreo = @puertoDeCorreo,
                usuarioDeCorreo = @usuarioDeCorreo,
                passwordDeCorreo = @passwordDeCorreo,
                AutentificacionCorreo = @cAutentificacionCorreo,
                TipoAutentificacionCorreo = @cTipoAutentificacionCorreo,
                SSL = @cSSL,
                TLS = @cTLS,
                mensajeDeCorreo = @mensajeDeCorreo,
                correoDestino = @correoDestino,
                asunto = @asunto,
                correoDestino2 = @correoDestino2,
                asunto2 = @asunto2,
                mensajeDeCorreo2 = @mensajeDeCorreo2
        END
GO

IF OBJECT_ID('dbo.ActualizaFactorDescuentoInfonavit') IS NOT NULL 
    DROP PROCEDURE dbo.ActualizaFactorDescuentoInfonavit
GO

CREATE PROCEDURE [dbo].[ActualizaFactorDescuentoInfonavit]
    @empresa INT ,
    @nss CHAR(11) ,
    @tipoCredito INT ,
    @valorDescuento FLOAT ,
    @fechaMovimiento DATETIME,
	@tipoMovimiento INT
AS 
    
	SET NOCOUNT ON

    --DECLARE @error INT
    DECLARE @codigo INT
    DECLARE @tipoCreditoInfonavit INT
    DECLARE @numeroCredito CHAR(10)
    DECLARE @periodo INT
    DECLARE @ayo_operacion INT
	DECLARE @tipoMovimientoClave CHAR(3)
	DECLARE @ultimoCambio CHAR(3)
	DECLARE @fechaUltimoCambio DATETIME
	DECLARE @observacion VARCHAR(100)
	DECLARE @reinicioDescuento CHAR(2)
	DECLARE @suspensionDescuento CHAR(3)
	DECLARE @inicioCreditoVivienda CHAR(3)
	DECLARE @modificacionValorDescuento CHAR(3)
	DECLARE @tipoMovimientoValido INT
	DECLARE @modificacionTipoDescuento CHAR(3)


	SET @reinicioDescuento = 'RD'
	SET @suspensionDescuento = 'FSD'
	SET @inicioCreditoVivienda = 'ICV'
	SET @modificacionValorDescuento = 'MVD'
	SET @modificacionTipoDescuento = 'MTD'

	SET @tipoMovimientoValido = 0

	SELECT TOP 1 @ultimoCambio = ic.cambio
            , @fechaUltimoCambio = ic.fecha
    FROM dbo.infonavit_cambios AS ic
         INNER JOIN dbo.empleados AS e ON ic.empresa = e.empresa
                                     AND ic.codigo = e.codigo
    WHERE   e.empresa = @empresa
            AND e.afiliacion + e.digvera = @nss
    ORDER BY ic.fecha DESC,
             ic.id_infocambio DESC

	IF @ultimoCambio IS NULL
	   BEGIN 
	     SELECT @ultimoCambio = CASE WHEN i.fechaSuspension IS NOT NULL THEN @suspensionDescuento ELSE @inicioCreditoVivienda END
                , @fechaUltimoCambio = CASE WHEN i.fechaSuspension IS NOT NULL THEN i.fechaSuspension ELSE i.fecha END
         FROM dbo.infonavit AS i
              INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                              AND i.codigo = e.codigo
         WHERE e.empresa = @empresa
               AND e.afiliacion + e.digvera = @nss
       END
       
	--SET @error = 1
/*
    IF @tipoMovimiento = 16
	  BEGIN
        SET @tipoMovimientoClave = @suspensionDescuento

         UPDATE  i
         SET     i.fechaSuspension = @fechaMovimiento
         FROM dbo.infonavit AS i
              INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                               AND i.codigo = e.codigo
         WHERE e.empresa = @empresa
               AND e.afiliacion + e.digvera = @nss
         SELECT  @error = @@ERROR
	  END

    ELSE IF @tipoMovimiento = 17
	  BEGIN
        SET @tipoMovimientoClave = @reinicioDescuento

         UPDATE  i
         SET     i.fecha = @fechaMovimiento
		         , i.fechaSuspension = NULL
         FROM    dbo.infonavit AS i
              INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                        AND i.codigo = e.codigo
         WHERE e.empresa = @empresa
               AND e.afiliacion + e.digvera = @nss
         SELECT  @error = @@ERROR
	  END

	ELSE IF @tipoMovimiento = 19
	   BEGIN
	     SET @tipoMovimientoClave = @modificacionValorDescuento
         UPDATE  i
         SET     i.descuento = @valorDescuento
         FROM dbo.infonavit AS i
              INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                               AND i.codigo = e.codigo
         WHERE e.empresa = @empresa
               AND e.afiliacion + e.digvera = @nss
         SELECT  @error = @@ERROR
	   END
*/

    IF @tipoMovimiento = 16 
	   BEGIN
         SET @tipoMovimientoClave = @suspensionDescuento
         SET @tipoMovimientoValido = 1
       END
    
    IF @tipoMovimiento = 17 
	   BEGIN
	     SET @tipoMovimientoClave = @reinicioDescuento
		 SET @tipoMovimientoValido = 1
	   END

    IF @tipoMovimiento = 18 
	   BEGIN
	     SET @tipoMovimientoClave = @modificacionTipoDescuento
		 SET @tipoMovimientoValido = 1
	   END

	IF @tipoMovimiento = 19
       BEGIN
	     SET @tipoMovimientoClave = @modificacionValorDescuento
		 SET @tipoMovimientoValido = 1
	   END
    
    IF @tipoMovimientoValido = 1
       BEGIN
          IF @ultimoCambio = @suspensionDescuento AND @tipoMovimientoClave <> @reinicioDescuento
             BEGIN
               SET @observacion = 'Tiene suspensin: (' + @ultimoCambio + ' ' + RIGHT(100 + DAY(@fechaUltimoCambio),2) + '/' + RIGHT(100 + MONTH(@fechaUltimoCambio),2) + '/' + RIGHT(10000 + YEAR(@fechaUltimoCambio),4) + ', ' + 'Debe registrar reinicio crdito'
             END
           
		  IF @observacion IS NULL
		     BEGIN
               IF @ultimoCambio <> @suspensionDescuento AND @tipoMovimientoClave = @reinicioDescuento
	              BEGIN
		            SET @observacion = 'Registro activo: (' + @ultimoCambio + ' ' + RIGHT(100 + DAY(@fechaUltimoCambio),2) + '/' + RIGHT(100 + MONTH(@fechaUltimoCambio),2) + '/' + RIGHT(10000 + YEAR(@fechaUltimoCambio),4) + ', ' + 'Debe registrar suspensin crdito'
                  END
             END

		  IF @observacion IS NULL
		     BEGIN
		       IF @fechaUltimoCambio > @fechaMovimiento
			      BEGIN
		            SET @observacion = 'Fecha ltimo cambio (' + @ultimoCambio + ' ' + RIGHT(100 + DAY(@fechaUltimoCambio),2) + '/' + RIGHT(100 + MONTH(@fechaUltimoCambio),2) + '/' + RIGHT(10000 + YEAR(@fechaUltimoCambio),4) + ' ' + 'mayor al que desea importar (' + @tipoMovimientoClave + ' ' + RIGHT(100 + DAY(@fechaMovimiento),2) + '/' + RIGHT(100 + MONTH(@fechaMovimiento),2) + '/' + RIGHT(10000 + YEAR(@fechaMovimiento),4) + ')'
				  END
             END

          IF @observacion IS NULL
		     BEGIN
               IF @tipoMovimiento = 16
                  BEGIN
                    SET @tipoMovimientoClave = @suspensionDescuento
                       
                    UPDATE  i
                    SET     i.fechaSuspension = @fechaMovimiento
                    FROM dbo.infonavit AS i
                         INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                                          AND i.codigo = e.codigo
                    WHERE e.empresa = @empresa
                          AND e.afiliacion + e.digvera = @nss
                    --SELECT  @error = @@ERROR
                  END
            
               ELSE IF @tipoMovimiento = 17
	              BEGIN
                    SET @tipoMovimientoClave = @reinicioDescuento
              
                    UPDATE  i
                    SET     i.fecha = @fechaMovimiento
                            , i.fechaSuspension = NULL
                    FROM dbo.infonavit AS i
                         INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                                          AND i.codigo = e.codigo
                    WHERE e.empresa = @empresa
                         AND e.afiliacion + e.digvera = @nss
                    --SELECT  @error = @@ERROR
	               END

	           ELSE IF @tipoMovimiento = 18
	              BEGIN
	                SET @tipoMovimientoClave = @modificacionTipoDescuento
                    UPDATE  i
                    SET     i.descuento = @valorDescuento
					        , i.tipo_cred = @tipoCredito
                    FROM dbo.infonavit AS i
                         INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                                          AND i.codigo = e.codigo
                    WHERE e.empresa = @empresa
                          AND e.afiliacion + e.digvera = @nss
                    --SELECT  @error = @@ERROR
	              END
               
	           ELSE IF @tipoMovimiento = 19
	              BEGIN
	                SET @tipoMovimientoClave = @modificacionValorDescuento
                    UPDATE  i
                    SET     i.descuento = @valorDescuento
                    FROM dbo.infonavit AS i
                         INNER JOIN dbo.empleados AS e ON i.empresa = e.empresa
                                                          AND i.codigo = e.codigo
                    WHERE e.empresa = @empresa
                          AND e.afiliacion + e.digvera = @nss
                    --SELECT  @error = @@ERROR
	              END
               
               SELECT  @codigo = dbo.empleados.codigo
               FROM    dbo.empleados
               WHERE   dbo.empleados.empresa = @empresa
                       AND dbo.empleados.afiliacion + dbo.empleados.digvera = @nss
   
               SELECT  @tipoCreditoInfonavit = dbo.infonavit.tipo_cred ,
                       @numeroCredito = dbo.infonavit.numcredito
               FROM    dbo.infonavit
               WHERE   dbo.infonavit.empresa = @empresa
                       AND dbo.infonavit.codigo = @codigo
   
               SELECT  @periodo = dbo.Periodos.periodo ,
                       @ayo_operacion = dbo.Periodos.ayo_operacion
               FROM    dbo.Llaves
                       INNER JOIN dbo.Periodos ON dbo.Llaves.empresa = dbo.Periodos.empresa
                                               AND dbo.Llaves.tiponom = dbo.Periodos.tiponom
               WHERE   dbo.Llaves.empresa = @empresa
                       AND dbo.Llaves.codigo = @codigo
                       AND dbo.Periodos.estatus = 'A'
   
               INSERT  dbo.infonavit_cambios (empresa, codigo , fecha           , tipo_cred            , descuento      , cambio              , periodo , ayo_operacion , numcredito)
                                      SELECT @empresa, @codigo, @fechaMovimiento, @tipoCreditoInfonavit, @valorDescuento, @tipoMovimientoClave, @periodo, @ayo_operacion, @numeroCredito 
                                      WHERE NOT EXISTS (SELECT 1 
                                                        FROM dbo.infonavit_cambios 
                                                        WHERE empresa = @empresa 
													          AND codigo = @codigo 
														      AND fecha = @fechaMovimiento 
														      AND tipo_cred = @tipoCreditoInfonavit 
														      AND descuento = @valorDescuento 
														      AND cambio = @tipoMovimientoClave 
														      AND numcredito = @numeroCredito)
             END
       END
    
	SELECT CASE WHEN @observacion IS NULL THEN 'Afectado' ELSE @observacion END AS observacion 
GO

IF OBJECT_ID('dbo.ActualizaLoteEnvio') IS NOT NULL 
    DROP PROCEDURE dbo.ActualizaLoteEnvio
GO
CREATE PROCEDURE dbo.ActualizaLoteEnvio
    @empresa INT ,
    @fechaEnvio DATETIME ,
    @lote VARCHAR(25) ,
    @fechaConfirmacion DATETIME
AS 
    UPDATE  dbo.avisos_imss
    SET     dbo.avisos_imss.lote = @lote ,
            dbo.avisos_imss.fechaConfirmacion = @fechaConfirmacion
    WHERE   dbo.avisos_imss.empresa = @empresa
            AND dbo.avisos_imss.fechaEnvio = @fechaEnvio
GO

IF OBJECT_ID('dbo.ActualizaTablaEmpleadoAdicional') IS NOT NULL 
    DROP PROCEDURE dbo.ActualizaTablaEmpleadoAdicional
GO
CREATE PROCEDURE dbo.ActualizaTablaEmpleadoAdicional
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @discapacitado CHAR(1) ,
    @clabe VARCHAR(20) ,
    @tipoRegimen INT ,
    @tipoContrato INT,
    @Claveestado VARCHAR(3)
AS 
    SET NOCOUNT ON
    DECLARE @nerr_ins_dis INT

    BEGIN TRANSACTION
    IF EXISTS ( SELECT  dbo.EmpleadoAdicional.codigo
                FROM    dbo.EmpleadoAdicional
                WHERE   dbo.EmpleadoAdicional.empresa = @nempresa
                        AND dbo.EmpleadoAdicional.codigo = @ncodigo ) 
        BEGIN
            UPDATE  empleadoAdicional
            SET     empleadoAdicional.discapacitado = @discapacitado ,
                    empleadoAdicional.clabe = @clabe ,
                    empleadoAdicional.tipoRegimen = @tipoRegimen ,
                    empleadoAdicional.tipoContrato = @tipoContrato,
                    empleadoAdicional.Claveestado = @Claveestado
            FROM    dbo.EmpleadoAdicional AS empleadoAdicional
            WHERE   empleadoAdicional.empresa = @nempresa
                    AND empleadoAdicional.codigo = @ncodigo
            SELECT  @nerr_ins_dis = @@ERROR
        END
    ELSE 
        BEGIN
            INSERT  dbo.EmpleadoAdicional
                    ( empresa ,
                      codigo ,
                      discapacitado ,
                      clabe ,
                      tipoRegimen ,
                      tipoContrato,
                      Claveestado
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      @discapacitado ,
                      @clabe ,
                      @tipoRegimen ,
                      @tipoContrato,
                      @Claveestado
                    )
            SELECT  @nerr_ins_dis = @@ERROR
        END

    IF @nerr_ins_dis <> 0 
        BEGIN
            ROLLBACK TRANSACTION
        END
    ELSE 
        BEGIN
            COMMIT TRANSACTION
        END
GO

IF OBJECT_ID('dbo.ActualizaTblUMA') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaTblUMA
GO
CREATE PROCEDURE dbo.ActualizaTblUMA
@idUma INT,
@fecha DATETIME,
@umaDiario NUMERIC(12,2),
@umaMensual NUMERIC(12,2),
@umaAnual NUMERIC(12,2),
--@aplicaIMSS BIT,
--@aplicaInfonavit BIT,
--@aplicaISR BIT,
@accion INT

AS
  SET NOCOUNT ON

  DECLARE @id INT
   
  IF @accion = 1 OR @accion = 2
     BEGIN
       IF EXISTS (SELECT 1 FROM dbo.TblUMA AS uma WHERE uma.fecha = @fecha)
          BEGIN
            SET @id = @idUma
            
            UPDATE uma
            SET uma.umaDiario = @umaDiario,
                uma.umaMensual = @umaMensual,
                uma.umaAnual = @umaAnual
                --uma.aplicaIMSS = @aplicaIMSS,
                --uma.aplicaInfonavit = @aplicaInfonavit,
                --uma.aplicaISR = @aplicaISR
            FROM dbo.TblUMA	AS uma
            WHERE uma.fecha = @fecha
          END
       ELSE
          BEGIN
            INSERT dbo.TblUMA (fecha, umaDiario, umaMensual, umaAnual) VALUES (@fecha, @umaDiario, @umaMensual, @umaAnual)
            SELECT @id = @@IDENTITY
          END
     END
     
  IF @accion = 0
     BEGIN
       SELECT TOP 1 @id = uma.idUma FROM dbo.TblUma AS uma WHERE uma.idUma < @idUma ORDER BY uma.idUma DESC
       DELETE uma FROM dbo.TblUMA AS uma WHERE uma.idUma = @idUma
     END
     
  SELECT @id AS id
GO

IF OBJECT_ID('dbo.ActualizaTblUMAFD') IS NOT NULL
   DROP PROCEDURE dbo.ActualizaTblUMAFD
GO
CREATE PROCEDURE dbo.ActualizaTblUMAFD
@idUma INT,
@fecha DATETIME,
@umaDiario NUMERIC(12,2),
@accion INT

AS
  SET NOCOUNT ON

  DECLARE @id INT
   
  IF @accion = 1 OR @accion = 2
     BEGIN
       IF EXISTS (SELECT 1 FROM dbo.TblUMAFD AS uma WHERE uma.fecha = @fecha)
          BEGIN
            SET @id = @idUma
            
            UPDATE umaFd
            SET umaFd.umaDiario = @umaDiario
            FROM dbo.TblUMAFd AS umaFd
            WHERE umaFd.fecha = @fecha
          END
       ELSE
          BEGIN
            INSERT dbo.TblUMAFD (fecha, umaDiario) VALUES (@fecha, @umaDiario)
            SELECT @id = @@IDENTITY
          END
     END
     
  IF @accion = 0
     BEGIN
       SELECT TOP 1 @id = umaFd.idUma FROM dbo.TblUmaFd AS umaFd WHERE umaFd.fecha < @fecha ORDER BY umaFd.fecha DESC
       DELETE umaFd FROM dbo.TblUMAFD AS umaFd WHERE umaFd.fecha = @fecha
     END
     
  SELECT @id AS id
GO

IF OBJECT_ID('dbo.ActualizaUltimoMovimientoEmpleados') IS NOT NULL 
    DROP PROCEDURE dbo.ActualizaUltimoMovimientoEmpleados
GO
CREATE PROCEDURE dbo.ActualizaUltimoMovimientoEmpleados
    @empresa INT ,
    @codigo INT
AS 
    UPDATE e
    SET e.ultmov = ultimoMovimiento.mov,
        e.ultfchmov = ultimoMovimiento.fch_mov,
		e.fch_baja = CASE WHEN ultimoMovimiento.mov = 'B' THEN ultimoMovimiento.fch_mov ELSE NULL END
    FROM dbo.empleados AS e
         CROSS APPLY (SELECT TOP 1
                             a.mov,
                             a.fch_mov 
                      FROM dbo.avisos_imss AS a
                      WHERE a.empresa = e.empresa
                            AND a.codigo = e.codigo
							AND ISNULL(a.origen,'') <> 'S'
                      ORDER BY a.fch_mov DESC ,
                               a.serial DESC) AS ultimoMovimiento 
    WHERE e.empresa = @empresa
          AND e.codigo = @codigo
GO

IF OBJECT_ID('dbo.ActualizaUltimoSueldo') IS NOT NULL 
    DROP PROCEDURE dbo.ActualizaUltimoSueldo
GO
CREATE PROCEDURE dbo.ActualizaUltimoSueldo
    @empresa INT ,
    @codigo INT
AS 
    UPDATE  dbo.empleados
    SET     dbo.empleados.sueldo = ultimoSueldo.sueldo ,
            dbo.empleados.saldiaint = ultimoSueldo.saldiaint
    FROM    dbo.empleados
            INNER JOIN ( SELECT TOP 1
                                dbo.avisos_imss.empresa ,
                                dbo.avisos_imss.codigo ,
                                dbo.avisos_imss.sueldo ,
                                dbo.avisos_imss.saldiaint
                         FROM   dbo.avisos_imss
                         WHERE  dbo.avisos_imss.empresa = @empresa
                                AND dbo.avisos_imss.codigo = @codigo
                                AND dbo.avisos_imss.mov <> 'B'
                         ORDER BY dbo.avisos_imss.ayo_operacion DESC ,
                                dbo.avisos_imss.mes_operacion DESC ,
                                dbo.avisos_imss.serial DESC
                       ) AS ultimoSueldo ON dbo.empleados.empresa = ultimoSueldo.empresa
                                            AND dbo.empleados.codigo = ultimoSueldo.codigo
    WHERE   dbo.empleados.empresa = @empresa
            AND dbo.empleados.codigo = @codigo
GO

IF OBJECT_ID('dbo.AgregaComa') IS NOT NULL 
    DROP  FUNCTION [dbo].[AgregaComa]
GO
CREATE FUNCTION [dbo].[AgregaComa] ( @valor NUMERIC(30, 10) )
RETURNS VARCHAR(50)

AS 
    BEGIN

       /*
       DECLARE @valor NUMERIC(30,10)
 
       SET @valor = 100.09
       */

        DECLARE @valorReturn VARCHAR(50)
        DECLARE @valorCaracter VARCHAR(50)
        DECLARE @entero VARCHAR(50)
        DECLARE @decimal VARCHAR(50)
        DECLARE @posicionDecimal INT
        DECLARE @ciclo INT
        DECLARE @cuenta INT
        DECLARE @decimalTemporal VARCHAR(50)

        DECLARE @valorEncontrado CHAR(1)
     
        SET @valorCaracter = CONVERT(VARCHAR(50), @valor)
        SET @posicionDecimal = CHARINDEX('.', @valorCaracter)
        SET @entero = CASE WHEN @posicionDecimal > 0
                           THEN SUBSTRING(@valorCaracter, 1,
                                          @posicionDecimal - 1)
                           ELSE @valorCaracter
                      END
        SET @decimal = CASE WHEN @posicionDecimal > 0
                            THEN SUBSTRING(@valorCaracter,
                                           @posicionDecimal + 1, 10)
                            ELSE ''
                       END
                       
        SET @ciclo = LEN(@entero)
        SET @cuenta = 0
        SET @valorReturn = ''
        SET @decimalTemporal = ''
     
        WHILE @ciclo >= 1 
            BEGIN
                SET @valorReturn = SUBSTRING(@entero, @ciclo, 1)
                    + @valorReturn
                SET @cuenta = @cuenta + 1
        
                IF @cuenta = 3
                    AND @ciclo > 1 
                    BEGIN
                        SET @cuenta = 0
                        SET @valorReturn = ',' + @valorReturn 
                    END
          
                SET @ciclo = @ciclo - 1
            END
     
        SET @ciclo = LEN(@decimal)
     
        SET @valorEncontrado = 'N'
     
        WHILE @ciclo >= 1 
            BEGIN
                IF SUBSTRING(@decimal, @ciclo, 1) = '0' AND @valorEncontrado = 'N'
                    SET @decimalTemporal = SUBSTRING(@decimal, 1, @ciclo - 1)
     	        ELSE
     	            SET @valorEncontrado = 'S'
     	            
                SET @ciclo = @ciclo - 1
            END

        SET @valorReturn = @valorReturn
            + CASE WHEN LEN(@decimalTemporal) = 1
                   THEN '.' + @decimalTemporal + '0'
                   WHEN LEN(@decimalTemporal) > 1 THEN '.' + @decimalTemporal
                   ELSE ''
              END   

    
        RETURN @valorReturn
    END
GO

IF OBJECT_ID('dbo.AspDatosEmpleado') IS NOT NULL 
    DROP PROCEDURE dbo.AspDatosEmpleado
GO
CREATE PROCEDURE [dbo].[AspDatosEmpleado]
    @empresa INTEGER = 0 ,
    @user VARCHAR(50)
AS 
    DECLARE @costCenterEmployee VARCHAR(50)
    DECLARE @system VARCHAR(50)
    DECLARE @typePayrollEmployee INT
    DECLARE @totalRegistros INT
    DECLARE @ayo INT
    DECLARE @mes INT
    DECLARE @ayo2 INT 
    DECLARE @mes2 INT 

    SET @costCenterEmployee = ''
    SET @system = 'NO'
    SET @typePayrollEmployee = 0
    
    SELECT @ayo2 = empresa.ayo_operacion,
           @mes2 = empresa.mes_operacion
    FROM dbo.empresas AS empresa
    WHERE empresa.empresa = @empresa
    
    --SET @ayo = @ayo2 - 5 -- Antes - 1  se cambio a - 5 JCMM 25/01/2018
    SET @ayo = @ayo2 - 100 --Antes - 5 se cambio a 100 16/01/2023 JFT

    SET @mes = 1

    --SET @ayo2 = @ayo2 + CASE WHEN @mes2 = 12 THEN 1 ELSE 0 END
    ----SET @mes2 = CASE WHEN @mes2 = 12 THEN 1 ELSE @mes2 + 1 END
    --SET @mes2 = CASE WHEN @mes2 = 12 THEN 1 ELSE @mes2 END
    
    SELECT DISTINCT
           @totalRegistros = COUNT(*) 
    FROM    dbo.empleados
            LEFT JOIN dbo.llaves ON dbo.empleados.empresa = dbo.llaves.empresa
                                    AND dbo.empleados.codigo = dbo.llaves.codigo
    WHERE   dbo.empleados.borrado = 'N'
            AND dbo.empleados.empresa = @empresa
            AND dbo.Llaves.centro IN (
            SELECT  costCenter
            FROM    [dbo].[GetCostCenterByProfile](@user, @costCenterEmployee,
                                                   @empresa, @system) )
            AND dbo.Llaves.tiponom IN (
            SELECT  typePayroll
            FROM    [dbo].[GetTypePayrollByProfile](@user,
                                                    @typePayrollEmployee,
                                                    @empresa, @system) )
            AND EXISTS (SELECT TOP 1
                               avisosImss.codigo
                        FROM dbo.avisos_imss AS avisosImss
                        WHERE RIGHT(10000 + YEAR(avisosImss.fch_mov),4) + RIGHT(100 + MONTH(avisosImss.fch_mov),2) >= RIGHT(10000 + @ayo,4) + RIGHT(100 + @mes,2)
                              --AND RIGHT(10000 + YEAR(avisosImss.fch_mov),4) + RIGHT(100 + MONTH(avisosImss.fch_mov),2) <= RIGHT(10000 + @ayo2,4) + RIGHT(100 + @mes2,2)
                              AND avisosImss.codigo = dbo.empleados.codigo
                              AND avisosImss.empresa = dbo.empleados.empresa)
    
    SET @totalRegistros = ISNULL(@totalRegistros,0)
          
            
    SELECT DISTINCT
            dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.empleados.fchalta ,
            dbo.empleados.fchantigua ,
            dbo.llaves.ocupacion ,
            dbo.tabulador.actividad ,
            dbo.llaves.clase ,
            dbo.empleados.tiposal ,
            dbo.llaves.tiponom ,
            dbo.llaves.horario ,
            dbo.llaves.centro ,
            dbo.empleados.sindicato ,
            dbo.empleados.sueldo ,
            dbo.empleados.varia_imss ,
            dbo.empleados.varia_next ,
            dbo.empleados.saldiaint ,
            dbo.empleados.tipo_emp ,
            dbo.empleados.art39 ,
            dbo.empleados.sexo ,
            dbo.empleados.edonac ,
            dbo.empleados.fchnac ,
            dbo.empleados.rfcalfa ,
            dbo.empleados.rfcnum ,
            dbo.empleados.rfchomo ,
            dbo.empleados.curp ,
            dbo.datosemps.edocivil ,
            dbo.datosemps.telefono ,
            dbo.empleados.manoobra ,
            dbo.llaves.supervisor ,
            dbo.datosemps.inegi ,
            dbo.datosemps.umf ,
            dbo.datosemps.afore ,
            dbo.datosemps.nacional ,
            dbo.bancos.nombre AS nombreBanco ,
            dbo.empleados.tipo_deposito ,
            dbo.empleados.cta_bco_no ,
            dbo.datosemps.domicilio ,
            dbo.datosemps.colonia ,
            dbo.datosemps.poblacion ,
            dbo.datosemps.codpostal ,
            dbo.horarios_catalogo.turno ,
            dbo.horarios_catalogo.jornada ,
            ( SELECT    CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N'
                             ELSE dbo.excepciones.excepcion1
                        END
              FROM      dbo.excepciones
              WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                        AND dbo.excepciones.codigo = dbo.empleados.codigo
                        AND dbo.excepciones.excepcion1 = 'CV'
            ) AS 'cv' ,
            ( SELECT    CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N'
                             ELSE dbo.excepciones.excepcion1
                        END
              FROM      dbo.excepciones
              WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                        AND dbo.excepciones.codigo = dbo.empleados.codigo
                        AND dbo.excepciones.excepcion1 = 'IV'
            ) AS 'iv' ,
            ( SELECT    CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'S'
                             ELSE dbo.excepciones.excepcion1
                        END
              FROM      dbo.excepciones
              WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                        AND dbo.excepciones.codigo = dbo.empleados.codigo
                        AND dbo.excepciones.excepcion1 = 'NOIMSS'
            ) AS 'imss' ,
            ( SELECT    CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'S'
                             ELSE dbo.excepciones.excepcion1
                        END
              FROM      dbo.excepciones
              WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                        AND dbo.excepciones.codigo = dbo.empleados.codigo
                        AND dbo.excepciones.excepcion1 = '115'
            ) AS '115' ,
            'N' AS 'chofer' ,      --(SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'CHOFER') AS 'chofer' ,
            0 AS 'isr_chofer' ,    --(SELECT CASE WHEN dbo.excepciones.excepcion2 IS NULL THEN 0   ELSE dbo.excepciones.excepcion2 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'CHOFER') AS 'isr_chofer' ,
            'N' AS 'ayu_chofer' ,  --(SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'ACHOFER') AS 'ayu_chofer' ,
            0 AS 'isr_ayu' ,       --(SELECT CASE WHEN dbo.excepciones.excepcion2 IS NULL THEN 0   ELSE dbo.excepciones.excepcion2 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'ACHOFER') AS 'isr_ayu' ,
            dbo.llaves.banco ,
            dbo.empleados.mcamov ,
            dbo.empleados.sig_bim ,
            dbo.empleados.var_sigmes ,
            dbo.empleados.cotiza_imss ,
            dbo.empleados.pagar_nomina ,
            dbo.empleados.rpu ,
            dbo.empleados.multiple ,
            dbo.empleados.cuenta ,
            ISNULL(dbo.EmpleadoAdicional.discapacitado, 'N') AS discapacitado ,
            ISNULL(dbo.EmpleadoAdicional.clabe, SPACE(20)) AS clabe ,
            ISNULL(dbo.EmpleadoAdicional.tipoRegimen, 2) AS tipoRegimen ,
            ISNULL(dbo.EmpleadoAdicional.tipoContrato, 1) AS tipoContrato ,
            ISNULL(dbo.datosemps.email, SPACE(40)) AS email ,
            ISNULL(dbo.datosemps.cta_vales, SPACE(20)) AS cta_vales ,
            dbo.datosemps.numeroExterior ,
            dbo.datosemps.numeroInterior ,
            dbo.datosemps.municipio ,
            dbo.datosemps.localidad ,
            dbo.empleados.codigo ,
            dbo.clasificacion_empleados.campo_02 ,
            dbo.clasificacion_empleados.campo_03 ,
            dbo.clasificacion_empleados.campo_04 ,
            dbo.clasificacion_empleados.campo_05 ,
            dbo.clasificacion_empleados.campo_07 ,
            dbo.clasificacion_empleados.campo_08 ,
            dbo.clasificacion_empleados.campo_10 ,
            dbo.clasificacion_empleados.campo_11 ,
            @totalRegistros AS totalRegistros ,
            dbo.empleados.tiposal AS tipoSalario ,
            dbo.empleados.sindicato AS sindicalizado ,
            dbo.datosemps.edocivil AS estadoCivil ,
            CASE WHEN RIGHT(10000 + YEAR(dbo.empleados.ultfchmov),4) + RIGHT(100 + MONTH(dbo.empleados.ultfchmov),2) >= RIGHT(10000 + @ayo2,4) + RIGHT(100 + @mes2,2) THEN 1 ELSE 0 END AS grupo,
            dbo.EmpleadoAdicional.claveEstado,
            dbo.empleados.ultfchmov,
            --dbo.empleados.ultmov,
			iif(dbo.empleados.activo <> 'S','B',dbo.empleados.ultmov) as ultmov,
            dbo.empleados.factorsd,
            CASE WHEN RIGHT(10000 + YEAR(ultimoAviso.fch_mov), 4) + RIGHT(100 + MONTH(ultimoAviso.fch_mov), 2) >= RIGHT(10000 + @ayo2, 4) + RIGHT(100 + @mes2, 2) THEN ultimoAviso.serial ELSE 0 END AS serial,
            ISNULL(ultimoAviso.sueldo,0) AS ultimoSueldo,
            ISNULL(ultimoAviso.saldiaint,0) AS ultimoSaldiaint,
            dbo.clasificacion_empleados.campo__09 ,
            dbo.clasificacion_empleados.campo__10 ,
            dbo.clasificacion_empleados.campo__11 ,
            dbo.clasificacion_empleados.campo__12 ,
            dbo.clasificacion_empleados.campo__13 ,
            dbo.clasificacion_empleados.campo__14 ,
            dbo.clasificacion_empleados.campo__15 ,
			dbo.empleados.activo
    FROM    dbo.empleados
            LEFT JOIN dbo.llaves ON dbo.empleados.empresa = dbo.llaves.empresa
                                    AND dbo.empleados.codigo = dbo.llaves.codigo
            LEFT JOIN dbo.tabulador ON dbo.empleados.empresa = dbo.tabulador.empresa
                                       AND dbo.llaves.ocupacion = dbo.tabulador.ocupacion
            LEFT JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                       AND dbo.empleados.codigo = dbo.datosemps.codigo
            LEFT JOIN dbo.horarios_catalogo ON dbo.empleados.empresa = dbo.horarios_catalogo.empresa
                                               AND dbo.llaves.horario = dbo.horarios_catalogo.horario
            LEFT JOIN dbo.bancos ON dbo.llaves.banco = dbo.bancos.banco
            LEFT JOIN dbo.EmpleadoAdicional ON dbo.empleados.empresa = dbo.EmpleadoAdicional.empresa
                                               AND dbo.empleados.codigo = dbo.EmpleadoAdicional.codigo
            LEFT JOIN dbo.clasificacion_empleados ON dbo.EmpleadoAdicional.codigo = dbo.clasificacion_empleados.codigo
                                                     AND dbo.EmpleadoAdicional.empresa = dbo.clasificacion_empleados.empresa
                                                     
            OUTER APPLY (SELECT TOP 1
                                ultimoAviso.empresa,
                                ultimoAviso.codigo,
                                ultimoAviso.mov,
                                ultimoAviso.fch_mov,
                                ultimoAviso.serial,
                                ultimoAviso.sueldo,
                                ultimoAviso.saldiaint
                         FROM dbo.avisos_imss AS ultimoAviso
                                    WHERE ultimoAviso.empresa = dbo.empleados.empresa
                                          AND ultimoAviso.codigo = dbo.empleados.codigo
                                          AND RIGHT(10000 + YEAR(ultimoAviso.fch_mov), 4) + RIGHT(100 + MONTH(ultimoAviso.fch_mov), 2) >= RIGHT(10000 + @ayo2, 4) + RIGHT(100 + @mes2, 2)
                                          --AND RIGHT(10000 + YEAR(ultimoAviso.fch_mov), 4) + RIGHT(100 + MONTH(ultimoAviso.fch_mov), 2) <= RIGHT(10000 + @nayo_fin, 4) + RIGHT(100 + @nmes_fin, 2)
                                    ORDER BY ultimoAviso.fch_mov DESC ,
                                             ultimoAviso.serial DESC) AS ultimoAviso
                                             
    WHERE   dbo.empleados.borrado = 'N'
            AND dbo.empleados.empresa = @empresa
            AND dbo.Llaves.centro IN (
            SELECT  costCenter
            FROM    [dbo].[GetCostCenterByProfile](@user, @costCenterEmployee,
                                                   @empresa, @system) )
            AND dbo.Llaves.tiponom IN (
            SELECT  typePayroll
            FROM    [dbo].[GetTypePayrollByProfile](@user,
                                                    @typePayrollEmployee,
                                                    @empresa, @system) )
            AND EXISTS (SELECT TOP 1
                               avisosImss.codigo
                        FROM dbo.avisos_imss AS avisosImss
                        WHERE RIGHT(10000 + YEAR(avisosImss.fch_mov),4) + RIGHT(100 + MONTH(avisosImss.fch_mov),2) >= RIGHT(10000 + @ayo,4) + RIGHT(100 + @mes,2)
                              --AND RIGHT(10000 + YEAR(avisosImss.fch_mov),4) + RIGHT(100 + MONTH(avisosImss.fch_mov),2) <= RIGHT(10000 + @ayo2,4) + RIGHT(100 + @mes2,2)
                              AND avisosImss.codigo = dbo.empleados.codigo
                              AND avisosImss.empresa = dbo.empleados.empresa)
    ORDER BY CASE WHEN RIGHT(10000 + YEAR(dbo.empleados.ultfchmov),4) + RIGHT(100 + MONTH(dbo.empleados.ultfchmov),2) >= RIGHT(10000 + @ayo2,4) + RIGHT(100 + @mes2,2) THEN 1 ELSE 0 END DESC ,
            dbo.empleados.codigo            
GO

If OBJECT_ID('dbo.sp_agrega_aviso_baja') Is NOT NULL
  Drop Procedure dbo.sp_agrega_aviso_baja
Go


If OBJECT_ID('dbo.asp_agrega_aviso_baja') Is NOT NULL
  Drop Procedure dbo.asp_agrega_aviso_baja
Go

CREATE procedure dbo.asp_agrega_aviso_baja
@nempresa numeric(5,0),
@ncodigo numeric(8,0),
@nserial int,
@nmes_operacion int,
@nayo_operacion int,
@dfch_mov datetime,
@dfch_real datetime,
@cmov varchar(  2),
@nsaldiaint decimal(9,2),
@nsaldiaiv decimal(9,2),
@nsueldo decimal(9,2),
@ndiastr int,
@nincap int,
@nausen decimal(5,2),
@cmot_baja varchar(30),
@nclave_baja INT,
@origen CHAR(2)

as

declare @nerr_ins_avi int
declare @nerr_ins_emp int

declare @nsdo numeric(12,2)
declare @nsdi numeric(12,2)
declare @dfch_antigua DATETIME
DECLARE @rpu VARCHAR(3)

set @nerr_ins_avi = 0
set @nerr_ins_emp = 0

set @nsdo = 0
set @nsdi = 0


begin tran
               
          select top 1 @nsdo = sueldo, @nsdi = saldiaint 
          from avisos_imss
          where empresa = @nempresa and codigo = @ncodigo and mov <> 'B' and fch_mov <= @dfch_mov
          order by ayo_operacion desc, mes_operacion desc, serial desc
                
          select @dfch_antigua = dbo.empleados.fchantigua,
                 @rpu = dbo.empleados.rpu
          from dbo.empleados
          where dbo.empleados.empresa = @nempresa and dbo.empleados.codigo = @ncodigo

                  
          insert into avisos_imss
                          (empresa, 
                           codigo, 
                           serial, 
                           mes_operacion, 
                           ayo_operacion, 
                           fch_mov, 
                           fch_real, 
                           mov, 
                           saldiaint, 
                           saldiaiv, 
                           sueldo, 
                           diastr, 
                           incap, 
                           ausen, 
                           mot_baja, 
                           clave_baja,
                           sueldoant,
                           saldiaintant,
                           campo_07,
                           rpu,
                           origen)
          values         
                          (@nempresa, 
                           @ncodigo, 
                           @nserial, 
                           @nmes_operacion, 
                           @nayo_operacion, 
                           @dfch_mov, 
                           @dfch_real, 
                           @cmov, 
                           0, 
                           0, 
                           0, 
                           @ndiastr, 
                           @nincap, 
                           @nausen, 
                           @cmot_baja, 
                           @nclave_baja,
                           @nsdo,
                           @nsdi,
                           @dfch_antigua,
                           @rpu,
                           @origen)

          select @nerr_ins_avi = @@error

          update empleados
          set ultmov = @cmov,
                ultfchmov = @dfch_mov,
                sueldo = @nsueldo,
                saldiaint = @nsaldiaint
          where empresa = @nempresa and 
                     codigo = @ncodigo

          select @nerr_ins_emp = @@error

If @nerr_ins_avi <> 0 or @nerr_ins_emp <> 0
    rollback tran
else
    commit tran
GO

DELETE dbo.ActualizaDB WHERE Script = 'actualizadb_asp_agrega_periodo.sql'
GO
IF OBJECT_ID('dbo.asp_agrega_periodo') IS NOT NULL
    DROP PROCEDURE dbo.asp_agrega_periodo
GO
CREATE PROCEDURE dbo.asp_agrega_periodo
    @nempresa NUMERIC(5, 0) ,
    @ntiponom INT ,
    @nayo INT
AS
    DECLARE @nmes INT
    DECLARE @dinicio DATETIME
    DECLARE @dcierre DATETIME
    DECLARE @cdia_feb CHAR(2)

    SET @nmes = 0

    IF @nayo % 4 = 0
        SET @cdia_feb = '29'
    ELSE
        SET @cdia_feb = '28'

    WHILE @nmes < 12
        BEGIN
            SET @nmes = @nmes + 1
            SET @dinicio = LTRIM(STR(@nayo)) + SUBSTRING(LTRIM(STR(@nmes + 100)),
                                                         2, 2) + '01'
            IF @nmes = 1
                OR @nmes = 3
                OR @nmes = 5
                OR @nmes = 7
                OR @nmes = 8
                OR @nmes = 10
                OR @nmes = 12
                SET @dcierre = LTRIM(STR(@nayo)) + SUBSTRING(LTRIM(STR(@nmes
                                                              + 100)), 2, 2)
                    + '31'

            IF @nmes = 4
                OR @nmes = 6
                OR @nmes = 9
                OR @nmes = 11
                SET @dcierre = LTRIM(STR(@nayo)) + SUBSTRING(LTRIM(STR(@nmes
                                                              + 100)), 2, 2)
                    + '30'

            IF @nmes = 2
                SET @dcierre = LTRIM(STR(@nayo)) + SUBSTRING(LTRIM(STR(@nmes
                                                              + 100)), 2, 2)
                    + @cdia_feb

            INSERT  periodos
                    ( tiponom ,
                      periodo ,
                      ayo_operacion ,
                      empresa ,
                      inicio ,
                      cierre ,
                      pago ,
                      dias ,
                      mes ,
                      bimestre ,
                      estatus ,
                      dias_anticipados
                    )
            VALUES  ( @ntiponom ,
                      @nmes ,
                      @nayo ,
                      @nempresa ,
                      @dinicio ,
                      @dcierre ,
                      @dcierre ,
                      DATEDIFF(dd, @dinicio, @dcierre) + 1 ,
                      SUBSTRING(LTRIM(STR(@nmes + 100)), 2, 2)
                      + LTRIM(STR(@nayo)) ,
                      SUBSTRING(LTRIM(STR(ROUND(@nmes / 2.0, 0) + 100)), 2, 2)
                      + LTRIM(STR(@nayo)) ,
                      ' ' ,
                      0
                    )
        END
GO

IF OBJECT_ID('dbo.asp_anexo_rt') IS NOT NULL
   DROP PROCEDURE dbo.asp_anexo_rt
GO
CREATE PROCEDURE [dbo].[asp_anexo_rt]
@nempresa numeric(5,0),
@nayo int

AS

insert into casos_rt_importado 
                (empresa, emp_original, codigo, nombre, afiliacion, digvera, curp, caso, ayo_operacion, st1_accidente, st1_trayecto, st1_fecha, st2_accidente, st2_fecha, st3_accidente, st3_valuacion, dias_subs, apellidoPaterno, apellidoMaterno, nombreEmpleado)
                 select @nempresa,0,c.codigo,rtrim(e.ap_paterno) + ' ' + rtrim(e.ap_materno) + ' ' + rtrim(e.nombre),e.afiliacion,e.digvera,e.curp, c.caso, c.ayo_operacion, c.st1_accidente, c.st1_trayecto, c.st1_fecha, c.st2_accidente, c.st2_fecha, c.st3_accidente, c.st3_valuacion, 
                        isnull((select sum(dias) 
                                from incapacidades_rt as i 
                                where i.empresa = @nempresa 
                                      and i.ayo_operacion = @nayo 
                                      and i.codigo = c.codigo 
                                      and i.caso = c.caso),0),
                 e.ap_paterno, 
                 e.ap_materno, 
                 e.nombre
                from casos_rt as c
                inner join empleados as e on e.empresa = c.empresa and e.codigo = c.codigo
                where c.empresa = @nempresa and c.ayo_operacion = @nayo and c.caso > 0 and c.st1_trayecto <> 'S'


update cri set cri.dias_subs = (select sum(iri.dias) 
                                from incapacidades_rt_importado as iri
                                where iri.empresa       = cri.empresa      and 
                                      iri.emp_original  = cri.emp_original and
                                      iri.codigo        = cri.codigo       and 
                                      iri.caso          = cri.caso         and 
                                      iri.ayo_operacion = cri.ayo_operacion)
from casos_rt_importado as cri
where cri.empresa = @nempresa and cri.emp_original > 0 and cri.st1_trayecto <> 'S'



if not exists (select caso from casos_rt_importado where empresa = @nempresa and ayo_operacion = @nayo)
   insert casos_rt_importado (empresa, emp_original, ayo_operacion) values (@nempresa, 0, @nayo)

GO

if object_id('dbo.asp_bim_aus') IS NOT NULL
   drop procedure dbo.asp_bim_aus
go

create procedure dbo.asp_bim_aus
@nempresa numeric(5,0),
@nayo int,
@nmes_non int,
@nmes_par int,
@ncodigo numeric(8,0),
@ndias_tope decimal(5,2)

as

declare @ndias_non numeric(5,0)
declare @ndias_par numeric(5,0)
declare @ninicio numeric(8,0)
declare @nfin numeric(8,0)
declare @naus_non decimal(5,2)
declare @naus_par decimal(5,2) 
declare @ncodant numeric(8,0)
declare @nfolio int
DECLARE @fechaInicio1 DATETIME
DECLARE @fechaFin1 DATETIME
DECLARE @dias1 INT
DECLARE @fechaInicio2 DATETIME
DECLARE @fechaFin2 DATETIME
DECLARE @dias2 INT
DECLARE @bimestre INT

SET @bimestre = CASE WHEN @nmes_par > 0
                     THEN CASE WHEN @nmes_par % 2 = 0 THEN 1 ELSE 0 END
                     ELSE 0
                END

SET @fechaInicio1 = CONVERT(DATETIME, RIGHT(STR(@nayo),4) + RIGHT(STR(100 + @nmes_non),2) + '01')
SET @fechaFin1 = DATEADD(dd,-(DAY(DATEADD(mm,1,@fechaInicio1))),DATEADD(mm,1,@fechaInicio1))
SET @dias1 = DATEDIFF(dd,@fechaInicio1,@fechaFin1) + 1

IF @bimestre = 1
   BEGIN
     SET @fechaInicio2 = DATEADD(dd,(DAY(DATEADD(mm,1,@fechaInicio1))-1),DATEADD(mm,1,@fechaInicio1))
     SET @fechaFin2 = DATEADD(dd,-(DAY(DATEADD(mm,1,@fechaInicio1))),DATEADD(mm,2,@fechaInicio1))
     SET @dias2 = DATEDIFF(dd,@fechaInicio2,@fechaFin2) + 1
   END 
   
--SELECT @dias1, @dias2   

set @ndias_non = 0
set @ndias_par = 0
set @naus_non = 0
set @naus_par = 0 
set @ncodant = 0
set @nfolio = 0

if @ncodigo = 0
   begin  
       set @ninicio = 1
       set @nfin     = 99999999
   end
else
   begin
       set @ninicio = @ncodigo
       set @nfin   = @ncodigo
   end

update a 
set a.ausen = 0
from avisos_imss as a
where a.empresa        = @nempresa
      --a.ayo_operacion  = @nayo     and 
      --(a.mes_operacion = @nmes_non or 
      -- a.mes_operacion = @nmes_par) and
      AND YEAR(a.fch_mov) = @nayo
      AND (MONTH(a.fch_mov) = @nmes_non
           OR MONTH(a.fch_mov) = @nmes_par)
      AND a.codigo between @ninicio and @nfin

select a.empresa, 
       a.codigo, 
       a.ayo_operacion, 
       a.mes_operacion, 
       a.serial,
       0 as 'serial_bim', 
       d.fchinicio, 
       d.dias,
       case when d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
            then datediff(dd,a.fch_mov,d.fchinicio + d.dias)  
            else case when d.fchinicio >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                      then d.dias
                      else case when d.fchinicio >= a.fch_mov and d.fchinicio <= a.fch_mov + a.diastr - 1 and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                then datediff(dd,d.fchinicio,a.fch_mov + a.diastr)
                                else case when d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                          then a.diastr
                                          else 0
                                     end 
                           end 
                  end 
       end 
       as 'aus',
       @naus_non as 'aus_non',
       @naus_par as 'aus_par'
into #tmp_aus
FROM    dbo.avisos_imss AS a
        LEFT JOIN dbo.deducciones AS d ON a.empresa = d.empresa
                                 AND a.codigo = d.codigo
WHERE   a.empresa = @nempresa
        AND a.ayo_operacion = @nayo
        AND (a.mes_operacion = @nmes_non
             OR a.mes_operacion = @nmes_par)
        AND a.diastr > 0
        AND d.num_conc = 108
        AND ( ( d.fchinicio <= a.fch_mov
                AND d.fchtermino >= a.fch_mov
                AND d.fchinicio <= a.fch_mov
                + a.diastr - 1
              )
              OR ( d.fchinicio >= a.fch_mov
                   AND d.fchtermino <= a.fch_mov
                   + a.diastr - 1
                 )
              OR ( d.fchinicio >= a.fch_mov
                   AND d.fchinicio <= a.fch_mov
                   + a.diastr - 1
                   AND d.fchtermino >= a.fch_mov
                   + a.diastr - 1
                 )
              OR ( d.fchinicio <= a.fch_mov
                   AND d.fchtermino >= a.fch_mov
                   + a.diastr - 1
                 )
            )


delete #tmp_aus where aus = 0

update #tmp_aus 
--set aus_non = case when month(fchinicio) = @nmes_non then aus else 0 end,
--    aus_par = case when month(fchinicio) = @nmes_par then aus else 0 end
SET aus_non = CASE WHEN fchinicio <= @fechaInicio1
                        AND fchinicio + dias - 1 >= @fechaInicio1
                        AND fchinicio + dias - 1 <= @fechaFin1
                   THEN DATEDIFF(dd, @fechaInicio1, fchinicio + dias)
                   ELSE CASE WHEN fchinicio >= @fechaInicio1
                                  AND fchinicio + dias - 1 <= @fechaFin1
                             THEN dias
                             ELSE CASE WHEN fchinicio >= @fechaInicio1
                                            AND fchinicio <= @fechaFin1
                                            AND fchinicio + dias - 1 >= @fechaFin1
                                       THEN DATEDIFF(dd, fchinicio, @fechaFin1) + 1
                                       ELSE CASE WHEN fchinicio <= @fechaInicio1
                                                      AND fchinicio + dias - 1 >= @fechaFin1
                                                 THEN @dias1
                                                 ELSE 0
                                            END
                                  END
                        END
              END,
aus_par = CASE WHEN fchinicio <= @fechaInicio2
                        AND fchinicio + dias - 1 >= @fechaInicio2
                        AND fchinicio + dias - 1 <= @fechaFin2
                   THEN DATEDIFF(dd, @fechaInicio2, fchinicio + dias)
                   ELSE CASE WHEN fchinicio >= @fechaInicio2
                                  AND fchinicio + dias - 1 <= @fechaFin2
                             THEN dias
                             ELSE CASE WHEN fchinicio >= @fechaInicio2
                                            AND fchinicio <= @fechaFin2
                                            AND fchinicio + dias - 1 >= @fechaFin2
                                       THEN DATEDIFF(dd, fchinicio, @fechaFin2) + 1
                                       ELSE CASE WHEN fchinicio <= @fechaInicio2
                                                      AND fchinicio + dias - 1 >= @fechaFin2
                                                 THEN @dias2
                                                 ELSE 0
                                            END
                                  END
                        END
              END


update #tmp_aus 
set 
@nfolio = case when @ncodant <> codigo then 0 else @nfolio end, 
@nfolio = @nfolio + 1,
serial_bim = @nfolio,
@ncodant = codigo 

update t 
set @ndias_non = case when t.serial_bim = 1 then 0 else @ndias_non end,
    @ndias_par = case when t.serial_bim = 1 then 0 else @ndias_par end,
    @ndias_non = @ndias_non + case when t.aus_non is null then 0 else t.aus_non end,
    @ndias_par = @ndias_par + case when t.aus_par is null then 0 else t.aus_par end,
    t.aus_non = case when @ndias_non < @ndias_tope 
                     then t.aus_non 
                     else case when t.aus_non - (@ndias_non - @ndias_tope) < 0 
                               then 0 
                               else t.aus_non - (@ndias_non - @ndias_tope) 
                          end 
                end,
    t.aus_par = case when @ndias_par < @ndias_tope 
                     then t.aus_par 
                     else case when t.aus_par - (@ndias_par - @ndias_tope) < 0 
                               then 0 
                               else t.aus_par - (@ndias_par - @ndias_tope) 
                          end 
                end
from #tmp_aus as t

update a 
set a.ausen = isnull((select sum(b.aus_non) + sum(b.aus_par)
               from #tmp_aus as b 
               where a.empresa       = b.empresa       and 
                     a.codigo        = b.codigo        and 
                     a.ayo_operacion = b.ayo_operacion and 
                     a.mes_operacion = b.mes_operacion and 
                     a.serial        = b.serial),0)
from avisos_imss as a
where a.empresa       = @nempresa and 
      a.ayo_operacion = @nayo     and 
      (a.mes_operacion = @nmes_non or
       a.mes_operacion = @nmes_par) and 
      a.codigo between @ninicio and @nfin and
      a.diastr > 0





drop table #tmp_aus


--select a.codigo, e.ap_paterno, e.ap_materno, e.nombre, a.mov, a.fch_mov, a.diastr, a.ausen, a.incap 
--from avisos_imss as a
--inner join empleados as e on e.empresa = a.empresa and e.codigo = a.codigo
--where a.empresa = 6 and a.ayo_operacion = 2006 and (a.mes_operacion = 11 or a.mes_operacion = 12)
--order by e.ap_paterno, e.ap_materno, e.nombre, a.ayo_operacion, a.mes_operacion, a.serial
go

IF OBJECT_ID('dbo.asp_bim_aus_UMA') IS NOT NULL
   DROP PROCEDURE dbo.asp_bim_aus_UMA
GO
CREATE PROCEDURE dbo.asp_bim_aus_UMA
@nempresa INT,
@nayo INT,
@nmes_non INT,
@nmes_par INt,
@ncodigo INT,
@ndias_tope NUMERIC(5,2)
, @proceso VARCHAR(250)
, @fechaProceso DATETIME
, @horaProceso VARCHAR(8)

AS

  SET NOCOUNT ON

  DECLARE @ndias_non INT
  DECLARE @ninicio INT
  DECLARE @nfin INT
  DECLARE @bimestre INT
  DECLARE @CodigoAnterior INT
  DECLARE @FiNon DATETIME
  DECLARE @FfNon DATETIME
  DECLARE @EsRpuEspecial INT

  SET @EsRpuEspecial = dbo.EsRpuEspecial(@nempresa)

  SET @bimestre = CASE WHEN @nmes_par > 0
                       THEN CASE WHEN @nmes_par % 2 = 0 THEN 1 ELSE 0 END
                       ELSE 0
                  END

  SET @ndias_non = 0

  IF @ncodigo = 0
     BEGIN  
       SET @ninicio = 1
       SET @nfin     = 99999999
     END
  ELSE
     BEGIN
       SET @ninicio = @ncodigo
       SET @nfin   = @ncodigo
     END

  SET @FiNon = CONVERT(DATETIME, RIGHT('0000' + LTRIM(RTRIM(STR(@nayo))),4) + RIGHT('00' + LTRIM(RTRIM(STR(@nmes_non))),2) + '01')
  SET @FfNon = (SELECT fechaFin FROM [dbo].[ObtieneRangoFecha](@FiNon, 7))

  DECLARE @FiPar DATETIME
  DECLARE @FfPar DATETIME
  DECLARE @ndias_par INT

  SET @FiPar = CONVERT(DATETIME, RIGHT('0000' + LTRIM(RTRIM(STR(@nayo))),4) + RIGHT('00' + LTRIM(RTRIM(STR(@nmes_par))),2) + '01')
  SET @FfPar = (SELECT fechaFin FROM [dbo].[ObtieneRangoFecha](@FiPar, 7))
  SET @ndias_par = 0

  UPDATE a
  SET a.ausen = 0
  FROM dbo.AvisosImssTemporalCalculo AS a
       INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
  WHERE a.proceso = @proceso
        AND a.fechaProceso = @fechaProceso
        AND a.horaProceso = @horaProceso
        --AND a.empresa = @nempresa
        AND a.fch_mov >= @FiNon --YEAR(a.fch_mov) = @nayo AND 
        AND a.fch_mov <= @FfPar --MONTH(a.fch_mov) = @nmes_non AND 
        AND a.codigo >= CASE WHEN @ncodigo = 0 THEN @ninicio ELSE @ncodigo END
        AND a.codigo <= CASE WHEN @ncodigo = 0 THEN @nfin ELSE @ncodigo END

  SET @CodigoAnterior = 0
  SET @ndias_non = 0


--SELECT '1', @FiNon AS FiNon, @FfNon AS FfNon, * FROM dbo.AvisosImssTemporalCalculo AS a where empresa = 2 and codigo = 1004


  UPDATE a
  --SET @ndias_non = CASE WHEN @CodigoAnterior <> a.codigo THEN 0 ELSE @ndias_non END,
  SET @ndias_non = CASE WHEN a.serial = 1 THEN 0 ELSE ISNULL(@ndias_non,0) END,
      @ndias_non = @ndias_non + ISNULL(ausentismo.ausen_deducciones,0),
      a.ausen = CASE WHEN @ndias_non < @ndias_tope 
                     THEN ISNULL(ausentismo.ausen_deducciones,0)
                     ELSE CASE WHEN ISNULL(ausentismo.ausen_deducciones,0) - (@ndias_non - @ndias_tope) < 0 
                               THEN 0 
                               ELSE ISNULL(ausentismo.ausen_deducciones,0) - (@ndias_non - @ndias_tope) 
                          END 
                END
      --, @CodigoAnterior = a.codigo

--SELECT *
  FROM (

--select * from (
  SELECT TOP 2147483647
               a.empresa
               , a.codigo
               , a.fch_mov
			   , a.diastr
			   , a.serial
               , a.ausen
			   , fch.ff_mov
			   , a.fch_mov + a.diastr - CASE WHEN a.diastr > 0 THEN 1 ELSE 0 END as tt
			   --, @FiNon AS FiNon
			   --, @FfNon AS FfNon
        FROM dbo.AvisosImssTemporalCalculo AS a
		     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
             CROSS APPLY (SELECT dbo.NOM_FUN_AjustaFechaUltimoDiaMes(@FfNon, a.fch_mov, a.diastr) AS ff_mov) AS fch
        WHERE a.proceso = @proceso
              AND a.fechaProceso = @fechaProceso
              AND a.horaProceso = @horaProceso
              --AND  a.empresa = @nempresa AND
              --YEAR(a.fch_mov) = @nayo AND 
              --MONTH(a.fch_mov) = @nmes_non AND 
			  AND a.fch_mov >= @FiNon
			  AND a.fch_mov <= @FfNon
			  AND CASE WHEN a.fch_mov + a.diastr - CASE WHEN a.diastr > 0 THEN 1 ELSE 0 END > @FfNon THEN @FfNon ELSE a.fch_mov END <= @FfNon
              AND a.codigo >= CASE WHEN @ncodigo = 0 THEN @ninicio ELSE @ncodigo END
              AND a.codigo <= CASE WHEN @ncodigo = 0 THEN @nfin ELSE @ncodigo END
			  --and (codigo = 9894424 or codigo = 9894945)
              --AND a.diastr > 0
        ORDER BY a.codigo ASC,
                 a.fch_mov ASC,
                 a.serial ASC) AS a
--  CROSS APPLY (SELECT dbo.NOM_FUN_AjustaFechaUltimoDiaMes(@FfNon, a.fch_mov, a.diastr) AS ff_mov) AS fch

  OUTER APPLY (SELECT SUM(ISNULL(deducciones.ausen,0)) AS ausen_deducciones
               FROM (SELECT CASE WHEN d.fchinicio <= a.fch_mov AND d.fchinicio + d.dias - 1 >= a.fch_mov AND d.fchinicio + d.dias - 1 <= a.ff_mov
                                 THEN DATEDIFF(dd,a.fch_mov,d.fchinicio + d.dias)
                                 ELSE CASE WHEN d.fchinicio >= a.fch_mov AND d.fchinicio + d.dias - 1 <= a.ff_mov
                                           THEN d.dias
                                           ELSE CASE WHEN d.fchinicio >= a.fch_mov AND d.fchinicio <= a.ff_mov AND d.fchinicio + d.dias - 1 >= a.ff_mov
                                                     THEN DATEDIFF(dd,d.fchinicio, a.ff_mov) + 1
                                                     ELSE CASE WHEN d.fchinicio <= a.fch_mov AND d.fchinicio + d.dias - 1 >= a.ff_mov
                                                               THEN a.diastr
                                                               ELSE 0
                                                          END 
                                                END 
                                      END  
                            END AS 'ausen'
                     FROM dbo.deducciones AS d
                     WHERE a.diastr > 0 AND 
						   d.empresa = a.empresa 
				           AND d.codigo = a.codigo
                           AND d.num_conc = 108 
                           AND ((d.fchinicio <= a.fch_mov AND d.fchinicio + d.dias - 1 >= a.fch_mov AND d.fchinicio + d.dias - 1 <= a.ff_mov)
                               OR (d.fchinicio >= a.fch_mov AND d.fchinicio + d.dias - 1 <= a.ff_mov)
                               OR (d.fchinicio >= a.fch_mov AND d.fchinicio <= a.ff_mov AND d.fchinicio + d.dias - 1 >= a.ff_mov)
                               OR (d.fchinicio <= a.fch_mov AND d.fchinicio + d.dias - 1 >= a.ff_mov)) 
					) AS deducciones
			  ) AS ausentismo

--SELECT '2', * FROM dbo.AvisosImssTemporalCalculo AS a where empresa = 2 and codigo = 1004

  IF @bimestre =  1
     BEGIN
	   /*
       DECLARE @FiPar DATETIME
       DECLARE @FfPar DATETIME
       DECLARE @ndias_par INT

       SET @FiPar = CONVERT(DATETIME, RIGHT('0000' + LTRIM(RTRIM(STR(@nayo))),4) + RIGHT('00' + LTRIM(RTRIM(STR(@nmes_par))),2) + '01')
       SET @FfPar = (SELECT fechaFin FROM [dbo].[ObtieneRangoFecha](@FiPar, 7))
	   SET @ndias_par = 0
	   */
	   /*
       UPDATE a
       SET a.ausen = 0
       FROM dbo.AvisosImssTemporalCalculo AS a
       WHERE a.proceso = @proceso
             AND a.fechaProceso = @fechaProceso
             AND a.horaProceso = @horaProceso
             AND a.empresa = @nempresa 
             AND a.fch_mov >= @FiPar --YEAR(a.fch_mov) = @nayo AND 
             AND a.fch_mov <= @FfPar --MONTH(a.fch_mov) = @nmes_par AND 
             AND a.codigo >= CASE WHEN @ncodigo = 0 THEN @ninicio ELSE @ncodigo END 
             AND a.codigo <= CASE WHEN @ncodigo = 0 THEN @nfin ELSE @ncodigo END
       */

       UPDATE a
       --SET @ndias_par = CASE WHEN @CodigoAnterior <> a.codigo THEN 0 ELSE @ndias_par END,
       SET @ndias_par = CASE WHEN a.serial = 1 THEN 0 ELSE @ndias_par END,
           @ndias_par = @ndias_par + ISNULL(ausentismo.ausen,0),
           a.ausen = a.ausen
		             + CASE WHEN @ndias_par < @ndias_tope 
                          THEN ISNULL(ausentismo.ausen,0)
                          ELSE CASE WHEN ISNULL(ausentismo.ausen,0) - (@ndias_par - @ndias_tope) < 0 
                                    THEN 0 
                                    ELSE ISNULL(ausentismo.ausen,0) - (@ndias_par - @ndias_tope) 
                               END 
                     END
           --, @CodigoAnterior = a.codigo

--SELECT *
       FROM (SELECT TOP 2147483647
                    a.empresa,
                    a.codigo,
			        a.fch_mov,
					ROW_NUMBER() OVER (PARTITION BY a.codigo, CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END ORDER BY a.codigo, a.fch_mov, a.serial) AS serial, 
			        a.diastr,
			        a.ausen
             FROM dbo.AvisosImssTemporalCalculo AS a
			      INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
             WHERE a.proceso = @proceso
                   AND a.fechaProceso = @fechaProceso
                   AND a.horaProceso = @horaProceso
                   --AND a.empresa = @nempresa AND
                   AND YEAR(a.fch_mov) = @nayo AND 
				   MONTH(dbo.NOM_FUN_AjustaFechaPrimerDiaMes(@FiPar, a.fch_mov, a.diastr)) = @nmes_par AND 
                   a.codigo >= CASE WHEN @ncodigo = 0 THEN @ninicio ELSE @ncodigo END AND
                   a.codigo <= CASE WHEN @ncodigo = 0 THEN @nfin ELSE @ncodigo END AND
                   a.diastr > 0
             ORDER BY a.codigo ASC,
                      a.fch_mov ASC,
                      a.serial ASC) AS a
       CROSS APPLY (SELECT dbo.NOM_FUN_AjustaFechaPrimerDiaMes(@FiPar, a.fch_mov, a.diastr) AS fi_mov,
	                       dbo.NOM_FUN_AjustaFechaUltimoDiaMes(@FfPar, a.fch_mov, a.diastr) AS ff_mov) AS fch
       OUTER APPLY (SELECT SUM(ISNULL(ausentismo.ausen,0)) AS ausen
                    FROM (SELECT CASE WHEN d.fchinicio <= fch.fi_mov AND d.fchinicio + d.dias - 1 >= fch.fi_mov AND d.fchinicio + d.dias - 1 <= fch.ff_mov
                                      THEN DATEDIFF(dd, fch.fi_mov, d.fchinicio + d.dias)
                                      ELSE CASE WHEN d.fchinicio >= fch.fi_mov AND d.fchinicio + d.dias - 1 <= fch.ff_mov
                                                THEN d.dias
                                                ELSE CASE WHEN d.fchinicio >= fch.fi_mov AND d.fchinicio <= fch.ff_mov AND d.fchinicio + d.dias - 1 >= fch.ff_mov
                                                          THEN DATEDIFF(dd,d.fchinicio, fch.ff_mov) + 1
                                                          ELSE CASE WHEN d.fchinicio <= fch.fi_mov AND d.fchinicio + d.dias - 1 >= fch.ff_mov
                                                                    THEN DATEDIFF(dd, fch.fi_mov, fch.ff_mov) 
                                                                    ELSE 0
                                                               END 
                                                     END 
                                           END  
                                 END AS 'ausen'
                          FROM dbo.deducciones AS d
                          WHERE d.empresa = a.empresa 
				                AND d.codigo = a.codigo
                                AND d.num_conc = 108 
                                AND ((d.fchinicio <= fch.fi_mov AND d.fchinicio + d.dias - 1 >= fch.fi_mov AND d.fchinicio + d.dias - 1 <= fch.ff_mov)
                                     OR (d.fchinicio >= fch.fi_mov AND d.fchinicio + d.dias - 1 <= fch.ff_mov)
                                     OR (d.fchinicio >= fch.fi_mov AND d.fchinicio <= fch.ff_mov AND d.fchinicio + d.dias - 1 >= fch.ff_mov)
                                     OR (d.fchinicio <= fch.fi_mov AND d.fchinicio + d.dias - 1 >= fch.ff_mov)) ) AS ausentismo ) AS ausentismo

	 END
GO

if object_id('dbo.asp_bim_ds') IS NOT NULL
   drop procedure dbo.asp_bim_ds
go


create procedure dbo.asp_bim_ds
@nempresa numeric(5,0),
@nayo int,
@nmes_non int,
@nmes_par int,
@ncodigo numeric(8,0),
@dfch_fin_mes datetime



/*
declare @dfch_fin_mes datetime
declare @nserial int
declare @ncodigo numeric(8,0)
declare @nfolio int
declare @nayo int
declare @nmes_non int
declare @nmes_par int
declare @nempresa numeric(5,0)
declare @ninicio numeric(8,0)
declare @nfin numeric(8,0)

set @dfch_fin_mes = '20061231'
set @nfolio = 0

set @nayo = 2006
set @nmes_non = 11
set @nmes_par = 12
set @nempresa = 6
set @ncodigo = 0
*/


as


declare @nserial int
declare @nfolio int
declare @ninicio numeric(8,0)
declare @nfin numeric(8,0)

set @nserial = 0
set @nfolio  = 0
set @ninicio = 0
set @nfin    = 0




if @ncodigo = 0
   begin
     set @ninicio = 1
     set @nfin = 99999999
   end
else
   begin
     set @ninicio = @ncodigo
     set @nfin = @ncodigo
   end  


select empresa, ayo_operacion, mes_operacion, codigo, serial, @nserial as 'serial_bim', fch_mov, mov, diastr, @dfch_fin_mes as 'fecha1', @dfch_fin_mes as 'fecha2'
into #tmp_mov
from dbo.avisos_imss
where empresa = @nempresa
      AND YEAR(fch_mov) = @nayo --ayo_operacion = @nayo and 
      AND (MONTH(fch_mov) = @nmes_non OR MONTH(fch_mov) = @nmes_par) --(mes_operacion = @nmes_non or mes_operacion = @nmes_par) and
      AND codigo between @ninicio and @nfin
order by codigo, ayo_operacion, mes_operacion, serial

create index [#tmp_mov] on [dbo].[#tmp_mov](codigo, ayo_operacion, mes_operacion, serial) ON [PRIMARY]


delete #tmp_mov where mov = 'IM' and mes_operacion = @nmes_par

update #tmp_mov 
set 
diastr = 0, 
@nfolio = case when @ncodigo <> codigo then 0 else @nfolio end, 
@nfolio = @nfolio + 1,
serial_bim = @nfolio,
@ncodigo = codigo

update a 
set a.diastr = case when a.mov = 'B' 
                    then 0 
                    else case when a.fch_mov = d.fch_mov and d.mov <> 'B'
                              then 0 
                              else case when d.fch_mov is null 
                                        then datediff(dd,a.fch_mov,@dfch_fin_mes) + 1 
                                        else datediff(dd,a.fch_mov,d.fch_mov) + case when d.mov = 'B' 
                                                                                     then 1 
                                                                                     else 0 
                                                                                end
                                   end 
                         end 
               end ,
fecha1 = a.fch_mov, fecha2 = d.fch_mov
from #tmp_mov as a
left join #tmp_mov as d on a.empresa = d.empresa and a.codigo = d.codigo and a.serial_bim + 1 = d.serial_bim

--select *
--from #tmp_mov as a
--left join #tmp_mov as d on a.empresa = d.empresa and a.codigo = d.codigo and a.serial_bim + 1 = d.serial_bim
--where a.codigo = 146



update dbo.avisos_imss 
set diastr = 0 
where empresa = @nempresa
      AND YEAR(fch_mov) = @nayo --ayo_operacion = @nayo and 
      AND (MONTH(fch_mov) = @nmes_non OR MONTH(fch_mov) = @nmes_par)  --(mes_operacion = @nmes_non or mes_operacion = @nmes_par) and
      AND codigo between @ninicio and @nfin

--select * from #tmp_mov where codigo = 146 order by ayo_operacion, mes_operacion, serial

update a 
set a.diastr = d.diastr
from dbo.avisos_imss as a --, #tmp_mov as d
--inner join #tmp_mov as d on d.empresa = a.empresa and d.codigo = a.codigo and d.ayo_operacion = a.ayo_operacion and d.mes_operacion = a.mes_operacion and d.serial = a.serial
inner join #tmp_mov as d on d.empresa = a.empresa and d.codigo = a.codigo and d.ayo_operacion = YEAR(a.fch_mov) and d.mes_operacion = MONTH(a.fch_mov) and d.serial = a.serial
where a.empresa = @nempresa
      AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo and
      AND (MONTH(a.fch_mov) = @nmes_non OR MONTH(a.fch_mov) = @nmes_par) --(a.mes_operacion = @nmes_non or a.mes_operacion = @nmes_par) 
      -- and a.codigo = d.codigo and
      --a.serial = d.serial and 
      --a.ayo_operacion = d.ayo_operacion and
      --a.mes_operacion = d.mes_operacion

--select * 
--from avisos_imss as a --, #tmp_mov as d
--inner join #tmp_mov as d on d.empresa = a.empresa and d.codigo = a.codigo and d.ayo_operacion = a.ayo_operacion and d.mes_operacion = d.mes_operacion and d.serial = a.serial
--where a.empresa = @nempresa and
--      a.ayo_operacion = @nayo and
--      (a.mes_operacion = @nmes_non or a.mes_operacion = @nmes_par) 



--select * from avisos_imss 
--where empresa = @nempresa and ayo_operacion = @nayo and mes_operacion in (@nmes_non, @nmes_par)
--order by codigo, ayo_operacion, mes_operacion, serial


drop index #tmp_mov.#tmp_mov
drop table #tmp_mov

GO

IF OBJECT_ID('dbo.asp_bim_ds_UMA') IS NOT NULL
   DROP PROCEDURE dbo.asp_bim_ds_UMA
GO
CREATE PROCEDURE dbo.asp_bim_ds_UMA
@nempresa INT,
@nayo INT,
@nmes_non INT,
@nmes_par INT,
@ncodigo INT,
@dfch_fin_mes DATETIME
, @proceso VARCHAR(250) 
, @fechaProceso DATETIME 
, @horaProceso VARCHAR(8) 

AS

  SET NOCOUNT ON

  DECLARE @nfolio INT
  DECLARE @ninicio INT
  DECLARE @nfin INT
  DECLARE @fechaInicio DATETIME
  DECLARE @fechaTermino DATETIME

  SET @fechaInicio = CONVERT(DATETIME, RIGHT(10000 + @nayo,4) + RIGHT(100 + @nmes_non,2) + '01')
  SET @fechaTermino = CONVERT(DATETIME, RIGHT(10000 + @nayo,4) + RIGHT(100 + @nmes_par,2) + '01')
  SET @fechaTermino = (SELECT fechaFin FROM [dbo].[ObtieneRangoFecha](@fechaTermino, 7))

  SET @nfolio  = 0
  SET @ninicio = 0
  SET @nfin    = 0

  IF @ncodigo = 0
     BEGIN
       SET @ninicio = 1
       SET @nfin = 99999999
     END
  ELSE
     BEGIN
       SET @ninicio = @ncodigo
       SET @nfin = @ncodigo
     END  

  DELETE aItc 
  FROM dbo.AvisosImssTemporalCalculo AS aItc 
       INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = aItc.empresa
  WHERE aItc.proceso = @proceso
        AND aItc.fechaProceso = @fechaProceso
        AND aItc.horaProceso = @horaProceso
        AND aItc.mov = 'IM' 
		AND aItc.mes_operacion = @nmes_par

  UPDATE a
  SET a.diastr = CASE WHEN a.mov = 'B' 
                      THEN 0 
                      ELSE CASE WHEN a.fch_mov = ISNULL(SiguienteAviso.fch_mov, @dfch_fin_mes) AND (ISNULL(SiguienteAviso.mov,'') = 'IM' OR ISNULL(SiguienteAviso.mov,'') = 'A' OR ISNULL(SiguienteAviso.mov,'') = 'RI' OR ISNULL(SiguienteAviso.mov,'') = 'MS')
                                THEN 0 
                                ELSE DATEDIFF(dd,a.fch_mov, ISNULL(SiguienteAviso.fch_mov, @dfch_fin_mes)) + CASE WHEN ISNULL(SiguienteAviso.mov,'') = 'B' OR ISNULL(SiguienteAviso.mov,'') = ''
                                                                                                                  THEN 1 
                                                                                                                  ELSE 0 
                                                                                                             END
                           END 
                 END
                  
  FROM dbo.AvisosImssTemporalCalculo AS a
       INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
     OUTER APPLY (SELECT TOP 1
                         m.mov,
                         m.fch_mov
                  FROM dbo.AvisosImssTemporalCalculo AS m
                  WHERE m.proceso = a.proceso
                        AND m.fechaProceso = a.fechaProceso
                        AND m.horaProceso = a.horaProceso
                        AND m.empresa = a.empresa
                        AND m.codigo = a.codigo
                        --AND LTRIM(STR(YEAR(m.fch_mov)))
                        --    + RIGHT('0' + LTRIM(STR(MONTH(m.fch_mov))),2)
	                    --    + RIGHT('0' + LTRIM(STR(DAY(m.fch_mov))),2)
	                    --    + RIGHT('000' + LTRIM(STR(m.serial)),3)	 > LTRIM(STR(YEAR(a.fch_mov)))
                        --                                               + RIGHT('0' + LTRIM(STR(MONTH(a.fch_mov))),2)
	                    --                                               + RIGHT('0' + LTRIM(STR(DAY(a.fch_mov))),2)
	                    --                                               + RIGHT('000' + LTRIM(STR(a.serial)),3)
                        AND m.fch_mov >= a.fch_mov
                        AND m.serial > a.serial
                  ORDER BY m.fch_mov ASC,
                           m.serial ASC) AS SiguienteAviso
  WHERE a.proceso = @proceso
        AND a.fechaProceso = @fechaProceso
        AND a.horaProceso = @horaProceso
        --AND a.empresa = @nempresa 
        --AND YEAR(a.fch_mov) = @nayo
        --AND (MONTH(a.fch_mov) = @nmes_non OR MONTH(a.fch_mov) = @nmes_par) 
		AND a.fch_mov >= @fechaInicio
		AND a.fch_mov <= @fechaTermino
        --AND (a.mov + RIGHT(100 + MONTH(a.fch_mov),2) <> 'IM' + RIGHT(100 + @nmes_par,2))
        AND a.codigo BETWEEN @ninicio AND @nfin        
GO

if object_id('dbo.asp_bim_inc') IS NOT NULL
   drop procedure dbo.asp_bim_inc
go


create procedure dbo.asp_bim_inc
@nempresa numeric(5,0),
@nayo int,
@nmes_non int,
@nmes_par int,
@ncodigo numeric(8,0)

as

SET NOCOUNT ON

declare @ninicio numeric(8,0)
declare @nfin numeric(8,0)

if @ncodigo = 0
   begin
       set @ninicio = 1
       set @nfin = 99999999
   end
else
    begin
        set @ninicio = @ncodigo
        set @nfin = @ncodigo
    end

update a 
set a.incap = 0,
    a.lic = 0
from dbo.avisos_imss as a
where a.empresa = @nempresa
      AND a.ayo_operacion  = @nayo and 
      (a.mes_operacion = @nmes_non or a.mes_operacion = @nmes_par) and 
      a.codigo between @ninicio and @nfin


select a.empresa, a.codigo, a.ayo_operacion, a.mes_operacion, a.serial,
CASE WHEN d.num_conc = 109 AND d.inicsubs = '4'
     THEN case when d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
               then datediff(dd,a.fch_mov,d.fchinicio + d.dias)  
               else case when d.fchinicio >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                         then d.dias
                         else case when d.fchinicio >= a.fch_mov and d.fchinicio <= a.fch_mov + a.diastr - 1 and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                   then datediff(dd,d.fchinicio,a.fch_mov + a.diastr)
                                   else case when d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                             then a.diastr
                                             else 0
                                        end 
                              end 
                    end 
	      END
     ELSE 0
end as 'lic',
case when d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
     then datediff(dd,a.fch_mov,d.fchinicio + d.dias)  
     else case when d.fchinicio >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
               then d.dias
               else case when d.fchinicio >= a.fch_mov and d.fchinicio <= a.fch_mov + a.diastr - 1 and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                         then datediff(dd,d.fchinicio,a.fch_mov + a.diastr)
                         else case when d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                   then a.diastr
                                   else 0
                              end 
                    end 
          end 
end as 'incap'
--d.fchinicio as '1', a.fch_mov as '2', d.fchinicio + d.dias - 1 as '3', a.fch_mov + a.diastr - 1 as '4'
into #tmp_incap
FROM    dbo.avisos_imss AS a
        LEFT JOIN dbo.deducciones AS d ON a.empresa = d.empresa
                                 AND a.codigo = d.codigo
WHERE   a.empresa = @nempresa
        AND a.diastr > 0
        AND YEAR(a.fch_mov) = @nayo
        AND (MONTH(a.fch_mov) = @nmes_non
             OR MONTH(a.fch_mov) = @nmes_par)
        AND (d.num_conc = 109 
             OR d.num_conc = 110 
             OR d.num_conc = 111
            ) 
        AND ( ( d.fchinicio <= a.fch_mov
                AND d.fchtermino >= a.fch_mov
                AND d.fchinicio <= a.fch_mov
                + a.diastr - 1
              )
              OR ( d.fchinicio >= a.fch_mov
                   AND d.fchtermino <= a.fch_mov
                   + a.diastr - 1
                 )
              OR ( d.fchinicio >= a.fch_mov
                   AND d.fchinicio <= a.fch_mov
                   + a.diastr - 1
                   AND d.fchtermino >= a.fch_mov
                   + a.diastr - 1
                 )
              OR ( d.fchinicio <= a.fch_mov
                   AND d.fchtermino >= a.fch_mov
                   + a.diastr - 1
                 )
            )   

update a set a.incap = isnull((select sum(b.incap) from #tmp_incap as b where a.empresa = b.empresa and a.codigo = b.codigo and a.ayo_operacion = b.ayo_operacion and a.mes_operacion = b.mes_operacion and a.serial = b.serial),0),
             a.lic = isnull((select sum(b.lic) from #tmp_incap as b where a.empresa = b.empresa and a.codigo = b.codigo and a.ayo_operacion = b.ayo_operacion and a.mes_operacion = b.mes_operacion and a.serial = b.serial),0)
from dbo.avisos_imss as a
where a.empresa = @nempresa and 
      YEAR(a.fch_mov) = @nayo and 
      (MONTH(a.fch_mov) = @nmes_non or MONTH(a.fch_mov) = @nmes_par) and 
      a.diastr > 0 and 
      a.codigo between @ninicio and @nfin

drop table #tmp_incap
go

IF OBJECT_ID('dbo.asp_bim_inc_UMA') IS NOT NULL
   DROP PROCEDURE dbo.asp_bim_inc_UMA
GO
CREATE PROCEDURE dbo.asp_bim_inc_UMA
@nempresa NUMERIC(5,0),
@nayo INT,
@nmes_non INT,
@nmes_par INT,
@ncodigo NUMERIC(8,0)
, @proceso VARCHAR(250)
, @fechaProceso DATETIME
, @horaProceso VARCHAR(8)

AS

DECLARE @ninicio NUMERIC(8,0)
DECLARE @nfin NUMERIC(8,0)
DECLARE @fechaInicio DATETIME
DECLARE @fechaTermino DATETIME
DECLARE @EsRpuEspecial INT

SET @EsRpuEspecial = dbo.EsRpuEspecial(@nempresa)
SET @fechaInicio = CONVERT(DATETIME, RIGHT(10000 + @nayo,4) + RIGHT(100 + @nmes_non,2) + '01')

SELECT @fechaTermino = fechaFin
FROM [dbo].[ObtieneRangoFecha](@fechaInicio, 7)

IF @nmes_par > @nmes_non
   SELECT @fechaTermino = fechaFin
   FROM [dbo].[ObtieneRangoFecha](@fechaTermino + 1, 7)
   
IF @ncodigo = 0
   BEGIN
       SET @ninicio = 1
       SET @nfin = 99999999
   END
ELSE
    BEGIN
        SET @ninicio = @ncodigo
        SET @nfin = @ncodigo
    END

UPDATE a 
SET a.incap = 0,
    a.lic = 0
FROM dbo.AvisosImssTemporalCalculo AS a
     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
      --AND a.empresa = @nempresa
      AND a.fch_mov >= @fechaInicio --AND YEAR(a.fch_mov) = @nayo
      AND a.fch_mov <= @fechaTermino --AND (MONTH(a.fch_mov) = @nmes_non OR MONTH(a.fch_mov) = @nmes_par)
      AND a.codigo BETWEEN @ninicio AND @nfin

SELECT a.empresa,
       a.codigo,
       a.ayo_operacion,
       a.mes_operacion,
       a.serial,
       CASE WHEN d.num_conc = 109 AND d.inicsubs = '4'
            THEN CASE WHEN d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                      THEN DATEDIFF(dd,a.fch_mov,d.fchinicio + d.dias)  
                      ELSE CASE WHEN d.fchinicio >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                                THEN d.dias
                                ELSE CASE WHEN d.fchinicio >= a.fch_mov and d.fchinicio <= a.fch_mov + a.diastr - 1 and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                          THEN DATEDIFF(dd,d.fchinicio,a.fch_mov + a.diastr)
                                          ELSE CASE WHEN d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                                    THEN a.diastr
                                                    ELSE 0
                                               END 
                                     END
                           END 
                   END
            ELSE 0
       END AS 'lic',
       CASE WHEN d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
            THEN DATEDIFF(dd,a.fch_mov,d.fchinicio + d.dias)  
            ELSE CASE WHEN d.fchinicio >= a.fch_mov and d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                      THEN d.dias
                      ELSE CASE WHEN d.fchinicio >= a.fch_mov and d.fchinicio <= a.fch_mov + a.diastr - 1 and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                THEN DATEDIFF(dd,d.fchinicio,a.fch_mov + a.diastr)
                                ELSE CASE WHEN d.fchinicio <= a.fch_mov and d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1 
                                          THEN a.diastr
                                          ELSE 0
                                     END 
                           END
                 END 
       END AS 'incap',
       d.fchinicio AS '1',
       a.fch_mov AS '2', 
       d.fchinicio + d.dias - 1 AS '3',
       a.fch_mov + a.diastr - 1 AS '4',
	   a.rpu
INTO #tmp_incap
FROM    dbo.AvisosImssTemporalCalculo AS a
        INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
        LEFT JOIN dbo.deducciones AS d ON a.empresa = d.empresa
                                 AND a.codigo = d.codigo
WHERE   a.proceso = @proceso
        AND a.fechaProceso = @fechaProceso
        AND a.horaProceso = @horaProceso
        --AND  a.empresa = @nempresa
        AND a.diastr > 0
        --AND YEAR(a.fch_mov) = @nayo
        --AND (MONTH(a.fch_mov) = @nmes_non
        --     OR MONTH(a.fch_mov) = @nmes_par)
        AND a.fch_mov >= @fechaInicio
        AND a.fch_mov <= @fechaTermino
        AND (d.num_conc = 109 
             OR d.num_conc = 110 
             OR d.num_conc = 111
            ) 
        AND ( ( d.fchinicio <= a.fch_mov
                AND d.fchtermino >= a.fch_mov
                AND d.fchinicio <= a.fch_mov
                + a.diastr - 1
              )
              OR ( d.fchinicio >= a.fch_mov
                   AND d.fchtermino <= a.fch_mov
                   + a.diastr - 1
                 )
              OR ( d.fchinicio >= a.fch_mov
                   AND d.fchinicio <= a.fch_mov
                   + a.diastr - 1
                   AND d.fchtermino >= a.fch_mov
                   + a.diastr - 1
                 )
              OR ( d.fchinicio <= a.fch_mov
                   AND d.fchtermino >= a.fch_mov
                   + a.diastr - 1
                 )
            )   

UPDATE a SET a.incap = ISNULL((SELECT SUM(b.incap) 
                               FROM #tmp_incap AS b 
							   WHERE b.empresa = a.empresa 
							         AND b.codigo = a.codigo 
									 AND b.ayo_operacion = a.ayo_operacion 
									 AND b.mes_operacion = a.mes_operacion 
									 AND b.serial = a.serial
									 AND CASE WHEN @EsRpuEspecial = 1 THEN b.rpu ELSE '' END = CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END),0),
             a.lic = ISNULL((SELECT SUM(b.lic) 
			                 FROM #tmp_incap AS b 
							 WHERE b.empresa = a.empresa 
							       AND b.codigo = a.codigo 
								   AND b.ayo_operacion = a.ayo_operacion 
								   AND b.mes_operacion = a.mes_operacion 
								   AND b.serial = a.serial
								   AND CASE WHEN @EsRpuEspecial = 1 THEN b.rpu ELSE '' END = CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END),0)
FROM dbo.AvisosImssTemporalCalculo AS a
     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
      --AND a.empresa = @nempresa
      AND a.fch_mov >= @fechaInicio
      AND a.fch_mov <= @fechaTermino
      --AND YEAR(a.fch_mov) = @nayo
      --AND (MONTH(a.fch_mov) = @nmes_non OR MONTH(a.fch_mov) = @nmes_par)
      AND a.diastr > 0
      AND a.codigo BETWEEN @ninicio AND @nfin

DROP TABLE #tmp_incap
GO

IF OBJECT_ID('dbo.asp_calcula_prt') IS NOT NULL
   DROP PROCEDURE dbo.asp_calcula_prt
GO
CREATE PROCEDURE [dbo].[asp_calcula_prt]
    @nempresa NUMERIC(5, 0) ,
    @nayo INT
AS 
    DECLARE @creg_pat CHAR(11)
    DECLARE @cnom_pat NVARCHAR(70)
    DECLARE @cdom_pat NVARCHAR(100)
    DECLARE @cpob_pat NVARCHAR(60)
    DECLARE @ccod_pat VARCHAR(5)
    DECLARE @ctelefono VARCHAR(30)
    DECLARE @cact_pat VARCHAR(100)
    DECLARE @cclase VARCHAR(5)
    DECLARE @nfraccion INT
    DECLARE @nprima_anterior NUMERIC(9, 7)
    DECLARE @crep_pat VARCHAR(50)
    DECLARE @crfc_pat CHAR(13)

    DECLARE @nsFormula NUMERIC(18,8) 
    DECLARE @nvFormula NUMERIC(18,8)
    DECLARE @niFormula NUMERIC(18,8)
    DECLARE @ndFormula NUMERIC(18,8)
    DECLARE @nfFormula NUMERIC(18,8)
    DECLARE @nnFormula NUMERIC(18,8)
    DECLARE @nmFormula NUMERIC(18,8)
    DECLARE @sCedula VARCHAR(25)
    DECLARE @iCedula VARCHAR(25)
    DECLARE @dCedula VARCHAR(25)
    DECLARE @nCedula VARCHAR(25)
    DECLARE @mCedula VARCHAR(25)

    DECLARE @ns NUMERIC(7, 0)
    DECLARE @ni NUMERIC(12, 2)
    DECLARE @nd INT
    DECLARE @nn NUMERIC(6, 1)
    DECLARE @nn_paso NUMERIC(6, 2)
    DECLARE @nv INT
    DECLARE @nf NUMERIC(5, 2)
    DECLARE @nm NUMERIC(9, 5)
    DECLARE @nopera_1 NUMERIC(18, 8)
    DECLARE @nopera_2 NUMERIC(18, 8)
    DECLARE @nopera_3 NUMERIC(18, 8)
    DECLARE @nopera_4 NUMERIC(18, 8)
    DECLARE @nopera_5 NUMERIC(18, 8)
    DECLARE @nprima_nva NUMERIC(9, 7)
    DECLARE @csistema VARCHAR(5)
    DECLARE @ndiferencia NUMERIC(12, 7)
    DECLARE @ndias NUMERIC(7, 0)
    DECLARE @cnn CHAR(20)
    DECLARE @nn1 NUMERIC(6, 1)
    DECLARE @ccasos CHAR(5)

    DELETE  resumen_rt
    WHERE   empresa = @nempresa
            AND ayo_operacion = @nayo

    SELECT TOP 1
            @nprima_anterior = prima_rt
    FROM    primas_rt
    WHERE   empresa = @nempresa
            AND @nayo BETWEEN YEAR(fecha_inicial)
                      AND     YEAR(fecha_final)
    ORDER BY fecha_inicial DESC

    SET @nprima_anterior = @nprima_anterior / 100

    SELECT  @creg_pat = registro_patronal ,
            @cnom_pat = nombre_empresa ,
            @cdom_pat = direccion_empresa ,
            @cpob_pat = poblacion_empresa ,
            @ccod_pat = codigo_postal_empresa ,
            @ctelefono = telefono_empresa ,
            @cact_pat = actividad_empresa ,
            @cclase = CASE WHEN clase = 1 THEN 'I'
                           WHEN clase = 2 THEN 'II'
                           WHEN clase = 3 THEN 'III'
                           WHEN clase = 4 THEN 'IV'
                           WHEN clase = 5 THEN 'V'
                           ELSE ' '
                      END ,
            @nfraccion = fraccion_rt ,
            @crep_pat = representante_legal ,
            @crfc_pat = rfc_empresa
    FROM    empresas
    WHERE   empresa = @nempresa

    SET @nsFormula = ISNULL(( SELECT   SUM(i.dias)
                       FROM     incapacidades_rt AS i
                                INNER JOIN casos_rt AS c ON c.empresa = i.empresa
                                                            AND c.codigo = i.codigo
                                                            AND c.ayo_operacion = i.ayo_operacion
                                                            AND c.caso = i.caso
                       WHERE    i.empresa = @nempresa
                                AND i.ayo_operacion = @nayo
                                AND i.caso > 0
                                AND c.st1_trayecto <> 'S'
                     ), 0)

-- Suma los dias de los casos importados
    SET @nsFormula = @nsFormula
        + ISNULL(( SELECT   SUM(i.dias)
                   FROM     incapacidades_rt_importado AS i
                            INNER JOIN casos_rt_importado AS c ON c.empresa = i.empresa
                                                              AND c.codigo = i.codigo
                                                              AND c.ayo_operacion = i.ayo_operacion
                                                              AND c.caso = i.caso
                   WHERE    i.empresa = @nempresa
                            AND i.ayo_operacion = @nayo
                            AND i.caso > 0
                            AND c.st1_trayecto <> 'S'
                 ), 0)
                 
    SET @ns = @nsFormula
    SET @sCedula = RIGHT(1000000 + @ns,6)

    SET @niFormula = ISNULL(( SELECT   SUM(st3_valuacion)
                       FROM     casos_rt
                       WHERE    empresa = @nempresa
                                AND ayo_operacion = @nayo
                                AND caso > 0
                                AND st3_accidente IN ( 2, 3 )
                                AND st1_trayecto <> 'S'
                     ), 0)


-- Suma los porcentajes de valacion de los casos importados
    SET @niFormula = @niFormula + ISNULL(( SELECT SUM(st3_valuacion)
                             FROM   casos_rt_importado
                             WHERE  empresa = @nempresa
                                    AND ayo_operacion = @nayo
                                    AND caso > 0
                                    AND st3_accidente IN ( 2, 3 )
                                    AND st1_trayecto <> 'S'
                           ), 0)


    SET @niFormula = @niFormula / 100
    
    SET @ni = @niFormula
    SET @iCedula = RIGHT(10000 + @ni,7)
    

    SET @ndFormula = ISNULL(( SELECT   COUNT(st3_accidente)
                       FROM     casos_rt
                       WHERE    empresa = @nempresa
                                AND ayo_operacion = @nayo
                                AND caso > 0
                                AND st3_accidente = 4
                                AND st1_trayecto <> 'S'
                     ), 0)

-- Suma las defunciones de los casos importados
    SET @ndFormula = @ndFormula + ISNULL(( SELECT COUNT(st3_accidente)
                             FROM   casos_rt_importado
                             WHERE  empresa = @nempresa
                                    AND ayo_operacion = @nayo
                                    AND caso > 0
                                    AND st3_accidente = 4
                                    AND st1_trayecto <> 'S'
                           ), 0)
    SET @nd = @ndFormula
    SET @dCedula = RIGHT(100000 + @nd,5)

    SET @ndias = ISNULL(( SELECT    SUM(dias)
                          FROM      dias_rt
                          WHERE     empresa = @nempresa
                                    AND ayo_operacion = @nayo
                        ), 1)

-- Suma los dias cotizados importados
    SET @ndias = @ndias + ISNULL(( SELECT   SUM(dias)
                                   FROM     dias_rt_importado
                                   WHERE    empresa = @nempresa
                                            AND ayo_operacion = @nayo
                                 ), 1)

--set @nn = round(@ndias / 365,2)
    SET @nn_paso = @ndias / 365

    DECLARE @ctrab_pro CHAR(9)
    SET @ctrab_pro = CONVERT(CHAR(9), @nn_paso)

    SET @nnFormula = SUBSTRING(@ctrab_pro, 1,
                                               CHARINDEX('.', @ctrab_pro))
        + SUBSTRING(@ctrab_pro, CHARINDEX('.', @ctrab_pro) + 1, 1)

--print @ndias
--print @nn
--print @ctrab_pro

    SET @nnFormula = CASE WHEN @nnFormula = 0
                        OR @nnFormula IS NULL THEN 1
                   ELSE @nnFormula
              END
    SET @nn = CONVERT(NUMERIC(7,1), @nnFormula)

    SET @cnn = CONVERT(CHAR(20), @nn)

    SET @nn1 = CONVERT(NUMERIC(6, 1), SUBSTRING(@cnn, 1,
                                                CHARINDEX('.', @cnn) - 1)
        + '.' + SUBSTRING(@cnn, CHARINDEX('.', @cnn) + 1, 1))
    SET @nCedula = RIGHT(100000.0 + @nn1,7)


    SET @nvFormula = 28.00000000
    SET @nv = 28

    SET @csistema = ISNULL(( SELECT sistema
                             FROM   styps_rt
                             WHERE  empresa = @nempresa
                                    AND ayo_operacion = @nayo
                           ), 'N')

    SET @nfFormula = CASE WHEN @csistema = 'S' THEN 2.2
                   ELSE 2.3
              END
    SET @nf = @nfFormula

    SET @nmFormula = 0.00500000
    SET @nm = 0.0050
    SET @mCedula = '0.0050'

    SET @nopera_1 = @nsFormula / 365.00000000

--print @ns
--print @nopera_1

    SET @nopera_2 = @niFormula + @ndformula

    SET @nopera_3 = @nfFormula / @nnFormula

    --SET @nopera_4 = ( ( @ns / 365 ) + @nv * ( @ni + @nd ) ) * ( @nf / @nn ) + @nm
    SET @nopera_4 = ( ( @nopera_1 ) + @nvFormula * ( @nopera_2 ) ) 
    SET @nopera_4 = @nopera_4 * ( @nopera_3 ) 
    SET @nopera_4 = @nopera_4 + @nmFormula

    SET @nprima_nva = @nopera_4

    SET @nopera_5 = ROUND(@nopera_4 * 100,5)

    SET @ndiferencia = ABS(@nprima_nva - @nprima_anterior)

    IF @ndiferencia > 0.01 
        SET @ndiferencia = 0.01

    IF @nprima_nva >= @nprima_anterior 
        SET @nprima_nva = @nprima_anterior + @ndiferencia

    IF @nprima_nva <= @nprima_anterior 
        SET @nprima_nva = @nprima_anterior - @ndiferencia

    IF @nprima_nva < @nm 
        SET @nprima_nva = @nm

    IF @nprima_nva > .15 
        SET @nprima_nva = .15

    SET @nprima_anterior = @nprima_anterior * 100
    SET @nprima_nva = @nprima_nva * 100

    SET @ccasos = CASE WHEN ISNULL(( SELECT SUM(caso)
                                     FROM   casos_rt
                                     WHERE  empresa = @nempresa
                                            AND ayo_operacion = @nayo
                                   ), 0)
                            + ISNULL(( SELECT   SUM(caso)
                                       FROM     casos_rt_importado
                                       WHERE    empresa = @nempresa
                                                AND ayo_operacion = @nayo
                                     ), 0) > 0 THEN 'SI'
                       ELSE 'NO'
                  END

    INSERT  resumen_rt
            ( empresa ,
              ayo_operacion ,
              reg_pat ,
              nom_pat ,
              dom_pat ,
              pob_pat ,
              cod_pat ,
              telefono ,
              act_pat ,
              clase ,
              fraccion ,
              prima_anterior ,
              s ,
              i ,
              d ,
              n ,
              v ,
              f ,
              m ,
              opera_1 ,
              opera_2 ,
              opera_3 ,
              opera_4 ,
              opera_5 ,
              prima_nva ,
              sistema ,
              rep_pat ,
              casos ,
              rfc ,
              iCedula ,
              sCedula ,
              dCedula ,
              nCedula ,
              mCedula
            )
    VALUES  ( @nempresa ,
              @nayo ,
              @creg_pat ,
              @cnom_pat ,
              @cdom_pat ,
              @cpob_pat ,
              @ccod_pat ,
              @ctelefono ,
              @cact_pat ,
              @cclase ,
              @nfraccion ,
              @nprima_anterior ,
              @ns ,
              @ni ,
              @nd ,
              @nn1 ,
              @nv ,
              @nf ,
              @nm ,
              @nopera_1 ,
              @nopera_2 ,
              @nopera_3 ,
              @nopera_4 ,
              @nopera_5 ,
              @nprima_nva ,
              @csistema ,
              @crep_pat ,
              @ccasos ,
              @crfc_pat ,
              @iCedula ,
              @sCedula ,
              @dCedula ,
              @nCedula ,
              @mCedula
            )
GO

IF OBJECT_ID('dbo.asp_checa_kardex') IS NOT NULL
   DROP PROCEDURE dbo.asp_checa_kardex
GO
CREATE PROCEDURE dbo.asp_checa_kardex
@nempresa INT,
@nomina CHAR(3)

AS

  SET NOCOUNT ON
  
  SELECT TOP 1 codigo 
  FROM dbo.kardex
  WHERE empresa = @nempresa 
        AND nomina = @nomina
GO

IF OBJECT_ID('dbo.asp_checa_primas_imss') IS NOT NULL
   DROP PROCEDURE dbo.asp_checa_primas_imss
GO
CREATE PROCEDURE [dbo].[asp_checa_primas_imss] @dfecha DATETIME
AS 
    IF NOT EXISTS ( SELECT  periodo
                    FROM    primas_imss
                    WHERE   periodo = @dfecha ) 
        INSERT  INTO primas_imss
                SELECT  @dfecha ,
                        eymart25 ,
                        eympat25 ,
                        eymtra25 ,
                        eymart106I ,
                        eymart1062 ,
                        eympat1062 ,
                        eymtra1062 ,
                        eymart107 ,
                        eympat107 ,
                        eymtra107 ,
                        ivart147 ,
                        ivpat147 ,
                        ivtra147 ,
                        retiro ,
                        cvart168II ,
                        cvpat168II ,
                        cvtra168ii ,
                        ISNULL(infonavit,5) AS infonavit,
                        ISNULL(art211,1) AS art211,
                        seguroDesempleo
                FROM    primas_imss
                WHERE   periodo = '20080101'
GO

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'asp_codigo_nuevo_empleados' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[asp_codigo_nuevo_empleados]
    END
GO

create procedure [dbo].[asp_codigo_nuevo_empleados]
@nempresa numeric(5,0),
@ncodigo_act numeric(8,0),
@ncodigo_new numeric(8,0)

as

insert into empleados (empresa, codigo, mcamov, nombre, ap_paterno, ap_materno, afiliacion, digvera, curp, fchantigua, fchalta,
                                   sueldo, saldiaint, saldiaiv, art39, tiposal, jornada, varia_imss, varia_next, var_sigmes, turno, sig_bim,
                                   horadia, finikito, tipo_emp, cta_bco_no, planta, sindicato, manoobra, diastr, factorsd, inc, aus, rfcalfa,
                                   rfcnum, rfchomo, sexo, fchnac, lugnac, edonac, tipo_deposito, activo, password_empleado, fch_baja, borrado,
                                   ultmov, ultfchmov, nomina, Isr2006, Nivelacionisr, cotiza_imss, pension_iv_cv, cuotas_imss, pagar_nomina,
                                   mail, rpu, multiple, cuenta)
                        select empresa, @ncodigo_new,  mcamov, nombre, ap_paterno, ap_materno, afiliacion, digvera, curp, fchantigua, fchalta,
                                   sueldo, saldiaint, saldiaiv, art39, tiposal, jornada, varia_imss, varia_next, var_sigmes, turno, sig_bim,
                                   horadia, finikito, tipo_emp, cta_bco_no, planta, sindicato, manoobra, diastr, factorsd, inc, aus, rfcalfa,
                                   rfcnum, rfchomo, sexo, fchnac, lugnac, edonac, tipo_deposito, activo, password_empleado, fch_baja, borrado,
                                   ultmov, ultfchmov, nomina, Isr2006, Nivelacionisr, cotiza_imss, pension_iv_cv, cuotas_imss, pagar_nomina,
                                   mail, rpu, multiple, cuenta
                        from empleados
                        where empresa = @nempresa and codigo = @ncodigo_act






insert into casos_rt (empresa, codigo, caso, ayo_operacion, st1_accidente, st1_trayecto, st1_fecha, 
                               st2_accidente, st2_fecha, st3_accidente, st3_valuacion)
                select empresa, @ncodigo_new, caso, ayo_operacion, st1_accidente, st1_trayecto, st1_fecha, 
                          st2_accidente, st2_fecha, st3_accidente, st3_valuacion
                from casos_rt
                where empresa = @nempresa and codigo = @ncodigo_act


insert into infonavit (empresa, codigo      , tipo_cred, numcredito, descuento, amortizacion_cedula, amortizacion_retenido, amortizacion_sigmes, fecha, fch_otorga, fch_termino, ntd, info, porc_abono, seguro_vivienda, exportado, fechaSuspension)
                select empresa, @ncodigo_new, tipo_cred, numcredito, descuento, amortizacion_cedula, amortizacion_retenido, amortizacion_sigmes, fecha, fch_otorga, fch_termino, ntd, info, porc_abono, seguro_vivienda, exportado, fechaSuspension
                from infonavit
                where empresa = @nempresa and codigo = @ncodigo_act
                



insert into kardex (codigo, empresa, nomina, centro, num_conc, clase, folio, renglon, fch_inicio, fch_cierre, fch_pago,
                             dias, inc, aus, diastr, dias_imss, tpago_desc, concepto, variaimss, variable, imss, ispt, ptu, 
                             despensa, mca_agui, fdoahorro, calculo, impor_base, saldiaint, tabulador, unidades, horas, tipo_mov,
                             secuencia, importe, igravable, iexento, credito, descuento, saldo, referencia, siempre, justificar,
                             septimo, prevsocial, varia1, varia2, varia3, varia4, variable1, variable2, variable3, variable4,
                             masivo, formula, ispt_ng, imss_ni, marca, serial, informativo, detalle_prn)
                select @ncodigo_new, empresa, nomina, centro, num_conc, clase, folio, renglon, fch_inicio, fch_cierre, fch_pago,
                           dias, inc, aus, diastr, dias_imss, tpago_desc, concepto, variaimss, variable, imss, ispt, ptu, 
                           despensa, mca_agui, fdoahorro, calculo, impor_base, saldiaint, tabulador, unidades, horas, tipo_mov,
                           secuencia, importe, igravable, iexento, credito, descuento, saldo, referencia, siempre, justificar,
                           septimo, prevsocial, varia1, varia2, varia3, varia4, variable1, variable2, variable3, variable4,
                           masivo, formula, ispt_ng, imss_ni, marca, serial, informativo, detalle_prn
                from kardex
               where empresa = @nempresa and codigo = @ncodigo_act
               




insert into percepciones (empresa, codigo, folio, num_conc, mes_operacion, ayo_operacion, centro, clase, periodo, tiponom, fch_real,
                          fch_pago, variable, varia_imss, horas_ex, operacion, unidades, partevaria, nomina, siempre, varia1, varia2,
                          varia3, varia4, masivo, baja, destajo, origen, motivo)
                select empresa, @ncodigo_new, folio, num_conc, mes_operacion, ayo_operacion, centro, clase, periodo, tiponom, fch_real,
                       fch_pago, variable, varia_imss, horas_ex, operacion, unidades, partevaria, nomina, siempre, varia1, varia2,
                       varia3, varia4, masivo, baja, destajo, origen, motivo
                from percepciones
                where empresa = @nempresa and codigo = @ncodigo_act

INSERT INTO dbo.infonavit_cambios (empresa, codigo      , fecha, tipo_cred, descuento, cambio, periodo, ayo_operacion,  numcredito)
                            SELECT empresa, @ncodigo_new, fecha, tipo_cred, descuento, cambio, periodo, ayo_operacion, numcredito
                            FROM dbo.infonavit_cambios
                            WHERE dbo.infonavit_cambios.empresa = @nempresa AND dbo.infonavit_cambios.codigo = @ncodigo_act

/*
DECLARE @pensionAlementicaActual TABLE 
(empresa INT,
 renglon INT ,
 codigoActual INT ,
 consecutivoActual INT)

DECLARE @pensionAlementicaNuevo TABLE 
(empresa INT,
 renglon INT ,
 codigoNuevo INT ,
 consecutivoNuevo INT)
 
INSERT @pensionAlementicaActual
        ( empresa ,
          renglon ,
          codigoActual ,
          consecutivoActual 
        )
SELECT  empresa ,
        ROW_NUMBER() OVER(order by consecutivo) as renglon,
        codigo ,
        consecutivo AS consecutivoActual 
FROM    dbo.PensionAlimenticia
WHERE   dbo.PensionAlimenticia.empresa = @nempresa
        AND dbo.PensionAlimenticia.codigo = @ncodigo_act

INSERT  dbo.PensionAlimenticia
        ( empresa ,
          codigo ,
          porcentaje ,
          importe ,
          fecha ,
          uso ,
          beneficiario ,
          referencia ,
          cuentaBanco ,
          Domicilio ,
          Colonia ,
          Poblacion ,
          Telefono ,
          EMail
        )
        SELECT  empresa ,
                @ncodigo_new ,
                porcentaje ,
                importe ,
                fecha ,
                uso ,
                beneficiario ,
                referencia ,
                cuentaBanco ,
                Domicilio ,
                Colonia ,
                Poblacion ,
                Telefono ,
                EMail
        FROM    dbo.PensionAlimenticia
        WHERE   dbo.PensionAlimenticia.empresa = @nempresa
                AND dbo.PensionAlimenticia.codigo = @ncodigo_act

INSERT @pensionAlementicaNuevo
        ( empresa ,
          renglon ,
          codigoNuevo ,
          consecutivoNuevo 
        )
SELECT  empresa ,
        ROW_NUMBER() OVER(order by consecutivo) as renglon,
        codigo ,
        consecutivo AS consecutivoNuevo 
FROM    dbo.PensionAlimenticia
WHERE   dbo.PensionAlimenticia.empresa = @nempresa
        AND dbo.PensionAlimenticia.codigo = @ncodigo_new

UPDATE dbo.PensionAlimenticiaConcepto
SET dbo.PensionAlimenticiaConcepto.codigo = @ncodigo_new,
    dbo.PensionAlimenticiaConcepto.consecutivo = pensionNuevo.consecutivoNuevo
FROM dbo.PensionAlimenticiaConcepto
INNER JOIN dbo.PensionAlimenticia ON dbo.PensionAlimenticiaConcepto.empresa = dbo.PensionAlimenticia.empresa 
                                     AND dbo.PensionAlimenticiaConcepto.codigo = dbo.PensionAlimenticia.codigo 
                                     AND dbo.PensionAlimenticiaConcepto.consecutivo = dbo.PensionAlimenticia.consecutivo
INNER JOIN @pensionAlementicaActual AS pensionActual ON dbo.PensionAlimenticia.empresa = pensionActual.empresa
                                                        AND dbo.PensionAlimenticia.codigo = pensionActual.codigoActual
                                                        AND dbo.PensionAlimenticia.consecutivo = pensionActual.consecutivoActual
INNER JOIN @pensionAlementicaNuevo AS pensionNuevo ON pensionActual.empresa = pensionNuevo.empresa
                                                      AND pensionActual.renglon = pensionNuevo.renglon
*/                                                      
GO

IF OBJECT_ID('dbo.asp_datos_empleado') IS NOT NULL
    DROP PROCEDURE dbo.asp_datos_empleado
GO
CREATE PROCEDURE [dbo].[asp_datos_empleado]
    @nempresa INTEGER ,
    @ccampo VARCHAR(15) ,
    @ncodigo NUMERIC(8, 0) ,
    @cafilia CHAR(15) ,
    @cpaterno VARCHAR(50) ,
    @cmaterno VARCHAR(50) ,
    @cnombre VARCHAR(50)
AS
    DECLARE @cespacio CHAR(3)
    DECLARE @cestatus CHAR(3)
    DECLARE @ccondicion VARCHAR(150)
	DECLARE @fsd CHAR(5) 

    SET @cespacio = CHAR(39) + ' ' + CHAR(39)
    SET @cestatus = CHAR(39) + 'A' + CHAR(39)
	SET @fsd = CHAR(39) + 'FSD' + CHAR(39)


    SET @cafilia = CHAR(39) + LTRIM(RTRIM(@cafilia)) + CHAR(39)
    SET @cpaterno = CHAR(39) + LTRIM(RTRIM(@cpaterno)) + CHAR(39)
    SET @cmaterno = CHAR(39) + LTRIM(RTRIM(@cmaterno)) + CHAR(39)
    SET @cnombre = CHAR(39) + LTRIM(RTRIM(@cnombre)) + CHAR(39)



    SET @ccondicion = CASE WHEN @ccampo = 'CODIGO'
                           THEN 'empleados.codigo = ' + STR(@ncodigo)
                                + ' AND '
                           WHEN @ccampo = 'NSS'
                           THEN 'empleados.afiliacion + empleados.digvera = '
                                + @cafilia + ' AND '
                           WHEN @ccampo = 'NOMBRE'
                           THEN 'empleados.ap_paterno = ' + @cpaterno
                                + ' AND empleados.ap_materno = ' + @cmaterno
                                + ' AND empleados.nombre = ' + @cnombre
                                + ' AND '
                           ELSE ' '
                      END



    EXEC ('select (rtrim(dbo.empleados.ap_paterno) + ' + @cespacio + ' + rtrim(dbo.empleados.ap_materno) + ' +  @cespacio + ' + rtrim(dbo.empleados.nombre)) as nombre,
    dbo.empleados.fchalta,
    dbo.empleados.fchantigua,
    dbo.empleados.borrado,
    dbo.llaves.clase,
    dbo.llaves.tiponom,
    dbo.tabulador.actividad,
    dbo.periodos.inicio,
    dbo.periodos.cierre,
    dbo.periodos.pago,
    dbo.nominas.nomina,
    dbo.llaves.centro,
    dbo.centros.nomdepto,
    dbo.empleados.activo,
    dbo.empleados.fch_baja,
    dbo.llaves.horario,
    dbo.datosemps.foto,
    dbo.empleados.afiliacion,
    dbo.empleados.digvera,
    dbo.tabulador.ocupacion,
    dbo.empleados.fchnac,
    dbo.empleados.rfcalfa,
    dbo.empleados.rfcnum,
    dbo.empleados.rfchomo,
    dbo.empleados.curp,
    dbo.periodos.periodo,
    dbo.empleados.empresa,
    dbo.empleados.ultmov,
    dbo.empleados.ultfchmov,
    dbo.empleados.codigo,

    dbo.infonavit.tipo_cred,
    ISNULL(dbo.infonavit.numcredito,0) AS numcredito,
    ISNULL(dbo.infonavit.descuento,0) AS descuento,
    dbo.infonavit.fecha ,
    dbo.infonavit.fch_otorga ,
    dbo.infonavit.fch_termino,
    dbo.infonavit.seguro_vivienda ,
    dbo.infonavit.fechaSuspension

    FROM dbo.empleados
    left join
    Llaves on dbo.empleados.empresa = dbo.Llaves.empresa and dbo.empleados.codigo = dbo.Llaves.codigo
    left join
    dbo.datosemps on dbo.empleados.empresa = dbo.datosemps.empresa and dbo.empleados.codigo = dbo.datosemps.codigo
    left join
    dbo.tabulador on dbo.empleados.empresa = dbo.tabulador.empresa AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
    left join
    dbo.periodos on dbo.empleados.empresa = dbo.periodos.empresa and dbo.Llaves.tiponom = dbo.periodos.tiponom and dbo.periodos.estatus = ' + @cestatus + '
    left join
    dbo.nominas on dbo.empleados.empresa = dbo.nominas.empresa and Llaves.tiponom = dbo.nominas.tiponom
    left join
    dbo.centros on dbo.empleados.empresa = dbo.centros.empresa and dbo.Llaves.centro = dbo.centros.centro
    OUTER APPLY  (SELECT TOP 1
                         CASE WHEN ic.cambio = ' + @fsd + ' THEN 0 ELSE 1 END AS cambio
                  FROM dbo.infonavit_cambios AS ic
	              WHERE ic.empresa = dbo.empleados.empresa
	                    AND ic.codigo = dbo.empleados.codigo) AS ic
    LEFT JOIN dbo.infonavit ON dbo.empleados.empresa = dbo.infonavit.empresa AND dbo.empleados.codigo = dbo.infonavit.codigo AND dbo.infonavit.fechaSuspension IS NULL AND  ISNULL(ic.cambio,0) = 1
    where ' + @ccondicion + ' not dbo.empleados.empresa = ' + @nempresa)
GO

IF OBJECT_ID('dbo.asp_ds') IS NOT NULL
   DROP PROCEDURE dbo.asp_ds
GO
CREATE PROCEDURE [dbo].[asp_ds]
@nempresa NUMERIC(5,0),
@ncodigo NUMERIC(8,0),
@nayo INT,
@nmes INT,
@dfch_fin_mes DATETIME

AS

DECLARE @ninicio NUMERIC(8,0)
DECLARE @nfin NUMERIC(8,0)
DECLARE @cSiguienteMov CHAR(2)
DECLARE @dSiguienteFechaMov DATETIME

IF @ncodigo = 0
   BEGIN 
       SET @ninicio = 1
       SET @nfin = 99999999
   END
ELSE
   BEGIN
       SET @ninicio = @ncodigo
       SET @nfin = @ncodigo
   END

--UPDATE a 
--SET a.diastr = 0 
--FROM dbo.avisos_imss AS a
--WHERE a.empresa = @nempresa 
--      AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo and
--      AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes and
--      AND a.codigo BETWEEN @ninicio AND @nfin        
/*
update a 
set a.diastr = case when a.mov = 'B' 
                              then 0 
                              else case when a.fch_mov = d.fch_mov and d.mov <> 'B'
                                              then 0 
                                              else case when d.fch_mov is null 
                                                              then datediff(dd,a.fch_mov,@dfch_fin_mes) + 1 
                                                              else datediff(dd,a.fch_mov,d.fch_mov) + case when d.mov = 'B' 
                                                                                                                                       then 1 
                                                                                                                                       else 0 
                                                                                                                              end
                                                      end 
                                      end 
                     end 
from avisos_imss as a
left join avisos_imss as d on a.empresa = d.empresa and a.codigo = d.codigo and a.ayo_operacion = d.ayo_operacion and a.mes_operacion = d.mes_operacion and a.serial + 1 = d.serial
where a.empresa = @nempresa and a.ayo_operacion = @nayo and a.mes_operacion = @nmes and a.codigo between @ninicio and @nfin
*/

UPDATE a
SET @cSiguienteMov = ISNULL((SELECT TOP 1
                                    m.mov
                             FROM dbo.avisos_imss AS m
                             WHERE m.empresa = a.empresa
                                   AND m.codigo = a.codigo
                                   AND YEAR(m.fch_mov) = YEAR(a.fch_mov)
                                   AND MONTH(m.fch_mov) = MONTH(a.fch_mov)
                                   AND m.serial > a.serial
                             ORDER BY m.fch_mov ASC,
                                      m.serial ASC),''),

    @dSiguienteFechaMov = ISNULL((SELECT TOP 1
                                         m.fch_mov
                                  FROM dbo.avisos_imss AS m
                                  WHERE m.empresa = a.empresa
                                        AND m.codigo = a.codigo
                                        AND YEAR(m.fch_mov) = YEAR(a.fch_mov)
                                        AND MONTH(m.fch_mov) = MONTH(a.fch_mov)
                                        AND m.serial > a.serial
                                  ORDER BY m.fch_mov ASC,
                                           m.serial ASC),@dfch_fin_mes),
                               
    a.diastr = CASE WHEN a.mov = 'B' 
                    THEN 0 
                    ELSE CASE WHEN a.fch_mov = @dSiguienteFechaMov AND (@cSiguienteMov = 'IM' OR @cSiguienteMov = 'A' OR @cSiguienteMov = 'RI' OR @cSiguienteMov = 'MS')
                              THEN 0 
                              ELSE DATEDIFF(dd,a.fch_mov,@dSiguienteFechaMov) + CASE WHEN @cSiguienteMov = 'B' OR @cSiguienteMov = ''
                                                                                     THEN 1 
                                                                                     ELSE 0 
                                                                                END
                         END 
               END
                  
FROM dbo.avisos_imss AS a
WHERE a.empresa = @nempresa 
      AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo and
      AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes and
      AND a.codigo BETWEEN @ninicio AND @nfin        
GO

IF OBJECT_ID('dbo.asp_ds_aus') IS NOT NULL
   DROP PROCEDURE dbo.asp_ds_aus
GO
CREATE PROCEDURE [dbo].[asp_ds_aus]
@nempresa NUMERIC(5,0),
@ncodigo NUMERIC(8,0),
@nayo INT,
@nmes INT,
@ndias_tope DECIMAL(5,2)

AS

DECLARE @ndias NUMERIC(5,0)
DECLARE @ninicio NUMERIC(8,0)
DECLARE @nfin NUMERIC(8,0)

SET @ndias = 0

IF @ncodigo = 0
   BEGIN
     SET @ninicio = 1
     SET @nfin     = 99999999
   END
ELSE
   BEGIN
     SET @ninicio = @ncodigo
     SET @nfin   = @ncodigo
   END

UPDATE a
SET a.ausen = 0
FROM dbo.avisos_imss AS a
WHERE a.empresa           = @nempresa
      AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo
      AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes
      AND a.codigo BETWEEN @ninicio AND @nfin

SELECT a.empresa,
       a.codigo,
       YEAR(a.fch_mov) AS ayo_operacion, --a.ayo_operacion,
       MONTH(a.fch_mov) AS mes_operacion, --a.mes_operacion,
       a.serial,
       d.fchinicio,
       d.dias,
       CASE WHEN d.fchinicio < a.fch_mov AND d.fchinicio + d.dias - 1 > a.fch_mov 
                 AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
            THEN DATEDIFF(dd,a.fch_mov,d.fchinicio + d.dias)
            ELSE CASE WHEN d.fchinicio >= a.fch_mov 
                           AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                      THEN d.dias
                      ELSE CASE WHEN d.fchinicio >= a.fch_mov 
                                     AND d.fchinicio <= a.fch_mov + a.diastr - 1 
                                     AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                THEN datediff(dd,d.fchinicio,a.fch_mov + a.diastr)
                                ELSE CASE WHEN d.fchinicio < a.fch_mov 
                                               AND d.fchinicio + d.dias - 1 > a.fch_mov + a.diastr - 1
                                          THEN a.diastr
                                          ELSE 0
                                     END
                           END
                 END
       END AS 'aus'
INTO #tmp_aus
FROM dbo.avisos_imss AS a
     LEFT JOIN dbo.deducciones AS d ON a.empresa = d.empresa
                                       AND a.codigo = d.codigo
WHERE a.empresa = @nempresa
      AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo
      AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes
      AND a.diastr > 0
      AND d.num_conc = 108
      AND ( 
            ( d.fchinicio <= a.fch_mov
              AND d.fchtermino >= a.fch_mov
              AND d.fchinicio <= a.fch_mov + a.diastr - 1
            )
            OR ( d.fchinicio >= a.fch_mov
                 AND d.fchtermino <= a.fch_mov + a.diastr - 1
               )
            OR ( d.fchinicio >= a.fch_mov
                 AND d.fchinicio <= a.fch_mov + a.diastr - 1
                 AND d.fchtermino >= a.fch_mov + a.diastr - 1
               )
            OR ( d.fchinicio <= a.fch_mov
                 AND d.fchtermino >= a.fch_mov + a.diastr - 1
               )
          )

UPDATE a
SET a.ausen = ISNULL((SELECT SUM(b.aus)
                      FROM #tmp_aus AS b
                      WHERE a.empresa = b.empresa
                            AND a.codigo = b.codigo
                            AND YEAR(a.fch_mov) = b.ayo_operacion --a.ayo_operacion = b.ayo_operacion
                            AND MONTH(a.fch_mov) = b.mes_operacion --a.mes_operacion = b.mes_operacion
                            AND a.serial = b.serial),0)
FROM dbo.avisos_imss AS a
WHERE a.empresa = @nempresa
      AND YEAR(a.fch_mov) =  @nayo --a.ayo_operacion = @nayo
      AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes
      AND a.codigo BETWEEN @ninicio AND @nfin
      AND a.diastr > 0

UPDATE a
SET @ndias = CASE WHEN a.serial = 1 THEN 0 ELSE @ndias END,
    @ndias = @ndias + a.ausen,
    a.ausen = CASE WHEN @ndias < @ndias_tope
                   THEN a.ausen
                   ELSE CASE WHEN CASE WHEN a.ausen is null 
                                       THEN 0 
                                       ELSE a.ausen 
                                  END - (@ndias - @ndias_tope) < 0
                             THEN 0
                             ELSE CASE WHEN a.ausen is null 
                                       THEN 0 
                                       ELSE a.ausen 
                                  END - (@ndias - @ndias_tope)
                        END
              END
FROM dbo.avisos_imss AS a
WHERE a.empresa = @nempresa
      AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo
      AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes 
      AND a.codigo BETWEEN @ninicio AND @nfin

DROP TABLE #tmp_aus
GO

IF OBJECT_ID('dbo.asp_ds_aus_UMA') IS NOT NULL
   DROP PROCEDURE dbo.asp_ds_aus_UMA
GO
CREATE PROCEDURE [dbo].[asp_ds_aus_UMA]
@nempresa NUMERIC(5,0),
@ncodigo NUMERIC(8,0),
@nayo INT,
@nmes INT,
@ndias_tope DECIMAL(5,2)
, @proceso VARCHAR(250)
, @fechaProceso DATETIME
, @horaProceso VARCHAR(8)

AS

DECLARE @ndias NUMERIC(5,0)
DECLARE @ninicio NUMERIC(8,0)
DECLARE @nfin NUMERIC(8,0)
DECLARE @fechaInicio DATETIME
DECLARE @fechaTermino DATETIME
DECLARE @EsRpuEspecial INT

SET @EsRpuEspecial = dbo.EsRpuEspecial(@nempresa)
SET @fechaInicio = CONVERT(DATETIME, RIGHT(10000 + @nayo,4) + RIGHT(100 + @nmes,2) + '01')

SELECT @fechaInicio = fechaInicio 
      , @fechaTermino = fechaFin
FROM [dbo].[ObtieneRangoFecha](@fechaInicio, 7)


--SELECT @fechaInicio, @fechaTermino


SET @ndias = 0

IF @ncodigo = 0
   BEGIN
     SET @ninicio = 1
     SET @nfin     = 99999999
   END
ELSE
   BEGIN
     SET @ninicio = @ncodigo
     SET @nfin   = @ncodigo
   END

UPDATE a
SET a.ausen = 0
FROM dbo.AvisosImssTemporalCalculo AS a
     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
      --AND a.empresa           = @nempresa
      AND a.fch_mov >= @fechaInicio   --AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo
      AND a.fch_mov <= @fechaTermino  --AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes
      AND a.codigo BETWEEN @ninicio AND @nfin

/*
SELECT *
FROM dbo.AvisosImssTemporalCalculo AS a
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
*/

SELECT a.empresa,
       a.codigo,
       YEAR(a.fch_mov) AS ayo_operacion, --a.ayo_operacion,
       MONTH(a.fch_mov) AS mes_operacion, --a.mes_operacion,
       a.serial,
	   --ROW_NUMBER() OVER (PARTITION BY a.empresa, a.codigo, CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END ORDER BY a.empresa, a.codigo, a.fch_mov, a.serial) AS serial, 
       d.fchinicio,
       d.dias,
       CASE WHEN d.fchinicio <= a.fch_mov 
                 AND d.fchinicio + d.dias - 1 >= a.fch_mov 
                 AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
            THEN DATEDIFF(dd,a.fch_mov,d.fchinicio + d.dias)
            ELSE CASE WHEN d.fchinicio >= a.fch_mov 
                           AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                      THEN d.dias
                      ELSE CASE WHEN d.fchinicio >= a.fch_mov 
                                     AND d.fchinicio <= a.fch_mov + a.diastr - 1 
                                     AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                THEN datediff(dd,d.fchinicio,a.fch_mov + a.diastr)
                                ELSE CASE WHEN d.fchinicio <= a.fch_mov 
                                               AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                          THEN a.diastr
                                          ELSE 0
                                     END
                           END
                 END
       END AS 'aus'
	   , CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END AS rpu
INTO #tmp_aus
FROM dbo.AvisosImssTemporalCalculo AS a
     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
     LEFT JOIN dbo.deducciones AS d ON d.empresa = a.empresa
                                       AND d.codigo = a.codigo
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
      --AND a.empresa = @nempresa
      AND a.fch_mov >= @fechaInicio   --AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo
      AND a.fch_mov <= @fechaTermino  --AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes
      AND a.diastr > 0
      AND d.num_conc = 108
      AND ( 
            ( d.fchinicio <= a.fch_mov
              AND d.fchtermino >= a.fch_mov
              AND d.fchinicio <= a.fch_mov + a.diastr - 1
            )
            OR ( d.fchinicio >= a.fch_mov
                 AND d.fchtermino <= a.fch_mov + a.diastr - 1
               )
            OR ( d.fchinicio >= a.fch_mov
                 AND d.fchinicio <= a.fch_mov + a.diastr - 1
                 AND d.fchtermino >= a.fch_mov + a.diastr - 1
               )
            OR ( d.fchinicio <= a.fch_mov
                 AND d.fchtermino >= a.fch_mov + a.diastr - 1
               )
          )

UPDATE a
SET a.ausen = ISNULL((SELECT SUM(b.aus)
                      FROM #tmp_aus AS b
                      WHERE b.empresa = a.empresa
                            AND b.codigo = a.codigo
                            AND b.ayo_operacion = YEAR(a.fch_mov)   --a.ayo_operacion = b.ayo_operacion
                            AND b.mes_operacion = MONTH(a.fch_mov) --a.mes_operacion = b.mes_operacion
                            AND b.serial = a.serial
							AND CASE WHEN @EsRpuEspecial = 1 THEN b.rpu ELSE '' END = CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END),0)
FROM dbo.AvisosImssTemporalCalculo AS a
     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
      --AND a.empresa = @nempresa
      AND a.fch_mov >= @fechaInicio   --AND YEAR(a.fch_mov) =  @nayo --a.ayo_operacion = @nayo
      AND a.fch_mov <= @fechaTermino  --AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes
      AND a.codigo BETWEEN @ninicio AND @nfin
      AND a.diastr > 0

UPDATE a
SET @ndias = CASE WHEN a.serial = 1 THEN 0 ELSE @ndias END,
    @ndias = @ndias + a.ausen,
    a.ausen = CASE WHEN @ndias < @ndias_tope
                   THEN a.ausen
                   ELSE CASE WHEN CASE WHEN a.ausen is null 
                                       THEN 0 
                                       ELSE a.ausen 
                                  END - (@ndias - @ndias_tope) < 0
                             THEN 0
                             ELSE CASE WHEN a.ausen is null 
                                       THEN 0 
                                       ELSE a.ausen 
                                  END - (@ndias - @ndias_tope)
                        END
              END
FROM dbo.AvisosImssTemporalCalculo AS a
     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
      --AND a.empresa = @nempresa
      AND a.fch_mov >= @fechaInicio   --AND YEAR(a.fch_mov) = @nayo --a.ayo_operacion = @nayo
      AND a.fch_mov <= @fechaTermino  --AND MONTH(a.fch_mov) = @nmes --a.mes_operacion = @nmes 
      AND a.codigo BETWEEN @ninicio AND @nfin

DROP TABLE #tmp_aus
GO

IF OBJECT_ID('dbo.asp_ds_inc') IS NOT NULL 
    DROP PROCEDURE dbo.asp_ds_inc
GO
CREATE PROCEDURE dbo.asp_ds_inc
    @nempresa INT ,
    @ncodigo INT ,
    @nayo INT ,
    @nmes INT
AS 
    DECLARE @ninicio INT
    DECLARE @nfin INT

    IF @ncodigo = 0 
        BEGIN
          SET @ninicio = 1
          SET @nfin = 99999999
        END
    ELSE 
        BEGIN
          SET @ninicio = @ncodigo
          SET @nfin = @ncodigo
        END

    UPDATE  a
    SET     a.incap = 0,
	        a.lic = 0
    FROM    dbo.avisos_imss AS a
    WHERE   a.empresa = @nempresa
            AND YEAR(a.fch_mov) = @nayo
            AND MONTH(a.fch_mov) = @nmes
            AND a.codigo BETWEEN @ninicio AND @nfin

    SELECT  a.empresa ,
            a.codigo ,
            YEAR(a.fch_mov) AS ayo_operacion,
            MONTH(a.fch_mov) AS mes_operacion,
            a.serial ,
			CASE WHEN d.num_conc = 109 AND d.inicsubs = '4'
			     THEN CASE WHEN d.fchinicio <= a.fch_mov
                                AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                           THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                                     THEN d.dias
                                     ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                                    AND d.fchinicio <= a.fch_mov + a.diastr - 1
                                                    AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                               THEN DATEDIFF(dd, d.fchinicio, a.fch_mov + a.diastr)
                                               ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                              AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                                         THEN a.diastr
                                                         ELSE 0
                                                    END
                                          END
                                END
                      END
                 ELSE 0
            END AS 'lic' ,
			--CASE WHEN (d.num_conc = 109 AND d.inicsubs <> '4') OR d.num_conc = 110 OR d.num_conc = 111
			--     THEN 
				 CASE WHEN d.fchinicio <= a.fch_mov
                                AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                           THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                                     THEN d.dias
                                     ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                                    AND d.fchinicio <= a.fch_mov + a.diastr - 1
                                                    AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                               THEN DATEDIFF(dd, d.fchinicio, a.fch_mov + a.diastr)
                                               ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                              AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                                         THEN a.diastr
                                                         ELSE 0
                                                    END
                                          END
                                END
                      --END
                 --ELSE 0
            END AS 'incap'
            
    INTO    #tmp_incap
    FROM    dbo.avisos_imss AS a
            LEFT JOIN dbo.deducciones AS d ON a.empresa = d.empresa
                                              AND a.codigo = d.codigo
    WHERE   a.empresa = @nempresa
            AND YEAR(a.fch_mov) = @nayo
            AND MONTH(a.fch_mov) = @nmes
            AND a.diastr > 0
            AND ( d.num_conc = 109
                  OR d.num_conc = 110
                  OR d.num_conc = 111
                )
            AND ( ( d.fchinicio <= a.fch_mov
                    AND d.fchtermino >= a.fch_mov
                    AND d.fchinicio <= a.fch_mov + a.diastr - 1
                  )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchtermino <= a.fch_mov + a.diastr - 1
                     )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchinicio <= a.fch_mov + a.diastr - 1
                       AND d.fchtermino >= a.fch_mov + a.diastr - 1
                     )
                  OR ( d.fchinicio <= a.fch_mov
                       AND d.fchtermino >= a.fch_mov + a.diastr - 1
                     )
                )   
            
    UPDATE  a
    --SET     a.incap = ISNULL(( SELECT SUM(b.incap)
    --                           FROM #tmp_incap AS b
    --                           WHERE a.empresa = b.empresa
    --                                 AND a.codigo = b.codigo
    --                                 AND YEAR(a.fch_mov) = b.ayo_operacion
    --                                 AND MONTH(a.fch_mov) = b.mes_operacion
    --                                 AND a.serial = b.serial
    --                         ), 0)
	SET a.incap = ISNULL(incap.incap,0),
	    a.lic = ISNULL(incap.lic,0)
    FROM    dbo.avisos_imss AS a
	        CROSS APPLY (SELECT SUM(b.incap) AS incap, SUM(b.lic) AS lic
                         FROM #tmp_incap AS b
                         WHERE a.empresa = b.empresa
                               AND a.codigo = b.codigo
                               AND YEAR(a.fch_mov) = b.ayo_operacion
                               AND MONTH(a.fch_mov) = b.mes_operacion
                               AND a.serial = b.serial
                             ) AS incap
    WHERE   a.empresa = @nempresa
            AND YEAR(a.fch_mov) = @nayo
            AND MONTH(a.fch_mov) = @nmes
            AND a.diastr > 0
            AND a.codigo BETWEEN @ninicio AND @nfin

    DROP TABLE #tmp_incap
GO

IF OBJECT_ID('dbo.asp_ds_inc_UMA') IS NOT NULL 
    DROP PROCEDURE dbo.asp_ds_inc_UMA
GO
CREATE PROCEDURE dbo.asp_ds_inc_UMA
    @nempresa INT ,
    @ncodigo INT ,
    @nayo INT ,
    @nmes INT
    , @proceso VARCHAR(250)
    , @fechaProceso DATETIME
    , @horaProceso VARCHAR(8)

AS 
    DECLARE @ninicio INT
    DECLARE @nfin INT
    DECLARE @fechaInicio DATETIME
    DECLARE @fechaTermino DATETIME
    DECLARE @EsRpuEspecial INT

    SET @EsRpuEspecial = dbo.EsRpuEspecial(@nempresa)
    SET @fechaInicio = CONVERT(DATETIME, RIGHT(10000 + @nayo,4) + RIGHT(100 + @nmes,2) + '01')

    SELECT @fechaInicio = fechaInicio 
           , @fechaTermino = fechaFin
    FROM [dbo].[ObtieneRangoFecha](@fechaInicio, 7)

    IF @ncodigo = 0 
        BEGIN
          SET @ninicio = 1
          SET @nfin = 99999999
        END
    ELSE 
        BEGIN
          SET @ninicio = @ncodigo
          SET @nfin = @ncodigo
        END

    UPDATE  a
    SET     a.incap = 0,
	        a.lic = 0
    FROM    dbo.AvisosImssTemporalCalculo AS a
	        INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
    WHERE   a.proceso = @proceso
            AND a.fechaProceso = @fechaProceso
            AND a.horaProceso = @horaProceso
            --AND a.empresa = @nempresa
            AND a.fch_mov >= @fechaInicio   --AND YEAR(a.fch_mov) = @nayo 
            AND a.fch_mov <= @fechaTermino  --AND MONTH(a.fch_mov) = @nmes 
            AND a.codigo BETWEEN @ninicio AND @nfin

    SELECT  a.empresa ,
            a.codigo ,
            YEAR(a.fch_mov) AS ayo_operacion,
            MONTH(a.fch_mov) AS mes_operacion,
            a.serial ,
			CASE WHEN d.num_conc = 109 AND d.inicsubs = '4'
                 THEN CASE WHEN d.fchinicio <= a.fch_mov
                                AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                           THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                                     THEN d.dias
                                     ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                                    AND d.fchinicio <= a.fch_mov + a.diastr - 1
                                                    AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                               THEN DATEDIFF(dd, d.fchinicio, a.fch_mov + a.diastr)
                                               ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                              AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                                         THEN a.diastr
                                                         ELSE 0
                                                    END
                                          END
                                END
                      END
                 ELSE 0
            END AS 'lic',
			--CASE WHEN (d.num_conc = 109 AND d.inicsubs <> '4') OR d.num_conc = 110 OR d.num_conc = 111
            --     THEN 
				 CASE WHEN d.fchinicio <= a.fch_mov
                                AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                           THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                                     THEN d.dias
                                     ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                                    AND d.fchinicio <= a.fch_mov + a.diastr - 1
                                                    AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                               THEN DATEDIFF(dd, d.fchinicio, a.fch_mov + a.diastr)
                                               ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                              AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                                         THEN a.diastr
                                                         ELSE 0
                                                    END
                                          END
                                END
            --          END
            --     ELSE 0
            END AS 'incap'
			, CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END AS rpu
    INTO    #tmp_incap
    FROM    dbo.AvisosImssTemporalCalculo AS a
	        INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
            LEFT JOIN dbo.deducciones AS d ON a.empresa = d.empresa
                                              AND a.codigo = d.codigo
    WHERE   a.proceso = @proceso
            AND a.fechaProceso = @fechaProceso
            AND a.horaProceso = @horaProceso
            --AND a.empresa = @nempresa
            AND a.fch_mov >= @fechaInicio   --AND YEAR(a.fch_mov) = @nayo
            AND a.fch_mov <= @fechaTermino  --AND MONTH(a.fch_mov) = @nmes
            AND a.diastr > 0
            AND ( d.num_conc = 109
                  OR d.num_conc = 110
                  OR d.num_conc = 111
                )
            AND ( ( d.fchinicio <= a.fch_mov
                    AND d.fchtermino >= a.fch_mov
                    AND d.fchinicio <= a.fch_mov + a.diastr - 1
                  )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchtermino <= a.fch_mov + a.diastr - 1
                     )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchinicio <= a.fch_mov + a.diastr - 1
                       AND d.fchtermino >= a.fch_mov + a.diastr - 1
                     )
                  OR ( d.fchinicio <= a.fch_mov
                       AND d.fchtermino >= a.fch_mov + a.diastr - 1
                     )
                )   

    UPDATE  a
    --SET     a.incap = ISNULL(( SELECT SUM(b.incap)
    --                           FROM #tmp_incap AS b
    --                           WHERE a.empresa = b.empresa
    --                                 AND a.codigo = b.codigo
    --                                 AND YEAR(a.fch_mov) = b.ayo_operacion
    --                                 AND MONTH(a.fch_mov) = b.mes_operacion
    --                                 AND a.serial = b.serial
    --                         ), 0)
	SET a.incap = ISNULL(incap.incap,0),
	    a.lic = ISNULL(incap.lic,0)
    FROM dbo.AvisosImssTemporalCalculo AS a
	     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
         CROSS APPLY (SELECT SUM(b.incap) AS incap, SUM(b.lic) AS lic
                      FROM #tmp_incap AS b
                      WHERE b.empresa = a.empresa
                            AND b.codigo = a.codigo
                            AND b.ayo_operacion = YEAR(a.fch_mov)
                            AND b.mes_operacion = MONTH(a.fch_mov) 
                            AND b.serial = a.serial
							AND CASE WHEN @EsRpuEspecial = 1 THEN b.rpu ELSE '' END = CASE WHEN @EsRpuEspecial = 1 THEN a.rpu ELSE '' END) AS incap

    WHERE   a.proceso = @proceso
            AND a.fechaProceso = @fechaProceso
            AND a.horaProceso = @horaProceso
            --AND a.empresa = @nempresa
            AND a.fch_mov >= @fechaInicio   --AND YEAR(a.fch_mov) = @nayo 
            AND a.fch_mov <= @fechaTermino  --AND MONTH(a.fch_mov) = @nmes 
            AND a.diastr > 0
            AND a.codigo BETWEEN @ninicio AND @nfin

    DROP TABLE #tmp_incap
GO

IF OBJECT_ID('dbo.asp_ds_UMA') IS NOT NULL
   DROP PROCEDURE dbo.asp_ds_UMA
GO
CREATE PROCEDURE [dbo].[asp_ds_UMA]
@nempresa NUMERIC(5,0)
, @ncodigo NUMERIC(8,0) 
, @nayo INT 
, @nmes INT
, @dfch_fin_mes DATETIME 
, @proceso VARCHAR(250) 
, @fechaProceso DATETIME 
, @horaProceso VARCHAR(8) 

AS

DECLARE @ninicio NUMERIC(8,0)
DECLARE @nfin NUMERIC(8,0)
DECLARE @cSiguienteMov CHAR(2)
DECLARE @dSiguienteFechaMov DATETIME
DECLARE @fechaInicio DATETIME
DECLARE @fechaTermino DATETIME

SET @fechaInicio = CONVERT(DATETIME, RIGHT(10000 + @nayo,4) + RIGHT(100 + @nmes,2) + '01')
SELECT @fechaTermino = fechaFin
FROM [dbo].[ObtieneRangoFecha](@fechaInicio, 7)

IF @ncodigo = 0
   BEGIN 
       SET @ninicio = 1
       SET @nfin = 99999999
   END
ELSE
   BEGIN
       SET @ninicio = @ncodigo
       SET @nfin = @ncodigo
   END

UPDATE a
SET a.diastr = CASE WHEN a.mov = 'B' 
                    THEN 0 
                    ELSE CASE WHEN a.fch_mov = ISNULL(SiguienteAviso.fch_mov, @dfch_fin_mes) AND (ISNULL(SiguienteAviso.mov,'') = 'IM' OR ISNULL(SiguienteAviso.mov,'') = 'A' OR ISNULL(SiguienteAviso.mov,'') = 'RI' OR ISNULL(SiguienteAviso.mov,'') = 'MS')
                              THEN 0 
                              ELSE DATEDIFF(dd,a.fch_mov, ISNULL(SiguienteAviso.fch_mov, @dfch_fin_mes)) + CASE WHEN ISNULL(SiguienteAviso.mov,'') = 'B' OR ISNULL(SiguienteAviso.mov,'') = ''
                                                                                     THEN 1 
                                                                                     ELSE 0 
                                                                                END
                         END 
               END
FROM dbo.AvisosImssTemporalCalculo AS a
     INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@nempresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = a.empresa
     OUTER APPLY (SELECT TOP 1
                         m.mov,
                         m.fch_mov
                  FROM dbo.AvisosImssTemporalCalculo AS m
                  WHERE m.proceso = a.proceso
                        AND m.fechaProceso = a.fechaProceso
                        AND m.horaProceso = a.horaProceso
                        AND m.empresa = a.empresa
                        AND m.codigo = a.codigo
                        --AND LTRIM(STR(YEAR(m.fch_mov)))
                        --    + RIGHT('0' + LTRIM(STR(MONTH(m.fch_mov))),2)
	                    --    + RIGHT('0' + LTRIM(STR(DAY(m.fch_mov))),2)
	                    --    + RIGHT('000' + LTRIM(STR(m.serial)),3)	 > LTRIM(STR(YEAR(a.fch_mov)))
                        --                                               + RIGHT('0' + LTRIM(STR(MONTH(a.fch_mov))),2)
	                    --                                               + RIGHT('0' + LTRIM(STR(DAY(a.fch_mov))),2)
	                    --                                               + RIGHT('000' + LTRIM(STR(a.serial)),3)
                        AND m.fch_mov >= a.fch_mov
                        AND m.serial > a.serial
                  ORDER BY m.fch_mov ASC,
                           m.serial ASC) AS SiguienteAviso
WHERE a.proceso = @proceso
      AND a.fechaProceso = @fechaProceso
      AND a.horaProceso = @horaProceso
      --AND a.empresa = @nempresa 
      AND a.fch_mov >= @fechaInicio
      AND a.fch_mov <= @fechaTermino
      AND a.codigo BETWEEN @ninicio AND @nfin        
GO

IF OBJECT_ID('dbo.asp_exp_casos_rt') IS NOT NULL 
    DROP PROCEDURE dbo.asp_exp_casos_rt
GO
CREATE PROCEDURE [dbo].[asp_exp_casos_rt]
    @nempresa NUMERIC(5, 0) ,
    @nayo INT
AS 
    SELECT  c.codigo ,
            c.caso ,
            c.st1_accidente ,
            c.st1_trayecto ,
            c.st1_fecha ,
            c.st2_accidente ,
            c.st2_fecha ,
            c.st3_accidente ,
            c.st3_valuacion ,
            RTRIM(e.ap_paterno) + ' ' + RTRIM(e.ap_materno) + ' ' + RTRIM(e.nombre) ,
            e.afiliacion ,
            e.digvera ,
            e.curp ,
            e.ap_paterno ,
            e.ap_materno ,
            e.nombre
    FROM    casos_rt AS c
            INNER JOIN empleados AS e ON e.empresa = c.empresa
                                         AND e.codigo = c.codigo
    WHERE   c.empresa = @nempresa
            AND c.ayo_operacion = @nayo
            AND c.caso > 0
    ORDER BY c.codigo ,
            c.caso
GO

IF OBJECT_ID('dbo.asp_fun_d_agrega_cl') IS NOT NULL
   DROP PROCEDURE dbo.asp_fun_d_agrega_cl
GO
CREATE PROCEDURE dbo.asp_fun_d_agrega_cl
@nempresa  NUMERIC(5,0),
@ncodigo   NUMERIC(8,0),
@ccampo_02 VARCHAR(50) ,
@ccampo_03 VARCHAR(50) ,
@ncampo_04 NUMERIC(15,5),
@ncmapo_05 NUMERIC(15,5),
@ncampo_07 INT,
@ncampo_08 INT,
@dcampo_10 DATETIME,
@dcampo_11 DATETIME,
@campo__09 VARCHAR(100),
@campo__10 VARCHAR(100),
@campo__11 VARCHAR(100),
@campo__12 VARCHAR(100),
@campo__13 VARCHAR(100),
@campo__14 VARCHAR(100),
@campo__15 VARCHAR(100)

AS

  SET NOCOUNT ON

  INSERT dbo.clasificacion_empleados 
         (empresa, 
          codigo, 
          campo_02, 
          campo_03,
          campo_04,
          campo_05,
          campo_07,
          campo_08,
          campo_10,
          campo_11,
          campo__09,
          campo__10,
          campo__11,
          campo__12,
          campo__13,
          campo__14,
          campo__15)
  VALUES    
         (@nempresa,
          @ncodigo,
          @ccampo_02,
          @ccampo_03,
          @ncampo_04,
          @ncmapo_05,
          @ncampo_07,
          @ncampo_08,
          @dcampo_10,
          @dcampo_11,
          @campo__09,
          @campo__10,
          @campo__11,
          @campo__12,
          @campo__13,
          @campo__14,
          @campo__15)
GO

IF OBJECT_ID('dbo.asp_fun_d_borra_cl') IS NOT NULL
   DROP PROCEDURE dbo.asp_fun_d_borra_cl
GO
CREATE PROCEDURE dbo.asp_fun_d_borra_cl
@empresa NUMERIC(5,0),
@codigo NUMERIC(8,0)

AS

  SET NOCOUNT ON

  DELETE dbo.clasificacion_empleados 
  WHERE empresa = @empresa and codigo = @codigo
GO

IF OBJECT_ID('dbo.asp_fun_d_etiquetas') IS NOT NULL
   DROP PROCEDURE dbo.asp_fun_d_etiquetas
GO
CREATE PROCEDURE dbo.asp_fun_d_etiquetas
@empresa NUMERIC(5,0)

AS
   SET NOCOUNT ON
   
   SELECT campo,
          etiqueta, 
          mensaje 
   FROM dbo.clasificacion_etiquetas 
   WHERE empresa = @empresa 
   ORDER BY campo
GO

IF OBJECT_ID('dbo.asp_rt_importa_casos') IS NOT NULL
    DROP PROCEDURE dbo.asp_rt_importa_casos
GO
CREATE PROCEDURE [dbo].[asp_rt_importa_casos]
    @nempresa NUMERIC(5, 0) ,
    @nemp_original NUMERIC(5, 0) ,
    @nayo INT ,
    @ncodigo NUMERIC(8, 0) ,
    @cnombre VARCHAR(50) ,
    @ncaso INT ,
    @nst1 INT ,
    @ctrayecto CHAR(3) ,
    @dst1fch DATETIME ,
    @nst2 INT ,
    @dst2fch DATETIME ,
    @nst3 INT ,
    @nvaluacion INT ,
    @cnss NUMERIC(10, 0) ,
    @cdigvera INT ,
    @ccurp CHAR(20) ,
    @apellidoPaterno VARCHAR(40) ,
    @apellidoMaterno VARCHAR(40) ,
    @nombreEmpleado VARCHAR(40)
AS
    INSERT  casos_rt_importado
            ( empresa ,
              emp_original ,
              codigo ,
              nombre ,
              caso ,
              ayo_operacion ,
              st1_accidente ,
              st1_trayecto ,
              st1_fecha ,
              st2_accidente ,
              st2_fecha ,
              st3_accidente ,
              st3_valuacion ,
              afiliacion ,
              digvera ,
              curp ,
              apellidoPaterno ,
              apellidoMaterno ,
              nombreEmpleado
            )
    VALUES  ( @nempresa ,
              @nemp_original ,
              @ncodigo ,
              @cnombre ,
              @ncaso ,
              @nayo ,
              @nst1 ,
              @ctrayecto ,
              @dst1fch ,
              @nst2 ,
              @dst2fch ,
              @nst3 ,
              @nvaluacion ,
              @cnss ,
              @cdigvera ,
              @ccurp ,
              @apellidoPaterno ,
              @apellidoMaterno ,
              @nombreEmpleado
            )
GO

IF OBJECT_ID('dbo.asp_trabajadores') IS NOT NULL 
    DROP PROCEDURE dbo.asp_trabajadores
GO
CREATE PROCEDURE [dbo].[asp_trabajadores]
    @empresa NUMERIC(5, 0) ,
    @fechaInicioMes DATETIME ,
    @user VARCHAR(50)
AS 
    DECLARE @costCenterEmployee VARCHAR(50)
    DECLARE @system VARCHAR(50)
    DECLARE @typePayrollEmployee INT

    SET @costCenterEmployee = ''
    SET @system = 'NO'
    SET @typePayrollEmployee = 0

    SELECT DISTINCT
            dbo.avisos_imss.codigo ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.Llaves.tiponom ,
            dbo.Llaves.centro
    FROM    dbo.avisos_imss
            INNER JOIN dbo.empleados ON dbo.empleados.empresa = dbo.avisos_imss.empresa
                                        AND dbo.empleados.codigo = dbo.avisos_imss.codigo
            INNER JOIN dbo.llaves ON dbo.Llaves.empresa = dbo.avisos_imss.empresa
                                     AND dbo.Llaves.codigo = dbo.avisos_imss.codigo
    WHERE   dbo.avisos_imss.empresa = @empresa
            AND dbo.avisos_imss.fch_mov >= @fechaInicioMes
            AND dbo.Llaves.centro IN (
            SELECT  costCenter
            FROM    [dbo].[GetCostCenterByProfile](@user, @costCenterEmployee,
                                                   @empresa, @system) )
            AND dbo.Llaves.tiponom IN (
            SELECT  typePayroll
            FROM    [dbo].[GetTypePayrollByProfile](@user,
                                                    @typePayrollEmployee,
                                                    @empresa, @system) )
    ORDER BY dbo.avisos_imss.codigo
GO

IF OBJECT_ID('dbo.BorraDeduccionesFuncionD') IS NOT NULL
   DROP PROCEDURE dbo.BorraDeduccionesFuncionD
GO   
CREATE PROCEDURE dbo.BorraDeduccionesFuncionD
@empresa INT
, @codigo INT
, @ayo_operacion INT
, @periodo INT

AS

  SET NOCOUNT ON

  DELETE d
  FROM dbo.deducciones AS d
  WHERE d.empresa = @empresa  
        AND d.codigo = @codigo
		AND d.ayo_operacion = @ayo_operacion
		AND d.periodo = @periodo
		AND (d.num_conc < 108 OR d.num_conc > 111)
GO

IF OBJECT_ID('dbo.BorraParteVariable') IS NOT NULL 
    DROP PROCEDURE dbo.BorraParteVariable
GO
CREATE PROCEDURE dbo.BorraParteVariable
    @empresa INT ,
    @ayo INT ,
    @mes INT
AS 
    DELETE  dbo.Partes_variables
    WHERE   dbo.Partes_variables.empresa = @empresa
            AND dbo.Partes_variables.ayo_operacion = @ayo
            AND dbo.Partes_variables.mes_operacion = @mes
GO

IF OBJECT_ID('dbo.BorraPercepcionesFuncionD') IS NOT NULL
   DROP PROCEDURE dbo.BorraPercepcionesFuncionD
GO   
CREATE PROCEDURE dbo.BorraPercepcionesFuncionD
@empresa INT
, @codigo INT
, @ayo_operacion INT
, @periodo INT

AS

  SET NOCOUNT ON

  DELETE p
  FROM dbo.percepciones AS p
  WHERE p.empresa = @empresa
        AND p.codigo = @codigo
	    AND p.ayo_operacion = @ayo_operacion
        AND p.periodo = @periodo
GO

IF OBJECT_ID('dbo.BuscaCuentaBancaria') IS NOT NULL
   DROP PROCEDURE dbo.BuscaCuentaBancaria
GO
CREATE PROCEDURE dbo.BuscaCuentaBancaria
@Empresa INT,
@Codigo INT,
@NoCuentaBanco VARCHAR(20)

AS 

  SELECT e.codigo
  FROM dbo.empleados AS e
  WHERE e.codigo <> @Codigo
        AND e.empresa = @Empresa
        AND CASE WHEN LTRIM(RTRIM(e.cta_bco_no)) = '' THEN '999' ELSE LTRIM(RTRIM(e.cta_bco_no)) END = CASE WHEN LTRIM(RTRIM(@NoCuentaBanco)) = '' THEN '888' ELSE LTRIM(RTRIM(@NoCuentaBanco)) END
GO

IF OBJECT_ID('dbo.CalculaAmortizacionMensualProcedure') IS NOT NULL
   DROP  PROCEDURE [dbo].[CalculaAmortizacionMensualProcedure]
GO
CREATE PROCEDURE [dbo].[CalculaAmortizacionMensualProcedure]
    @nempresa NUMERIC(5, 0) ,
    @nayo INT ,
    @nmes_non INT ,
    @ndias_tope DECIMAL(5, 2) ,
    @czonageo CHAR(1) ,
    @ncodigo NUMERIC(8, 0),
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS 

    DELETE  [dbo].[TemporalAmortizacion]
    WHERE   empresa = @nempresa

    DECLARE @nserial_bim INT
    DECLARE @nfolio INT
    DECLARE @csw CHAR(1)
    DECLARE @namortiza NUMERIC(12, 2)
    DECLARE @ninicio NUMERIC(8, 0)
    DECLARE @nfin NUMERIC(8, 0)
    DECLARE @naus_non DECIMAL(5, 2) 
    DECLARE @naus_par DECIMAL(5, 2) 
    DECLARE @ncodant NUMERIC(8, 0)
    DECLARE @ndias_non NUMERIC(5, 0)
    DECLARE @ndias_par NUMERIC(5, 0)
    DECLARE @nntd INT
    DECLARE @ninfo INT
    DECLARE @nporc_abono NUMERIC(8, 4)
    DECLARE @cDiasLab CHAR(1)
    DECLARE @cRetenido CHAR(1)
    DECLARE @cPropCred CHAR(1)
    DECLARE @cConvenio CHAR(8)
    DECLARE @nsaldiaint NUMERIC(12, 2)
    DECLARE @nvsm NUMERIC(12, 2)
    DECLARE @nseg_viv NUMERIC(5, 2)
    DECLARE @dfch_ini_non DATETIME
    DECLARE @dfch_fin_non DATETIME
    DECLARE @ndiasprop INT
    DECLARE @ndiasnon INT
    DECLARE @nsaldf NUMERIC(10, 02)
    DECLARE @nsalmin NUMERIC(10, 02)
    DECLARE @usaInfonavit CHAR(1)
    DECLARE @fchMovSuspension DATETIME
    DECLARE @movSuspension CHAR(2)

    DECLARE @salarioRegionA FLOAT
    DECLARE @salarioRegionB FLOAT
    DECLARE @salarioRegionC FLOAT
    
    DECLARE @seleccionSalarioMinimo CHAR(1)
    DECLARE @salarioMinimo FLOAT
    
    SELECT @seleccionSalarioMinimo = ISNULL(dbo.empresas.usarSalarioMinimo,'R')
    FROM dbo.empresas
    WHERE dbo.empresas.empresa = @nempresa

-- saca parametros infonavit
    SELECT  @cDiasLab = CASE WHEN hrs_min2 = 999 THEN 'N'
                             ELSE 'S'
                        END ,
            @cRetenido = CASE WHEN hrs_min3 = 999 THEN 'S'
                              ELSE 'N'
                         END ,
            @cPropCred = CASE WHEN marca2 = 'M' THEN 'N'
                              ELSE 'S'
                         END ,
            @cConvenio = RTRIM(LTRIM(variable1)),
            @usaInfonavit = uso
    FROM    conceptos
    WHERE   empresa = @nempresa
            AND num_conc = 112

IF @usaInfonavit = 'S'
BEGIN
    SET @nsaldf = 0
    SET @nsalmin = 0
    SET @namortiza = 0
    SET @nserial_bim = 0
    SET @nfolio = 0
    SET @csw = 'F'
    SET @nntd = 0
    SET @ninfo = 0
    SET @nporc_abono = 0
    SET @nsaldiaint = 0
    SET @nvsm = 0
    SET @nseg_viv = 0
    SET @dfch_ini_non = CAST(SUBSTRING(LTRIM(STR(@nayo + 10000)), 2, 4) + SUBSTRING(LTRIM(STR(@nmes_non + 100)), 2, 2) + '01' AS DATETIME)
    SET @dfch_fin_non = dbo.fin_mes(@nmes_non, @nayo)
    SET @ndiasnon = DATEDIFF(dd, @dfch_ini_non, @dfch_fin_non) + 1


    --SET @ndiaspar = 0

    --IF @nmes_par % 2 = 0 
    --    BEGIN
    --        SET @dfch_ini_par = CAST(SUBSTRING(LTRIM(STR(@nayo + 10000)), 2, 4) + SUBSTRING(LTRIM(STR(@nmes_par + 100)), 2, 2) + '01' AS DATETIME)
    --        SET @dfch_fin_par = dbo.fin_mes(@nmes_par, @nayo)
    --        SET @ndiaspar = CASE WHEN @nmes_par % 2 = 0
    --                             THEN DATEDIFF(dd, @dfch_ini_par, @dfch_fin_par) + 1
    --                             ELSE 0
    --                        END
    --    END

    SET @ndiasprop = DATEDIFF(dd, @dfch_ini_non, @dfch_fin_non) + 1

-- si la variable @ncodigo es cero
-- va a afectar a todos los trabajadores
-- si no solo afecta al codigo deseado 
    IF @ncodigo = 0 
        BEGIN
            SET @ninicio = 1
            SET @nfin = 99999999
        END
    ELSE 
        BEGIN
            SET @ninicio = @ncodigo
            SET @nfin = @ncodigo
        END

    SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
            @salarioRegionB = ISNULL(zona_b, 0) ,
            @salarioRegionC = ISNULL(zona_c, 0)
    FROM    [dbo].[GetMinimumWage](@nmes_non, @nayo)
    
    SET @nsaldf = @salarioRegionA
        
    SET @nsalmin = CASE @czonageo
                           WHEN 'A' THEN @salarioRegionA
                           WHEN 'B' THEN @salarioRegionB
                           WHEN 'C' THEN @salarioRegionC
                           ELSE 0
                         END
    
    IF @seleccionSalarioMinimo = 'D'
       SET @salarioMinimo = @nsaldf
    ELSE
       SET @salarioMinimo = @nsalmin
  
-- creo una tabla temporal con movimientos del mes o bimestre
-- y los datos del credito infonavit
    SELECT  
            aItc.empresa ,
            aItc.ayo_operacion ,
            aItc.mes_operacion ,
            aItc.codigo ,
            aItc.serial ,
            @nserial_bim AS 'serial_bim' ,
            aItc.mov ,
            aItc.fch_mov ,
            aItc.saldiaint ,
            aItc.diastr ,
            aItc.ausen ,
            aItc.incap ,
            i.tipo_cred ,
            i.descuento ,
            CASE WHEN i.fecha < @dfch_ini_non
                 THEN CASE WHEN @dfch_ini_non < aItc.fch_mov
                                AND aItc.mov = 'A' THEN aItc.fch_mov
                           ELSE @dfch_ini_non
                      END
                 ELSE CASE WHEN i.fecha < aItc.fch_mov
                                AND aItc.mov = 'A' THEN aItc.fch_mov
                           ELSE i.fecha
                      END
            END AS 'fch_cred' ,
            i.fch_otorga ,
            @namortiza AS 'amortizacion' ,
            @nntd AS 'ntd' ,
            @ninfo AS 'info' ,
            i.descuento AS 'porc_abono' ,
            @nporc_abono AS 'vsm' ,
            i.seguro_vivienda ,
            i.fecha ,
            i.fch_termino ,
            i.numcredito ,
            e.afiliacion ,
            e.digvera,
            dbo.Llaves.clase,
            CASE WHEN i.fechaSuspension >= @dfch_ini_non AND i.fechaSuspension <= @dfch_fin_non
                 THEN i.fechaSuspension
                 ELSE NULL
            END AS fechaSuspension,
            @movSuspension AS movSuspension,
            @fchMovSuspension AS fchMovSuspension
    INTO    #tmp_inf
    FROM    infonavit AS i
            INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON aItc.empresa = i.empresa
                                           AND aItc.codigo = i.codigo
                                           AND aItc.ayo_operacion = @nayo
                                           AND aItc.mes_operacion = @nmes_non
            INNER JOIN empleados AS e ON e.empresa = i.empresa
                                         AND e.codigo = i.codigo
            INNER JOIN dbo.Llaves ON i.empresa = dbo.Llaves.empresa AND i.codigo = dbo.Llaves.codigo
    WHERE   i.empresa = @nempresa
            AND i.fecha <= @dfch_fin_non
            AND ( ( i.fch_termino >= @dfch_ini_non
                    AND @dfch_fin_non <= i.fch_termino
                    AND (i.fechaSuspension IS NULL
                         OR i.fechaSuspension >= @dfch_ini_non
                        )     
                  )
                  OR i.fch_termino IS NULL
                  OR i.fch_termino = '19000101'
                )
            AND i.codigo BETWEEN @ninicio AND @nfin
            AND e.cotiza_imss = 'S'
            AND e.borrado = 'N'
            AND aItc.horaProceso = @horaProceso
            AND aItc.fechaProceso = @fechaProceso
            AND aItc.proceso = @proceso
    ORDER BY aItc.codigo ,
            aItc.ayo_operacion ,
            aItc.mes_operacion ,
            aItc.serial

    -- Cambia la Alta a Ringreso cuando hay una baja anterior
    -- porque tomaba el inicio del credito apartir de la ultima alta
    -- 07/03/2012
    -- jorge Mtz
    -- Reportado por Mario Esparza
    -- Empresa Zebra
    DECLARE @codigoAnterior INT
    DECLARE @movimientoAnterior varchar(2)
    DECLARE @movimientoActual VARCHAR(2)
    DECLARE @fechaCredito DATETIME
    DECLARE @fechaCreditoActual DATETIME
    
    SET @codigoAnterior = 0        
    SET @movimientoAnterior = ''

    UPDATE  t1
    SET     @fechaCredito = CASE WHEN @codigoAnterior <> t1.codigo THEN t1.fch_cred ELSE @fechaCredito END,
            @movimientoActual = CASE WHEN @codigoAnterior = t1.codigo AND RTRIM(LTRIM(t1.mov)) = 'A' AND @movimientoAnterior = 'B' THEN 'RI' ELSE t1.mov END,
            @fechaCreditoActual = CASE WHEN @codigoAnterior = t1.codigo AND RTRIM(LTRIM(t1.mov)) = 'A' AND @movimientoAnterior = 'B' THEN @fechaCredito ELSE t1.fch_cred END,
            @codigoAnterior = t1.codigo,
            @movimientoAnterior = RTRIM(LTRIM(t1.mov)),
            t1.mov = @movimientoActual ,
            t1.fch_cred = @fechaCreditoActual
    FROM    #tmp_inf AS t1
    -- Fin Rutina Cambia Alta a Reingreso

   
-- para los creditos que tengan fecha de otorgamiento 
-- hasta el 30/01/1998 y sean tipo 1
-- poner el saldiaint de inicio de bimestre en todos 
-- los movimientos del trabajador
    UPDATE  a
    SET     a.saldiaint = ( SELECT TOP 1
                                    b.saldiaint
                            FROM    #tmp_inf AS b
                            WHERE   b.empresa = a.empresa
                                    AND b.codigo = a.codigo
                                    AND b.diastr > 0
                          )
    FROM    #tmp_inf AS a
    WHERE   a.tipo_cred = 1
            AND a.fch_otorga <= '19980130'
            AND @cpropcred = 'S'
            AND ( porc_abono = 20
                  OR porc_abono = 25
                  OR porc_abono = 30
                )

-- inicializa en ceros el campo diastr
-- y asigna un folio consecituvo en campo serial_bim
    SET @ncodigo = 0

    UPDATE  #tmp_inf
    SET     diastr = 0 ,
            @nfolio = CASE WHEN @ncodigo <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodigo = codigo


-- calcula dias cotizados 
    UPDATE  t1
    SET     t1.diastr = CASE WHEN t1.fch_mov = t2.fch_mov
                                  AND t2.mov <> 'B' THEN 0
                             ELSE CASE WHEN t2.fch_mov IS NULL
                                       THEN DATEDIFF(dd, t1.fch_mov, @dfch_fin_non) + 1
                                       ELSE DATEDIFF(dd, t1.fch_mov, t2.fch_mov) + CASE WHEN t2.mov = 'B' THEN 1 ELSE 0 END
                                  END
                        END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo AND t1.serial_bim + 1 = t2.serial_bim

-- dependiendo de la fecha del credito la acomoda
-- entre los avisos
    UPDATE  t1
    SET     t1.mov = CASE WHEN t1.fch_cred >= t1.fch_mov 
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov <> 'B' 
                          THEN 'CR'
                          ELSE t1.mov
                     END ,
            t1.fch_mov = CASE WHEN t1.fch_cred >= t1.fch_mov
                                   AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                                   AND t1.mov <> 'B' 
                              THEN t1.fch_cred
                              ELSE t1.fch_mov
                         END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial

-- pone la marca 'CR' dependiendo de cuando inicie el credito
    UPDATE  t2
    SET     t2.mov = CASE WHEN t1.fch_cred >= t1.fch_mov
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov = 'B' 
                          THEN CASE WHEN (SELECT TOP 1    -- Rutina Nueva 20140306
                                                 t3.mov
                                          FROM #tmp_inf AS t3 
                                          WHERE t1.codigo = t3.codigo
                                                AND t3.serial_bim < t1.serial_bim
                                          ORDER BY t3.serial_bim DESC) = 'CR'
                                    THEN t2.mov
                                    ELSE 'CR'
                               END                            
                          --'CR'
                          ELSE t2.mov
                     END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial

-- dependiendo de la fecha de SUSPENSION la acomoda
-- entre los avisos
    UPDATE  t1
    SET     t1.movSuspension = CASE WHEN t1.fechaSuspension >= t1.fch_mov
                                         AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
                                         AND t1.mov <> 'B'
                                    THEN 'SC'  -- SC = suspension credito
                                    ELSE NULL
                               END,
            t1.fchMovSuspension = CASE WHEN t1.fechaSuspension >= t1.fch_mov
                                            AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
                                            AND t1.mov <> 'B'
                                       THEN t1.fechaSuspension
                                       ELSE NULL 
                                  END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial

-- pone la marca 'SC' dependiendo de cuando suspenda el credito
-- vuelve a calcular los dias cotizados
-- los avisos anteriores a la marca CR no les calcula
-- dias los deja en ceros
    UPDATE  t1
    SET     @csw = CASE WHEN t1.serial_bim = 1 
                        THEN 'F'
                        ELSE @csw
                   END ,
            @csw = CASE WHEN t1.mov = 'CR' AND @csw = 'F' 
                        THEN 'T'
                        ELSE @csw
                   END ,
            t1.diastr = CASE WHEN @csw = 'T'
                             THEN CASE WHEN t1.mov = 'B' 
                                       THEN 0
                                       ELSE CASE WHEN t1.fch_mov = t2.fch_mov AND t2.mov <> 'B' 
                                                 THEN 0
                                                 ELSE CASE WHEN t2.fch_mov IS NULL
                                                           THEN DATEDIFF(dd,t1.fch_mov, @dfch_fin_non) + 1
                                                           ELSE DATEDIFF(dd,t1.fch_mov,t2.fch_mov) + CASE WHEN t2.mov = 'B' THEN 1 ELSE 0 END
                                                      END
                                            END
                                  END
                             ELSE 0
                        END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo AND t1.serial_bim + 1 = t2.serial_bim
    
    UPDATE  tempInf
    SET     tempInf.diastr = DATEDIFF(dd, tempInf.fch_mov, tempInf.fchMovSuspension) + 1
    FROM    #tmp_inf AS tempInf
    WHERE   tempInf.fchMovSuspension IS NOT NULL

-- borra los registros anteriores a CR
-- no tiene caso que esten en la tabla 
-- puesto que no se va usar ese registro
-- para calcular la amotizacion
    DELETE  t1
    FROM    #tmp_inf AS t1
            INNER JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                         AND t2.mov = 'CR'
                                         AND t1.fch_mov < t2.fch_mov


-- borra los registros posteriores a SC
-- no tiene caso que esten en la tabla 
-- puesto que no se va usar ese registro
-- para calcular la amotizacion
    DELETE  t1
    FROM    #tmp_inf AS t1
            INNER JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                         AND t2.movSuspension = 'SC'
                                         AND t1.fch_mov > t2.fechaSuspension
                                         
-- vuelve a reconstruir el folio
    SET @ncodigo = 0
    UPDATE  #tmp_inf
    SET     @nfolio = CASE WHEN @ncodigo <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodigo = codigo


    UPDATE  a
    SET     a.incap = 0 ,
            a.ausen = 0
    FROM    #tmp_inf AS a


-- ajusta los dias de incapcidad para cada movimiento
-- y lo guarda en la tabla temporal @tmp_incap
    SELECT  a.empresa ,
            a.codigo ,
            a.ayo_operacion ,
            a.mes_operacion ,
            a.serial ,
            CASE WHEN d.fchinicio <= a.fch_mov
                      AND d.fchinicio + d.dias - 1 >= a.fch_mov
                      AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                 THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                 ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                           THEN d.dias
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio <= a.fch_mov + a.diastr - 1
                                          AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                     THEN DATEDIFF(dd, d.fchinicio, a.fch_mov + a.diastr)
                                     ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                    AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                               THEN a.diastr
                                               ELSE 0
                                          END
                                END
                      END
            END AS 'incap'
    INTO    #tmp_incap
    FROM    #tmp_inf AS a
            LEFT JOIN deducciones AS d ON a.empresa = d.empresa
                                          AND a.codigo = d.codigo
    WHERE   a.empresa = @nempresa
            AND a.diastr > 0
            AND a.ayo_operacion = @nayo
            AND a.mes_operacion = @nmes_non
            AND (d.num_conc = 109 
                 OR d.num_conc = 110 
                 OR d.num_conc = 111
                ) 
            AND ( ( d.fchinicio <= a.fch_mov 
                    AND d.fchtermino >= a.fch_mov
                    AND d.fchinicio <= a.fch_mov + a.diastr - 1
                  )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchtermino <= a.fch_mov + a.diastr - 1
                     )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchinicio <= a.fch_mov + a.diastr - 1
                       AND d.fchtermino >= a.fch_mov + a.diastr - 1
                     )
                  OR ( d.fchinicio <= a.fch_mov
                       AND d.fchtermino >= a.fch_mov + a.diastr - 1
                     )
                )   
    
-- pasa de la tabla #tmp_incap el ajuste de las incapacidades
    UPDATE  a
    SET     a.incap = ISNULL(( SELECT   SUM(b.incap)
                               FROM     #tmp_incap AS b
                               WHERE    a.empresa = b.empresa
                                        AND a.codigo = b.codigo
                                        AND a.ayo_operacion = b.ayo_operacion
                                        AND a.mes_operacion = b.mes_operacion
                                        AND a.serial = b.serial
                             ), 0)
    FROM    #tmp_inf AS a
    WHERE   a.diastr > 0

-- ajusta los ausentismos y los guarda en la 
-- tabla temporal #tmp_aus
    SELECT  a.empresa ,
            a.codigo ,
            a.ayo_operacion ,
            a.mes_operacion ,
            a.serial ,
            0 AS 'serial_bim' ,
            d.fchinicio ,
            d.dias ,
            CASE WHEN d.fchinicio <= a.fch_mov
                      AND d.fchinicio + d.dias - 1 >= a.fch_mov
                      AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                 THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                 ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1 
                           THEN d.dias
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio <= a.fch_mov + a.diastr - 1
                                          AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                     THEN DATEDIFF(dd, d.fchinicio, a.fch_mov + a.diastr)
                                     ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                    AND d.fchinicio + d.dias - 1 >= a.fch_mov + a.diastr - 1
                                               THEN a.diastr
                                               ELSE 0
                                          END
                                END
                      END
            END AS 'aus' ,
            @naus_non AS 'aus_non' ,
            @naus_par AS 'aus_par'
    INTO    #tmp_aus
    FROM    #tmp_inf AS a
            LEFT JOIN deducciones AS d ON a.empresa = d.empresa
                                          AND a.codigo = d.codigo
                                          AND a.ayo_operacion = d.ayo_operacion
                                          AND d.mes_operacion = @nmes_non
                                          AND d.num_conc = 108
    WHERE   a.diastr > 0

-- los registros que no tengan ausentismo
-- los borra 
    DELETE  #tmp_aus
    WHERE   aus = 0

-- inicializa en ceros los ausentismos 
-- para cada mes (non y par)
    UPDATE  #tmp_aus
    SET     aus_non = CASE WHEN MONTH(fchinicio) = MONTH(@dfch_ini_non)
                           THEN aus
                           ELSE 0
                      END

    SET @nfolio = 0

-- reconstruye folio
    UPDATE  #tmp_aus
    SET     @nfolio = CASE WHEN @ncodant <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodant = codigo 


-- ajusta al tope los dias de ausentismo para cada mes (non y par)
    UPDATE  t
    SET     @ndias_non = CASE WHEN t.serial_bim = 1 THEN 0
                              ELSE @ndias_non
                         END ,
            @ndias_par = CASE WHEN t.serial_bim = 1 THEN 0
                              ELSE @ndias_par
                         END ,
            @ndias_non = @ndias_non + CASE WHEN t.aus_non IS NULL THEN 0
                                           ELSE t.aus_non
                                      END ,
            @ndias_par = @ndias_par + CASE WHEN t.aus_par IS NULL THEN 0
                                           ELSE t.aus_par
                                      END ,
            t.aus_non = CASE WHEN @ndias_non < @ndias_tope THEN t.aus_non
                             ELSE CASE WHEN t.aus_non - ( @ndias_non - @ndias_tope ) < 0
                                       THEN 0
                                       ELSE t.aus_non - ( @ndias_non - @ndias_tope )
                                  END
                        END ,
            t.aus_par = CASE WHEN @ndias_par < @ndias_tope THEN t.aus_par
                             ELSE CASE WHEN t.aus_par - ( @ndias_par - @ndias_tope ) < 0
                                       THEN 0
                                       ELSE t.aus_par - ( @ndias_par - @ndias_tope )
                                  END
                        END
    FROM    #tmp_aus AS t


-- pasa el ajuste de ausentismo a la tabla #tmp_inf
    UPDATE  a
    SET     a.ausen = ( SELECT  SUM(b.aus_non) + SUM(b.aus_par)
                        FROM    #tmp_aus AS b
                        WHERE   a.empresa = b.empresa
                                AND a.codigo = b.codigo
                                AND a.ayo_operacion = b.ayo_operacion
                                AND a.mes_operacion = b.mes_operacion
                                AND a.serial = b.serial
                      )
    FROM    #tmp_inf AS a
    WHERE   a.diastr > 0


-- para los registros que tienen null en ausen poner cero
    UPDATE  #tmp_inf
    SET     ausen = 0
    WHERE   empresa = @nempresa
            AND ayo_operacion = @nayo
            AND mes_operacion = @nmes_non
            AND codigo BETWEEN @ninicio AND @nfin
            AND ausen IS NULL


-- los creditos que su fecha de otorgamiento hasta el 30/01/1998 
-- y tengan tipo 1 y que el porcentaje sea 20,25,30 
-- los ubica en la tabla de descuento
    UPDATE  #tmp_inf
    SET     ntd = CASE WHEN descuento = 20 AND fch_otorga <= '19980130' THEN 1
                       WHEN descuento = 25 AND fch_otorga <= '19980130' THEN 2
                       WHEN descuento = 30 AND fch_otorga <= '19980130' THEN 3
                       ELSE 0
                  END ,
            @nvsm = ROUND(saldiaint / @salarioMinimo,2),
            vsm = @nvsm ,
            info = CASE WHEN @nvsm >= 0.01
                             AND @nvsm <= 02.50
                             AND fch_otorga <= '19980130' THEN 1
                        WHEN @nvsm >= 2.51
                             AND @nvsm <= 03.50
                             AND fch_otorga <= '19980130' THEN 2
                        WHEN @nvsm >= 3.51
                             AND @nvsm <= 04.50
                             AND fch_otorga <= '19980130' THEN 3
                        WHEN @nvsm >= 4.51
                             AND @nvsm <= 05.50
                             AND fch_otorga <= '19980130' THEN 4
                        WHEN @nvsm >= 5.51
                             AND @nvsm <= 06.50
                             AND fch_otorga <= '19980130' THEN 5
                        WHEN @nvsm >= 6.51
                             AND @nvsm <= 99.99
                             AND fch_otorga <= '19980130' THEN 6
                        ELSE 0
                   END ,
            porc_abono = CASE descuento
                           WHEN 20
                           THEN CASE WHEN @nvsm >= 0.01
                                          AND @nvsm <= 02.50
                                          AND fch_otorga <= '19980130'
                                     THEN 15.7
                                     WHEN @nvsm >= 2.51
                                          AND @nvsm <= 03.50
                                          AND fch_otorga <= '19980130'
                                     THEN 16.8
                                     WHEN @nvsm >= 3.51
                                          AND @nvsm <= 04.50
                                          AND fch_otorga <= '19980130'
                                     THEN 17.2
                                     WHEN @nvsm >= 4.51
                                          AND @nvsm <= 05.50
                                          AND fch_otorga <= '19980130'
                                     THEN 17.7
                                     WHEN @nvsm >= 5.51
                                          AND @nvsm <= 06.50
                                          AND fch_otorga <= '19980130'
                                     THEN 17.8
                                     WHEN @nvsm >= 6.51
                                          AND @nvsm <= 99.99
                                          AND fch_otorga <= '19980130'
                                     THEN 20.0
                                     ELSE descuento
                                END
                           WHEN 25
                           THEN CASE WHEN @nvsm >= 0.01
                                          AND @nvsm <= 02.50
                                          AND fch_otorga <= '19980130'
                                     THEN 19.6
                                     WHEN @nvsm >= 2.51
                                          AND @nvsm <= 03.50
                                          AND fch_otorga <= '19980130'
                                     THEN 21.0
                                     WHEN @nvsm >= 3.51
                                          AND @nvsm <= 04.50
                                          AND fch_otorga <= '19980130'
                                     THEN 21.5
                                     WHEN @nvsm >= 4.51
                                          AND @nvsm <= 05.50
                                          AND fch_otorga <= '19980130'
                                     THEN 22.1
                                     WHEN @nvsm >= 5.51
                                          AND @nvsm <= 06.50
                                          AND fch_otorga <= '19980130'
                                     THEN 22.3
                                     WHEN @nvsm >= 6.51
                                          AND @nvsm <= 99.99
                                          AND fch_otorga <= '19980130'
                                     THEN 25.0
                                     ELSE descuento
                                END
                           WHEN 30
                           THEN CASE WHEN @nvsm >= 0.01
                                          AND @nvsm <= 02.50
                                          AND fch_otorga <= '19980130'
                                     THEN 24.6
                                     WHEN @nvsm >= 2.51
                                          AND @nvsm <= 03.50
                                          AND fch_otorga <= '19980130'
                                     THEN 26.0
                                     WHEN @nvsm >= 3.51
                                          AND @nvsm <= 04.50
                                          AND fch_otorga <= '19980130'
                                     THEN 26.5
                                     WHEN @nvsm >= 4.51
                                          AND @nvsm <= 05.50
                                          AND fch_otorga <= '19980130'
                                     THEN 27.1
                                     WHEN @nvsm >= 5.51
                                          AND @nvsm <= 06.50
                                          AND fch_otorga <= '19980130'
                                     THEN 27.3
                                     WHEN @nvsm >= 6.51
                                          AND @nvsm <= 99.99
                                          AND fch_otorga <= '19980130'
                                     THEN 30.0
                                     ELSE descuento
                                END
                           ELSE descuento
                         END
    WHERE   tipo_cred = 1

    UPDATE  #tmp_inf
    SET     amortizacion = CASE tipo_cred
                             WHEN 1
                             THEN saldiaint * ( diastr - ausen - CASE WHEN @cconvenio = 'CONVENIO'
                                                                      THEN 0
                                                                      ELSE incap
                                                                 END ) * ( porc_abono / 100 )
                             WHEN 2
                             THEN ( ( descuento * 2 ) / @ndiasprop ) * CASE WHEN @cdiaslab = 'S'
                                                                            THEN ( diastr - ausen - CASE WHEN @cconvenio = 'CONVENIO'
                                                                                                         THEN 0
                                                                                                         ELSE incap
                                                                                                    END )
                                                                            ELSE ( diastr - ausen - CASE WHEN @cconvenio = 'CONVENIO'
                                                                                                         THEN 0
                                                                                                         ELSE incap
                                                                                                    END )
                                                                       END
                             WHEN 3
                             THEN ( ( descuento * 2 * @nsaldf ) / @ndiasprop ) * ( diastr - ausen - CASE WHEN @cconvenio = 'CONVENIO'
                                                                                                         THEN 0
                                                                                                         ELSE incap
                                                                                                    END )
                             ELSE 0
                           END
                   
                   
    INSERT  [dbo].[TemporalAmortizacion]
            ( empresa ,
              codigo ,
              descuento,
              clase
            )
            SELECT DISTINCT
                    Tmp_Inf.empresa ,
                    Tmp_Inf.codigo ,
                    CASE WHEN Tmp_Inf.tipo_cred = 2 OR Tmp_Inf.tipo_cred = 3 
                         THEN Tmp_Inf.porc_abono
                         ELSE CASE WHEN @cpropcred = 'S' 
                                   THEN Tmp_Inf.porc_abono 
                                   ELSE 0 
                              END
                    END,
                    Tmp_Inf.clase
            FROM    #tmp_inf AS Tmp_Inf
            WHERE   Tmp_Inf.empresa = @nempresa
                    AND Tmp_Inf.codigo BETWEEN @ninicio AND @nfin


    UPDATE  TemporalAmortizacion
    SET     TemporalAmortizacion.amortizacion = ISNULL(( SELECT SUM(Tmp_Inf.amortizacion)
                                                         FROM #tmp_inf AS Tmp_Inf
                                                         WHERE Tmp_Inf.empresa = TemporalAmortizacion.empresa
                                                               AND Tmp_Inf.codigo = TemporalAmortizacion.codigo
                                                       ), 0)
    FROM    [dbo].[TemporalAmortizacion] AS TemporalAmortizacion

    DROP TABLE #tmp_inf
    DROP TABLE #tmp_incap
    DROP TABLE #tmp_aus
END    
GO

IF OBJECT_ID('dbo.CalculaAmortizacionProcedure') IS NOT NULL
   DROP  PROCEDURE [dbo].[CalculaAmortizacionProcedure]
GO
CREATE PROCEDURE [dbo].[CalculaAmortizacionProcedure]
    @nempresa NUMERIC(5, 0) ,
    @nayo INT ,
    @nmes_non INT ,
    @nmes_par INT ,
    @ndias_tope DECIMAL(5, 2) ,
    @czonageo CHAR(1) ,
    @ncodigo NUMERIC(8, 0),
    @esBimestre CHAR(1) ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS 

    DELETE  [dbo].[TemporalAmortizacion]
    WHERE   empresa = @nempresa

    DECLARE @nserial_bim INT
    DECLARE @nfolio INT
    DECLARE @csw CHAR(1)
    DECLARE @namortiza NUMERIC(12, 2)
    DECLARE @ninicio NUMERIC(8, 0)
    DECLARE @nfin NUMERIC(8, 0)
    DECLARE @naus_non DECIMAL(5, 2) 
    DECLARE @naus_par DECIMAL(5, 2) 
    DECLARE @ncodant NUMERIC(8, 0)
    DECLARE @ndias_non NUMERIC(5, 0)
    DECLARE @ndias_par NUMERIC(5, 0)
    DECLARE @nntd INT
    DECLARE @ninfo INT
    DECLARE @nporc_abono NUMERIC(8, 4)
    DECLARE @cDiasLab CHAR(1)
    DECLARE @cRetenido CHAR(1)
    DECLARE @cPropCred CHAR(1)
    DECLARE @cConvenio CHAR(8)
    DECLARE @nsaldiaint NUMERIC(12, 2)
    DECLARE @nvsm NUMERIC(12, 2)
    DECLARE @nseg_viv NUMERIC(5, 2)
    DECLARE @dfch_ini_non DATETIME  -- @dfch_fin   datetime 
    DECLARE @dfch_fin_non DATETIME  -- @dfch_ini   datetime
    DECLARE @dfch_ini_par DATETIME
    DECLARE @dfch_fin_par DATETIME
    DECLARE @ndiasprop INT
    DECLARE @ndiasnon INT
    DECLARE @ndiaspar INT
    --DECLARE @nsal_a NUMERIC(10, 02)
    --DECLARE @nsal_b NUMERIC(10, 02)
    --DECLARE @nsal_c NUMERIC(10, 02)
    --DECLARE @nsal_df NUMERIC(10, 02)
    --DECLARE @nsal_min NUMERIC(10, 02)
    --DECLARE @dfch_sube DATETIME
    DECLARE @nsaldf NUMERIC(10, 02)
    DECLARE @nsalmin NUMERIC(10, 02)
    --DECLARE @dfchinisal DATETIME
    --DECLARE @dfchfinsal DATETIME 
    DECLARE @usaInfonavit CHAR(1)
    DECLARE @fchMovSuspension DATETIME
    DECLARE @movSuspension CHAR(2)

    DECLARE @salarioRegionA FLOAT
    DECLARE @salarioRegionB FLOAT
    DECLARE @salarioRegionC FLOAT
    
    DECLARE @seleccionSalarioMinimo CHAR(1)
    DECLARE @salarioMinimo FLOAT

    DECLARE @periodoInicioUMA VARCHAR(6)
    SET @periodoInicioUMA = RIGHT(STR(10000 + @nayo), 4) + RIGHT(STR(100 + @nmes_non), 2)
    
    SELECT @seleccionSalarioMinimo = ISNULL(dbo.empresas.usarSalarioMinimo,'R')
    FROM dbo.empresas
    WHERE dbo.empresas.empresa = @nempresa

-- saca parametros infonavit
    SELECT  @cDiasLab = CASE WHEN hrs_min2 = 999 THEN 'N'
                             ELSE 'S'
                        END ,
            @cRetenido = CASE WHEN hrs_min3 = 999 THEN 'S'
                              ELSE 'N'
                         END ,
            @cPropCred = CASE WHEN marca2 = 'M' THEN 'N'
                              ELSE 'S'
                         END ,
            @cConvenio = RTRIM(LTRIM(variable1)),
            @usaInfonavit = uso
    FROM    conceptos
    WHERE   empresa = @nempresa
            AND num_conc = 112
            
--SELECT @cPropCred            


IF @usaInfonavit = 'S'
BEGIN
    --SET @nsal_df = 0
    --SET @nsal_min = 0
    --SET @dfch_sube = ' '
    SET @nsaldf = 0
    SET @nsalmin = 0
    SET @namortiza = 0
    SET @nserial_bim = 0
    SET @nfolio = 0
    SET @csw = 'F'
    SET @nntd = 0
    SET @ninfo = 0
    SET @nporc_abono = 0
    SET @nsaldiaint = 0
    SET @nvsm = 0
    SET @nseg_viv = 0
    SET @dfch_ini_non = CAST(SUBSTRING(LTRIM(STR(@nayo + 10000)), 2, 4)
        + SUBSTRING(LTRIM(STR(@nmes_non + 100)), 2, 2) + '01' AS DATETIME)
    SET @dfch_fin_non = dbo.fin_mes(@nmes_non, @nayo)
    SET @ndiasnon = DATEDIFF(dd, @dfch_ini_non, @dfch_fin_non) + 1


    SET @ndiaspar = 0

    IF @nmes_par % 2 = 0 
        BEGIN
            SET @dfch_ini_par = CAST(SUBSTRING(LTRIM(STR(@nayo + 10000)), 2, 4)
                + SUBSTRING(LTRIM(STR(@nmes_par + 100)), 2, 2) + '01' AS DATETIME)
            SET @dfch_fin_par = dbo.fin_mes(@nmes_par, @nayo)
            SET @ndiaspar = CASE WHEN @nmes_par % 2 = 0
                                 THEN DATEDIFF(dd, @dfch_ini_par,
                                               @dfch_fin_par) + 1
                                 ELSE 0
                            END
        END
        
    SET @ndiasprop = DATEDIFF(dd, @dfch_ini_non,
                              CASE WHEN @nmes_par % 2 = 1
                                   THEN dbo.fin_mes(@nmes_par + 1, @nayo)
                                   ELSE @dfch_fin_par
                              END) + 1


--SELECT @dfch_ini_non,@dfch_fin_non,@dfch_ini_par,@dfch_fin_par

-- si la variable @ncodigo es cero
-- va a afectar a todos los trabajadores
-- si no solo afecta al codigo deseado 
    IF @ncodigo = 0 
        BEGIN
            SET @ninicio = 1
            SET @nfin = 99999999
        END
    ELSE 
        BEGIN
            SET @ninicio = @ncodigo
            SET @nfin = @ncodigo
        END

/*
-- sacar salarios minimos 
    DECLARE sal_min CURSOR
    FOR
    SELECT fecha_ini,
    fecha_fin,
    zona_a   ,
    zona_b   ,
    zona_c
    FROM salarios_minimos

    OPEN sal_min 


    FETCH NEXT FROM sal_min INTO @dfchinisal, @dfchfinsal, @nsal_a, @nsal_b, @nsal_c

    WHILE ( @@fetch_status <> -1 ) 
        BEGIN
            IF @dfchinisal <= @dfch_ini_non
                AND @dfchfinsal >= @dfch_ini_non
                AND @dfchfinsal <= CASE WHEN @nmes_par % 2 = 0
                                        THEN @dfch_fin_par
                                        ELSE @dfch_fin_non
                                   END 
                BEGIN
                    SET @nsal_df = @nsal_A
                    SET @nsal_min = CASE WHEN @czonageo = 'A' THEN @nsal_a
                                         WHEN @czonageo = 'B' THEN @nsal_b
                                         WHEN @czonageo = 'C' THEN @nsal_c
                                    END
                END
            ELSE 
                IF @dfchinisal >= @dfch_ini_non
                    AND @dfchfinsal <= CASE WHEN @nmes_par % 2 = 0
                                            THEN @dfch_fin_par
                                            ELSE @dfch_fin_non
                                       END 
                    BEGIN
                        SET @nsal_df = @nsal_a
                        SET @nsal_min = CASE WHEN @czonageo = 'A' THEN @nsal_a
                                             WHEN @czonageo = 'B' THEN @nsal_b
                                             WHEN @czonageo = 'C' THEN @nsal_c
                                        END
                    END
                ELSE 
                    IF @dfchinisal >= @dfch_ini_non
                        AND @dfchinisal <= CASE WHEN @nmes_par % 2 = 0
                                                THEN @dfch_fin_par
                                                ELSE @dfch_fin_non
                                           END
                        AND @dfchfinsal >= CASE WHEN @nmes_par % 2 = 0
                                                THEN @dfch_fin_par
                                                ELSE @dfch_fin_non
                                           END 
                        BEGIN 
                            SET @nsaldf = @nsal_a
                            SET @nsalmin = CASE WHEN @czonageo = 'A'
                                                THEN @nsal_a
                                                WHEN @czonageo = 'B'
                                                THEN @nsal_b
                                                WHEN @czonageo = 'C'
                                                THEN @nsal_c
                                           END
               
                            IF @dfchinisal > @dfch_ini_non 
                                SET @dfch_sube = @dfchinisal
                        END
                    ELSE 
                        IF @dfchinisal <= @dfch_ini_non
                            AND @dfchfinsal >= CASE WHEN @nmes_par % 2 = 0
                                                    THEN @dfch_fin_par
                                                    ELSE @dfch_fin_non
                                               END 
                            BEGIN
                                SET @nsaldf = @nsal_a
                                SET @nsalmin = CASE WHEN @czonageo = 'A'
                                                    THEN @nsal_a
                                                    WHEN @czonageo = 'B'
                                                    THEN @nsal_b
                                                    WHEN @czonageo = 'C'
                                                    THEN @nsal_c
                                               END
                            END
         
            FETCH NEXT FROM sal_min INTO @dfchinisal, @dfchfinsal, @nsal_a, @nsal_b, @nsal_c
        END

    DEALLOCATE sal_min
*/    


    SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
            @salarioRegionB = ISNULL(zona_b, 0) ,
            @salarioRegionC = ISNULL(zona_c, 0)
    FROM    [dbo].[GetMinimumWage](@nmes_non, @nayo)
    
    SET @nsaldf = @salarioRegionA
        
    SET @nsalmin = CASE @czonageo
                           WHEN 'A' THEN @salarioRegionA
                           WHEN 'B' THEN @salarioRegionB
                           WHEN 'C' THEN @salarioRegionC
                           ELSE 0
                         END
    
    IF @seleccionSalarioMinimo = 'D'
       SET @salarioMinimo = @nsaldf
    ELSE
       SET @salarioMinimo = @nsalmin
  

--SELECT @nsaldf, @nsalmin

-- creo una tabla temporal con movimientos del mes o bimestre
-- y los datos del credito infonavit
    SELECT  
            aItc.empresa ,
            aItc.ayo_operacion ,
            aItc.mes_operacion ,
            aItc.codigo ,
            aItc.serial ,
            @nserial_bim AS 'serial_bim' ,
            aItc.mov ,
            aItc.fch_mov ,
            CASE WHEN @periodoInicioUMA >= '201701' THEN CASE WHEN aItc.saldiaint > ROUND(aItc.umaDiario * 25,2) THEN ROUND(aItc.umaDiario * 25,2) ELSE aItc.saldiaint END ELSE aItc.saldiaint END AS saldiaint,
            aItc.diastr ,
            aItc.ausen ,
            aItc.incap ,
            i.tipo_cred ,
            i.descuento ,
            CASE WHEN i.fecha < @dfch_ini_non
                 THEN CASE WHEN @dfch_ini_non < aItc.fch_mov
                                AND aItc.mov = 'A' THEN aItc.fch_mov
                           ELSE @dfch_ini_non
                      END
                 ELSE CASE WHEN i.fecha < aItc.fch_mov
                                AND aItc.mov = 'A' THEN aItc.fch_mov
                           ELSE i.fecha
                      END
            END AS 'fch_cred' ,
            i.fch_otorga ,
            @namortiza AS 'amortizacion' ,
            @nntd AS 'ntd' ,
            @ninfo AS 'info' ,
            i.descuento AS 'porc_abono' ,
            @nporc_abono AS 'vsm' ,
            i.seguro_vivienda ,
            i.fecha ,
            i.fch_termino ,
            i.numcredito ,
            e.afiliacion ,
            e.digvera,
            dbo.Llaves.clase,
            CASE WHEN i.fechaSuspension >= @dfch_ini_non
                      AND i.fechaSuspension <= CASE WHEN @nmes_par % 2 = 0 
                                                    THEN @dfch_fin_par
                                                    ELSE @dfch_fin_non
                                               END 
                 THEN i.fechaSuspension
                 ELSE NULL
            END AS fechaSuspension,
            @movSuspension AS movSuspension,
            @fchMovSuspension AS fchMovSuspension
    INTO    #tmp_inf
    FROM    infonavit AS i
            INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON aItc.empresa = i.empresa
                                           AND aItc.codigo = i.codigo
                                           AND aItc.ayo_operacion = @nayo
                                           AND ( aItc.mes_operacion = @nmes_non
                                                 OR aItc.mes_operacion = @nmes_par
                                               )
            INNER JOIN empleados AS e ON e.empresa = i.empresa
                                         AND e.codigo = i.codigo
            INNER JOIN dbo.Llaves ON i.empresa = dbo.Llaves.empresa AND i.codigo = dbo.Llaves.codigo
    WHERE   i.empresa = @nempresa
            AND i.fecha <= CASE WHEN @nmes_par % 2 = 0 THEN @dfch_fin_par
                                ELSE @dfch_fin_non
                           END
            AND ( ( i.fch_termino >= @dfch_ini_non
                    AND CASE WHEN @nmes_par % 2 = 0 
                             THEN @dfch_fin_par
                             ELSE @dfch_fin_non
                        END <= i.fch_termino
                    AND (i.fechaSuspension IS NULL
                         OR i.fechaSuspension >= @dfch_ini_non
                        )     
                  )
                  OR i.fch_termino IS NULL
                  OR i.fch_termino = '19000101'
                )
            AND i.codigo BETWEEN @ninicio AND @nfin
            AND e.cotiza_imss = 'S'
            AND e.borrado = 'N'
            AND aItc.horaProceso = @horaProceso
            AND aItc.fechaProceso = @fechaProceso
            AND aItc.proceso = @proceso
    ORDER BY aItc.codigo ,
            aItc.ayo_operacion ,
            aItc.mes_operacion ,
            aItc.serial
            
--SELECT 1,* FROM #tmp_inf WHERE codigo = 1000
            
   
    -- Cambia la Alta a Ringreso cuando hay una baja anterior
    -- porque tomaba el inicio del credito apartir de la ultima alta
    -- 07/03/2012
    -- jorge Mtz
    -- Reportado por Mario Esparza
    -- Empresa Zebra
    DECLARE @codigoAnterior INT
    DECLARE @movimientoAnterior varchar(2)
    DECLARE @movimientoActual VARCHAR(2)
    DECLARE @fechaCredito DATETIME
    DECLARE @fechaCreditoActual DATETIME
    
    SET @codigoAnterior = 0        
    SET @movimientoAnterior = ''

    UPDATE  t1
    SET     @fechaCredito = CASE WHEN @codigoAnterior <> t1.codigo THEN t1.fch_cred ELSE @fechaCredito END,
            @movimientoActual = CASE WHEN @codigoAnterior = t1.codigo AND RTRIM(LTRIM(t1.mov)) = 'A' AND @movimientoAnterior = 'B' THEN 'RI' ELSE t1.mov END,
            @fechaCreditoActual = CASE WHEN @codigoAnterior = t1.codigo AND RTRIM(LTRIM(t1.mov)) = 'A' AND @movimientoAnterior = 'B' THEN @fechaCredito ELSE t1.fch_cred END,
            @codigoAnterior = t1.codigo,
            @movimientoAnterior = RTRIM(LTRIM(t1.mov)),
            t1.mov = @movimientoActual ,
            t1.fch_cred = @fechaCreditoActual
    FROM    #tmp_inf AS t1
    -- Fin Rutina Cambia Alta a Reingreso

   
--SELECT 2,* FROM #tmp_inf WHERE codigo = 1000
            
--SELECT * FROM #tmp_inf ORDER BY codigo            

-- para los creditos que tengan fecha de otorgamiento 
-- hasta el 30/01/1998 y sean tipo 1
-- poner el saldiaint de inicio de bimestre en todos 
-- los movimientos del trabajador
    UPDATE  a
    SET     a.saldiaint = ( SELECT TOP 1
                                    b.saldiaint
                            FROM    #tmp_inf AS b
                            WHERE   b.empresa = a.empresa
                                    AND b.codigo = a.codigo
                                    AND b.diastr > 0
                          )
    FROM    #tmp_inf AS a
    WHERE   a.tipo_cred = 1
            AND a.fch_otorga <= '19980130'
            AND @cpropcred = 'S'
            AND ( porc_abono = 20
                  OR porc_abono = 25
                  OR porc_abono = 30
                )



-- cuando es bimestre borra el registro de IM del mes par
-- para mas delante calcular los dias por bimestre
    IF @nmes_par = 02
        OR @nmes_par = 04
        OR @nmes_par = 06
        OR @nmes_par = 08
        OR @nmes_par = 10
        OR @nmes_par = 12 
        BEGIN
            DELETE  #tmp_inf
            WHERE   mov = 'IM'
                    AND diastr = 0
        END



-- inicializa en ceros el campo diastr
-- y asigna un folio consecituvo en campo serial_bim
    SET @ncodigo = 0

    UPDATE  #tmp_inf
    SET     diastr = 0 ,
            @nfolio = CASE WHEN @ncodigo <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodigo = codigo


-- calcula dias cotizados 
    UPDATE  t1
    SET     t1.diastr = CASE WHEN t1.fch_mov = t2.fch_mov
                                  AND t2.mov <> 'B' THEN 0
                             ELSE CASE WHEN t2.fch_mov IS NULL
                                       THEN DATEDIFF(dd, t1.fch_mov,
                                                     --CASE WHEN @nmes_par % 2 = 0
                                                     --     THEN @dfch_fin_par
                                                     --     ELSE @dfch_fin_non
                                                     --END
                                                     CASE WHEN @esBimestre = 'S'
                                                          THEN @dfch_fin_par
                                                          ELSE CASE WHEN MONTH(t1.fch_mov) % 2 = 0
                                                                    THEN @dfch_fin_par
                                                                    ELSE @dfch_fin_non
                                                               END
                                                     END
                                                     ) + 1
                                       ELSE DATEDIFF(dd, t1.fch_mov,
                                                     t2.fch_mov)
                                            + CASE WHEN t2.mov = 'B' THEN 1
                                                   ELSE 0
                                              END
                                  END
                        END
    FROM    #tmp_inf AS t1
    LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo AND t1.serial_bim + 1 = t2.serial_bim

--SELECT 3,* FROM #tmp_inf WHERE codigo = 1000

-- dependiendo de la fecha del credito la acomoda
-- entre los avisos
    /*
    SELECT  t1.fch_cred AS fch_cred,
            t1.fch_mov  AS fch_mov,
            t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END AS fch_mov2,
            t1.diastr ,
    CASE WHEN t1.fch_cred >= t1.fch_mov 
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov <> 'B' 
                          THEN 'CR'
                          ELSE t1.mov
                     END ,
            CASE WHEN t1.fch_cred >= t1.fch_mov
                                   AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                                   AND t1.mov <> 'B' 
                              THEN t1.fch_cred
                              ELSE t1.fch_mov
                         END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial_bim + 1 = t2.serial_bim
    WHERE t1.codigo = 1000
    */ 

    UPDATE  t1
    SET     t1.mov = CASE WHEN t1.fch_cred >= t1.fch_mov 
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov <> 'B' 
                          THEN 'CR'
                          ELSE t1.mov
                     END ,
            t1.fch_mov = CASE WHEN t1.fch_cred >= t1.fch_mov
                                   AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                                   AND t1.mov <> 'B' 
                              THEN t1.fch_cred
                              ELSE t1.fch_mov
                         END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial

--SELECT 4,* FROM #tmp_inf WHERE codigo = 1000

-- pone la marca 'CR' dependiendo de cuando inicie el credito
    /* 
    SELECT t1.fch_cred AS fch_cred,
           t1.fch_mov AS fch_mov,
           t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END AS fch_mov2,
           t1.diastr ,
          CASE WHEN (SELECT TOP 1
                                                 t3.mov
                                          FROM #tmp_inf AS t3 
                                          WHERE t1.codigo = t3.codigo
                                                AND t3.serial_bim < t1.serial_bim
                                          ORDER BY t3.serial_bim DESC) = 'CR'
                                    THEN t2.mov
                                    ELSE 'CR'
              end                            
                                          ,
           CASE WHEN t1.fch_cred >= t1.fch_mov
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov = 'B' 
                          THEN CASE WHEN (SELECT TOP 1
                                                 t3.mov
                                          FROM #tmp_inf AS t3 
                                          WHERE t1.codigo = t3.codigo
                                                AND t3.serial_bim < t1.serial_bim
                                          ORDER BY t3.serial_bim DESC) = 'CR'
                                    THEN t2.mov
                                    ELSE 'CR'
              end                            
                          ELSE t2.mov
                     END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial_bim + 1 = t2.serial_bim
    WHERE t1.codigo = 1000
    */

    UPDATE  t2
    SET     t2.mov = CASE WHEN t1.fch_cred >= t1.fch_mov
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov = 'B' 
                          THEN CASE WHEN (SELECT TOP 1    -- Rutina Nueva 20140306
                                                 t3.mov
                                          FROM #tmp_inf AS t3 
                                          WHERE t1.codigo = t3.codigo
                                                AND t3.serial_bim < t1.serial_bim
                                          ORDER BY t3.serial_bim DESC) = 'CR'
                                    THEN t2.mov
                                    ELSE 'CR'
                               end                            
                          --'CR'
                          ELSE t2.mov
                     END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial


--SELECT 5,* FROM #tmp_inf WHERE codigo = 1000
--SELECT *
--FROM    #tmp_inf AS t1
--LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
--                            AND t1.serial + 1 = t2.serial
--ORDER BY t1.codigo

-- dependiendo de la fecha de SUSPENSION la acomoda
-- entre los avisos
    UPDATE  t1
    SET     t1.movSuspension = CASE WHEN t1.fechaSuspension >= t1.fch_mov
                                         AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
                                         AND t1.mov <> 'B'
                                    THEN 'SC'  -- SC = suspension credito
                                    ELSE NULL
                               END,
            t1.fchMovSuspension = CASE WHEN t1.fechaSuspension >= t1.fch_mov
                                            AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
                                            AND t1.mov <> 'B'
                                       THEN t1.fechaSuspension
                                       ELSE NULL 
                                  END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial


--SELECT * FROM #tmp_inf WHERE codigo = 7629

--SELECT t1.codigo, t2.codigo, CASE WHEN t1.fechaSuspension >= t1.fch_mov
--                 AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
--                 AND t1.mov <> 'B'
--            THEN 'SC'  -- SC = suspension credito
--            ELSE NULL
--       END,
--       CASE WHEN t1.fechaSuspension >= t1.fch_mov
--                 AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
--                 AND t1.mov <> 'B'
--            THEN t1.fechaSuspension
--            ELSE NULL 
--       END
--    FROM    #tmp_inf AS t1
--            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
--                                        AND t1.serial + 1 = t2.serial



-- pone la marca 'SC' dependiendo de cuando suspenda el credito
--    UPDATE  t2
--    SET     t2.movSuspension = CASE WHEN t1.fechaSuspension >= t1.fch_mov
--                               AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
--                               AND t1.mov = 'B'
--                          THEN 'SC'
--                          ELSE NULL
--                     END
--    FROM    #tmp_inf AS t1
--            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
--                                        AND t1.serial + 1 = t2.serial


--SELECT t1.codigo, t2.codigo, CASE WHEN t1.fechaSuspension >= t1.fch_mov
--                 AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
--                 AND t1.mov = 'B'
--            THEN 'SC'
--            ELSE NULL
--       END
--FROM    #tmp_inf AS t1
--            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
--                                        AND t1.serial + 1 = t2.serial


--SELECT * FROM #tmp_inf WHERE codigo = 7629

-- vuelve a calcular los dias cotizados
-- los avisos anteriores a la marca CR no les calcula
-- dias los deja en ceros
    UPDATE  t1
    SET     @csw = CASE WHEN t1.serial_bim = 1 
                        THEN 'F'
                        ELSE @csw
                   END ,
            @csw = CASE WHEN t1.mov = 'CR' AND @csw = 'F' 
                        THEN 'T'
                        ELSE @csw
                   END ,
            t1.diastr = CASE WHEN @csw = 'T'
                             THEN CASE WHEN t1.mov = 'B' 
                                       THEN 0
                                       ELSE CASE WHEN t1.fch_mov = t2.fch_mov AND t2.mov <> 'B' 
                                                 THEN 0
                                                 ELSE CASE WHEN t2.fch_mov IS NULL
                                                           THEN DATEDIFF(dd,t1.fch_mov,
                                                                         CASE WHEN @esBimestre = 'S'
                                                                              THEN @dfch_fin_par
                                                                              ELSE CASE WHEN MONTH(t1.fch_mov) % 2 = 0
                                                                                        THEN @dfch_fin_par
                                                                                        ELSE @dfch_fin_non
                                                                                   END
                                                                         END
                                                                        ) + 1
                                                           ELSE DATEDIFF(dd,t1.fch_mov,t2.fch_mov) + CASE WHEN t2.mov = 'B'
                                                                                                          THEN 1
                                                                                                          ELSE 0
                                                                                                     END
                                                      END
                                            END
                                  END
                             ELSE 0
                        END
    FROM    #tmp_inf AS t1
    LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo AND t1.serial_bim + 1 = t2.serial_bim
    

--SELECT 6,* FROM #tmp_inf WHERE codigo = 1000
    
    UPDATE  tempInf
    SET     tempInf.diastr = DATEDIFF(dd, tempInf.fch_mov,
                                      tempInf.fchMovSuspension) + 1
    FROM    #tmp_inf AS tempInf
    WHERE   tempInf.fchMovSuspension IS NOT NULL

--SELECT 7,* FROM #tmp_inf WHERE codigo = 1000


--SELECT * FROM #tmp_inf WHERE codigo = 7629

-- borra los registros anteriores a CR
-- no tiene caso que esten en la tabla 
-- puesto que no se va usar ese registro
-- para calcular la amotizacion
    DELETE  t1
    FROM    #tmp_inf AS t1
            INNER JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                         AND t2.mov = 'CR'
                                         AND t1.fch_mov < t2.fch_mov


-- borra los registros posteriores a SC
-- no tiene caso que esten en la tabla 
-- puesto que no se va usar ese registro
-- para calcular la amotizacion
    DELETE  t1
    FROM    #tmp_inf AS t1
            INNER JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                         AND t2.movSuspension = 'SC'
                                         AND t1.fch_mov > t2.fechaSuspension
                                         


--SELECT * FROM #tmp_inf WHERE codigo = 7629

-- vuelve a reconstruir el folio
    SET @ncodigo = 0
    UPDATE  #tmp_inf
    SET     @nfolio = CASE WHEN @ncodigo <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodigo = codigo


    UPDATE  a
    SET     a.incap = 0 ,
            a.ausen = 0
    FROM    #tmp_inf AS a


-- ajusta los dias de incapcidad para cada movimiento
-- y lo guarda en la tabla temporal @tmp_incap
    SELECT  a.empresa ,
            a.codigo ,
            a.ayo_operacion ,
            a.mes_operacion ,
            a.serial ,
            CASE WHEN d.fchinicio <= a.fch_mov
                      AND d.fchinicio + d.dias - 1 >= a.fch_mov
                      AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                 THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                 ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov
                                + a.diastr - 1 THEN d.dias
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio <= a.fch_mov
                                          + a.diastr - 1
                                          AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                          + a.diastr - 1
                                     THEN DATEDIFF(dd, d.fchinicio,
                                                   a.fch_mov + a.diastr)
                                     ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                    AND d.fchinicio + d.dias
                                                    - 1 >= a.fch_mov
                                                    + a.diastr - 1
                                               THEN a.diastr
                                               ELSE 0
                                          END
                                END
                      END
            END AS 'incap'
    INTO    #tmp_incap
    FROM    #tmp_inf AS a
            LEFT JOIN deducciones AS d ON a.empresa = d.empresa
                                          AND a.codigo = d.codigo --and a.ayo_operacion = d.ayo_operacion and a.mes_operacion = d.mes_operacion and d.num_conc between 109 and 111
    --WHERE   a.diastr > 0
    --        AND a.ayo_operacion = @nayo
    --        AND a.mes_operacion IN ( @nmes_non, @nmes_par )
    --        AND d.num_conc BETWEEN 109 AND 111
    --        AND d.mes_operacion IN (@nmes_non, @nmes_par)
    --        AND d.ayo_operacion = @nayo
    WHERE   a.empresa = @nempresa
            AND a.diastr > 0
            AND a.ayo_operacion = @nayo
            AND (a.mes_operacion = @nmes_non
                 OR a.mes_operacion = @nmes_par)
            AND (d.num_conc = 109 
                 OR d.num_conc = 110 
                 OR d.num_conc = 111
                ) 
            AND ( ( d.fchinicio <= a.fch_mov 
                    AND d.fchtermino >= a.fch_mov
                    AND d.fchinicio <= a.fch_mov
                    + a.diastr - 1
                  )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchtermino <= a.fch_mov
                       + a.diastr - 1
                     )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchinicio <= a.fch_mov
                           + a.diastr - 1
                       AND d.fchtermino >= a.fch_mov
                           + a.diastr - 1
                     )
                  OR ( d.fchinicio <= a.fch_mov
                       AND d.fchtermino >= a.fch_mov
                       + a.diastr - 1
                     )
                )   
    


-- pasa de la tabla #tmp_incap el ajuste de las incapacidades
    UPDATE  a
    SET     a.incap = ISNULL(( SELECT   SUM(b.incap)
                               FROM     #tmp_incap AS b
                               WHERE    a.empresa = b.empresa
                                        AND a.codigo = b.codigo
                                        AND a.ayo_operacion = b.ayo_operacion
                                        AND a.mes_operacion = b.mes_operacion
                                        AND a.serial = b.serial
                             ), 0)
    FROM    #tmp_inf AS a
    WHERE   a.diastr > 0


-- ajusta los ausentismos y los guarda en la 
-- tabla temporal #tmp_aus
    SELECT  a.empresa ,
            a.codigo ,
            a.ayo_operacion ,
            a.mes_operacion ,
            a.serial ,
            0 AS 'serial_bim' ,
            d.fchinicio ,
            d.dias ,
            CASE WHEN d.fchinicio <= a.fch_mov
                      AND d.fchinicio + d.dias - 1 >= a.fch_mov
                      AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                 THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                 ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov
                                + a.diastr - 1 THEN d.dias
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio <= a.fch_mov
                                          + a.diastr - 1
                                          AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                          + a.diastr - 1
                                     THEN DATEDIFF(dd, d.fchinicio,
                                                   a.fch_mov + a.diastr)
                                     ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                    AND d.fchinicio + d.dias
                                                    - 1 >= a.fch_mov
                                                    + a.diastr - 1
                                               THEN a.diastr
                                               ELSE 0
                                          END
                                END
                      END
            END AS 'aus' ,
            @naus_non AS 'aus_non' ,
            @naus_par AS 'aus_par'
    INTO    #tmp_aus
    FROM    #tmp_inf AS a
            LEFT JOIN deducciones AS d ON a.empresa = d.empresa
                                          AND a.codigo = d.codigo
                                          AND a.ayo_operacion = d.ayo_operacion
                                          AND ( d.mes_operacion = @nmes_non
                                                OR d.mes_operacion = @nmes_par
                                              )
                                          AND d.num_conc = 108
    WHERE   a.diastr > 0



-- los registros que no tengan ausentismo
-- los borra 
    DELETE  #tmp_aus
    WHERE   aus = 0


-- inicializa en ceros los ausentismos 
-- para cada mes (non y par)
    UPDATE  #tmp_aus
    SET     aus_non = CASE WHEN MONTH(fchinicio) = MONTH(@dfch_ini_non)
                           THEN aus
                           ELSE 0
                      END ,    --@nmes_non
            aus_par = CASE WHEN MONTH(fchinicio) = MONTH(@dfch_ini_par)
                           THEN aus
                           ELSE 0
                      END


    SET @nfolio = 0

-- reconstruye folio
    UPDATE  #tmp_aus
    SET     @nfolio = CASE WHEN @ncodant <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodant = codigo 


-- ajusta al tope los dias de ausentismo para cada mes (non y par)
    UPDATE  t
    SET     @ndias_non = CASE WHEN t.serial_bim = 1 THEN 0
                              ELSE @ndias_non
                         END ,
            @ndias_par = CASE WHEN t.serial_bim = 1 THEN 0
                              ELSE @ndias_par
                         END ,
            @ndias_non = @ndias_non + CASE WHEN t.aus_non IS NULL THEN 0
                                           ELSE t.aus_non
                                      END ,
            @ndias_par = @ndias_par + CASE WHEN t.aus_par IS NULL THEN 0
                                           ELSE t.aus_par
                                      END ,
            t.aus_non = CASE WHEN @ndias_non < @ndias_tope THEN t.aus_non
                             ELSE CASE WHEN t.aus_non - ( @ndias_non
                                                          - @ndias_tope ) < 0
                                       THEN 0
                                       ELSE t.aus_non - ( @ndias_non
                                                          - @ndias_tope )
                                  END
                        END ,
            t.aus_par = CASE WHEN @ndias_par < @ndias_tope THEN t.aus_par
                             ELSE CASE WHEN t.aus_par - ( @ndias_par
                                                          - @ndias_tope ) < 0
                                       THEN 0
                                       ELSE t.aus_par - ( @ndias_par
                                                          - @ndias_tope )
                                  END
                        END
    FROM    #tmp_aus AS t


-- pasa el ajuste de ausentismo a la tabla #tmp_inf
    UPDATE  a
    SET     a.ausen = ( SELECT  SUM(b.aus_non) + SUM(b.aus_par)
                        FROM    #tmp_aus AS b
                        WHERE   a.empresa = b.empresa
                                AND a.codigo = b.codigo
                                AND a.ayo_operacion = b.ayo_operacion
                                AND a.mes_operacion = b.mes_operacion
                                AND a.serial = b.serial
                      )
    FROM    #tmp_inf AS a
    WHERE   a.diastr > 0


-- para los registros que tienen null en ausen poner cero
    UPDATE  #tmp_inf
    SET     ausen = 0
    WHERE   empresa = @nempresa
            AND ayo_operacion = @nayo
            AND ( mes_operacion = @nmes_non
                  OR mes_operacion = @nmes_par
                )
            AND codigo BETWEEN @ninicio AND @nfin
            AND ausen IS NULL


-- los creditos que su fecha de otorgamiento hasta el 30/01/1998 
-- y tengan tipo 1 y que el porcentaje sea 20,25,30 
-- los ubica en la tabla de descuento
    UPDATE  #tmp_inf
    SET     ntd = CASE WHEN descuento = 20
                            AND fch_otorga <= '19980130' THEN 1
                       WHEN descuento = 25
                            AND fch_otorga <= '19980130' THEN 2
                       WHEN descuento = 30
                            AND fch_otorga <= '19980130' THEN 3
                       ELSE 0
                  END ,
            @nvsm = ROUND(saldiaint / @salarioMinimo,2), -- ROUND(saldiaint / @nsalmin, 2) ,  -- @nvsm = ROUND(saldiaint / @nsaldf, 2) ,
            vsm = @nvsm ,
            info = CASE WHEN @nvsm >= 0.01
                             AND @nvsm <= 02.50
                             AND fch_otorga <= '19980130' THEN 1
                        WHEN @nvsm >= 2.51
                             AND @nvsm <= 03.50
                             AND fch_otorga <= '19980130' THEN 2
                        WHEN @nvsm >= 3.51
                             AND @nvsm <= 04.50
                             AND fch_otorga <= '19980130' THEN 3
                        WHEN @nvsm >= 4.51
                             AND @nvsm <= 05.50
                             AND fch_otorga <= '19980130' THEN 4
                        WHEN @nvsm >= 5.51
                             AND @nvsm <= 06.50
                             AND fch_otorga <= '19980130' THEN 5
                        WHEN @nvsm >= 6.51
                             AND @nvsm <= 99.99
                             AND fch_otorga <= '19980130' THEN 6
                        ELSE 0
                   END ,
            porc_abono = CASE descuento
                           WHEN 20
                           THEN CASE WHEN @nvsm >= 0.01
                                          AND @nvsm <= 02.50
                                          AND fch_otorga <= '19980130'
                                     THEN 15.7
                                     WHEN @nvsm >= 2.51
                                          AND @nvsm <= 03.50
                                          AND fch_otorga <= '19980130'
                                     THEN 16.8
                                     WHEN @nvsm >= 3.51
                                          AND @nvsm <= 04.50
                                          AND fch_otorga <= '19980130'
                                     THEN 17.2
                                     WHEN @nvsm >= 4.51
                                          AND @nvsm <= 05.50
                                          AND fch_otorga <= '19980130'
                                     THEN 17.7
                                     WHEN @nvsm >= 5.51
                                          AND @nvsm <= 06.50
                                          AND fch_otorga <= '19980130'
                                     THEN 17.8
                                     WHEN @nvsm >= 6.51
                                          AND @nvsm <= 99.99
                                          AND fch_otorga <= '19980130'
                                     THEN 20.0
                                     ELSE descuento
                                END
                           WHEN 25
                           THEN CASE WHEN @nvsm >= 0.01
                                          AND @nvsm <= 02.50
                                          AND fch_otorga <= '19980130'
                                     THEN 19.6
                                     WHEN @nvsm >= 2.51
                                          AND @nvsm <= 03.50
                                          AND fch_otorga <= '19980130'
                                     THEN 21.0
                                     WHEN @nvsm >= 3.51
                                          AND @nvsm <= 04.50
                                          AND fch_otorga <= '19980130'
                                     THEN 21.5
                                     WHEN @nvsm >= 4.51
                                          AND @nvsm <= 05.50
                                          AND fch_otorga <= '19980130'
                                     THEN 22.1
                                     WHEN @nvsm >= 5.51
                                          AND @nvsm <= 06.50
                                          AND fch_otorga <= '19980130'
                                     THEN 22.3
                                     WHEN @nvsm >= 6.51
                                          AND @nvsm <= 99.99
                                          AND fch_otorga <= '19980130'
                                     THEN 25.0
                                     ELSE descuento
                                END
                           WHEN 30
                           THEN CASE WHEN @nvsm >= 0.01
                                          AND @nvsm <= 02.50
                                          AND fch_otorga <= '19980130'
                                     THEN 24.6
                                     WHEN @nvsm >= 2.51
                                          AND @nvsm <= 03.50
                                          AND fch_otorga <= '19980130'
                                     THEN 26.0
                                     WHEN @nvsm >= 3.51
                                          AND @nvsm <= 04.50
                                          AND fch_otorga <= '19980130'
                                     THEN 26.5
                                     WHEN @nvsm >= 4.51
                                          AND @nvsm <= 05.50
                                          AND fch_otorga <= '19980130'
                                     THEN 27.1
                                     WHEN @nvsm >= 5.51
                                          AND @nvsm <= 06.50
                                          AND fch_otorga <= '19980130'
                                     THEN 27.3
                                     WHEN @nvsm >= 6.51
                                          AND @nvsm <= 99.99
                                          AND fch_otorga <= '19980130'
                                     THEN 30.0
                                     ELSE descuento
                                END
                           ELSE descuento
                         END
    WHERE   tipo_cred = 1

    UPDATE  #tmp_inf
    SET     amortizacion = CASE tipo_cred
                             WHEN 1
                             THEN saldiaint * ( diastr - ausen
                                                - CASE WHEN @cconvenio = 'CONVENIO'
                                                       THEN 0
                                                       ELSE incap
                                                  END ) * ( porc_abono / 100 )
                             WHEN 2
                             THEN ( ( descuento * 2 ) / @ndiasprop )
                                  * CASE WHEN @cdiaslab = 'S'
                                         THEN ( diastr - ausen
                                                - CASE WHEN @cconvenio = 'CONVENIO'
                                                       THEN 0
                                                       ELSE incap
                                                  END )
                                         ELSE ( diastr - ausen
                                                - CASE WHEN @cconvenio = 'CONVENIO'
                                                       THEN 0
                                                       ELSE incap
                                                  END )
                                    END
                             WHEN 3
                             THEN ( ( descuento * 2 * @nsaldf ) / @ndiasprop )
                                  * ( diastr - ausen
                                      - CASE WHEN @cconvenio = 'CONVENIO'
                                             THEN 0
                                             ELSE incap
                                        END )
                             ELSE 0
                           END
                   
                   
    INSERT  [dbo].[TemporalAmortizacion]
            ( empresa ,
              codigo ,
              descuento,
              clase
            )
            SELECT DISTINCT
                    Tmp_Inf.empresa ,
                    Tmp_Inf.codigo ,
                    CASE WHEN Tmp_Inf.tipo_cred = 2 OR Tmp_Inf.tipo_cred = 3 
                         THEN Tmp_Inf.porc_abono
                         ELSE CASE WHEN @cpropcred = 'S' 
                                   THEN Tmp_Inf.porc_abono 
                                   ELSE 0 
                              END
                    END,
                    Tmp_Inf.clase
            FROM    #tmp_inf AS Tmp_Inf
            WHERE   Tmp_Inf.empresa = @nempresa
                    AND Tmp_Inf.codigo BETWEEN @ninicio AND @nfin


    UPDATE  TemporalAmortizacion
    SET     TemporalAmortizacion.amortizacion = ISNULL(( SELECT
                                                              SUM(Tmp_Inf.amortizacion)
                                                         FROM #tmp_inf AS Tmp_Inf
                                                         WHERE
                                                              Tmp_Inf.empresa = TemporalAmortizacion.empresa
                                                              AND Tmp_Inf.codigo = TemporalAmortizacion.codigo
                                                       ), 0)
    FROM    [dbo].[TemporalAmortizacion] AS TemporalAmortizacion

    DROP TABLE #tmp_inf
    DROP TABLE #tmp_incap
    DROP TABLE #tmp_aus
END    
GO

IF OBJECT_ID('dbo.CalculaAmortizacionProcedureUMA') IS NOT NULL
   DROP  PROCEDURE [dbo].[CalculaAmortizacionProcedureUMA]
GO
CREATE PROCEDURE [dbo].[CalculaAmortizacionProcedureUMA]
    @nempresa NUMERIC(5, 0) ,
    @nayo INT ,
    @nmes_non INT ,
    @nmes_par INT ,
    @ndias_tope DECIMAL(5, 2) ,
    @czonageo CHAR(1) ,
    @ncodigo NUMERIC(8, 0),
    @esBimestre CHAR(1) ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS 
    
    SET NOCOUNT ON
    
    DELETE  [dbo].[TemporalAmortizacion]
    WHERE   empresa = @nempresa

    DECLARE @nserial_bim INT
    DECLARE @nfolio INT
    DECLARE @csw CHAR(1)
    DECLARE @namortiza NUMERIC(12, 2)
    DECLARE @ninicio NUMERIC(8, 0)
    DECLARE @nfin NUMERIC(8, 0)
    DECLARE @naus_non DECIMAL(5, 2) 
    DECLARE @naus_par DECIMAL(5, 2) 
    DECLARE @ncodant NUMERIC(8, 0)
    DECLARE @ndias_non NUMERIC(5, 0)
    DECLARE @ndias_par NUMERIC(5, 0)
    DECLARE @nntd INT
    DECLARE @ninfo INT
    DECLARE @nporc_abono NUMERIC(8, 4)
    DECLARE @cDiasLab CHAR(1)
    DECLARE @cRetenido CHAR(1)
    DECLARE @cPropCred CHAR(1)
    DECLARE @cConvenio CHAR(8)
    DECLARE @nsaldiaint NUMERIC(12, 2)
    DECLARE @nvsm NUMERIC(12, 2)
    DECLARE @nseg_viv NUMERIC(5, 2)
    DECLARE @dfch_ini_non DATETIME  
    DECLARE @dfch_fin_non DATETIME  
    DECLARE @dfch_ini_par DATETIME
    DECLARE @dfch_fin_par DATETIME
    DECLARE @ndiasprop INT
    DECLARE @ndiasnon INT
    DECLARE @ndiaspar INT
    DECLARE @nsaldf NUMERIC(10, 02)
    DECLARE @nsalmin NUMERIC(10, 02)
    DECLARE @usaInfonavit CHAR(1)
    DECLARE @fchMovSuspension DATETIME
    DECLARE @movSuspension CHAR(2)

    DECLARE @salarioRegionA FLOAT
    DECLARE @salarioRegionB FLOAT
    DECLARE @salarioRegionC FLOAT
    
    DECLARE @seleccionSalarioMinimo CHAR(1)
    DECLARE @salarioMinimo FLOAT
    
    DECLARE @variableNumeric NUMERIC(12,2)
    DECLARE @variableINT INT
    DECLARE @variableBIT BIT
    
    DECLARE @periodoInicio VARCHAR(6)
    
    SET @periodoInicio = RIGHT(STR(10000 + @nayo), 4) + RIGHT(STR(100 + @nmes_non), 2)
    
    SELECT @seleccionSalarioMinimo = ISNULL(dbo.empresas.usarSalarioMinimo,'R')
    FROM dbo.empresas
    WHERE dbo.empresas.empresa = @nempresa

-- saca parametros infonavit
    SELECT  @cDiasLab = CASE WHEN hrs_min2 = 999 THEN 'N'
                             ELSE 'S'
                        END ,
            @cRetenido = CASE WHEN hrs_min3 = 999 THEN 'S'
                              ELSE 'N'
                         END ,
            @cPropCred = CASE WHEN marca2 = 'M' THEN 'N'
                              ELSE 'S'
                         END ,
            @cConvenio = RTRIM(LTRIM(variable1)),
            @usaInfonavit = uso
    FROM    dbo.conceptos
    WHERE   empresa = @nempresa
            AND num_conc = 112
            

IF @usaInfonavit = 'S'
BEGIN
    SET @nsaldf = 0
    SET @nsalmin = 0
    SET @namortiza = 0
    SET @nserial_bim = 0
    SET @nfolio = 0
    SET @csw = 'F'
    SET @nntd = 0
    SET @ninfo = 0
    SET @nporc_abono = 0
    SET @nsaldiaint = 0
    SET @nvsm = 0
    SET @nseg_viv = 0
    SET @dfch_ini_non = CAST(SUBSTRING(LTRIM(STR(@nayo + 10000)), 2, 4)
        + SUBSTRING(LTRIM(STR(@nmes_non + 100)), 2, 2) + '01' AS DATETIME)
    SET @dfch_fin_non = dbo.fin_mes(@nmes_non, @nayo)
    SET @ndiasnon = DATEDIFF(dd, @dfch_ini_non, @dfch_fin_non) + 1


    SET @ndiaspar = 0

    IF @nmes_par % 2 = 0 
        BEGIN
            SET @dfch_ini_par = CAST(SUBSTRING(LTRIM(STR(@nayo + 10000)), 2, 4)
                + SUBSTRING(LTRIM(STR(@nmes_par + 100)), 2, 2) + '01' AS DATETIME)
            SET @dfch_fin_par = dbo.fin_mes(@nmes_par, @nayo)
            SET @ndiaspar = CASE WHEN @nmes_par % 2 = 0
                                 THEN DATEDIFF(dd, @dfch_ini_par,
                                               @dfch_fin_par) + 1
                                 ELSE 0
                            END
        END
        
    SET @ndiasprop = DATEDIFF(dd, @dfch_ini_non,
                              CASE WHEN @nmes_par % 2 = 1
                                   THEN dbo.fin_mes(@nmes_par + 1, @nayo)
                                   ELSE @dfch_fin_par
                              END) + 1


-- si la variable @ncodigo es cero
-- va a afectar a todos los trabajadores
-- si no solo afecta al codigo deseado 
    IF @ncodigo = 0 
        BEGIN
            SET @ninicio = 1
            SET @nfin = 99999999
        END
    ELSE 
        BEGIN
            SET @ninicio = @ncodigo
            SET @nfin = @ncodigo
        END

    SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
            @salarioRegionB = ISNULL(zona_b, 0) ,
            @salarioRegionC = ISNULL(zona_c, 0)
    FROM    [dbo].[GetMinimumWage](@nmes_non, @nayo)
    
    SET @nsaldf = @salarioRegionA
        
    SET @nsalmin = CASE @czonageo
                           WHEN 'A' THEN @salarioRegionA
                           WHEN 'B' THEN @salarioRegionB
                           WHEN 'C' THEN @salarioRegionC
                           ELSE 0
                         END
    
    IF @seleccionSalarioMinimo = 'D'
       SET @salarioMinimo = @nsaldf
    ELSE
       SET @salarioMinimo = @nsalmin
  

-- creo una tabla temporal con movimientos del mes o bimestre
-- y los datos del credito infonavit
    SELECT  
            aItc.empresa ,
            aItc.ayo_operacion ,
            aItc.mes_operacion ,
            aItc.codigo ,
            aItc.serial ,
            @nserial_bim AS 'serial_bim' ,
            aItc.mov ,
            aItc.fch_mov ,
            aItc.saldiaint ,
            aItc.diastr ,
            aItc.ausen ,
            aItc.incap ,
            i.tipo_cred ,
            i.descuento ,
            CASE WHEN i.fecha < @dfch_ini_non
                 THEN CASE WHEN @dfch_ini_non < aItc.fch_mov
                                AND aItc.mov = 'A' THEN aItc.fch_mov
                           ELSE @dfch_ini_non
                      END
                 ELSE CASE WHEN i.fecha < aItc.fch_mov
                                AND aItc.mov = 'A' THEN aItc.fch_mov
                           ELSE i.fecha
                      END
            END AS 'fch_cred' ,
            i.fch_otorga ,
            @namortiza AS 'amortizacion' ,
            @nntd AS 'ntd' ,
            @ninfo AS 'info' ,
            i.descuento AS 'porc_abono' ,
            @nporc_abono AS 'vsm' ,
            i.seguro_vivienda ,
            i.fecha ,
            i.fch_termino ,
            i.numcredito ,
            e.afiliacion ,
            e.digvera,
            dbo.Llaves.clase,
            CASE WHEN i.fechaSuspension >= @dfch_ini_non
                      AND i.fechaSuspension <= CASE WHEN @nmes_par % 2 = 0 
                                                    THEN @dfch_fin_par
                                                    ELSE @dfch_fin_non
                                               END 
                 THEN i.fechaSuspension
                 ELSE NULL
            END AS fechaSuspension,
            @movSuspension AS movSuspension,
            @fchMovSuspension AS fchMovSuspension,
            @variableNumeric AS umaDiario,
            @variableNumeric AS registro,
            @variableNumeric AS umaFD
    INTO    #tmp_inf
    FROM    infonavit AS i
            INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON aItc.empresa = i.empresa
                                           AND aItc.codigo = i.codigo
                                           AND aItc.ayo_operacion = @nayo
                                           AND ( aItc.mes_operacion = @nmes_non
                                                 OR aItc.mes_operacion = @nmes_par
                                               )
            INNER JOIN empleados AS e ON e.empresa = i.empresa
                                         AND e.codigo = i.codigo
            INNER JOIN dbo.Llaves ON i.empresa = dbo.Llaves.empresa AND i.codigo = dbo.Llaves.codigo
    WHERE   i.empresa = @nempresa
            AND i.fecha <= CASE WHEN @nmes_par % 2 = 0 THEN @dfch_fin_par
                                ELSE @dfch_fin_non
                           END
            AND ( ( i.fch_termino >= @dfch_ini_non
                    AND CASE WHEN @nmes_par % 2 = 0 
                             THEN @dfch_fin_par
                             ELSE @dfch_fin_non
                        END <= i.fch_termino
                    AND (i.fechaSuspension IS NULL
                         OR i.fechaSuspension >= @dfch_ini_non
                        )     
                  )
                  OR i.fch_termino IS NULL
                  OR i.fch_termino = '19000101'
                )
            AND i.codigo BETWEEN @ninicio AND @nfin
            AND e.cotiza_imss = 'S'
            AND e.borrado = 'N'
            AND aItc.horaProceso = @horaProceso
            AND aItc.fechaProceso = @fechaProceso
            AND aItc.proceso = @proceso
    ORDER BY aItc.codigo ,
            aItc.ayo_operacion ,
            aItc.mes_operacion ,
            aItc.serial
            
            
-- Rutina para integrar UMA
    IF @periodoInicio >= '201701'
       BEGIN
         IF (SELECT COUNT(*) FROM dbo.TblUMA) > 0
            BEGIN
              IF (SELECT TOP 1 
                         1 --uma.aplicaInfonavit
                  FROM dbo.TblUMA AS uma 
                  WHERE RIGHT(YEAR(uma.fecha),4) + RIGHT(STR(100 + MONTH(uma.fecha)),2) <= @periodoInicio 
                  ORDER BY uma.fecha DESC) = 1
                 BEGIN
                   UPDATE ti
                   SET ti.umaDiario = ISNULL((SELECT TOP 1 uma.umaDiario
                                              FROM dbo.TblUMA AS uma
                                              WHERE uma.fecha <= CASE WHEN @nmes_par = 1 OR @nmes_par = 2 
                                                                      THEN CASE WHEN @nmes_par % 2 = 1 
                                                                                THEN dbo.fin_mes(@nmes_par + 1, @nayo) 
                                                                                ELSE @dfch_fin_par 
                                                                           END 
                                                                      ELSE ti.fch_mov 
                                                                 END
                                              ORDER BY uma.fecha DESC),0),
                       ti.umaFD = ISNULL((SELECT TOP 1 uma.umaDiario
                                              FROM dbo.TblUMAFD AS uma
                                              WHERE uma.fecha <= CASE WHEN @nmes_par = 1 OR @nmes_par = 2 
                                                                      THEN CASE WHEN @nmes_par % 2 = 1 
                                                                                THEN dbo.fin_mes(@nmes_par + 1, @nayo) 
                                                                                ELSE @dfch_fin_par 
                                                                           END 
                                                                      ELSE ti.fch_mov 
                                                                 END
                                              ORDER BY uma.fecha DESC),0)                                              
                   FROM #tmp_inf AS ti

                   SELECT ti.empresa, ti.ayo_operacion, ti.mes_operacion, ti.codigo, ISNULL(@variableINT,0) AS serial, ISNULL(@variableINT,0) AS serial_bim, 'UM' AS mov, uma.fecha AS fch_mov, ti.saldiaint, ti.diastr, ti.ausen, ti.incap, ti.tipo_cred, ti.descuento, ti.fch_cred, ti.fch_otorga, ti.amortizacion, ti.ntd, ti.info, ti.porc_abono, ti.vsm, ti.seguro_vivienda, ti.fecha, ti.fch_termino, ti.numcredito, ti.afiliacion, ti.digvera, ti.clase, ti.fechaSuspension, ti.movSuspension, ti.fchMovSuspension, uma.umaDiario, ti.registro, umaFD
                   INTO #tmp_inf_1
                   FROM #tmp_inf AS ti
                        INNER JOIN dbo.TblUMA AS uma ON uma.fecha > ti.fch_mov AND uma.fecha <= ti.fch_mov + ti.diastr - 1
                   WHERE ti.mov <> 'B'

                   UPDATE ti
                   SET ti.umaFD = uma.umaDiario
                   FROM #tmp_inf AS ti
                        INNER JOIN dbo.TblUMAFD AS uma ON uma.fecha > ti.fch_mov AND uma.fecha <= ti.fch_mov + ti.diastr - 1
                   WHERE ti.mov <> 'B'

                   INSERT #tmp_inf_1 (empresa, ayo_operacion, mes_operacion, codigo, serial, serial_bim, mov, fch_mov, saldiaint, diastr, ausen, incap, tipo_cred, descuento, fch_cred, fch_otorga, amortizacion, ntd, info, porc_abono, vsm, seguro_vivienda, fecha, fch_termino, numcredito, afiliacion, digvera, clase, fechaSuspension, movSuspension, fchMovSuspension, umaDiario, registro, umaFD)
                   SELECT ti.empresa, ti.ayo_operacion, ti.mes_operacion, ti.codigo, ti.serial, ti.serial_bim, ti.mov, ti.fch_mov, ti.saldiaint, ti.diastr, ti.ausen, ti.incap, ti.tipo_cred, ti.descuento, ti.fch_cred, ti.fch_otorga, ti.amortizacion, ti.ntd, ti.info, ti.porc_abono, ti.vsm, ti.seguro_vivienda, ti.fecha, ti.fch_termino, ti.numcredito, ti.afiliacion, ti.digvera, ti.clase, ti.fechaSuspension, ti.movSuspension, ti.fchMovSuspension, ti.umaDiario, 1 AS registro, ti.umaFD
                   FROM #tmp_inf AS ti

                   DELETE #tmp_inf

                   INSERT #tmp_inf (empresa, ayo_operacion, mes_operacion, codigo, serial, serial_bim, mov, fch_mov, saldiaint, diastr, ausen, incap, tipo_cred, descuento, fch_cred, fch_otorga, amortizacion, ntd, info, porc_abono, vsm, seguro_vivienda, fecha, fch_termino, numcredito, afiliacion, digvera, clase, fechaSuspension, movSuspension, fchMovSuspension, umaDiario, registro, umaFD)
                   SELECT ti.empresa, ti.ayo_operacion, ti.mes_operacion, ti.codigo, ti.serial, ti.serial_bim, ti.mov, ti.fch_mov, ti.saldiaint, ti.diastr, ti.ausen, ti.incap, ti.tipo_cred, ti.descuento, ti.fch_cred, ti.fch_otorga, ti.amortizacion, ti.ntd, ti.info, ti.porc_abono, ti.vsm, ti.seguro_vivienda, ti.fecha, ti.fch_termino, ti.numcredito, ti.afiliacion, ti.digvera, ti.clase, ti.fechaSuspension, ti.movSuspension, ti.fchMovSuspension, ti.umaDiario, 1 AS registro, ti.umaFD
                   FROM #tmp_inf_1 AS ti
                   ORDER BY ti.codigo ,
                            ti.fch_mov,
                            ti.serial
    
                   DROP TABLE #tmp_inf_1

                   --SELECT * FROM #tmp_inf ORDER BY codigo, fch_mov, serial
                 END
            END
       END
            
    -- Cambia la Alta a Ringreso cuando hay una baja anterior
    -- porque tomaba el inicio del credito apartir de la ultima alta
    -- 07/03/2012
    -- jorge Mtz
    -- Reportado por Mario Esparza
    -- Empresa Zebra
    DECLARE @codigoAnterior INT
    DECLARE @movimientoAnterior varchar(2)
    DECLARE @movimientoActual VARCHAR(2)
    DECLARE @fechaCredito DATETIME
    DECLARE @fechaCreditoActual DATETIME
    
    SET @codigoAnterior = 0        
    SET @movimientoAnterior = ''

    UPDATE  t1
    SET     @fechaCredito = CASE WHEN @codigoAnterior <> t1.codigo THEN t1.fch_cred ELSE @fechaCredito END,
            @movimientoActual = CASE WHEN @codigoAnterior = t1.codigo AND RTRIM(LTRIM(t1.mov)) = 'A' AND @movimientoAnterior = 'B' THEN 'RI' ELSE t1.mov END,
            @fechaCreditoActual = CASE WHEN @codigoAnterior = t1.codigo AND RTRIM(LTRIM(t1.mov)) = 'A' AND @movimientoAnterior = 'B' THEN @fechaCredito ELSE t1.fch_cred END,
            @codigoAnterior = t1.codigo,
            @movimientoAnterior = RTRIM(LTRIM(t1.mov)),
            t1.mov = @movimientoActual ,
            t1.fch_cred = @fechaCreditoActual
    FROM    #tmp_inf AS t1
    -- Fin Rutina Cambia Alta a Reingreso



-- cuando es bimestre borra el registro de IM del mes par
-- para mas delante calcular los dias por bimestre
    IF @nmes_par = 02
        OR @nmes_par = 04
        OR @nmes_par = 06
        OR @nmes_par = 08
        OR @nmes_par = 10
        OR @nmes_par = 12 
        BEGIN
            DELETE  #tmp_inf
            WHERE   mov = 'IM'
                    AND diastr = 0
        END



-- inicializa en ceros el campo diastr
-- y asigna un folio consecituvo en campo serial_bim
    SET @ncodigo = 0

    UPDATE  #tmp_inf
    SET     diastr = 0 ,
            @nfolio = CASE WHEN @ncodigo <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodigo = codigo


-- calcula dias cotizados 
    UPDATE  t1
    SET     t1.diastr = CASE WHEN t1.fch_mov = t2.fch_mov
                                  AND t2.mov <> 'B' THEN 0
                             ELSE CASE WHEN t2.fch_mov IS NULL
                                       THEN DATEDIFF(dd, t1.fch_mov,
                                                     CASE WHEN @esBimestre = 'S'
                                                          THEN @dfch_fin_par
                                                          ELSE CASE WHEN MONTH(t1.fch_mov) % 2 = 0
                                                                    THEN @dfch_fin_par
                                                                    ELSE @dfch_fin_non
                                                               END
                                                     END
                                                     ) + 1
                                       ELSE DATEDIFF(dd, t1.fch_mov,
                                                     t2.fch_mov)
                                            + CASE WHEN t2.mov = 'B' THEN 1
                                                   ELSE 0
                                              END
                                  END
                        END
    FROM    #tmp_inf AS t1
    LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo AND t1.serial_bim + 1 = t2.serial_bim

-- dependiendo de la fecha del credito la acomoda
-- entre los avisos
    UPDATE  t1
    SET     t1.mov = CASE WHEN t1.fch_cred >= t1.fch_mov 
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov <> 'B' 
                          THEN 'CR'
                          ELSE t1.mov
                     END ,
            t1.fch_mov = CASE WHEN t1.fch_cred >= t1.fch_mov
                                   AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                                   AND t1.mov <> 'B' 
                              THEN t1.fch_cred
                              ELSE t1.fch_mov
                         END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial

-- pone la marca 'CR' dependiendo de cuando inicie el credito
    UPDATE  t2
    SET     t2.mov = CASE WHEN t1.fch_cred >= t1.fch_mov
                               AND t1.fch_cred <= t1.fch_mov + t1.diastr - CASE WHEN t1.diastr > 0 THEN 1 ELSE 0 END
                               AND t1.mov = 'B' 
                          THEN CASE WHEN (SELECT TOP 1    -- Rutina Nueva 20140306
                                                 t3.mov
                                          FROM #tmp_inf AS t3 
                                          WHERE t1.codigo = t3.codigo
                                                AND t3.serial_bim < t1.serial_bim
                                          ORDER BY t3.serial_bim DESC) = 'CR'
                                    THEN t2.mov
                                    ELSE 'CR'
                               end                            
                          --'CR'
                          ELSE t2.mov
                     END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial


-- dependiendo de la fecha de SUSPENSION la acomoda
-- entre los avisos
    UPDATE  t1
    SET     t1.movSuspension = CASE WHEN t1.fechaSuspension >= t1.fch_mov
                                         AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
                                         AND t1.mov <> 'B'
                                    THEN 'SC'  -- SC = suspension credito
                                    ELSE NULL
                               END,
            t1.fchMovSuspension = CASE WHEN t1.fechaSuspension >= t1.fch_mov
                                            AND t1.fechaSuspension <= t1.fch_mov + t1.diastr - 1
                                            AND t1.mov <> 'B'
                                       THEN t1.fechaSuspension
                                       ELSE NULL 
                                  END
    FROM    #tmp_inf AS t1
            LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                        AND t1.serial + 1 = t2.serial


-- vuelve a calcular los dias cotizados
-- los avisos anteriores a la marca CR no les calcula
-- dias los deja en ceros
    UPDATE  t1
    SET     @csw = CASE WHEN t1.serial_bim = 1 
                        THEN 'F'
                        ELSE @csw
                   END ,
            @csw = CASE WHEN t1.mov = 'CR' AND @csw = 'F' 
                        THEN 'T'
                        ELSE @csw
                   END ,
            t1.diastr = CASE WHEN @csw = 'T'
                             THEN CASE WHEN t1.mov = 'B' 
                                       THEN 0
                                       ELSE CASE WHEN t1.fch_mov = t2.fch_mov AND t2.mov <> 'B' 
                                                 THEN 0
                                                 ELSE CASE WHEN t2.fch_mov IS NULL
                                                           THEN DATEDIFF(dd,t1.fch_mov,
                                                                         CASE WHEN @esBimestre = 'S'
                                                                              THEN @dfch_fin_par
                                                                              ELSE CASE WHEN MONTH(t1.fch_mov) % 2 = 0
                                                                                        THEN @dfch_fin_par
                                                                                        ELSE @dfch_fin_non
                                                                                   END
                                                                         END
                                                                        ) + 1
                                                           ELSE DATEDIFF(dd,t1.fch_mov,t2.fch_mov) + CASE WHEN t2.mov = 'B'
                                                                                                          THEN 1
                                                                                                          ELSE 0
                                                                                                     END
                                                      END
                                            END
                                  END
                             ELSE 0
                        END
    FROM    #tmp_inf AS t1
    LEFT JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo AND t1.serial_bim + 1 = t2.serial_bim
    

    UPDATE  tempInf
    SET     tempInf.diastr = DATEDIFF(dd, tempInf.fch_mov,
                                      tempInf.fchMovSuspension) + 1
    FROM    #tmp_inf AS tempInf
    WHERE   tempInf.fchMovSuspension IS NOT NULL


-- borra los registros anteriores a CR
-- no tiene caso que esten en la tabla 
-- puesto que no se va usar ese registro
-- para calcular la amotizacion
    DELETE  t1
    FROM    #tmp_inf AS t1
            INNER JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                         AND t2.mov = 'CR'
                                         AND t1.fch_mov < t2.fch_mov


-- borra los registros posteriores a SC
-- no tiene caso que esten en la tabla 
-- puesto que no se va usar ese registro
-- para calcular la amotizacion
    DELETE  t1
    FROM    #tmp_inf AS t1
            INNER JOIN #tmp_inf AS t2 ON t1.codigo = t2.codigo
                                         AND t2.movSuspension = 'SC'
                                         AND t1.fch_mov > t2.fechaSuspension



-- vuelve a reconstruir el folio
    SET @ncodigo = 0
    UPDATE  #tmp_inf
    SET     @nfolio = CASE WHEN @ncodigo <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodigo = codigo
   

    UPDATE  a
    SET     a.incap = 0 ,
            a.ausen = 0
    FROM    #tmp_inf AS a


-- ajusta los dias de incapcidad para cada movimiento
-- y lo guarda en la tabla temporal @tmp_incap
    SELECT  a.empresa ,
            a.codigo ,
            a.ayo_operacion ,
            a.mes_operacion ,
            a.serial ,
            CASE WHEN d.fchinicio <= a.fch_mov
                      AND d.fchinicio + d.dias - 1 >= a.fch_mov
                      AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                 THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                 ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov
                                + a.diastr - 1 THEN d.dias
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio <= a.fch_mov
                                          + a.diastr - 1
                                          AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                          + a.diastr - 1
                                     THEN DATEDIFF(dd, d.fchinicio,
                                                   a.fch_mov + a.diastr)
                                     ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                    AND d.fchinicio + d.dias
                                                    - 1 >= a.fch_mov
                                                    + a.diastr - 1
                                               THEN a.diastr
                                               ELSE 0
                                          END
                                END
                      END
            END AS 'incap'
    INTO    #tmp_incap
    FROM    #tmp_inf AS a
            LEFT JOIN deducciones AS d ON a.empresa = d.empresa
                                          AND a.codigo = d.codigo
    WHERE   a.empresa = @nempresa
            AND a.diastr > 0
            AND a.ayo_operacion = @nayo
            AND (a.mes_operacion = @nmes_non
                 OR a.mes_operacion = @nmes_par)
            AND (d.num_conc = 109 
                 OR d.num_conc = 110 
                 OR d.num_conc = 111
                ) 
            AND ( ( d.fchinicio <= a.fch_mov 
                    AND d.fchtermino >= a.fch_mov
                    AND d.fchinicio <= a.fch_mov
                    + a.diastr - 1
                  )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchtermino <= a.fch_mov
                       + a.diastr - 1
                     )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchinicio <= a.fch_mov
                           + a.diastr - 1
                       AND d.fchtermino >= a.fch_mov
                           + a.diastr - 1
                     )
                  OR ( d.fchinicio <= a.fch_mov
                       AND d.fchtermino >= a.fch_mov
                       + a.diastr - 1
                     )
                )   
    


-- pasa de la tabla #tmp_incap el ajuste de las incapacidades
    UPDATE  a
    SET     a.incap = ISNULL(( SELECT   SUM(b.incap)
                               FROM     #tmp_incap AS b
                               WHERE    a.empresa = b.empresa
                                        AND a.codigo = b.codigo
                                        AND a.ayo_operacion = b.ayo_operacion
                                        AND a.mes_operacion = b.mes_operacion
                                        AND a.serial = b.serial
                             ), 0)
    FROM    #tmp_inf AS a
    WHERE   a.diastr > 0


-- ajusta los ausentismos y los guarda en la 
-- tabla temporal #tmp_aus
    SELECT  a.empresa ,
            a.codigo ,
            a.ayo_operacion ,
            a.mes_operacion ,
            a.serial ,
            0 AS 'serial_bim' ,
            d.fchinicio ,
            d.dias ,
            CASE WHEN d.fchinicio <= a.fch_mov
                      AND d.fchinicio + d.dias - 1 >= a.fch_mov
                      AND d.fchinicio + d.dias - 1 <= a.fch_mov + a.diastr - 1
                 THEN DATEDIFF(dd, a.fch_mov, d.fchinicio + d.dias)
                 ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                AND d.fchinicio + d.dias - 1 <= a.fch_mov
                                + a.diastr - 1 THEN d.dias
                           ELSE CASE WHEN d.fchinicio >= a.fch_mov
                                          AND d.fchinicio <= a.fch_mov
                                          + a.diastr - 1
                                          AND d.fchinicio + d.dias - 1 >= a.fch_mov
                                          + a.diastr - 1
                                     THEN DATEDIFF(dd, d.fchinicio,
                                                   a.fch_mov + a.diastr)
                                     ELSE CASE WHEN d.fchinicio <= a.fch_mov
                                                    AND d.fchinicio + d.dias
                                                    - 1 >= a.fch_mov
                                                    + a.diastr - 1
                                               THEN a.diastr
                                               ELSE 0
                                          END
                                END
                      END
            END AS 'aus' ,
            @naus_non AS 'aus_non' ,
            @naus_par AS 'aus_par'
    INTO    #tmp_aus
    FROM    #tmp_inf AS a
            LEFT JOIN deducciones AS d ON a.empresa = d.empresa
                                          AND a.codigo = d.codigo
                                          --AND a.ayo_operacion = YEAR(d.fchinicio)
                                          --AND ( MONTH(d.fchinicio) = @nmes_non
                                          --      OR MONTH(d.fchinicio) = @nmes_par
                                          --    )
                                          --AND d.num_conc = 108
    --WHERE   a.diastr > 0
    WHERE   a.empresa = @nempresa
            AND a.diastr > 0
            AND a.ayo_operacion = @nayo
            AND (a.mes_operacion = @nmes_non
                 OR a.mes_operacion = @nmes_par)
            AND d.num_conc = 108 
            AND ( ( d.fchinicio <= a.fch_mov 
                    AND d.fchtermino >= a.fch_mov
                    AND d.fchinicio <= a.fch_mov
                    + a.diastr - 1
                  )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchtermino <= a.fch_mov
                       + a.diastr - 1
                     )
                  OR ( d.fchinicio >= a.fch_mov
                       AND d.fchinicio <= a.fch_mov
                           + a.diastr - 1
                       AND d.fchtermino >= a.fch_mov
                           + a.diastr - 1
                     )
                  OR ( d.fchinicio <= a.fch_mov
                       AND d.fchtermino >= a.fch_mov
                       + a.diastr - 1
                     )
                )   


-- los registros que no tengan ausentismo
-- los borra 
    DELETE  #tmp_aus
    WHERE   aus = 0


-- inicializa en ceros los ausentismos 
-- para cada mes (non y par)
    UPDATE  #tmp_aus
    SET     aus_non = CASE WHEN MONTH(fchinicio) = MONTH(@dfch_ini_non)
                           THEN aus
                           ELSE 0
                      END ,    --@nmes_non
            aus_par = CASE WHEN MONTH(fchinicio) = MONTH(@dfch_ini_par)
                           THEN aus
                           ELSE 0
                      END


    SET @nfolio = 0

-- reconstruye folio
    UPDATE  #tmp_aus
    SET     @nfolio = CASE WHEN @ncodant <> codigo THEN 0
                           ELSE @nfolio
                      END ,
            @nfolio = @nfolio + 1 ,
            serial_bim = @nfolio ,
            @ncodant = codigo 


-- ajusta al tope los dias de ausentismo para cada mes (non y par)
    UPDATE  t
    SET     @ndias_non = CASE WHEN t.serial_bim = 1 THEN 0
                              ELSE @ndias_non
                         END ,
            @ndias_par = CASE WHEN t.serial_bim = 1 THEN 0
                              ELSE @ndias_par
                         END ,
            @ndias_non = @ndias_non + CASE WHEN t.aus_non IS NULL THEN 0
                                           ELSE t.aus_non
                                      END ,
            @ndias_par = @ndias_par + CASE WHEN t.aus_par IS NULL THEN 0
                                           ELSE t.aus_par
                                      END ,
            t.aus_non = CASE WHEN @ndias_non < @ndias_tope THEN t.aus_non
                             ELSE CASE WHEN t.aus_non - ( @ndias_non
                                                          - @ndias_tope ) < 0
                                       THEN 0
                                       ELSE t.aus_non - ( @ndias_non
                                                          - @ndias_tope )
                                  END
                        END ,
            t.aus_par = CASE WHEN @ndias_par < @ndias_tope THEN t.aus_par
                             ELSE CASE WHEN t.aus_par - ( @ndias_par
                                                          - @ndias_tope ) < 0
                                       THEN 0
                                       ELSE t.aus_par - ( @ndias_par
                                                          - @ndias_tope )
                                  END
                        END
    FROM    #tmp_aus AS t


-- pasa el ajuste de ausentismo a la tabla #tmp_inf
    UPDATE  a
    SET     a.ausen = ( SELECT  SUM(b.aus_non) + SUM(b.aus_par)
                        FROM    #tmp_aus AS b
                        WHERE   a.empresa = b.empresa
                                AND a.codigo = b.codigo
                                AND a.ayo_operacion = b.ayo_operacion
                                AND a.mes_operacion = b.mes_operacion
                                AND a.serial = b.serial
                      )
    FROM    #tmp_inf AS a
    WHERE   a.diastr > 0


-- para los registros que tienen null en ausen poner cero
    UPDATE  #tmp_inf
    SET     ausen = 0
    WHERE   empresa = @nempresa
            AND ayo_operacion = @nayo
            AND ( mes_operacion = @nmes_non
                  OR mes_operacion = @nmes_par
                )
            AND codigo BETWEEN @ninicio AND @nfin
            AND ausen IS NULL


-- para los creditos que tengan fecha de otorgamiento 
-- hasta el 30/01/1998 y sean tipo 1
-- poner el saldiaint de inicio de bimestre en todos 
-- los movimientos del trabajador
    UPDATE  ti
    SET     ti.saldiaint = ( SELECT TOP 1
                                    ti2.saldiaint
                             FROM    #tmp_inf AS ti2
                             WHERE   ti2.empresa = ti.empresa
                                     AND ti2.codigo = ti.codigo
                                     AND ti2.diastr > 0
                             ORDER BY ti2.serial_bim ASC
                           ),
            ti.umaDiario = ISNULL((SELECT TOP 1 uma.umaDiario
                                   FROM dbo.TblUMA AS uma
                                   WHERE uma.fecha <= CASE WHEN @nmes_par = 1 OR @nmes_par = 2 
                                                           THEN CASE WHEN @nmes_par % 2 = 1 
                                                                     THEN dbo.fin_mes(@nmes_par + 1, @nayo) 
                                                                     ELSE @dfch_fin_par 
                                                                END 
                                                           ELSE ti.fch_mov 
                                                      END
                                   ORDER BY uma.fecha DESC),0)
    FROM    #tmp_inf AS ti
    WHERE   ti.tipo_cred = 1
            AND ti.fch_otorga <= '19980130'
            AND @cpropcred = 'S'
            AND ( ti.porc_abono = 20
                  OR ti.porc_abono = 25
                  OR ti.porc_abono = 30
                )


-- los creditos que su fecha de otorgamiento hasta el 30/01/1998 
-- y tengan tipo 1 y que el porcentaje sea 20,25,30 
-- los ubica en la tabla de descuento
    UPDATE  tm
    SET tm.ntd = CASE WHEN tm.descuento = 20 AND tm.fch_otorga <= '19980130' THEN 1
                      WHEN tm.descuento = 25 AND tm.fch_otorga <= '19980130' THEN 2
                      WHEN tm.descuento = 30 AND tm.fch_otorga <= '19980130' THEN 3
                      ELSE 0
                 END ,
        @nvsm = ROUND(tm.saldiaint / CASE WHEN @periodoInicio >= '201701' THEN tm.umaDiario ELSE @salarioMinimo END,2),
        tm.vsm = @nvsm ,
        tm.info = CASE WHEN @nvsm >= 0.01 AND @nvsm <= 02.50 AND tm.fch_otorga <= '19980130' THEN 1
                       WHEN @nvsm >= 2.51 AND @nvsm <= 03.50 AND tm.fch_otorga <= '19980130' THEN 2
                       WHEN @nvsm >= 3.51 AND @nvsm <= 04.50 AND tm.fch_otorga <= '19980130' THEN 3
                       WHEN @nvsm >= 4.51 AND @nvsm <= 05.50 AND tm.fch_otorga <= '19980130' THEN 4
                       WHEN @nvsm >= 5.51 AND @nvsm <= 06.50 AND tm.fch_otorga <= '19980130' THEN 5
                       WHEN @nvsm >= 6.51 AND @nvsm <= 99.99 AND tm.fch_otorga <= '19980130' THEN 6
                       ELSE 0
                  END ,
        tm.porc_abono = CASE tm.descuento WHEN 20 THEN CASE WHEN @nvsm >= 0.01 AND @nvsm <= 02.50 AND tm.fch_otorga <= '19980130' THEN 15.7
                                                            WHEN @nvsm >= 2.51 AND @nvsm <= 03.50 AND tm.fch_otorga <= '19980130' THEN 16.8
                                                            WHEN @nvsm >= 3.51 AND @nvsm <= 04.50 AND tm.fch_otorga <= '19980130' THEN 17.2
                                                            WHEN @nvsm >= 4.51 AND @nvsm <= 05.50 AND tm.fch_otorga <= '19980130' THEN 17.7
                                                            WHEN @nvsm >= 5.51 AND @nvsm <= 06.50 AND tm.fch_otorga <= '19980130' THEN 17.8
                                                            WHEN @nvsm >= 6.51 AND @nvsm <= 99.99 AND tm.fch_otorga <= '19980130' THEN 20.0
                                                            ELSE tm.descuento
                                                       END
                                          WHEN 25 THEN CASE WHEN @nvsm >= 0.01 AND @nvsm <= 02.50 AND tm.fch_otorga <= '19980130' THEN 19.6
                                                            WHEN @nvsm >= 2.51 AND @nvsm <= 03.50 AND tm.fch_otorga <= '19980130' THEN 21.0
                                                            WHEN @nvsm >= 3.51 AND @nvsm <= 04.50 AND tm.fch_otorga <= '19980130' THEN 21.5
                                                            WHEN @nvsm >= 4.51 AND @nvsm <= 05.50 AND tm.fch_otorga <= '19980130' THEN 22.1
                                                            WHEN @nvsm >= 5.51 AND @nvsm <= 06.50 AND tm.fch_otorga <= '19980130' THEN 22.3
                                                            WHEN @nvsm >= 6.51 AND @nvsm <= 99.99 AND tm.fch_otorga <= '19980130' THEN 25.0
                                                            ELSE tm.descuento
                                                       END
                                          WHEN 30 THEN CASE WHEN @nvsm >= 0.01 AND @nvsm <= 02.50 AND tm.fch_otorga <= '19980130' THEN 24.6
                                                            WHEN @nvsm >= 2.51 AND @nvsm <= 03.50 AND tm.fch_otorga <= '19980130' THEN 26.0
                                                            WHEN @nvsm >= 3.51 AND @nvsm <= 04.50 AND tm.fch_otorga <= '19980130' THEN 26.5
                                                            WHEN @nvsm >= 4.51 AND @nvsm <= 05.50 AND tm.fch_otorga <= '19980130' THEN 27.1
                                                            WHEN @nvsm >= 5.51 AND @nvsm <= 06.50 AND tm.fch_otorga <= '19980130' THEN 27.3
                                                            WHEN @nvsm >= 6.51 AND @nvsm <= 99.99 AND tm.fch_otorga <= '19980130' THEN 30.0
                                                            ELSE tm.descuento
                                                       END
                                          ELSE tm.descuento
                        END
    FROM #tmp_inf AS tm
    WHERE tm.tipo_cred = 1

    UPDATE tm
    SET tm.amortizacion = CASE tm.tipo_cred WHEN 1 THEN tm.saldiaint * ( tm.diastr - tm.ausen - CASE WHEN @cconvenio = 'CONVENIO' THEN 0 ELSE tm.incap END ) * ( tm.porc_abono / 100 )
                                            WHEN 2 THEN ( ( tm.descuento * 2 ) / @ndiasprop ) * CASE WHEN @cdiaslab = 'S' THEN ( tm.diastr - tm.ausen - CASE WHEN @cconvenio = 'CONVENIO' THEN 0 ELSE tm.incap END ) ELSE ( tm.diastr - tm.ausen - CASE WHEN @cconvenio = 'CONVENIO' THEN 0 ELSE tm.incap END ) END
                                            WHEN 3 THEN ( ( tm.descuento * 2 * CASE WHEN @periodoInicio >= '201701' THEN CASE WHEN @periodoInicio >= '201801' THEN tm.umaFD ELSE tm.umaDiario END ELSE @nsaldf END) / @ndiasprop ) * ( tm.diastr - tm.ausen - CASE WHEN @cconvenio = 'CONVENIO' THEN 0 ELSE tm.incap END ) ELSE 0 END
    FROM #tmp_inf AS tm

    INSERT  [dbo].[TemporalAmortizacion]
            ( empresa ,
              codigo ,
              descuento,
              clase
            )
            SELECT DISTINCT
                    Tmp_Inf.empresa ,
                    Tmp_Inf.codigo ,
                    CASE WHEN Tmp_Inf.tipo_cred = 2 OR Tmp_Inf.tipo_cred = 3 
                         THEN Tmp_Inf.porc_abono
                         ELSE CASE WHEN @cpropcred = 'S' 
                                   THEN Tmp_Inf.porc_abono 
                                   ELSE 0 
                              END
                    END,
                    Tmp_Inf.clase
            FROM    #tmp_inf AS Tmp_Inf
            WHERE   Tmp_Inf.empresa = @nempresa
                    AND Tmp_Inf.codigo BETWEEN @ninicio AND @nfin


    UPDATE  TemporalAmortizacion
    SET     TemporalAmortizacion.amortizacion = ISNULL(( SELECT
                                                              SUM(Tmp_Inf.amortizacion)
                                                         FROM #tmp_inf AS Tmp_Inf
                                                         WHERE
                                                              Tmp_Inf.empresa = TemporalAmortizacion.empresa
                                                              AND Tmp_Inf.codigo = TemporalAmortizacion.codigo
                                                       ), 0)
    FROM    [dbo].[TemporalAmortizacion] AS TemporalAmortizacion

    
    DROP TABLE #tmp_inf
    DROP TABLE #tmp_incap
    DROP TABLE #tmp_aus
END    
GO

/**************************************************************************************************
 * Name          : CalculaDiferenciaCV2023
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total cuotas bimestre
 * Table name    : 
 * Return        : tabla con total cuotas CV
 * Copyright     : (c) Apsi 2009 - 2030. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 28, 2022
 **************************************************************************************************/
IF OBJECT_ID('dbo.CalculaDiferenciaCV2023') IS NOT NULL
   DROP  PROCEDURE dbo.CalculaDiferenciaCV2023
GO
CREATE PROCEDURE dbo.CalculaDiferenciaCV2023
@empresa INT
, @ayoTblCV INT
, @ayo INT
, @mesNon INT
, @mesPar INT
, @proceso VARCHAR(250)
, @fechaProceso DATETIME
, @horaProceso VARCHAR(8)

AS 

  SET NOCOUNT ON

  DECLARE @diasFaltaTope INT
  DECLARE @fiNon DATETIME
  DECLARE @ffNon DATETIME
  DECLARE @fiPar DATETIME
  DECLARE @ffPar DATETIME
  DECLARE @esBimestre CHAR(1)
  DECLARE @salarioRegionA NUMERIC(12,2)
  DECLARE @salarioRegionB NUMERIC(12,2)
  DECLARE @salarioRegionC NUMERIC(12,2)
  DECLARE @salarioRegion NUMERIC(12,2)
  DECLARE @salarioDF NUMERIC(12,2)
  DECLARE @areaGeografica CHAR(1)
  DECLARE @topeDF NUMERIC(12,2)
  DECLARE @topeRegion NUMERIC(12,2)
  DECLARE @cvArt168II NUMERIC(8,5)
  DECLARE @cvPat168II NUMERIC(8,5)
  DECLARE @cvTra168II NUMERIC(8,5)
  DECLARE @ayoEmpresa INT
  DECLARE @cesantiaVejez NUMERIC(12,2)
  DECLARE @fechaAplicaUMA DATETIME
  DECLARE @FechaFinita DATETIME

  SET @FechaFinita = '29991231'
  SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
  SET @diasFaltaTope = 7
  SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
  SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
  SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
  SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

  IF @mesPar / 2 = FLOOR(@mesPar / 2) AND @mesNon < @mesPar 
     BEGIN
       SET @esBimestre = 'S'
     END
  ELSE 
     BEGIN
       SET @esBimestre = 'N'
     END
    
  -- Obtiene Area Geografica
  SELECT @areaGeografica = empresa.zona_geografica ,
         @ayoEmpresa = empresa.ayo_operacion
  FROM dbo.empresas AS empresa
  WHERE empresa.empresa = @empresa

  -- Obtiene Salario Minimo
  SELECT @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
         @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
         @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
  FROM [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo
        
  SET @salarioDF = @salarioRegionA
  SET @salarioRegion = CASE @areaGeografica
                            WHEN 'A' THEN @salarioRegionA
                            WHEN 'B' THEN @salarioRegionB
                            WHEN 'C' THEN @salarioRegionC
                            ELSE 0
                       END
  SET @topeDF = ROUND(@salarioDF * 25, 2)
  SET @topeRegion = @salarioRegion    
    
  -- Obtiene Primas IMSS
  SELECT @cvArt168II = primasImss.cvArt168II,
         @cvPat168II = primasImss.cvPat168II,
         @cvTra168II = primasImss.cvTra168ii
  FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, 0) AS primasImss
                                                
  SELECT cesantiaVejezPatron AS cesantiaVejezPatron
         , cesantiaVejez AS cesantiaVejez
  FROM (SELECT SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                    CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                    @salarioRegion,
                                                                    dbo.empleados.art39,
                                                                    aItc.mov)
                                            , aItc.diastr
                                            , aItc.incap
                                            , aItc.ausen
                                            , tblCV.cvPat168II
										    , 'N'
										    , 0
											, aItc.sueldo
											, aItc.fch_mov
											, 0
											, @salarioRegion
											, 1
											, tblCV.cvPat168II
											, tblCV.cvTra168II)) AS cesantiaVejezPatron,
  
                 SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint
                                                                      , CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END
											                          , @topeRegion
											                          , dbo.empleados.art39
											                          , aItc.mov)
											  , aItc.diastr
											  , aItc.incap
											  , aItc.ausen
											  , tblCV.cvArt168II
											  , 'N'
											  , 0
											  , aItc.sueldo
											  , aItc.fch_mov
											  , 0
											  , @salarioRegion
											  , 0
											  , tblCV.cvArt168II
											  , 0)) AS cesantiaVejez
        FROM dbo.empleados

             INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                 AND dbo.empleados.codigo = aItc.codigo
                                                                 AND aItc.mes_operacion >= @mesNon 
                                                                 AND aItc.mes_operacion <= @mesPar 
                                                                 AND YEAR(aItc.fch_mov) = @ayo
                                                                 AND aItc.horaProceso = @horaproceso
                                                                 AND aItc.fechaProceso = @fechaproceso
                                                                 AND aItc.proceso = @proceso

             OUTER APPLY (SELECT CASE WHEN aItc.mov = 'B' THEN 0 ELSE rango END rango
			                     , cvArt168II
                                 , cvPat168II
                                 , cvTra168II
			              FROM dbo.NOM_FUN_ObtienePrimaCVPatron2023(aItc.empresa, aItc.fch_mov, @ayoTblCV, aItc.saldiaint, @cvArt168II, @cvPat168II, @cvTra168II)
					     ) AS tblCV

        WHERE dbo.empleados.empresa = @empresa
              AND dbo.empleados.cotiza_imss = 'S'
              AND dbo.empleados.borrado = 'N') AS cuotaCV
GO

IF OBJECT_ID('dbo.CalculaSBC') IS NOT NULL
   DROP PROCEDURE dbo.CalculaSBC
GO
CREATE  PROCEDURE dbo.CalculaSBC
@empresa INT,
@codigo INT,
@fechaCambioSalario DATETIME,
@cuotaDiaria NUMERIC(12,2),
@sistema CHAR(3)

AS 

--SET @empresa = 1
--SET @codigo = 53045
--SET @fechaCambioSalario = '20140301'
--SET @cuotaDiaria = 246.62
--SET @sistema = 'NOM'

SET NOCOUNT ON

DECLARE @ayoOperacion INT
DECLARE @mesOperacion INT
DECLARE @ayoCambioSalario INT
DECLARE @mesCambioSalario INT
DECLARE @ayoBimestreAnterior INT
DECLARE @mesNonBimestreAnterior INT
DECLARE @mesParBimestreAnterior INT
DECLARE @fechaOperacion DATETIME
DECLARE @variableImss NUMERIC(12,2)
DECLARE @aplicoVariable CHAR(1)
DECLARE @variableImssEmpleado NUMERIC(12,2)
DECLARE @factor DECIMAL(9,6)
DECLARE @aguinaldo DECIMAL(8,4)
DECLARE @dias_vac DECIMAL(8, 4)
DECLARE @prima_vac DECIMAL(8, 4)
DECLARE @pmavacdias DECIMAL(6, 2)
DECLARE @pmavacimpo DECIMAL(7, 2)
DECLARE @despensa DECIMAL(8, 4)
DECLARE @despensaim DECIMAL(12, 4)
DECLARE @dias_ayo DECIMAL(8, 4)
DECLARE @porc_ayo DECIMAL(8, 4)
DECLARE @imp_ayo DECIMAL(10, 2)
DECLARE @dias_mes DECIMAL(8, 4)
DECLARE @porc_mes DECIMAL(8, 4)
DECLARE @imp_mes DECIMAL(10, 2)
DECLARE @porc_dia DECIMAL(8, 4)
DECLARE @imp_dia DECIMAL(10, 2)
DECLARE @fdoahopatp DECIMAL(8, 4)
DECLARE @fdoahopati DECIMAL(7, 3)
DECLARE @fdoahotrap DECIMAL(8, 4)
DECLARE @fdoahotrai DECIMAL(7, 3)
DECLARE @pmo1ayopor DECIMAL(8, 4)
DECLARE @pmo1ayoimp DECIMAL(6, 2)
DECLARE @pmo2ayopor DECIMAL(8, 4)
DECLARE @pmo2ayoimp DECIMAL(6, 2)
DECLARE @ayosAntiguedad INT
DECLARE @fechaAntiguedad DATETIME
DECLARE @clase VARCHAR(2)
DECLARE @fechaFinMesNon DATETIME
DECLARE @fechaFinMesPar DATETIME
DECLARE @diasEmpleadoBimestreAnterior INT
DECLARE @ausEmpleadoBimestreAnterior INT
DECLARE @incEmpleadoBimestreAnterior INT
DECLARE @factorCalculado NUMERIC(9,6)
DECLARE @fondoAhorroPatron NUMERIC(12,2)
DECLARE @fondoAhorroTrabajador NUMERIC(12,2)
DECLARE @importeFijo NUMERIC(12,2)
DECLARE @despensaCalculada NUMERIC(12,2)
DECLARE @areaGeografica CHAR(1)
DECLARE @salarioMinimoDf NUMERIC(12,2)
DECLARE @salarioMinimoRegion NUMERIC(12,2)
DECLARE @toparDespensa CHAR(1)
DECLARE @fondoAhorro NUMERIC(12,2)
DECLARE @sbc NUMERIC(12,2)
DECLARE @retorno INT
DECLARE @umaDiario NUMERIC(12,2)
DECLARE @fechaAplicaUMA DATETIME

       
SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')

SELECT TOP 1
       @umaDiario = uma.umaDiario
FROM dbo.TblUMA AS uma
WHERE uma.fecha <= @fechaCambioSalario
ORDER BY uma.fecha DESC

SELECT @ayoOperacion = empresa.ayo_operacion,
       @mesOperacion = empresa.mes_operacion,
       @areaGeografica = empresa.zona_geografica
FROM dbo.empresas AS empresa
WHERE empresa.empresa = @empresa


SET @fechaOperacion = CONVERT(DATETIME, RIGHT(10000 + @ayoOperacion,4) + RIGHT(100 + @mesOperacion,2) + '01')


IF @fechaCambioSalario >= @fechaOperacion
   BEGIN
      SELECT @aplicoVariable =  empleado.var_sigmes,
             @variableImssEmpleado = CASE WHEN empleado.var_sigmes = 'T' THEN empleado.varia_next ELSE empleado.varia_imss END,
             @fechaAntiguedad = CASE WHEN empleado.fchantigua = '19000101' OR empleado.fchantigua IS NULL THEN empleado.fchalta ELSE empleado.fchantigua END
      FROM dbo.empleados AS empleado
      WHERE empleado.codigo = @codigo
            AND empleado.empresa = @empresa
      

      SELECT @clase = llave.clase
      FROM dbo.Llaves AS llave 
      WHERE llave.codigo = @codigo
            AND llave.empresa = @empresa
      

      SET @aplicoVariable = ISNULL(@aplicoVariable,'F')
      SET @variableImssEmpleado = ISNULL(@variableImssEmpleado,0)
      SET @ayoCambioSalario = YEAR(@fechaCambioSalario)
      SET @mesCambioSalario = MONTH(@fechaCambioSalario)
      

      IF MONTH(@fechaOperacion) % 2 = 0 AND MONTH(@fechaCambioSalario) % 2 = 1
         BEGIN
            IF @aplicoVariable = 'F'
               BEGIN
                  --SET @ayoCambioSalario = YEAR(@fechaCambioSalario)
                  --SET @mesCambioSalario = MONTH(@fechaCambioSalario)
      

                  SET @ayoBimestreAnterior = CASE WHEN @mesCambioSalario = 1 OR @mesCambioSalario = 2 THEN @ayoCambioSalario - 1 ELSE @ayoCambioSalario END
                  SET @mesNonBimestreAnterior = CASE WHEN @mesCambioSalario = 1 OR @mesCambioSalario = 2 THEN 11 ELSE CASE WHEN @mesCambioSalario % 2 = 0 THEN @mesCambioSalario - 3 ELSE @mesCambioSalario - 2 END END
                  SET @mesParBimestreAnterior = CASE WHEN @mesCambioSalario = 1 OR @mesCambioSalario = 2 THEN 12 ELSE CASE WHEN @mesCambioSalario % 2 = 0 THEN @mesCambioSalario - 2 ELSE @mesCambioSalario - 1 END END
                  SET @fechaFinMesNon = dbo.fin_mes(@mesNonBimestreAnterior,@ayoBimestreAnterior)
                  SET @fechaFinMesPar = dbo.fin_mes(@mesParBimestreAnterior,@ayoBimestreAnterior)
                  
               
                  SELECT  @variableImss = SUM(ISNULL(dbo.percepciones.varia_imss,0))
                  FROM    dbo.percepciones
                  WHERE   dbo.percepciones.empresa = @empresa
                          AND dbo.percepciones.codigo = @codigo
                          AND dbo.percepciones.ayo_operacion = @ayoOperacion
                          AND (dbo.percepciones.mes_operacion = @mesNonBimestreAnterior 
                               OR dbo.percepciones.mes_operacion = @mesParBimestreAnterior)
               
                  SET @variableImss = ISNULL(@variableImss,0)

                  EXECUTE dbo.asp_ds @empresa, @codigo, @ayoBimestreAnterior, @mesNonBimestreAnterior, @fechaFinMesNon
                  EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayoBimestreAnterior, @mesNonBimestreAnterior, 7
                  EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayoBimestreAnterior, @mesNonBimestreAnterior
      
                  EXECUTE dbo.asp_ds @empresa, @codigo, @ayoBimestreAnterior, @mesParBimestreAnterior, @fechaFinMesPar
                  EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayoBimestreAnterior, @mesParBimestreAnterior, 7
                  EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayoBimestreAnterior, @mesParBimestreAnterior
      

                  SELECT @diasEmpleadoBimestreAnterior = SUM(avisosImss.diastr),
                         @ausEmpleadoBimestreAnterior = SUM(avisosImss.ausen),
                         @incEmpleadoBimestreAnterior = SUM(avisosImss.incap)
                  FROM dbo.avisos_imss AS avisosImss
                  WHERE (MONTH(avisosImss.fch_mov) = @mesNonBimestreAnterior
                         OR MONTH(avisosImss.fch_mov) = @mesParBimestreAnterior)
                        AND YEAR(avisosImss.fch_mov) = @ayoBimestreAnterior
                        AND avisosImss.codigo = @codigo
                        AND avisosImss.empresa = @empresa
                  
                        
                  SET @variableImss = @variableImss / (CASE WHEN @diasEmpleadoBimestreAnterior - @ausEmpleadoBimestreAnterior - @incEmpleadoBimestreAnterior <= 0 THEN 1 ELSE @diasEmpleadoBimestreAnterior - @ausEmpleadoBimestreAnterior - @incEmpleadoBimestreAnterior END)
               END
            ELSE
               BEGIN
                  SET @variableImss = @variableImssEmpleado
               END
         END
      ELSE
         BEGIN
            SET @variableImss = @variableImssEmpleado
         END


      SET @ayosAntiguedad = dbo.CalculaAyosAntiguedad(@fechaAntiguedad,@fechaCambioSalario)
      
      SELECT @factor = tabla.factor,
             @aguinaldo = tabla.aguinaldo,
             @dias_vac = tabla.dias_vac,
             @prima_vac = tabla.prima_vac,
             @pmavacdias = tabla.pmavacdias,
             @pmavacimpo = tabla.pmavacimpo,
             @despensa = tabla.despensa,   
             @despensaim = tabla.despensaim,  
             @dias_ayo = tabla.dias_ayo,
             @porc_ayo = tabla.porc_ayo,
             @imp_ayo = tabla.imp_ayo,
             @dias_mes = tabla.dias_mes,
             @porc_mes = tabla.porc_mes,
             @imp_mes = tabla.imp_mes,
             @porc_dia = tabla.porc_dia,
             @imp_dia = tabla.imp_dia,
             @fdoahopatp = tabla.fdoahopatp,
             @fdoahopati = tabla.fdoahopati,
             @fdoahotrap = tabla.fdoahotrap,
             @fdoahotrai = tabla.fdoahotrai,
             @pmo1ayopor = tabla.pmo1ayopor,
             @pmo1ayoimp = tabla.pmo1ayoimp,
             @pmo2ayopor = tabla.pmo2ayopor,
             @pmo2ayoimp = tabla.pmo2ayoimp
      FROM dbo.tablas_int AS tabla
      WHERE  tabla.mes_operacion = @mesOperacion
             AND tabla.ayo_operacion = @ayoOperacion
             AND tabla.ayos = @ayosAntiguedad
             AND tabla.clase = @clase 
             AND tabla.empresa = @empresa
             
     
      IF @sistema = 'NOM'
         BEGIN
            SET @factorCalculado = Round(1 +
                                             (@aguinaldo / 365) + 
                                             ((@dias_vac / 365) * (@prima_vac / 100)) +
                                             (@pmavacdias / 365) +
                                             (@dias_ayo / 365) +
                                             (@porc_ayo / 100) +
                                             (@porc_mes / 100) +
                                             (@porc_dia / 100) +
                                             (@pmo1ayopor / 100) +
                                             (@pmo2ayopor / 100) +
                                             (@dias_mes / 030.4167),4)
         END 
      ELSE
         BEGIN
            SET @factorCalculado = @factor
         END
         
     
      SELECT  @salarioMinimoDf = ISNULL(salarioMinimo.zona_a, 0) ,
              @salarioMinimoRegion = CASE @areaGeografica WHEN 'A' THEN ISNULL(salarioMinimo.zona_a,0) 
                                                          WHEN 'B' THEN ISNULL(salarioMinimo.zona_b,0) 
                                                                   ELSE 0 
                                     END
      FROM    [dbo].[GetMinimumWage](@mesCambioSalario, @ayoCambioSalario) AS salarioMinimo
      

      SET @salarioMinimoDf = ISNULL(@salarioMinimoDf, 0)
      SET @salarioMinimoRegion = ISNULL(@salarioMinimoRegion, 0) 
        
      
      SET @importeFijo =  Round((@imp_ayo / 365) + (@pmo1ayoimp / 365) + (@pmo2ayopor / 365) + (@imp_mes / 30.4167) + @imp_dia,2)
      SET @despensaCalculada = ((@cuotaDiaria * (@despensa / 100)) + @despensaim) - (CASE WHEN @fechaCambioSalario >= @fechaAplicaUMA THEN @umaDiario ELSE @salarioMinimoDf END * 0.40)
      
      SELECT @toparDespensa = CASE WHEN concepto.variable2 = 'CONTOPE' THEN 'S' ELSE 'N' END
      FROM dbo.conceptos AS concepto
      WHERE concepto.num_conc = 31
            AND concepto.empresa = @empresa
            
      SET @toparDespensa = ISNULL(@toparDespensa,'N')
      

      IF @toparDespensa = 'S'
         BEGIN
            IF ((@cuotaDiaria * (@despensa / 100)) + @despensaim) > CASE WHEN @fechaCambioSalario >= @fechaAplicaUMA THEN @umaDiario ELSE @salarioMinimoRegion END
               BEGIN
                  SET @despensaCalculada = @salarioMinimoRegion - (CASE WHEN @fechaCambioSalario >= @fechaAplicaUMA THEN @umaDiario ELSE @salarioMinimoDf END * 0.40)
               END
         END
         
      IF @despensaCalculada < 0
         BEGIN
            SET @despensaCalculada = 0
         END
         
      SET @fondoAhorroPatron = (@cuotaDiaria * (@fdoahopatp / 100)) + @fdoahopati
      SET @fondoAhorroTrabajador = (@cuotaDiaria * (@fdoahotrap / 100)) + @fdoahotrai
      
      IF @fondoAhorroPatron > @fondoAhorroTrabajador
         BEGIN
         	SET @fondoAhorro = @fondoAhorroPatron
         END
      ELSE   
         BEGIN
         	SET @fondoAhorro = 0
         END
      
      SET @sbc = (@cuotaDiaria * @factorCalculado) + @importeFijo + @despensaCalculada + @variableImss + @fondoAhorro
      SET @retorno = 1

   END
ELSE
   BEGIN
      SET @sbc = 0
      SET @retorno = 0
   END

   
SELECT @retorno AS retorno, @sbc AS sbc
GO

IF OBJECT_ID('dbo.CalculoAmortizacionInfonavit') IS NOT NULL
   DROP PROCEDURE dbo.CalculoAmortizacionInfonavit
GO
CREATE PROCEDURE [dbo].[CalculoAmortizacionInfonavit]
--ICV   -- Inicio Credito Vivienda
--RD    -- Reinicio Descuento
--MNC   -- Modificacion Numero Credito
--MFL   -- Modificacion Fecha Liberacion
--MFO   -- Modificacion Fecha Otorgamiento

@empresa INT,
@mes INT,
@ayo INT

AS 

  SET NOCOUNT ON
  SET ANSI_WARNINGS OFF

  DECLARE @FechaFinita DATETIME
  SET @FechaFinita = '29991231'

  DECLARE @fecha DATETIME
  DECLARE @tipomoimientocreditoinfonavit TABLE (mov VARCHAR(3), descripcion VARCHAR(50))
  INSERT @tipomoimientocreditoinfonavit (mov, descripcion) VALUES ('ICV', 'Inicio Credito Vivienda')
  INSERT @tipomoimientocreditoinfonavit (mov, descripcion) VALUES ('RD', 'Reinicio Descuento')
  INSERT @tipomoimientocreditoinfonavit (mov, descripcion) VALUES ('MNC', 'Modificacion Numero Credito')
  INSERT @tipomoimientocreditoinfonavit (mov, descripcion) VALUES ('MFL', 'Modificacion Fecha Liberacion')
  INSERT @tipomoimientocreditoinfonavit (mov, descripcion) VALUES ('MFO', 'Modificacion Fecha Otorgamiento')

  SET @fecha = CONVERT(DATETIME, RIGHT(10000 + @ayo,4) + RIGHT(100 + @mes,2) + '01')

  DECLARE @aplicarsbciniciobimestre BIT
  DECLARE @convenio BIT
  DECLARE @usainfonavit BIT

  SELECT @aplicarsbciniciobimestre = CASE WHEN marca2 = 'M' THEN 0 ELSE 1 END,
         @convenio = CASE WHEN RTRIM(LTRIM(variable1)) = 'CONVENIO' THEN 1 ELSE 0 END,
         @usainfonavit = CASE WHEN uso = 'N' THEN 0 ELSE 1 END
  FROM dbo.conceptos
  WHERE empresa = @empresa
        AND num_conc = 112

  DECLARE @avisosinfonavit TABLE (sec INT IDENTITY, 
                                  codigo INT, 
                                  fecha DATETIME, 
                                  mov CHAR(3), 
                                  saldiaint NUMERIC(12,2), 
                                  diastr INT, 
                                  ausen1 INT, 
                                  ausen2 INT, 
                                  incap INT, 
                                  serial INT, 
                                  numcredito CHAR(10), 
                                  tipo_cred INT, 
                                  descuento NUMERIC(12,4), 
                                  saldf_uma NUMERIC(12,2), 
                                  topedf_uma NUMERIC(12,2), 
                                  umaFD NUMERIC(12,2), 
                                  sbcInicioBimestre NUMERIC(12,2), 
                                  fechaOtorgamiento DATETIME, 
                                  veces NUMERIC(5,2), 
                                  amortizacion NUMERIC(12,2),
                                  tipoMovimiento VARCHAR(3),
                                  fechaMovimiento DATETIME,
                                  tipoCreditoParaCalculo INT,
                                  descuentoParaCalculo NUMERIC(12,4),
                                  seguroVivienda NUMERIC(12,2) DEFAULT 0)

  IF @usainfonavit = 1
     BEGIN
       DECLARE @fi DATETIME
       DECLARE @ff DATETIME
       DECLARE @fechainicio DATETIME
       DECLARE @fechafin DATETIME
       DECLARE @fechainicio1 DATETIME
       DECLARE @fechafin1 DATETIME
       DECLARE @fechainicio2 DATETIME
       DECLARE @fechafin2 DATETIME
       DECLARE @fechafin11 DATETIME
       DECLARE @fechainicio11 DATETIME
       DECLARE @fechafin22 DATETIME
       DECLARE @fechainicio22 DATETIME
       DECLARE @mes1 INT
       DECLARE @mes2 INT
       DECLARE @fechaaplicauma DATETIME
       DECLARE @fechaaplicaumafd DATETIME
       DECLARE @umadiario NUMERIC(12,2)
       DECLARE @umafd NUMERIC(12,2)
       DECLARE @salariominimo NUMERIC(12,2)
       DECLARE @fechaaplicatd DATETIME
       DECLARE @esbimestre INT
       DECLARE @topeausen INT
       DECLARE @diasbimestre INT
       DECLARE @segurovivienda NUMERIC(12,2)

       SET @fechaaplicauma = '20170101'
       SET @fechaaplicaumafd = '20180101'
       SET @fechaaplicatd = '19980130'
       SET @topeausen = 7

       SELECT @fechainicio1 = fechaInicio,
              @fechafin1 = fechaFin
       FROM [dbo].[ObtieneRangoFecha](@fecha, 8)

       SELECT @fechainicio2 = fechaInicio,
              @fechafin2 = fechaFin
       FROM [dbo].[ObtieneRangoFecha](@fecha, 7)

       IF @mes % 2 = 0
          BEGIN
            SET @fechainicio = @fechainicio1
            SET @fechafin = @fechafin2
            SET @mes1 = MONTH(@fechainicio1)
            SET @mes2 = MONTH(@fechafin2)
            SET @esbimestre = 1
          END
       ELSE
          BEGIN
            SET @fechainicio = @fechainicio2
            SET @fechafin = @fechafin2
            SET @mes1 = MONTH(@fechainicio2)
            SET @mes2 = MONTH(@fechafin2)
            SET @esbimestre = 0
          END

       IF @mes % 2 = 0
	      BEGIN
            SELECT @fechainicio11 = fechaInicio,
                   @fechafin11 = fechaFin
            FROM [dbo].[ObtieneRangoFecha](@fecha, 8)

            SELECT @fechainicio22 = fechaInicio,
                   @fechafin22 = fechaFin
            FROM [dbo].[ObtieneRangoFecha](@fecha, 7)

            SET @diasbimestre = DATEDIFF(dd, @fechainicio11, @fechafin22) + 1
	     END
       ELSE
          BEGIN
            SELECT @fechainicio11 = fechaInicio,
                   @fechafin11 = fechaFin
            FROM [dbo].[ObtieneRangoFecha](@fecha, 7)

            SELECT @fechainicio22 = fechaInicio,
                   @fechafin22 = fechaFin
            FROM [dbo].[ObtieneRangoFecha](@fecha, 10)

            SET @diasbimestre = DATEDIFF(dd, @fechainicio11, @fechafin22) + 1
	      END

       IF @fechainicio >= '20060101' AND @fechafin <= '20081231'
          SET @segurovivienda = 8
       ELSE IF @fechainicio >= '20090101' AND @fechafin <= '20101031'
          SET @segurovivienda = 13
       ELSE If @fechainicio >= '20101101'
          SET @segurovivienda = 15
       ELSE
          SET @segurovivienda = 0
     
       DECLARE @infonavitcambios TABLE (codigo INT, 
                                        fecha DATETIME, 
                                        mov CHAR(3), 
                                        numcredito CHAR(10), 
                                        tipo_cred INT, 
                                        descuento NUMERIC(12,4), 
                                        tipoMovimiento VARCHAR(3),
                                        fechaMovimiento DATETIME)

       INSERT @infonavitcambios (codigo, fecha, mov, numcredito, tipo_cred, descuento, tipoMovimiento, fechaMovimiento)
       SELECT ic.codigo,
              CASE WHEN ic.fecha < @fechainicio THEN @fechainicio ELSE CASE WHEN ic.fecha > @fechafin THEN @fechafin else ic.fecha END END AS fecha,
              ic.cambio AS mov,
              ic.numcredito,
              ic.tipo_cred,
              ic.descuento,
              ic.cambio,
              ic.fecha
       FROM dbo.infonavit_cambios AS ic
            OUTER APPLY (SELECT TOP 1
                                ic1.fecha,
                                ic1.cambio
                         FROM dbo.infonavit_cambios AS ic1
                         WHERE ic1.fecha <= @fechainicio
                               AND ic1.codigo = ic.codigo
                               AND ic1.empresa = ic.empresa
                         ORDER BY ic1.fecha DESC,
                                  ic1.id_infocambio DESC) AS ic1
            CROSS APPLY (SELECT TOP 1
                                a.codigo
                         FROM dbo.avisos_imss AS a
                         WHERE a.codigo = ic.codigo
                               AND a.empresa = ic.empresa
                               AND a.fch_mov >= @fechainicio
                               AND a.fch_mov <= @fechafin) AS a
            INNER JOIN dbo.infonavit AS i ON i.codigo = ic.codigo 
                                             AND i.empresa = ic.empresa
       WHERE ((ic.fecha >= ISNULL(ic1.fecha, @fechainicio)
               AND ISNULL(ic1.cambio,'') <> 'FSD'
               AND ic.fecha <= @fechafin)
              OR (ic.fecha >= @fechainicio
                  AND ic.fecha <= @fechafin))
             AND ic.empresa = @empresa
             AND i.fch_termino >= @fechainicio
       ORDER BY ic.codigo,
                ic.fecha

       INSERT @avisosinfonavit (codigo, fecha, mov, saldiaint, diastr, ausen1, ausen2, incap, serial, numcredito, tipo_cred, descuento, tipoMovimiento, fechaMovimiento)
       SELECT a.codigo,
              a.fch_mov AS fecha,
              a.mov,
              a.saldiaint,
              0 AS diastr,
              0 AS ausen1,
              0 AS ausen2,
              0 AS incap,
              a.serial,
              ic.numcredito,
              ic.tipo_cred,
              ic. descuento,
              ic.tipoMovimiento,
              ic.fechaMovimiento
       FROM dbo.avisos_imss AS a
            CROSS APPLY (SELECT TOP 1
                                ic.codigo,
                                ic.numcredito,
                                ic.tipo_cred,
                                ic.descuento,
                                ic.tipoMovimiento,
                                ic.fechaMovimiento
                         FROM @infonavitcambios AS ic
                         WHERE ic.codigo = a.codigo) AS ic
       WHERE a.fch_mov >= @fechainicio
             AND a.fch_mov <= @fechafin
             AND a.empresa = @empresa

       UNION

       SELECT a2.codigo,
              @fechaFin1 AS fecha,
              'MS' AS mov,
              a2.saldiaint,
              0 AS diastr,
              0 AS ausen1,
              0 AS ausen2,
              0 AS incap,
              a2.serial + 1 AS serial,
              ic.numcredito,
              ic.tipo_cred,
              ic. descuento,
              ic.tipoMovimiento,
              ic.fechaMovimiento
       FROM dbo.avisos_imss AS a2
            CROSS APPLY (SELECT TOP 1
                                ic.codigo,
                                ic.numcredito,
                                ic.tipo_cred,
                                ic.descuento,
                                ic.tipoMovimiento,
                                ic.fechaMovimiento
                         FROM @infonavitcambios AS ic
                         WHERE ic.codigo = a2.codigo) AS ic
       WHERE @esbimestre = 1
	         AND a2.fch_mov < @fechafin1
             AND a2.fch_mov + a2.diastr - 1 > @fechafin1
             AND a2.empresa = @empresa
			 AND a2.diastr > 0


       UNION

       SELECT a3.codigo,
              a3.fch_mov AS fecha,
              'MS' AS mov,
              a3.saldiaint,
              0 AS diastr,
              0 AS ausen1,
              0 AS ausen2,
              0 AS incap,
              a3.serial,
              ic.numcredito,
              ic.tipo_cred,
              ic. descuento,
              ic.tipoMovimiento,
              ic.fechaMovimiento
       FROM dbo.avisos_imss AS a3
            CROSS APPLY (SELECT TOP 1
                                ic.codigo,
                                ic.numcredito,
                                ic.tipo_cred,
                                ic.descuento,
                                ic.tipoMovimiento,
                                ic.fechaMovimiento
                         FROM @infonavitcambios AS ic
                         WHERE ic.codigo = a3.codigo) AS ic

             CROSS APPLY (SELECT TOP 1
			                     a4.codigo
                          FROM dbo.avisos_imss AS a4
						  WHERE a4.empresa = a3.empresa
						        AND a4.codigo = a3.codigo
								AND a4.fch_mov < @fechaInicio2
								AND a4.fch_mov + a4.diastr - 1 > @fechainicio2) AS a5

       WHERE @esbimestre = 1
	         AND a3.empresa = @empresa
	         AND a3.mov = 'IM'
			 AND a3.fch_mov = @fechaInicio2

       UNION

       SELECT ic.codigo,
              ic.fecha,
              ic.mov,
              0 AS saldiaint,
              0 AS diastr,
              0 AS ausen1,
              0 AS ausen2,
              0 AS incap,
              0 AS serial,
              ic.numcredito,
              ic.tipo_cred,
              ic. descuento,
              ic.tipoMovimiento,
              ic.fechaMovimiento
       FROM @infonavitcambios AS ic
       ORDER BY codigo, 
                fecha ASC,
                serial ASC

       -- Actualiza el SBC que corresponde a cada movimiento
       UPDATE ai
       SET ai.saldiaint = ai1.saldiaint
       FROM @avisosinfonavit AS ai
            CROSS APPLY (SELECT TOP 1
                                ai1.saldiaint
                         FROM @avisosinfonavit AS ai1
                         WHERE ai1.codigo = ai.codigo
                               AND ai1.sec > ai.sec
                               AND ai1.saldiaint > 0
							   AND MONTH(ai1.fecha) = @mes1
                         ORDER BY ai1.sec DESC) AS ai1
       WHERE ai.saldiaint = 0
	         AND MONTH(ai.fecha) = @mes1

	   IF @esbimestre = 1
          UPDATE ai
          SET ai.saldiaint = ai1.saldiaint
          FROM @avisosinfonavit AS ai
               CROSS APPLY (SELECT TOP 1
                                   ai1.saldiaint
                            FROM @avisosinfonavit AS ai1
                            WHERE ai1.codigo = ai.codigo
                                  AND ai1.sec > ai.sec
                                  AND ai1.saldiaint > 0
								  AND MONTH(ai1.fecha) = @mes2
                            ORDER BY ai1.sec DESC) AS ai1
          WHERE ai.saldiaint = 0
		        AND MONTH(ai.fecha) = @mes2

	   UPDATE ai
       SET ai.saldiaint = ai1.saldiaint
       FROM @avisosinfonavit AS ai
            CROSS APPLY (SELECT TOP 1
                                ai1.saldiaint
                         FROM @avisosinfonavit AS ai1
                         WHERE ai1.codigo = ai.codigo
                               AND ai1.sec < ai.sec
                               AND ai1.saldiaint > 0
                         ORDER BY ai1.fecha DESC, ai1.sec DESC) AS ai1
       WHERE ai.saldiaint = 0
	         AND ai.mov IN (SELECT tmci.mov FROM @tipomoimientocreditoinfonavit AS tmci)

       DELETE ai1
       FROM @avisosinfonavit AS ai1
            OUTER APPLY (SELECT TOP 1
	                            ai2.mov AS mov2
                         FROM @avisosinfonavit AS ai2
				         WHERE MONTH(ai2.fecha) IN (2,4,6,8,10,12) AND 
				               MONTH(ai1.fecha) IN (2,4,6,8,10,12) AND 
				               ai2.codigo = ai1.codigo AND 
				               ai2.fecha = ai1.fecha AND
						       ai2.serial > ai1.serial) AS ai2
       WHERE ai1.mov = 'IM' AND 
       ISNULL(ai2.mov2,'') <> 'B'
      
       -- Borra los registros anteriores a RD
       DELETE ai
       FROM @avisosinfonavit AS ai
            CROSS APPLY (SELECT TOP 1
                                ai2.sec
                         FROM @avisosinfonavit AS ai2
                         WHERE ai2.codigo = ai.codigo
                               AND ai2.mov = 'RD') AS ai2
            OUTER APPLY (SELECT TOP 1
                                ai1.sec
                         FROM @avisosinfonavit AS ai1
                         WHERE ai1.codigo = ai.codigo
                               AND ai1.mov = 'FSD'
                               AND ai1.sec < ai2.sec) AS ai1
       WHERE ai.sec > ISNULL(ai1.sec,0) AND ai.sec < ai2.sec
	         
       -- Borra las registros anterior a ICV      
       DELETE ai
       FROM @avisosinfonavit AS ai
            CROSS APPLY (SELECT TOP 1
                                ai1.sec
                         FROM @avisosinfonavit AS ai1
                         WHERE ai1.codigo = ai.codigo
                               AND ai1.mov = 'ICV') AS ai1
       WHERE ai.sec < ai1.sec

       -- Borra los registros porteriores que tengan la misma fecha
       DELETE ai 
       FROM @avisosinfonavit AS ai
       WHERE ai.mov IN ('ICV', 'RD', 'MNC', 'MFL', 'MTD', 'MFO', 'MVD', 'MS', 'RI', 'IM', 'A') AND (SELECT TOP 1
                                                                                                           ai1.mov
                                                                                                    FROM @avisosinfonavit AS ai1
                                                                                                    WHERE ai1.codigo = ai.codigo
                                                                                                          AND ai1.fecha = ai.fecha
                                                                                                          AND ai1.sec > ai.sec
                                                                                                    ORDER BY ai1.fecha ASC,
                                                                                                             ai1.sec ASC) IN ('ICV', 'RD', 'MNC', 'MFL', 'MTD', 'MFO', 'MVD', 'MS', 'RI', 'IM', 'A')


       -- Borra los registros que esten entre FSD y RD
       DELETE ai
       FROM @avisosinfonavit AS ai
            CROSS APPLY (SELECT TOP 1
                                ai1.fecha AS fecha1
                         FROM @avisosinfonavit AS ai1
                         WHERE ai1.codigo = ai.codigo
                               AND ai1.mov = 'FSD'
                         ORDER BY ai.sec ASC) AS ai1
            OUTER APPLY (SELECT TOP 1
                                ai2.fecha AS fecha2
                         FROM @avisosinfonavit AS ai2
                         WHERE ai2.codigo = ai.codigo
                               AND ai2.mov = 'RD'
                               AND ai2.fecha > ai1.fecha1
                         ORDER BY ai2.sec ASC) AS ai2
       WHERE (ai.fecha >= ai1.fecha1 AND ai.mov <> 'FSD')
             AND (ai.fecha <= ISNULL(ai2.fecha2, @fechafin) AND ai.mov <> 'RD')

       -- Borra registro ICV si tiene un reingreso o alta posterior
       DELETE ai
       FROM @avisosinfonavit AS ai
       WHERE ai.mov = 'ICV'
	         AND (SELECT TOP 1
                         ai1.mov 
                  FROM @avisosinfonavit AS ai1
                  WHERE ai1.codigo = ai.codigo
                        AND ai1.fecha >= ai.fecha
                        AND ai1.sec > ai.sec) IN ('A', 'RI')

       -- Borra registro MVD si tiene un reingreso o alta posterior
       DELETE ai
       FROM @avisosinfonavit AS ai
       WHERE ai.mov = 'MVD'
	         AND (SELECT TOP 1
                         ai1.mov 
                  FROM @avisosinfonavit AS ai1
                  WHERE ai1.codigo = ai.codigo
                        AND ai1.fecha >= ai.fecha
                        AND ai1.sec > ai.sec) IN ('A', 'RI')

       -- Borra registro MFL si tiene un reingreso o alta posterior
       DELETE ai
       FROM @avisosinfonavit AS ai
       WHERE ai.mov = 'MFL'
	         AND (SELECT TOP 1
                         ai1.mov 
                  FROM @avisosinfonavit AS ai1
                  WHERE ai1.codigo = ai.codigo
                        AND ai1.fecha >= ai.fecha
                        AND ai1.sec > ai.sec) IN ('A', 'RI')

       -- Borra registro MTD si tiene un reingreso o alta posterior
       DELETE ai
       FROM @avisosinfonavit AS ai
       WHERE ai.mov = 'MTD'
	         AND (SELECT TOP 1
                         ai1.mov 
                  FROM @avisosinfonavit AS ai1
                  WHERE ai1.codigo = ai.codigo
                        AND ai1.fecha >= ai.fecha
                        AND ai1.sec > ai.sec) IN ('A', 'RI')


       -- Borra registro RD si tiene un reingreso o alta posterior
       DELETE ai
       FROM @avisosinfonavit AS ai
       WHERE ai.mov = 'RD'
	         AND (SELECT TOP 1
                         ai1.mov 
                  FROM @avisosinfonavit AS ai1
                  WHERE ai1.codigo = ai.codigo
                        AND ai1.fecha >= ai.fecha
                        AND ai1.sec > ai.sec) IN ('A', 'RI')

	   UPDATE ai
	   SET ai.mov = 'FSD'
	   FROM @avisosinfonavit AS ai
	   WHERE ai.mov = 'B'
	         AND (SELECT COUNT(*) FROM @avisosinfonavit AS ai1 WHERE ai1.codigo = ai.codigo) = 1

       -- Calcula los dias cotizados para movimiento
       UPDATE ai
       SET ai.diastr = DATEDIFF(DD, ai.fecha, CASE WHEN ai.mov = 'FSD' AND ai.fecha = @fechainicio THEN ai.fecha ELSE ISNULL(ai1.fecha, @fechafin) END) + 
       CASE WHEN (ai1.mov = 'B' OR ai1.mov = 'FSD') OR ai1.mov IS NULL THEN 1 ELSE 0 END
       FROM @avisosinfonavit AS ai
            OUTER APPLY (SELECT TOP 1
                                ai1.fecha,
                                ai1.mov
                         FROM @avisosinfonavit AS ai1
                         WHERE ai1.codigo = ai.codigo
                               AND ai1.sec > ai.sec) AS ai1
       WHERE (ai.mov <> 'B'
              AND ai.mov <> 'FSD')
             OR (ai.mov = 'FSD'
                 AND ai.fecha = @fechainicio)

	   -- Para empleados con alta y baja el mismo dia
	   UPDATE ai
	   SET ai.diastr = 1,
	       ai.saldiaint = (SELECT TOP 1
		                          aviso.saldiaint
		                   FROM dbo.avisos_imss AS aviso
						   WHERE aviso.empresa = @empresa
						         AND aviso.codigo = ai.codigo
								 AND aviso.fch_mov <= ai.fecha
								 AND aviso.mov <> 'B'
						   ORDER BY aviso.fch_mov DESC,
						            aviso.serial DESC)
	       
	   FROM @avisosinfonavit AS ai
	        CROSS APPLY (SELECT COUNT(*) AS registros
			             FROM @avisosinfonavit AS ai1
						 WHERE ai1.codigo = ai.codigo) AS ai1
		WHERE ai.mov = 'FSD'
		      AND ai1.registros = 1

       -- Ajusta los das de incapacidad de acuerdo al movimiento
       IF @convenio = 0
          BEGIN
            DECLARE @incap TABLE (sec INT, codigo INT, incap INT DEFAULT 0)

            INSERT @incap (sec, codigo, incap)
            SELECT ai.sec,
                   ai.codigo,
                   CASE WHEN d.fchinicio <= ai.fecha and d.fchinicio + d.dias - 1 >= ai.fecha and d.fchinicio + d.dias - 1 <= ai.fecha + ai.diastr - 1 
                        THEN DATEDIFF(dd,ai.fecha,d.fchinicio + d.dias)  
                        ELSE CASE WHEN d.fchinicio >= ai.fecha and d.fchinicio + d.dias - 1 <= ai.fecha + ai.diastr - 1 
                                  THEN d.dias
                                  ELSE CASE WHEN d.fchinicio >= ai.fecha and d.fchinicio <= ai.fecha + ai.diastr - 1 and d.fchinicio + d.dias - 1 >= ai.fecha + ai.diastr - 1 
                                            THEN DATEDIFF(dd,d.fchinicio, ai.fecha + ai.diastr)
                                            ELSE CASE WHEN d.fchinicio <= ai.fecha and d.fchinicio + d.dias - 1 >= ai.fecha + ai.diastr - 1 
                                                      THEN ai.diastr
                                                      ELSE 0
                                                 END 
                                       END
                             END 
                   END AS incap
            FROM @avisosinfonavit AS ai
                 INNER JOIN dbo.deducciones as d ON d.codigo = ai.codigo
                                                    AND ((d.fchinicio <= ai.fecha
                                                          AND d.fchtermino >= ai.fecha
                                                          AND d.fchinicio <= ai.fecha + ai.diastr - 1)
                                                              OR (d.fchinicio >= ai.fecha
                                                                  AND d.fchtermino <= ai.fecha + ai.diastr - 1)
                                                              OR (d.fchinicio >= ai.fecha
                                                                  AND d.fchinicio <= ai.fecha + ai.diastr - 1
                                                                  AND d.fchtermino >= ai.fecha + ai.diastr - 1)
                                                              OR (d.fchinicio <= ai.fecha
                                                                  AND d.fchtermino >= ai.fecha + ai.diastr - 1)) 
                                                    AND d.empresa = @empresa
                                                    AND (d.num_conc = 109 
                                                         OR d.num_conc = 110 
                                                         OR d.num_conc = 111)
            WHERE ai.diastr > 0  

            UPDATE ai
            SET ai.incap = d.incap
            FROM @avisosinfonavit AS ai
                 INNER JOIN (SELECT d.codigo,
                                    d.sec,
                                    SUM(d.incap) AS incap
                             FROM @incap AS d
                             GROUP BY d.codigo,
                                      d.sec) AS d ON d.codigo = ai.codigo
                                                     AND d.sec = ai.sec
          END
                                          
       -- Ajusta los das de falta de acuerdo al movimiento                                          
       DECLARE @ausen TABLE (sec INT, codigo INT, ausen1 INT DEFAULT 0, ausen2 INT DEFAULT 0, mes INT)

       IF @esbimestre = 1
          BEGIN
            INSERT @ausen (sec, codigo, ausen1, mes)
            SELECT ai.sec,
                   ai.codigo,

                   CASE WHEN d.fchinicio <= CASE WHEN ai.fecha < @fechainicio1 THEN @fechainicio1 ELSE ai.fecha END
                             AND d.fchinicio + d.dias - 1 >= CASE WHEN ai.fecha < @fechainicio1 THEN @fechainicio1 ELSE ai.fecha END
                             AND d.fchinicio + d.dias - 1 <= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin1 THEN @fechafin1 ELSE ai.fecha + ai.diastr - 1 END
                        THEN DATEDIFF(dd, CASE WHEN ai.fecha < @fechainicio1 THEN @fechainicio1 ELSE ai.fecha END, d.fchinicio + d.dias)  
                        ELSE CASE WHEN d.fchinicio >= CASE WHEN ai.fecha < @fechainicio1 THEN @fechainicio1 ELSE ai.fecha END
                                       AND d.fchinicio + d.dias - 1 <= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin1 THEN @fechafin1 ELSE ai.fecha + ai.diastr - 1 END
                                  THEN d.dias
                                  ELSE CASE WHEN d.fchinicio >= CASE WHEN ai.fecha < @fechainicio1 THEN @fechainicio1 ELSE ai.fecha END
                                                 AND d.fchinicio <= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin1 THEN @fechafin1 ELSE ai.fecha + ai.diastr - 1 END
                                                 AND d.fchinicio + d.dias - 1 >= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin1 THEN @fechafin1 ELSE ai.fecha + ai.diastr - 1 END
                                            THEN DATEDIFF(dd,d.fchinicio, CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin1 THEN @fechafin1 + 1 ELSE ai.fecha + ai.diastr END)
                                            ELSE CASE WHEN d.fchinicio <= CASE WHEN ai.fecha < @fechainicio1 THEN @fechainicio1 ELSE ai.fecha END
                                                           AND d.fchinicio + d.dias - 1 >= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin1 THEN @fechafin1 ELSE CASE WHEN ai.fecha + ai.diastr - 1 < @fechafin1 THEN @fechafin1 ELSE ai.fecha + ai.diastr - 1 END END
                                                      THEN ai.diastr
                                                      ELSE 0
                                                 END 
                                       END
                             END   
                   END AS ausen1,
                   @mes1 AS mes
            FROM @avisosinfonavit AS ai
                 INNER JOIN dbo.deducciones as d ON d.codigo = ai.codigo
                                                    AND ((d.fchinicio <= ai.fecha
                                                          AND d.fchtermino >= ai.fecha
                                                          AND d.fchinicio <= ai.fecha + ai.diastr - 1)
                                                        OR (d.fchinicio >= ai.fecha
                                                            AND d.fchtermino <= ai.fecha + ai.diastr - 1)
                                                        OR (d.fchinicio >= ai.fecha
                                                            AND d.fchinicio <= ai.fecha + ai.diastr - 1
                                                            AND d.fchtermino >= ai.fecha + ai.diastr - 1)
                                                        OR (d.fchinicio <= ai.fecha
                                                            AND d.fchtermino >= ai.fecha + ai.diastr - 1)) 
                                                    AND d.empresa = @empresa
                                                    AND d.num_conc = 108

            WHERE ai.diastr > 0
                  AND d.fchinicio <= @fechafin1
          END

       INSERT @ausen (sec, codigo, ausen2, mes)
       SELECT ai.sec,
              ai.codigo,
			  
              CASE WHEN d.fchinicio <= CASE WHEN ai.fecha < @fechainicio2 THEN @fechainicio2 ELSE ai.fecha END
                        AND d.fchinicio + d.dias - 1 >= CASE WHEN ai.fecha < @fechainicio2 THEN @fechainicio2 ELSE ai.fecha END
                        AND d.fchinicio + d.dias - 1 <= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin2 THEN @fechafin1 ELSE ai.fecha + ai.diastr - 1 END
                   THEN DATEDIFF(dd, CASE WHEN ai.fecha < @fechainicio2 THEN @fechainicio2 ELSE ai.fecha END, d.fchinicio + d.dias)  
                   ELSE CASE WHEN d.fchinicio >= CASE WHEN ai.fecha < @fechainicio2 THEN @fechainicio2 ELSE ai.fecha END
                                  AND d.fchinicio + d.dias - 1 <= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin2 THEN @fechafin2 ELSE ai.fecha + ai.diastr - 1 END
                             THEN d.dias
                             ELSE CASE WHEN d.fchinicio >= CASE WHEN ai.fecha < @fechainicio2 THEN @fechainicio2 ELSE ai.fecha END
                                            AND d.fchinicio <= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin2 THEN @fechafin2 ELSE ai.fecha + ai.diastr - 1 END
                                            AND d.fchinicio + d.dias - 1 >= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin2 THEN @fechafin2 ELSE ai.fecha + ai.diastr - 1 END
                                       THEN DATEDIFF(dd,d.fchinicio, CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin2 THEN @fechafin2 + 1 ELSE ai.fecha + ai.diastr END)
                                       ELSE CASE WHEN d.fchinicio <= CASE WHEN ai.fecha < @fechainicio2 THEN @fechainicio2 ELSE ai.fecha END
                                                      AND d.fchinicio + d.dias - 1 >= CASE WHEN ai.fecha + ai.diastr - 1 > @fechafin2 THEN @fechafin2 ELSE CASE WHEN ai.fecha + ai.diastr - 1 < @fechafin2 THEN @fechafin2 ELSE ai.fecha + ai.diastr - 1 END END
                                                 THEN ai.diastr
                                                 ELSE 0
                                            END 
                                  END
                        END 
              END AS ausen2,
              @mes2 AS mes
       FROM @avisosinfonavit AS ai
            INNER JOIN dbo.deducciones as d ON d.codigo = ai.codigo
                                               AND ((d.fchinicio <= ai.fecha
                                                     AND d.fchtermino >= ai.fecha
                                                     AND d.fchinicio <= ai.fecha + ai.diastr - 1)
                                                    OR (d.fchinicio >= ai.fecha
                                                        AND d.fchtermino <= ai.fecha + ai.diastr - 1)
                                                    OR (d.fchinicio >= ai.fecha
                                                        AND d.fchinicio <= ai.fecha + ai.diastr - 1
                                                        AND d.fchtermino >= ai.fecha + ai.diastr - 1)
                                                    OR (d.fchinicio <= ai.fecha
                                                        AND d.fchtermino >= ai.fecha + ai.diastr - 1)) 
                                               AND d.empresa = @empresa
                                               AND d.num_conc = 108
       WHERE ai.diastr > 0
     
       DECLARE @ausen1 INT
       DECLARE @aiausen1 INT
       DECLARE @codigo1 INT

       SET @ausen1 = 0
       SET @aiausen1 = 0
       SET @codigo1 = 0

       IF @esbimestre = 1
          BEGIN
            UPDATE ai
            SET @ausen1 = CASE WHEN @codigo1 <> ai.codigo THEN 0 ELSE @ausen1 END,
                @ausen1 = @ausen1 + ai.ausen1 + d.ausen,
                ai.ausen1 = CASE WHEN @ausen1 < @topeausen
                                 THEN d.ausen
                                 ELSE CASE WHEN d.ausen - (@ausen1 - @topeausen) < 0
								           THEN 0
									       ELSE d.ausen - (@ausen1 - @topeausen)
									  END
                            END,
                @codigo1 = ai.codigo
            FROM @avisosinfonavit AS ai
                 INNER JOIN (SELECT d.codigo,
                                    d.sec,
                                    SUM(d.ausen1) AS ausen
                             FROM @ausen AS d
                             WHERE d.mes = @mes1
						           AND d.ausen1 > 0
                             GROUP BY d.codigo,
                                      d.sec,
                                      d.mes) AS d ON d.codigo = ai.codigo
                                                     AND d.sec = ai.sec
          END                                       

       DECLARE @ausen2 INT
       DECLARE @aiausen2 INT
       DECLARE @codigo2 INT

       SET @ausen2 = 0
       SET @aiausen2 = 0
       SET @codigo2 = 0

       UPDATE ai
       SET @ausen2 = CASE WHEN @codigo2 <> ai.codigo THEN 0 ELSE @ausen2 END,
           @ausen2 = @ausen2 + ai.ausen2 + d.ausen,
           ai.ausen2 = CASE WHEN @ausen2 < @topeausen
                            THEN d.ausen
                            ELSE CASE WHEN d.ausen - (@ausen2 - @topeausen) < 0
			                          THEN 0
                                      ELSE d.ausen - (@ausen2 - @topeausen)
                                 END
                       END,
           @codigo2 = ai.codigo
       FROM @avisosinfonavit AS ai
            INNER JOIN (SELECT d.codigo,
                               d.sec,
                               SUM(d.ausen2) AS ausen
                        FROM @ausen AS d
                        WHERE d.mes = @mes2
						      AND d.ausen2 > 0
                        GROUP BY d.codigo,
                                 d.sec,
                                 d.mes) AS d ON d.codigo = ai.codigo
                                                AND d.sec = ai.sec
       WHERE MONTH(ai.fecha) = @mes2

       DECLARE @descuento TABLE (tipo_cred INT, descuento NUMERIC(8,4), vecesMinimo NUMERIC(5,2), vecesMaximo NUMERIC(5,2), descuentoAplicar NUMERIC(8,4), fechaOtorgamiento DATETIME)

       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 20, 0.01, 002.50, 15.7, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 20, 2.51, 003.50, 16.8, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 20, 3.51, 004.50, 17.2, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 20, 4.51, 005.50, 17.7, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 20, 5.51, 006.50, 17.8, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 20, 6.51, 999.99, 20.0, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 25, 0.01, 002.50, 19.6, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 25, 2.51, 003.50, 21.0, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 25, 3.51, 004.50, 21.5, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 25, 4.51, 005.50, 22.1, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 25, 5.51, 006.50, 22.3, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 25, 6.51, 999.99, 25.0, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 30, 0.01, 002.50, 24.6, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 30, 2.51, 003.50, 26.0, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 30, 3.51, 004.50, 26.5, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 30, 4.51, 005.50, 27.1, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 30, 5.51, 006.50, 27.3, '19980130')
       INSERT @descuento (tipo_cred, descuento, vecesMinimo, vecesMaximo, descuentoAplicar, fechaOtorgamiento) VALUES (1, 30, 6.51, 999.99, 30.0, '19980130')

       DECLARE @veces NUMERIC(7,2)
       SET @veces = 0

       -- Actualiza UMA o salario minimo que corresponda al movimiento
       -- y para los creditos tipo 1 y fecha anterior o igual al 30/01/1998
       -- pone el SBC del inicio de bimestre
       IF @fechainicio >= @fechaaplicauma
          BEGIN
            SELECT TOP 1
                   @umadiario = tu.umaDiario
            FROM dbo.TblUma AS tu
            WHERE tu.fecha <= @fechafin
            ORDER BY tu.fecha DESC
     
            SELECT TOP 1
                   @umafd = ufd.umaDiario
            FROM dbo.TblUMAFD AS ufd
            WHERE ufd.fecha <= @fechafin
            ORDER BY ufd.fecha DESC

            UPDATE ai
            SET ai.saldf_uma = @umadiario,
                ai.topedf_uma = ROUND(@umadiario * 25,2),
                ai.umaFD = CASE WHEN @fechainicio >= @fechaaplicaumafd THEN @umafd ELSE @umadiario END,
                ai.sbcInicioBimestre = CASE WHEN ai.tipo_cred = 1 AND i.fch_otorga <= '19980130' AND @aplicarsbciniciobimestre = 1 THEN ai1.saldiaint ELSE ai.saldiaint END,
                ai.veces = CASE WHEN ai.tipo_cred = 1 AND i.fch_otorga <= '19980130' THEN ROUND(ai1.saldiaint / @umadiario,2) ELSE 0 END,
                ai.fechaOtorgamiento = i.fch_otorga
            FROM @avisosinfonavit AS ai
                 INNER JOIN dbo.infonavit AS i ON i.codigo = ai.codigo AND i.empresa = @empresa
                 CROSS APPLY (SELECT TOP 1
                                     ai1.saldiaint
                              FROM @avisosinfonavit AS ai1
                              WHERE ai1.codigo = ai.codigo
                                    AND ai.diastr > 0
                              ORDER BY ai1.fecha ASC,
                                       ai1.sec ASC) AS ai1
          END    
       ELSE
          BEGIN
            SELECT TOP 1
                   @salariominimo = sm.zona_a
            FROM dbo.salarios_minimos AS sm
            WHERE sm.fecha_ini <= @fechafin
            ORDER BY sm.fecha_ini DESC

            UPDATE ai
            SET saldf_uma = @salariominimo,
                topedf_uma = ROUND(@salariominimo * 25,2),
                umaFD = @salariominimo,
                sbcInicioBimestre = CASE WHEN ai.tipo_cred = 1 AND i.fch_otorga <= '19980130' THEN ai1.saldiaint ELSE ai.saldiaint END,
                fechaOtorgamiento = i.fch_otorga
            FROM @avisosinfonavit AS ai
                 INNER JOIN dbo.infonavit AS i ON i.codigo = ai.codigo AND i.empresa = @empresa
                 CROSS APPLY (SELECT TOP 1
                                     ai1.saldiaint
                              FROM @avisosinfonavit AS ai1
                              WHERE ai1.codigo = ai.codigo
                                    AND ai.diastr > 0
                              ORDER BY ai1.fecha ASC,
                                       ai1.sec ASC) AS ai1
          END

   
       -- Aplica descuento para los creditos tipo 1 
       -- y fecha de otorgamiento menor o igual a 30/01/1998   
       UPDATE ai
       SET ai.descuento = ISNULL(d.descuentoAplicar, ai.descuento)
       FROM @avisosinfonavit AS ai
            INNER JOIN @descuento AS d ON ai.tipo_cred = d.tipo_cred 
                                          AND ai.descuento = d.descuento
                                          AND ai.fechaOtorgamiento <= d.fechaOtorgamiento
                                          AND ai.veces >= d.vecesMinimo
                                          AND ai.veces <= d.vecesMaximo
                                        
       -- El calculo de la amortizacion siempre se hace considerando el tipo y valor de descuento
       -- registrado antes o igual al inicio del bimestre
       UPDATE ai
       SET ai.tipoCreditoParaCalculo = ai1.tipo_cred,
           ai.descuentoParaCalculo = ai1.descuento
       FROM @avisosinfonavit AS ai
            CROSS APPLY (SELECT TOP 1
                                ai1.tipo_cred,
                                ai1.descuento
                         FROM @avisosinfonavit AS ai1
                         WHERE ai1.codigo = ai.codigo
                         ORDER BY ai1.fecha ASC) AS ai1


       -- Calculo de amortizacin
       UPDATE ai
       SET ai.amortizacion = CASE ai.tipoCreditoParaCalculo WHEN 1 THEN ai.sbcInicioBimestre * (ai.diastr - ai.ausen1 - ai.ausen2 - CASE WHEN @convenio = 1 THEN 0 ELSE ai.incap END) * (ai.descuentoParaCalculo / 100)
                                                            WHEN 2 THEN ((ai.descuentoParaCalculo * 2) / @diasbimestre) * (ai.diastr - ai.ausen1 - ai.ausen2 - CASE WHEN @convenio = 1 THEN 0 ELSE ai.incap END) 
                                                            WHEN 3 THEN ((ai.descuentoParaCalculo * 2 * CASE WHEN @fechainicio >= @fechaaplicauma
                                                                                                             THEN CASE WHEN @fechainicio >= @fechaaplicaumafd
                                                                                                                       THEN ai.umaFD 
                                                                                                                       ELSE ai.saldf_uma 
                                                                                                                  END 
                                                                                                             ELSE saldf_uma 
                                                                                                        END) / @diasbimestre ) * (ai.diastr - ai.ausen1 - ai.ausen2 - CASE WHEN @convenio = 1 THEN 0 ELSE ai.incap END) 
                                                            ELSE 0 
                             END
       FROM @avisosinfonavit AS ai
       WHERE ai.diastr > 0
     
       -- Seguro de vivienda
       UPDATE ai
       SET ai.seguroVivienda = @segurovivienda
       FROM @avisosinfonavit AS ai
       WHERE ai.sec = (SELECT TOP 1
                              ai1.sec
                       FROM @avisosinfonavit AS ai1
                       WHERE ai1.codigo = ai.codigo
                       ORDER BY ai.sec)

       DELETE dbo.TemporalAmortizacion

       INSERT dbo.TemporalAmortizacion
              (empresa ,
               codigo ,
               descuento,
               amortizacion,
               clase,
			   tipo_cred,
			   numcredito)
               SELECT @empresa AS empresa,
                      ai.codigo,
                      ai.descuentoParaCalculo,
                      SUM(amortizacion) AS amortizacion,
                      ll.clase,
					  ai.tipo_cred,
					  ai.numcredito
               FROM @avisosinfonavit AS ai
                    INNER JOIN dbo.Llaves AS ll ON ll.codigo = ai.codigo
                                                   AND ll.empresa = @empresa
               GROUP BY ai.codigo,
                        ai.descuentoParaCalculo,
                        ll.clase,
                        ai.tipo_cred,
                        ai.numcredito

       INSERT dbo.TemporalAmortizacion
              (empresa ,
               codigo ,
               descuento,
               amortizacion,
               clase,
			   tipo_cred,
			   numcredito)

               SELECT e.empresa
                      , e.codigo
		              , 0 AS descuento
		              , 0 AS amortizacion
                      , ll.clase
		              , i.tipo_cred
		              , i.numcredito
               FROM dbo.empleados AS e
                    INNER JOIN dbo.Llaves AS ll ON e.empresa = ll.empresa
	                                               AND e.codigo = ll.codigo

	                CROSS APPLY (SELECT TOP 1
                                        a.codigo
                                 FROM dbo.avisos_imss AS a
                                 WHERE a.empresa = e.empresa
                                       AND a.codigo = e.codigo
                                       AND a.fch_mov >= @fechainicio1
                                       AND a.fch_mov <= @fechafin2) AS a
	  
	                CROSS APPLY (SELECT TOP 1
	                                    i.numcredito
                                        , i.tipo_cred
                                 FROM dbo.infonavit AS i
                                 WHERE i.empresa = e.empresa
				                       AND i.codigo = e.codigo
                                       AND i.fecha <= @fechafin2
	                                   AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fechainicio1
	                                   AND ISNULL(i.fch_termino, @FechaFinita) >= @fechainicio1) AS i
       
	                LEFT JOIN dbo.TemporalAmortizacion AS ta ON e.empresa = ta.empresa
	                                                            AND e.codigo = ta.codigo
 
               WHERE e.empresa = @empresa
                     AND e.borrado = 'N'
		             AND ta.codigo IS NULL
     END
GO

IF OBJECT_ID('dbo.CargaIeMoPers') IS NOT NULL 
    DROP PROCEDURE dbo.CargaIeMoPers
GO
CREATE PROCEDURE dbo.CargaIeMoPers
    @empresa INT ,
    @ayo INT ,
    @mes INT
AS 
    DECLARE @asegurados INT
    DECLARE @altas INT
    DECLARE @bajas INT
    DECLARE @vigentes INT
    DECLARE @modsalario INT
    DECLARE @variables INT


    SELECT  @asegurados = ISNULL(COUNT(DISTINCT dbo.avisos_imss.codigo), 0) ,
            @altas = ISNULL(SUM(CASE WHEN dbo.avisos_imss.mov = 'RI' THEN 1
                                     WHEN dbo.avisos_imss.mov = 'A' THEN 1
                                     ELSE 0
                                END), 0) ,
            @bajas = ISNULL(SUM(CASE WHEN dbo.avisos_imss.mov = 'B' THEN 1
                                     ELSE 0
                                END), 0) ,
            @vigentes = ISNULL(SUM(CASE WHEN dbo.avisos_imss.mov = 'RI' THEN 1
                                        WHEN dbo.avisos_imss.mov = 'A' THEN 1
                                        WHEN dbo.avisos_imss.mov = 'B' THEN -1
                                        ELSE 0
                                   END), 0) ,
            @modsalario = ISNULL(SUM(CASE WHEN dbo.avisos_imss.mov = 'MS'
                                          THEN 1
                                          ELSE 0
                                     END), 0) ,
            @variables = ISNULL(SUM(CASE WHEN dbo.avisos_imss.mov = 'MS'
                                              AND dbo.avisos_imss.origen = 'V'
                                         THEN 1
                                         ELSE 0
                                    END), 0)
    FROM    dbo.avisos_imss
            INNER JOIN dbo.empleados ON dbo.avisos_imss.empresa = dbo.empleados.empresa
                                        AND dbo.avisos_imss.codigo = dbo.empleados.codigo
    WHERE   dbo.avisos_imss.empresa = @empresa
            AND dbo.avisos_imss.ayo_operacion = @ayo
            AND dbo.avisos_imss.mes_operacion = @mes
        
    IF EXISTS ( SELECT  dbo.ie_mopers.empresa
                FROM    dbo.ie_mopers
                WHERE   dbo.ie_mopers.empresa = @empresa
                        AND dbo.ie_mopers.vyear = @ayo
                        AND dbo.ie_mopers.mes = @mes ) 
        UPDATE  dbo.ie_mopers
        SET     dbo.ie_mopers.asegurados = @asegurados ,
                dbo.ie_mopers.altas = @altas ,
                dbo.ie_mopers.bajas = @bajas ,
                dbo.ie_mopers.vigentes = @vigentes ,
                dbo.ie_mopers.modsalario = @modsalario ,
                dbo.ie_mopers.avisosbim = @variables
        WHERE   dbo.ie_mopers.empresa = @empresa
                AND dbo.ie_mopers.vyear = @ayo
                AND dbo.ie_mopers.mes = @mes
    ELSE 
        INSERT  dbo.ie_mopers
                ( empresa ,
                  vyear ,
                  mes ,
                  asegurados ,
                  altas ,
                  bajas ,
                  vigentes ,
                  modsalario ,
                  avisosbim ,
                  totalanual ,
                  observaciones
                )
        VALUES  ( @empresa , -- empresa - numeric
                  @ayo , -- vyear - int
                  @mes , -- mes - smallint
                  @asegurados , -- asegurados - bigint
                  @altas , -- altas - bigint
                  @bajas , -- bajas - bigint
                  @vigentes , -- vigentes - bigint
                  @modsalario , -- modsalario - bigint
                  @variables , -- avisosbim - bigint
                  0 , -- totalanual - bigint
                  ''  -- observaciones - varchar(250)
                )
GO            

IF OBJECT_ID('dbo.CargaIeTrabajadores') IS NOT NULL 
    DROP PROCEDURE dbo.CargaIeTrabajadores
GO
CREATE PROCEDURE dbo.CargaIeTrabajadores
    @empresa INT ,
    @ayo INT ,
    @mes INT
AS 
    DECLARE @noPaganNomina INT
    DECLARE @noPaganIMSS INT
    DECLARE @conInfonavit INT
    DECLARE @ff DATETIME

    SET @ff = dbo.fin_mes(@mes, @ayo)

    SELECT  @noPaganNomina = ISNULL(SUM(CASE WHEN dbo.empleados.pagar_nomina = 'N'
                                             THEN 1
                                             ELSE 0
                                        END), 0) ,
            @noPaganIMSS = ISNULL(SUM(CASE WHEN dbo.empleados.cotiza_imss = 'N'
                                           THEN 1
                                           ELSE 0
                                      END), 0)
    FROM    dbo.empleados
            INNER JOIN dbo.avisos_imss ON dbo.empleados.empresa = dbo.avisos_imss.empresa
                                          AND dbo.empleados.codigo = dbo.avisos_imss.codigo
    WHERE   dbo.avisos_imss.empresa = @empresa
            AND dbo.avisos_imss.ayo_operacion = @ayo
            AND dbo.avisos_imss.mes_operacion = @mes

    SELECT  @conInfonavit = ISNULL(COUNT(DISTINCT dbo.infonavit.codigo), 0)
    FROM    dbo.infonavit
            INNER JOIN dbo.avisos_imss ON dbo.infonavit.empresa = dbo.avisos_imss.empresa
                                          AND dbo.infonavit.codigo = dbo.avisos_imss.codigo
    WHERE   dbo.infonavit.empresa = @empresa
            AND dbo.infonavit.fecha <= @ff
            AND dbo.infonavit.fch_termino >= @ff
            AND dbo.avisos_imss.ayo_operacion = @ayo
            AND dbo.avisos_imss.mes_operacion = @mes
        
    IF EXISTS ( SELECT  dbo.ie_trabajadores.empresa
                FROM    dbo.ie_trabajadores
                WHERE   dbo.ie_trabajadores.empresa = @empresa
                        AND dbo.ie_trabajadores.vyear = @ayo
                        AND dbo.ie_trabajadores.mes = @mes ) 
        UPDATE  dbo.ie_trabajadores
        SET     dbo.ie_trabajadores.noPaganNomina = @noPaganNomina ,
                dbo.ie_trabajadores.noPaganIMSS = @noPaganIMSS ,
                dbo.ie_trabajadores.conInfonavit = @conInfonavit
        WHERE   dbo.ie_trabajadores.empresa = @empresa
                AND dbo.ie_trabajadores.vyear = @ayo
                AND dbo.ie_trabajadores.mes = @mes
    ELSE 
        INSERT  dbo.ie_trabajadores
                ( empresa ,
                  vyear ,
                  mes ,
                  noPaganNomina ,
                  noPaganIMSS ,
                  conInfonavit
                )
        VALUES  ( @empresa , -- empresa - numeric
                  @ayo , -- vyear - int
                  @mes , -- mes - smallint
                  @noPaganNomina , -- noPaganNomina - bigint
                  @noPaganIMSS , -- noPaganIMSS - bigint
                  @conInfonavit  -- conInfonavit - bigint
                )
GO

/**************************************************************************************************
 * Name          : CargaSeleccionElementos
 * Project       : APSI Nomina
 * Description   : Llena tabla temporal con los elementos seleccionados
 * Table name    : SeleccionElemtos
 * Return        : 
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Viernes, Julio 02, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'CargaSeleccionElementos' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[CargaSeleccionElementos]
    END
GO


CREATE PROCEDURE [dbo].[CargaSeleccionElementos]
    @empresa INT ,
    @procesoId INT ,
    @procesoName VARCHAR(100) ,
    @codigo INT ,
    @nomina VARCHAR(15) ,
    @tipoNomina INT ,
    @centro VARCHAR(15) ,
    @clase VARCHAR(5) ,
    @supvervisor INT
AS 
    IF NOT EXISTS ( SELECT  codigo
                    FROM    dbo.SeleccionElementos
                    WHERE   dbo.SeleccionElementos.empresa = @empresa
                            AND RTRIM(LTRIM(dbo.SeleccionElementos.procesoName)) = RTRIM(LTRIM(@procesoName))
                            AND dbo.SeleccionElementos.codigo = @codigo
                            AND dbo.SeleccionElementos.nomina = @nomina
                            AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                            AND dbo.SeleccionElementos.centro = @centro
                            AND dbo.SeleccionElementos.clase = @clase ) 
        INSERT  dbo.SeleccionElementos
                ( empresa ,
                  procesoId ,
                  procesoName ,
                  codigo ,
                  nomina ,
                  tipoNomina ,
                  centro ,
                  clase ,
                  supvervisor
                )
        VALUES  ( @empresa , -- empresa - int
                  @procesoId , -- procesoId - int
                  @procesoName , -- procesoName - varchar(50)
                  @codigo , -- codigo - int
                  @nomina ,
                  @tipoNomina ,
                  @centro , -- centro - varchar(15)
                  @clase , -- clase - varchar(5)
                  @supvervisor  -- supvervisor - int
                )
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[capa_entidad]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)  
CREATE TABLE [dbo].[capa_entidad](
	[idEntidad] [bigint] NOT NULL,
	[entidad] [varchar](100) NULL,
 CONSTRAINT [PK_capa_entidad] PRIMARY KEY CLUSTERED 
(
	[idEntidad] ASC
)
) ON [PRIMARY]
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[capa_poblacion]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)  
CREATE TABLE [dbo].[capa_poblacion](
	[idEntidad] [bigint] NOT NULL,
	[idPoblacion] [bigint] NOT NULL,
	[poblacion] [varchar](250) NULL,
 CONSTRAINT [PK_capa_poblacion] PRIMARY KEY CLUSTERED 
(
	[idEntidad] ASC,
	[idPoblacion] ASC
)
) ON [PRIMARY]
GO


IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'CatalogoPoblacion'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.CatalogoPoblacion
GO

CREATE PROCEDURE  dbo.CatalogoPoblacion
	
AS
BEGIN

		delete from capa_poblacion
		
		insert into capa_poblacion values (1,1,'AGUASCALIENTES')
		insert into capa_poblacion values (1,2,'ASIENTOS')
		insert into capa_poblacion values (1,3,'CALVILLO')
		insert into capa_poblacion values (1,4,'COSIO')
		insert into capa_poblacion values (1,5,'JESUS MARIA')
		insert into capa_poblacion values (1,6,'PABELLON DE ARTEAGA')
		insert into capa_poblacion values (1,7,'RINCON DE ROMOS')
		insert into capa_poblacion values (1,8,'SAN JOSE DE GRACIA')
		insert into capa_poblacion values (1,9,'TEPEZALA')
		insert into capa_poblacion values (1,10,'SAN FRANCISCO DE LOS ROMO')
		insert into capa_poblacion values (2,1,'ENSENADA')
		insert into capa_poblacion values (2,2,'MEXICALI')
		insert into capa_poblacion values (2,3,'TECATE')
		insert into capa_poblacion values (2,4,'TIJUANA')
		insert into capa_poblacion values (2,5,'PLAYAS DE ROSARITO')
		insert into capa_poblacion values (3,1,'COMONDU')
		insert into capa_poblacion values (3,2,'MULEGE')
		insert into capa_poblacion values (3,3,'LA PAZ')
		insert into capa_poblacion values (3,4,'LOS CABOS')
		insert into capa_poblacion values (3,5,'LORETO')
		insert into capa_poblacion values (4,1,'CALKINI')
		insert into capa_poblacion values (4,2,'CAMPECHE')
		insert into capa_poblacion values (4,3,'CIUDAD DEL CARMEN')
		insert into capa_poblacion values (4,4,'CHAMPOTON')
		insert into capa_poblacion values (4,5,'HECELCHAKAN')
		insert into capa_poblacion values (4,6,'HOPELCHEN')
		insert into capa_poblacion values (4,7,'PALIZADA')
		insert into capa_poblacion values (4,8,'TENABO')
		insert into capa_poblacion values (4,9,'ESCARCEGA')
		insert into capa_poblacion values (4,10,'CALAKMUL')
		insert into capa_poblacion values (4,11,'CANDELARIA')
		insert into capa_poblacion values (5,1,'ABASOLO')
		insert into capa_poblacion values (5,2,'ACUNA')
		insert into capa_poblacion values (5,3,'ALLENDE')
		insert into capa_poblacion values (5,4,'ARTEAGA')
		insert into capa_poblacion values (5,5,'CANDELA')
		insert into capa_poblacion values (5,6,'CASTANOS')
		insert into capa_poblacion values (5,7,'CUATROCIENEGAS DE CARRANZA')
		insert into capa_poblacion values (5,8,'ESCOBEDO')
		insert into capa_poblacion values (5,9,'FRANCISCO I MADERO')
		insert into capa_poblacion values (5,10,'FRONTERA')
		insert into capa_poblacion values (5,11,'GENERAL CEPEDA')
		insert into capa_poblacion values (5,12,'GUERRERO')
		insert into capa_poblacion values (5,13,'HIDALGO')
		insert into capa_poblacion values (5,14,'JIMENEZ')
		insert into capa_poblacion values (5,15,'JUAREZ')
		insert into capa_poblacion values (5,16,'LAMADRID')
		insert into capa_poblacion values (5,17,'MATAMOROS')
		insert into capa_poblacion values (5,18,'MONCLOVA')
		insert into capa_poblacion values (5,19,'MORELOS')
		insert into capa_poblacion values (5,20,'MELCHOR MUZQUIZ')
		insert into capa_poblacion values (5,21,'NADADORES')
		insert into capa_poblacion values (5,22,'NAVA')
		insert into capa_poblacion values (5,23,'OCAMPO')
		insert into capa_poblacion values (5,24,'PARRAS DE LA FUENTE')
		insert into capa_poblacion values (5,25,'PIEDRAS NEGRAS')
		insert into capa_poblacion values (5,26,'PROGRESO')
		insert into capa_poblacion values (5,27,'RAMOS ARIZPE')
		insert into capa_poblacion values (5,28,'SABINAS')
		insert into capa_poblacion values (5,29,'SACRAMENTO')
		insert into capa_poblacion values (5,30,'SALTILLO')
		insert into capa_poblacion values (5,31,'SAN BUENAVENTURA')
		insert into capa_poblacion values (5,32,'SAN JUAN DE SABINAS')
		insert into capa_poblacion values (5,33,'SAN PEDRO DE LAS COLONIAS')
		insert into capa_poblacion values (5,34,'SIERRA MOJADA')
		insert into capa_poblacion values (5,35,'TORREON')
		insert into capa_poblacion values (5,36,'VIESCA')
		insert into capa_poblacion values (5,37,'VILLA UNION')
		insert into capa_poblacion values (5,38,'ZARAGOZA')
		insert into capa_poblacion values (6,1,'ARMERIA')
		insert into capa_poblacion values (6,2,'COLIMA')
		insert into capa_poblacion values (6,3,'COMALA')
		insert into capa_poblacion values (6,4,'COQUIMATLAN')
		insert into capa_poblacion values (6,5,'CUAUHTEMOC')
		insert into capa_poblacion values (6,6,'IXTLAHUACAN')
		insert into capa_poblacion values (6,7,'MANZANILLO')
		insert into capa_poblacion values (6,8,'MINATITLAN')
		insert into capa_poblacion values (6,9,'TECOMAN')
		insert into capa_poblacion values (6,10,'VILLA DE ALVAREZ')
		insert into capa_poblacion values (7,1,'ACACOYAGUA')
		insert into capa_poblacion values (7,2,'ACALA')
		insert into capa_poblacion values (7,3,'ACAPETAGUA')
		insert into capa_poblacion values (7,4,'ALTAMIRANO')
		insert into capa_poblacion values (7,5,'AMATAN')
		insert into capa_poblacion values (7,6,'AMATENANGO DE LA FRONTERA')
		insert into capa_poblacion values (7,7,'AMATENANGO DEL VALLE')
		insert into capa_poblacion values (7,8,'ANGEL ALBINO CORZO')
		insert into capa_poblacion values (7,9,'ARRIAGA')
		insert into capa_poblacion values (7,10,'BEJUCAL DE OCAMPO')
		insert into capa_poblacion values (7,11,'BELLA VISTA')
		insert into capa_poblacion values (7,12,'BERRIOZABAL')
		insert into capa_poblacion values (7,13,'BOCHIL')
		insert into capa_poblacion values (7,14,'EL BOSQUE')
		insert into capa_poblacion values (7,15,'CACAHOATAN')
		insert into capa_poblacion values (7,16,'CATAZAJA')
		insert into capa_poblacion values (7,17,'CINTALAPA DE FIGUEROA')
		insert into capa_poblacion values (7,18,'COAPILLA')
		insert into capa_poblacion values (7,19,'COMITAN DE DOMINGUEZ')
		insert into capa_poblacion values (7,20,'LA CONCORDIA')
		insert into capa_poblacion values (7,21,'COPAINALA')
		insert into capa_poblacion values (7,22,'CHALCHIHUITAN')
		insert into capa_poblacion values (7,23,'CHAMULA')
		insert into capa_poblacion values (7,24,'CHANAL')
		insert into capa_poblacion values (7,25,'CHAPULTENANGO')
		insert into capa_poblacion values (7,26,'CHENALHO')
		insert into capa_poblacion values (7,27,'CHIAPA DE CORZO')
		insert into capa_poblacion values (7,28,'CHIAPILLA')
		insert into capa_poblacion values (7,29,'CHICOASEN')
		insert into capa_poblacion values (7,30,'CHICOMUSELO')
		insert into capa_poblacion values (7,31,'CHILON')
		insert into capa_poblacion values (7,32,'ESCUINTLA')
		insert into capa_poblacion values (7,33,'FRANCISCO LEON')
		insert into capa_poblacion values (7,34,'FRONTERA COMALAPA')
		insert into capa_poblacion values (7,35,'FRONTERA HIDALGO')
		insert into capa_poblacion values (7,36,'LA GRANDEZA')
		insert into capa_poblacion values (7,37,'HUEHUETAN')
		insert into capa_poblacion values (7,38,'HUISTAN')
		insert into capa_poblacion values (7,39,'HUITIUPAN')
		insert into capa_poblacion values (7,40,'HUIXTLA')
		insert into capa_poblacion values (7,41,'LA INDEPENDENCIA')
		insert into capa_poblacion values (7,42,'ISHUATAN')
		insert into capa_poblacion values (7,43,'IXTACOMITAN')
		insert into capa_poblacion values (7,44,'IXTAPA')
		insert into capa_poblacion values (7,45,'IXTAPANGAJOYA')
		insert into capa_poblacion values (7,46,'JIQUIPILAS')
		insert into capa_poblacion values (7,47,'JITOTOL')
		insert into capa_poblacion values (7,48,'JUAREZ')
		insert into capa_poblacion values (7,49,'LARRAINZAR')
		insert into capa_poblacion values (7,50,'LA LIBERTAD')
		insert into capa_poblacion values (7,51,'MAPASTEPEC')
		insert into capa_poblacion values (7,52,'LAS MARGARITAS')
		insert into capa_poblacion values (7,53,'MAZAPA DE MADERO')
		insert into capa_poblacion values (7,54,'MAZATAN')
		insert into capa_poblacion values (7,55,'METAPA DE DOMINGUEZ')
		insert into capa_poblacion values (7,56,'MITONTIC')
		insert into capa_poblacion values (7,57,'MOTOZINTLA DE MENDOZA')
		insert into capa_poblacion values (7,58,'NICOLAS RUIZ')
		insert into capa_poblacion values (7,59,'OCOSINGO')
		insert into capa_poblacion values (7,60,'OCOTEPEC')
		insert into capa_poblacion values (7,61,'OCOZOCOAUTLA DE ESPINOSA')
		insert into capa_poblacion values (7,62,'OSTUACAN')
		insert into capa_poblacion values (7,63,'OSUMACINTA')
		insert into capa_poblacion values (7,64,'OXCHUC')
		insert into capa_poblacion values (7,65,'PALENQUE')
		insert into capa_poblacion values (7,66,'PANTELHO')
		insert into capa_poblacion values (7,67,'PANTEPEC')
		insert into capa_poblacion values (7,68,'PICHUCALCO')
		insert into capa_poblacion values (7,69,'PIJIJIAPAN')
		insert into capa_poblacion values (7,70,'EL PORVENIR')
		insert into capa_poblacion values (7,71,'VILLA DE COMALTITLAN')
		insert into capa_poblacion values (7,72,'PUEBLO NUEVO SOLISTAHUACAN')
		insert into capa_poblacion values (7,73,'RAYON')
		insert into capa_poblacion values (7,74,'REFORMA')
		insert into capa_poblacion values (7,75,'LAS ROSAS')
		insert into capa_poblacion values (7,76,'SABANILLA')
		insert into capa_poblacion values (7,77,'SALTO DE AGUA')
		insert into capa_poblacion values (7,78,'SAN CRISTOBAL DE LAS CASAS')
		insert into capa_poblacion values (7,79,'SAN FERNANDO')
		insert into capa_poblacion values (7,80,'SILTEPEC')
		insert into capa_poblacion values (7,81,'SIMOJOVEL DE ALLENDE')
		insert into capa_poblacion values (7,82,'SITALA')
		insert into capa_poblacion values (7,83,'SOCOLTENANGO')
		insert into capa_poblacion values (7,84,'SOLUSUCHIAPA')
		insert into capa_poblacion values (7,85,'SOYALO')
		insert into capa_poblacion values (7,86,'SUCHIAPA')
		insert into capa_poblacion values (7,87,'SUCHIATE')
		insert into capa_poblacion values (7,88,'SUNUAPA')
		insert into capa_poblacion values (7,89,'TAPACHULA')
		insert into capa_poblacion values (7,90,'TAPALAPA')
		insert into capa_poblacion values (7,91,'TAPILULA')
		insert into capa_poblacion values (7,92,'TECPATAN')
		insert into capa_poblacion values (7,93,'TENEJAPA')
		insert into capa_poblacion values (7,94,'TEOPISCA')
		insert into capa_poblacion values (7,95,'TERAN')
		insert into capa_poblacion values (7,96,'TILA')
		insert into capa_poblacion values (7,97,'TONALA')
		insert into capa_poblacion values (7,98,'TOTOLAPA')
		insert into capa_poblacion values (7,99,'LA TRINITARIA')
		insert into capa_poblacion values (7,100,'TUMBALA')
		insert into capa_poblacion values (7,101,'TUXTLA GUTIERREZ')
		insert into capa_poblacion values (7,102,'TUXTLA CHICO')
		insert into capa_poblacion values (7,103,'TUZANTAN')
		insert into capa_poblacion values (7,104,'TZIMOL')
		insert into capa_poblacion values (7,105,'UNION JUAREZ')
		insert into capa_poblacion values (7,106,'VENUSTIANO CARRANZA')
		insert into capa_poblacion values (7,107,'VILLACORZO')
		insert into capa_poblacion values (7,108,'VILLA FLORES')
		insert into capa_poblacion values (7,109,'YAJALON')
		insert into capa_poblacion values (7,110,'SAN LUCAS')
		insert into capa_poblacion values (7,111,'ZINACANTAN')
		insert into capa_poblacion values (7,112,'SAN JUAN CANCUC')
		insert into capa_poblacion values (7,113,'ALDAMA')
		insert into capa_poblacion values (7,114,'BENEMERITO DE LAS AMERICAS')
		insert into capa_poblacion values (7,115,'MARAVILLA TENEJAPA')
		insert into capa_poblacion values (7,116,'MARQUES DE COMILLAS')
		insert into capa_poblacion values (7,117,'MONTECRISTO DE GUERRERO')
		insert into capa_poblacion values (7,118,'SAN ANDRES DURAZNAL')
		insert into capa_poblacion values (7,119,'SANTIAGO EL PINAR')
		insert into capa_poblacion values (8,1,'AHUMADA')
		insert into capa_poblacion values (8,2,'ALDAMA')
		insert into capa_poblacion values (8,3,'VALLE DE ALLENDE')
		insert into capa_poblacion values (8,4,'AQUILES SERDAN')
		insert into capa_poblacion values (8,5,'ASCENSION')
		insert into capa_poblacion values (8,6,'BACHINIVA')
		insert into capa_poblacion values (8,7,'BALLEZA')
		insert into capa_poblacion values (8,8,'BATOPILAS')
		insert into capa_poblacion values (8,9,'BOCOYNA')
		insert into capa_poblacion values (8,10,'BUENAVENTURA')
		insert into capa_poblacion values (8,11,'CAMARGO')
		insert into capa_poblacion values (8,12,'CARICHIC')
		insert into capa_poblacion values (8,13,'CASAS GRANDES')
		insert into capa_poblacion values (8,14,'CORONADO')
		insert into capa_poblacion values (8,15,'COYAME')
		insert into capa_poblacion values (8,16,'LA CRUZ')
		insert into capa_poblacion values (8,17,'CUAUHTEMOC')
		insert into capa_poblacion values (8,18,'CUSIHUIRIACHIC')
		insert into capa_poblacion values (8,19,'CHIHUAHUA')
		insert into capa_poblacion values (8,20,'CHINIPAS')
		insert into capa_poblacion values (8,21,'DELICIAS')
		insert into capa_poblacion values (8,22,'DOCTOR BELISARIO DOMINGUEZ')
		insert into capa_poblacion values (8,23,'GALEANA')
		insert into capa_poblacion values (8,24,'GENERAL TRIAS')
		insert into capa_poblacion values (8,25,'GOMEZ FARIAS')
		insert into capa_poblacion values (8,26,'GRAN MORELOS')
		insert into capa_poblacion values (8,27,'GUACHOCHI')
		insert into capa_poblacion values (8,28,'GUADALUPE')
		insert into capa_poblacion values (8,29,'GUADALUPE Y CALVO')
		insert into capa_poblacion values (8,30,'GUAZAPARES')
		insert into capa_poblacion values (8,31,'GUERRERO')
		insert into capa_poblacion values (8,32,'HIDALGO DEL PARRAL')
		insert into capa_poblacion values (8,33,'HUEJOTITAN')
		insert into capa_poblacion values (8,34,'IGNACIO ZARAGOZA')
		insert into capa_poblacion values (8,35,'JANOS')
		insert into capa_poblacion values (8,36,'JIMENEZ')
		insert into capa_poblacion values (8,37,'JUAREZ')
		insert into capa_poblacion values (8,38,'JULIMES')
		insert into capa_poblacion values (8,39,'LOPEZ')
		insert into capa_poblacion values (8,40,'MADERA')
		insert into capa_poblacion values (8,41,'MAGUARICHIC')
		insert into capa_poblacion values (8,42,'MANUEL BENAVIDES')
		insert into capa_poblacion values (8,43,'MATACHIC')
		insert into capa_poblacion values (8,44,'MATAMOROS')
		insert into capa_poblacion values (8,45,'MEOQUI')
		insert into capa_poblacion values (8,46,'MORELOS')
		insert into capa_poblacion values (8,47,'MORIS')
		insert into capa_poblacion values (8,48,'NAMIQUIPA')
		insert into capa_poblacion values (8,49,'NONOAVA')
		insert into capa_poblacion values (8,50,'NUEVO CASAS GRANDES')
		insert into capa_poblacion values (8,51,'OCAMPO')
		insert into capa_poblacion values (8,52,'OJINAGA')
		insert into capa_poblacion values (8,53,'PRAXEDIS G. GUERRERO')
		insert into capa_poblacion values (8,54,'RIVA PALACIO')
		insert into capa_poblacion values (8,55,'ROSALES')
		insert into capa_poblacion values (8,56,'VALLE DEL ROSARIO')
		insert into capa_poblacion values (8,57,'SAN FCO. DE BORJA')
		insert into capa_poblacion values (8,58,'SAN FCO. DE CONCHOS')
		insert into capa_poblacion values (8,59,'SAN FCO. DEL ORO')
		insert into capa_poblacion values (8,60,'SANTA BARBARA')
		insert into capa_poblacion values (8,61,'SATEVO')
		insert into capa_poblacion values (8,62,'SAUCILLO')
		insert into capa_poblacion values (8,63,'TEMOSACHIC')
		insert into capa_poblacion values (8,64,'EL TULE')
		insert into capa_poblacion values (8,65,'URIQUE')
		insert into capa_poblacion values (8,66,'URUACHIC')
		insert into capa_poblacion values (8,67,'VALLE DE ZARAGOZA')
		insert into capa_poblacion values (9,1,'ALVARO OBREGON')
		insert into capa_poblacion values (9,2,'AZCAPOTZALCO')
		insert into capa_poblacion values (9,3,'BENITO JUAREZ')
		insert into capa_poblacion values (9,4,'COYOACAN')
		insert into capa_poblacion values (9,5,'CUAJIMALPA DE MORELOS')
		insert into capa_poblacion values (9,6,'CUAUHTEMOC')
		insert into capa_poblacion values (9,7,'GUSTAVO A. MADERO')
		insert into capa_poblacion values (9,8,'IZTACALCO')
		insert into capa_poblacion values (9,9,'IZTAPALAPA')
		insert into capa_poblacion values (9,10,'MAGDALENA CONTRERAS')
		insert into capa_poblacion values (9,11,'MIGUEL HIDALGO')
		insert into capa_poblacion values (9,12,'MILPA ALTA')
		insert into capa_poblacion values (9,13,'TLAHUAC')
		insert into capa_poblacion values (9,14,'TLALPAN')
		insert into capa_poblacion values (9,15,'VENUSTIANO CARRANZA')
		insert into capa_poblacion values (9,16,'XOCHIMILCO')
		insert into capa_poblacion values (10,1,'CANATLAN')
		insert into capa_poblacion values (10,2,'CANELAS')
		insert into capa_poblacion values (10,3,'CONETO DE COMONFORT')
		insert into capa_poblacion values (10,4,'CUENCAME DE CENICEROS')
		insert into capa_poblacion values (10,5,'VICTORIA DE DURANGO')
		insert into capa_poblacion values (10,6,'GENERAL SIMON BOLIVAR')
		insert into capa_poblacion values (10,7,'GOMEZ PALACIO')
		insert into capa_poblacion values (10,8,'GUADALUPE VICTORIA')
		insert into capa_poblacion values (10,9,'GUANACEVI')
		insert into capa_poblacion values (10,10,'VILLA HIDALGO')
		insert into capa_poblacion values (10,11,'INDE')
		insert into capa_poblacion values (10,12,'CIUDAD LERDO')
		insert into capa_poblacion values (10,13,'MAPIMI')
		insert into capa_poblacion values (10,14,'MEZQUITAL')
		insert into capa_poblacion values (10,15,'NAZAS')
		insert into capa_poblacion values (10,16,'NOMBRE DE DIOS')
		insert into capa_poblacion values (10,17,'VILLA OCAMPO')
		insert into capa_poblacion values (10,18,'SANTA MARIA DEL ORO')
		insert into capa_poblacion values (10,19,'SANTA MARIA OTAEZ')
		insert into capa_poblacion values (10,20,'PANUCO DE CORONADO')
		insert into capa_poblacion values (10,21,'PENON BLANCO')
		insert into capa_poblacion values (10,22,'POANAS')
		insert into capa_poblacion values (10,23,'EL SALTO')
		insert into capa_poblacion values (10,24,'RODEO')
		insert into capa_poblacion values (10,25,'SAN BERNARDO')
		insert into capa_poblacion values (10,26,'SAN DIMAS')
		insert into capa_poblacion values (10,27,'SAN JUAN DE GUADALUPE')
		insert into capa_poblacion values (10,28,'SAN JUAN DEL RIO CUNA DEL CENTAURO')
		insert into capa_poblacion values (10,29,'SAN LUIS DEL CORDERO')
		insert into capa_poblacion values (10,30,'SAN PEDRO DEL GALLO')
		insert into capa_poblacion values (10,31,'SANTA CLARA')
		insert into capa_poblacion values (10,32,'SANTIAGO PAPASQUIARO')
		insert into capa_poblacion values (10,33,'SUCHIL')
		insert into capa_poblacion values (10,34,'TAMAZULA')
		insert into capa_poblacion values (10,35,'SANTA CATARINA DE TEPEHUANES')
		insert into capa_poblacion values (10,36,'TLAHUALILO DE ZARAGOZA')
		insert into capa_poblacion values (10,37,'TOPIA')
		insert into capa_poblacion values (10,38,'VICENTE GUERRERO')
		insert into capa_poblacion values (10,39,'NUEVO IDEAL')
		insert into capa_poblacion values (11,1,'ABASOLO')
		insert into capa_poblacion values (11,2,'ACAMBARO')
		insert into capa_poblacion values (11,3,'SAN MIGUEL ALLENDE')
		insert into capa_poblacion values (11,4,'VILLA DE APASEO EL ALTO')
		insert into capa_poblacion values (11,5,'APASEO EL GRANDE')
		insert into capa_poblacion values (11,6,'ATARJEA')
		insert into capa_poblacion values (11,7,'CELAYA')
		insert into capa_poblacion values (11,8,'CIUDAD MANUEL DOBLADO')
		insert into capa_poblacion values (11,9,'COMONFORT')
		insert into capa_poblacion values (11,10,'CORONEO')
		insert into capa_poblacion values (11,11,'CORTAZAR')
		insert into capa_poblacion values (11,12,'CUERAMARO')
		insert into capa_poblacion values (11,13,'VILLA DOCTOR MORA')
		insert into capa_poblacion values (11,14,'DOLORES HIDALGO CUNA DE LA INDEP. NAL.')
		insert into capa_poblacion values (11,15,'GUANAJUATO')
		insert into capa_poblacion values (11,16,'HUANIMARO')
		insert into capa_poblacion values (11,17,'IRAPUATO')
		insert into capa_poblacion values (11,18,'JARAL DEL PROGRESO')
		insert into capa_poblacion values (11,19,'JERECUARO')
		insert into capa_poblacion values (11,20,'LEON')
		insert into capa_poblacion values (11,21,'MOROLEON')
		insert into capa_poblacion values (11,22,'OCAMPO')
		insert into capa_poblacion values (11,23,'PENJAMO')
		insert into capa_poblacion values (11,24,'PUEBLO NUEVO')
		insert into capa_poblacion values (11,25,'PURISIMA DE BUSTOS')
		insert into capa_poblacion values (11,26,'ROMITA')
		insert into capa_poblacion values (11,27,'SALAMANCA')
		insert into capa_poblacion values (11,28,'SALVATIERRA')
		insert into capa_poblacion values (11,29,'SAN DIEGO DE LA UNION')
		insert into capa_poblacion values (11,30,'SAN FELIPE')
		insert into capa_poblacion values (11,31,'SAN FRANCISCO DEL RINCON')
		insert into capa_poblacion values (11,32,'SAN JOSE ITURBIDE')
		insert into capa_poblacion values (11,33,'SAN LUIS DE LA PAZ')
		insert into capa_poblacion values (11,34,'SANTA CATARINA')
		insert into capa_poblacion values (11,35,'SANTA CRUZ DE JUVENTINO ROSAS')
		insert into capa_poblacion values (11,36,'SANTIAGO MARAVATIO')
		insert into capa_poblacion values (11,37,'SILAO')
		insert into capa_poblacion values (11,38,'TARANDACUAO')
		insert into capa_poblacion values (11,39,'TARIMORO')
		insert into capa_poblacion values (11,40,'TIERRABLANCA')
		insert into capa_poblacion values (11,41,'URIANGATO')
		insert into capa_poblacion values (11,42,'VALLE DE SANTIAGO')
		insert into capa_poblacion values (11,43,'VICTORIA')
		insert into capa_poblacion values (11,44,'VILLAGRAN')
		insert into capa_poblacion values (11,45,'XICHU')
		insert into capa_poblacion values (11,46,'YURIRIA')
		insert into capa_poblacion values (12,1,'ACAPULCO DE JUAREZ')
		insert into capa_poblacion values (12,2,'AHUACUOTZINGO')
		insert into capa_poblacion values (12,3,'AJUCHITLAN DEL PROGRESO')
		insert into capa_poblacion values (12,4,'ALCOZAUCA DE GUERRERO')
		insert into capa_poblacion values (12,5,'ALPOYECA')
		insert into capa_poblacion values (12,6,'APAXTLA DE CASTREJON')
		insert into capa_poblacion values (12,7,'ARCELIA')
		insert into capa_poblacion values (12,8,'ATENANGO DEL RIO')
		insert into capa_poblacion values (12,9,'ATLAMAJALCINGO DEL MONTE')
		insert into capa_poblacion values (12,10,'ATLIXTAC')
		insert into capa_poblacion values (12,11,'ATOYAC DE ALVAREZ')
		insert into capa_poblacion values (12,12,'AYUTLA')
		insert into capa_poblacion values (12,13,'AZOYU')
		insert into capa_poblacion values (12,14,'BENITO JUAREZ')
		insert into capa_poblacion values (12,15,'BUENAVISTA DE CUELLAR')
		insert into capa_poblacion values (12,16,'COAHUAYUTLA DE JOSE MARIA IZAZAGA')
		insert into capa_poblacion values (12,17,'COCULA')
		insert into capa_poblacion values (12,18,'COPALA')
		insert into capa_poblacion values (12,19,'COPALILLO')
		insert into capa_poblacion values (12,20,'COPANATOYAC')
		insert into capa_poblacion values (12,21,'COYUCA DE BENITEZ')
		insert into capa_poblacion values (12,22,'COYUCA DE CATALAN')
		insert into capa_poblacion values (12,23,'CUAJINICUILAPA')
		insert into capa_poblacion values (12,24,'CUALAC')
		insert into capa_poblacion values (12,25,'CUAUTEPEC')
		insert into capa_poblacion values (12,26,'CUETZALA DEL PROGRESO')
		insert into capa_poblacion values (12,27,'CUTZAMALA DE PINZON')
		insert into capa_poblacion values (12,28,'CHILAPA DE ALVAREZ')
		insert into capa_poblacion values (12,29,'CHILPANCINGO DE LOS BRAVO')
		insert into capa_poblacion values (12,30,'FLORENCIO VILLARREAL ')
		insert into capa_poblacion values (12,31,'GENERAL CANUTO A. NERI')
		insert into capa_poblacion values (12,32,'GENERAL HELIODORO CASTILLO')
		insert into capa_poblacion values (12,33,'HUAMUXTITLAN')
		insert into capa_poblacion values (12,34,'HUITZUCO DE LOS FIGUEROA')
		insert into capa_poblacion values (12,35,'IGUALA DE LA INDEPENDENCIA')
		insert into capa_poblacion values (12,36,'IGUALAPA')
		insert into capa_poblacion values (12,37,'IXCATEOPAN DE CUAUHTEMOC')
		insert into capa_poblacion values (12,38,'JOSE AZUETA')
		insert into capa_poblacion values (12,39,'JUAN R. ESCUDERO')
		insert into capa_poblacion values (12,40,'LEONARDO BRAVO')
		insert into capa_poblacion values (12,41,'MALINALTEPEC')
		insert into capa_poblacion values (12,42,'MARTIR DE CUILAPAN')
		insert into capa_poblacion values (12,43,'METLATONOC')
		insert into capa_poblacion values (12,44,'MOCHITLAN')
		insert into capa_poblacion values (12,45,'OLINALA')
		insert into capa_poblacion values (12,46,'OMETEPEC')
		insert into capa_poblacion values (12,47,'PEDRO ASCENCIO ALQUICIRAS')
		insert into capa_poblacion values (12,48,'PETATLAN')
		insert into capa_poblacion values (12,49,'PILCAYA')
		insert into capa_poblacion values (12,50,'PUNGARABATO')
		insert into capa_poblacion values (12,51,'QUECHULTENANGO')
		insert into capa_poblacion values (12,52,'SAN LUIS ACATLAN')
		insert into capa_poblacion values (12,53,'SAN MARCOS')
		insert into capa_poblacion values (12,54,'SAN MIGUEL TOTOLAPAN')
		insert into capa_poblacion values (12,55,'TAXCO DE ALARCON')
		insert into capa_poblacion values (12,56,'TECOANAPA')
		insert into capa_poblacion values (12,57,'TECPAN DE GALEANA')
		insert into capa_poblacion values (12,58,'TELOLOAPAN')
		insert into capa_poblacion values (12,59,'TEPECOACUILCO DE TRUJANO')
		insert into capa_poblacion values (12,60,'TETIPAC')
		insert into capa_poblacion values (12,61,'TIXTLA DE GUERRERO')
		insert into capa_poblacion values (12,62,'TLACOACHISTLAHUACA')
		insert into capa_poblacion values (12,63,'TLACOAPA')
		insert into capa_poblacion values (12,64,'TLALCHAPA')
		insert into capa_poblacion values (12,65,'TLALIXTAQUILLA DE MALDONADO')
		insert into capa_poblacion values (12,66,'TLAPA DE COMONFORT')
		insert into capa_poblacion values (12,67,'TLAPEHUALA')
		insert into capa_poblacion values (12,68,'UNION DE ISIDORO MONTES DE OCA, LA')
		insert into capa_poblacion values (12,69,'XALPATLAHUAC')
		insert into capa_poblacion values (12,70,'XOCHIHUEHUETLAN')
		insert into capa_poblacion values (12,71,'XOCHISTLAHUACA')
		insert into capa_poblacion values (12,72,'ZAPOTITLAN TABLAS')
		insert into capa_poblacion values (12,73,'ZIRANDARO DE LOS CHAVEZ')
		insert into capa_poblacion values (12,74,'ZITLALA')
		insert into capa_poblacion values (12,75,'EDUARDO NERI')
		insert into capa_poblacion values (12,76,'ACATEPEC')
		insert into capa_poblacion values (13,1,'ACATLAN')
		insert into capa_poblacion values (13,2,'ACAXOCHITLAN')
		insert into capa_poblacion values (13,3,'ACTOPAN')
		insert into capa_poblacion values (13,4,'AGUA BLANCA ITURBIDE')
		insert into capa_poblacion values (13,5,'AJACUBA')
		insert into capa_poblacion values (13,6,'ALFAJAYUCAN')
		insert into capa_poblacion values (13,7,'ALMOLOYA')
		insert into capa_poblacion values (13,8,'APAN')
		insert into capa_poblacion values (13,9,'EL ARENAL')
		insert into capa_poblacion values (13,10,'ATITALAQUIA')
		insert into capa_poblacion values (13,11,'ATLAPEXCO')
		insert into capa_poblacion values (13,12,'ATOTONILCO EL GRANDE')
		insert into capa_poblacion values (13,13,'ATOTONILCO TULA')
		insert into capa_poblacion values (13,14,'CALNALI')
		insert into capa_poblacion values (13,15,'CARDONAL')
		insert into capa_poblacion values (13,16,'CUAUTEPEC DE HINOJOSA')
		insert into capa_poblacion values (13,17,'CHAPANTONGO')
		insert into capa_poblacion values (13,18,'CHAPULHUACAN')
		insert into capa_poblacion values (13,19,'CHILCUAUTLA')
		insert into capa_poblacion values (13,20,'ELOXOCHITLAN')
		insert into capa_poblacion values (13,21,'EMILIANO ZAPATA')
		insert into capa_poblacion values (13,22,'EPAZOYUCAN')
		insert into capa_poblacion values (13,23,'FRANCISCO I. MADERO')
		insert into capa_poblacion values (13,24,'HUASCA DE OCAMPO')
		insert into capa_poblacion values (13,25,'HUAUTLA')
		insert into capa_poblacion values (13,26,'HUAZALINGO')
		insert into capa_poblacion values (13,27,'HUEHUETLA')
		insert into capa_poblacion values (13,28,'HUEJUTLA DE REYES')
		insert into capa_poblacion values (13,29,'HUICHAPAN')
		insert into capa_poblacion values (13,30,'IXMIQUILPAN')
		insert into capa_poblacion values (13,31,'JACALA')
		insert into capa_poblacion values (13,32,'JALTOCAN')
		insert into capa_poblacion values (13,33,'JUAREZ')
		insert into capa_poblacion values (13,34,'LOLOTLA')
		insert into capa_poblacion values (13,35,'METEPEC')
		insert into capa_poblacion values (13,36,'METZQUITITLAN')
		insert into capa_poblacion values (13,37,'METZTITLAN')
		insert into capa_poblacion values (13,38,'MINERAL DEL CHICO')
		insert into capa_poblacion values (13,39,'MINERAL DEL MONTE')
		insert into capa_poblacion values (13,40,'LA MISION')
		insert into capa_poblacion values (13,41,'MIXQUIAHUALA')
		insert into capa_poblacion values (13,42,'MOLANGO')
		insert into capa_poblacion values (13,43,'NICOLAS FLORES')
		insert into capa_poblacion values (13,44,'NOPALA')
		insert into capa_poblacion values (13,45,'OMITLAN DE JUAREZ')
		insert into capa_poblacion values (13,46,'ORIZATLAN')
		insert into capa_poblacion values (13,47,'PACULA')
		insert into capa_poblacion values (13,48,'PACHUCA DE SOTO')
		insert into capa_poblacion values (13,49,'PISAFLORES')
		insert into capa_poblacion values (13,50,'PROGRESO')
		insert into capa_poblacion values (13,51,'MINERAL DE LA REFORMA')
		insert into capa_poblacion values (13,52,'SAN AGUSTIN TLAXIACA')
		insert into capa_poblacion values (13,53,'SAN BARTOLO TUTOTEPEC')
		insert into capa_poblacion values (13,54,'SAN SALVADOR')
		insert into capa_poblacion values (13,55,'SANTIAGO DE ANAYA')
		insert into capa_poblacion values (13,56,'SANTIAGO TULANTEPEC')
		insert into capa_poblacion values (13,57,'SINGUILUCAN')
		insert into capa_poblacion values (13,58,'TASQUILLO')
		insert into capa_poblacion values (13,59,'TECOZAUTLA')
		insert into capa_poblacion values (13,60,'TENANGO DE DORIA')
		insert into capa_poblacion values (13,61,'TEPEAPULCO')
		insert into capa_poblacion values (13,62,'TEPEHUACAN DE GUERRERO')
		insert into capa_poblacion values (13,63,'TEPEJI DEL RIO')
		insert into capa_poblacion values (13,64,'TEPETITLAN')
		insert into capa_poblacion values (13,65,'TETEPANGO')
		insert into capa_poblacion values (13,66,'TEZONTEPEC')
		insert into capa_poblacion values (13,67,'TEZONTEPEC DE ALDAMA')
		insert into capa_poblacion values (13,68,'TIANGUISTENGO')
		insert into capa_poblacion values (13,69,'TIZAYUCA')
		insert into capa_poblacion values (13,70,'TLAHUELILPAN')
		insert into capa_poblacion values (13,71,'TLAHUILTEPA')
		insert into capa_poblacion values (13,72,'TLANALAPA')
		insert into capa_poblacion values (13,73,'TLANCHINOL')
		insert into capa_poblacion values (13,74,'TLAXCOAPAN')
		insert into capa_poblacion values (13,75,'TOLCAYUCA')
		insert into capa_poblacion values (13,76,'TULA DE ALLENDE')
		insert into capa_poblacion values (13,77,'TULANCINGO')
		insert into capa_poblacion values (13,78,'XOCHIATIPAN')
		insert into capa_poblacion values (13,79,'XOCHICOATLAN')
		insert into capa_poblacion values (13,80,'YAHUALICA')
		insert into capa_poblacion values (13,81,'ZACUALTIPAN')
		insert into capa_poblacion values (13,82,'ZAPOTLAN DE JUAREZ')
		insert into capa_poblacion values (13,83,'ZEMPOALA')
		insert into capa_poblacion values (13,84,'ZIMAPAN')
		insert into capa_poblacion values (14,1,'ACATIC')
		insert into capa_poblacion values (14,2,'ACATLAN DE JUAREZ')
		insert into capa_poblacion values (14,3,'AHUALULCO DE MERCADO')
		insert into capa_poblacion values (14,4,'AMACUECA')
		insert into capa_poblacion values (14,5,'AMATITAN')
		insert into capa_poblacion values (14,6,'AMECA')
		insert into capa_poblacion values (14,7,'ANTONIO ESCOBEDO')
		insert into capa_poblacion values (14,8,'ARANDAS')
		insert into capa_poblacion values (14,9,'EL ARENAL')
		insert into capa_poblacion values (14,10,'ATEMAJAC DE BRIZUELA')
		insert into capa_poblacion values (14,11,'ATENGO')
		insert into capa_poblacion values (14,12,'ATENGUILLO')
		insert into capa_poblacion values (14,13,'ATOTONILCO EL ALTO')
		insert into capa_poblacion values (14,14,'ATOYAC')
		insert into capa_poblacion values (14,15,'AUTLAN DE NAVARRO')
		insert into capa_poblacion values (14,16,'AYO EL CHICO')
		insert into capa_poblacion values (14,17,'AYUTLA')
		insert into capa_poblacion values (14,18,'LA BARCA')
		insert into capa_poblacion values (14,19,'BOLANOS')
		insert into capa_poblacion values (14,20,'CABO CORRIENTES')
		insert into capa_poblacion values (14,21,'CASIMIRO CASTILLO')
		insert into capa_poblacion values (14,22,'CIHUATLAN')
		insert into capa_poblacion values (14,23,'ZAPOTLAN EL GRANDE')
		insert into capa_poblacion values (14,24,'COCULA')
		insert into capa_poblacion values (14,25,'COLOTLAN')
		insert into capa_poblacion values (14,26,'CONCEPCION DE BUENOS AIRES')
		insert into capa_poblacion values (14,27,'CUAUTITLAN')
		insert into capa_poblacion values (14,28,'CUAUTLA')
		insert into capa_poblacion values (14,29,'CUQUIO')
		insert into capa_poblacion values (14,30,'CHAPALA')
		insert into capa_poblacion values (14,31,'CHIMALTITAN')
		insert into capa_poblacion values (14,32,'CHIQUILISTLAN')
		insert into capa_poblacion values (14,33,'DEGOLLADO')
		insert into capa_poblacion values (14,34,'EJUTLA')
		insert into capa_poblacion values (14,35,'ENCARNACION DE DIAZ')
		insert into capa_poblacion values (14,36,'ETZATLAN')
		insert into capa_poblacion values (14,37,'EL GRULLO')
		insert into capa_poblacion values (14,38,'GUACHINANGO')
		insert into capa_poblacion values (14,39,'GUADALAJARA')
		insert into capa_poblacion values (14,40,'HOSTOTIPAQUILLO')
		insert into capa_poblacion values (14,41,'HUEJUCAR')
		insert into capa_poblacion values (14,42,'HUEJUQUILLA EL ALTO')
		insert into capa_poblacion values (14,43,'LA HUERTA')
		insert into capa_poblacion values (14,44,'IXTLAHUACAN DE LOS MEMBRILLOS')
		insert into capa_poblacion values (14,45,'IXTLAHUACAN DEL RIO')
		insert into capa_poblacion values (14,46,'JALOSTOTITLAN')
		insert into capa_poblacion values (14,47,'JAMAY')
		insert into capa_poblacion values (14,48,'JESUS MARIA')
		insert into capa_poblacion values (14,49,'JILOTLAN DE LOS DOLORES')
		insert into capa_poblacion values (14,50,'JOCOTEPEC')
		insert into capa_poblacion values (14,51,'JUANACATLAN')
		insert into capa_poblacion values (14,52,'JUCHITLAN')
		insert into capa_poblacion values (14,53,'LAGOS DE MORENO')
		insert into capa_poblacion values (14,54,'EL LIMON')
		insert into capa_poblacion values (14,55,'MAGDALENA')
		insert into capa_poblacion values (14,56,'MANUEL M. DIEGUEZ')
		insert into capa_poblacion values (14,57,'LA MANZANILLA DE LA PAZ')
		insert into capa_poblacion values (14,58,'MASCOTA')
		insert into capa_poblacion values (14,59,'MAZAMITLA')
		insert into capa_poblacion values (14,60,'MEXTICACAN')
		insert into capa_poblacion values (14,61,'MEZQUITIC')
		insert into capa_poblacion values (14,62,'MIXTLAN')
		insert into capa_poblacion values (14,63,'OCOTLAN')
		insert into capa_poblacion values (14,64,'OJUELOS DE JALISCO')
		insert into capa_poblacion values (14,65,'PIHUAMO')
		insert into capa_poblacion values (14,66,'PONCITLAN')
		insert into capa_poblacion values (14,67,'PUERTO VALLARTA')
		insert into capa_poblacion values (14,68,'PURIFICACION')
		insert into capa_poblacion values (14,69,'QUITUPAN')
		insert into capa_poblacion values (14,70,'EL SALTO')
		insert into capa_poblacion values (14,71,'SAN CRISTOBAL DE LA BARRANCA')
		insert into capa_poblacion values (14,72,'SAN DIEGO DE ALEJANDRIA')
		insert into capa_poblacion values (14,73,'SAN JUAN DE LOS LAGOS')
		insert into capa_poblacion values (14,74,'SAN JULIAN')
		insert into capa_poblacion values (14,75,'SAN MARCOS')
		insert into capa_poblacion values (14,76,'SAN MARTIN DE BOLANOS')
		insert into capa_poblacion values (14,77,'SAN MARTIN HIDALGO')
		insert into capa_poblacion values (14,78,'SAN MIGUEL EL ALTO')
		insert into capa_poblacion values (14,79,'GOMEZ FARIAS')
		insert into capa_poblacion values (14,80,'SAN SEBASTIAN')
		insert into capa_poblacion values (14,81,'STA. MA. DE LOS ANGELES')
		insert into capa_poblacion values (14,82,'SAYULA')
		insert into capa_poblacion values (14,83,'TALA')
		insert into capa_poblacion values (14,84,'TALPA DE ALLENDE')
		insert into capa_poblacion values (14,85,'TAMAZULA DE GORDIANO')
		insert into capa_poblacion values (14,86,'TAPALPA')
		insert into capa_poblacion values (14,87,'TECALITLAN')
		insert into capa_poblacion values (14,88,'TECOLOTLAN')
		insert into capa_poblacion values (14,89,'TECHALUTA')
		insert into capa_poblacion values (14,90,'TENAMAXTLAN')
		insert into capa_poblacion values (14,91,'TEOCALTICHE')
		insert into capa_poblacion values (14,92,'TECUITATLAN DE CORONA')
		insert into capa_poblacion values (14,93,'TEPATITLAN DE MORELOS')
		insert into capa_poblacion values (14,94,'TEQUILA')
		insert into capa_poblacion values (14,95,'TEUCHITLAN')
		insert into capa_poblacion values (14,96,'TIZAPAN EL ALTO')
		insert into capa_poblacion values (14,97,'TLAJOMULCO DE ZUNIGA')
		insert into capa_poblacion values (14,98,'TLAQUEPAQUE')
		insert into capa_poblacion values (14,99,'TOLIMAN')
		insert into capa_poblacion values (14,100,'TOMATLAN')
		insert into capa_poblacion values (14,101,'TONALA')
		insert into capa_poblacion values (14,102,'TONAYA')
		insert into capa_poblacion values (14,103,'TONILA')
		insert into capa_poblacion values (14,104,'TOTATIQUE')
		insert into capa_poblacion values (14,105,'TOTOTLAN')
		insert into capa_poblacion values (14,106,'TUXCACUESCO')
		insert into capa_poblacion values (14,107,'TUXCUECA')
		insert into capa_poblacion values (14,108,'TUXPAN')
		insert into capa_poblacion values (14,109,'UNION DE SAN ANTONIO')
		insert into capa_poblacion values (14,110,'UNION DE TULA')
		insert into capa_poblacion values (14,111,'VALLE DE GUADALUPE')
		insert into capa_poblacion values (14,112,'VALLE DE JUAREZ')
		insert into capa_poblacion values (14,113,'VENUSTIANO CARRANZA')
		insert into capa_poblacion values (14,114,'VILLA CORONA')
		insert into capa_poblacion values (14,115,'VILLA GUERRERO')
		insert into capa_poblacion values (14,116,'VILLA HIDALGO')
		insert into capa_poblacion values (14,117,'VILLA OBREGON')
		insert into capa_poblacion values (14,118,'YAHUALICA DE GLEZ. GALLO')
		insert into capa_poblacion values (14,119,'ZACOALCO DE TORRES')
		insert into capa_poblacion values (14,120,'ZAPOPAN')
		insert into capa_poblacion values (14,121,'ZAPOTILTIC')
		insert into capa_poblacion values (14,122,'ZAPOTITLAN')
		insert into capa_poblacion values (14,123,'ZAPOTLAN DEL REY')
		insert into capa_poblacion values (14,124,'ZAPOTLANEJO')
		insert into capa_poblacion values (15,1,'ACAMBAY')
		insert into capa_poblacion values (15,2,'ACOLMAN')
		insert into capa_poblacion values (15,3,'ACULCO')
		insert into capa_poblacion values (15,4,'ALMOLOYA DE ALQUISIRAS')
		insert into capa_poblacion values (15,5,'ALMOLOYA DE JUAREZ')
		insert into capa_poblacion values (15,6,'ALMOLOYA DEL RIO')
		insert into capa_poblacion values (15,7,'AMANALCO')
		insert into capa_poblacion values (15,8,'AMATEPEC')
		insert into capa_poblacion values (15,9,'AMECAMECA')
		insert into capa_poblacion values (15,10,'APAXCO')
		insert into capa_poblacion values (15,11,'ATENCO')
		insert into capa_poblacion values (15,12,'ATIZAPAN')
		insert into capa_poblacion values (15,13,'ATIZAPAN DE ZARAGOZA')
		insert into capa_poblacion values (15,14,'ATLACOMULCO')
		insert into capa_poblacion values (15,15,'ATLAUTLA')
		insert into capa_poblacion values (15,16,'AXAPUSCO')
		insert into capa_poblacion values (15,17,'AYAPANGO')
		insert into capa_poblacion values (15,18,'CALIMAYA')
		insert into capa_poblacion values (15,19,'CAPULHUAC')
		insert into capa_poblacion values (15,20,'COACALCO DE BERRIOZABAL')
		insert into capa_poblacion values (15,21,'COATEPEC HARINAS')
		insert into capa_poblacion values (15,22,'COCOTITLAN')
		insert into capa_poblacion values (15,23,'COYOTEPEC')
		insert into capa_poblacion values (15,24,'CUAUTITLAN')
		insert into capa_poblacion values (15,25,'CHALCO')
		insert into capa_poblacion values (15,26,'CHAPA DE MOTA')
		insert into capa_poblacion values (15,27,'CHAPULTEPEC')
		insert into capa_poblacion values (15,28,'CHIAUTLA')
		insert into capa_poblacion values (15,29,'CHICOLOAPAN')
		insert into capa_poblacion values (15,30,'CHICONCUAC')
		insert into capa_poblacion values (15,31,'CHIMALHUACAN')
		insert into capa_poblacion values (15,32,'DONATO GUERRA')
		insert into capa_poblacion values (15,33,'ECATEPEC DE MORELOS')
		insert into capa_poblacion values (15,34,'ECATZINGO')
		insert into capa_poblacion values (15,35,'HUEHUETOCA')
		insert into capa_poblacion values (15,36,'HUEYPOXTLA')
		insert into capa_poblacion values (15,37,'HUIXQUILUCAN')
		insert into capa_poblacion values (15,38,'ISIDRO FABELA')
		insert into capa_poblacion values (15,39,'IXTAPALUCA')
		insert into capa_poblacion values (15,40,'IXTAPAN DE LA SAL')
		insert into capa_poblacion values (15,41,'IXTAPAN DEL ORO')
		insert into capa_poblacion values (15,42,'IXTLAHUACA')
		insert into capa_poblacion values (15,43,'XALATLACO')
		insert into capa_poblacion values (15,44,'JALTENCO')
		insert into capa_poblacion values (15,45,'JILOTEPEC')
		insert into capa_poblacion values (15,46,'JILOTZINGO')
		insert into capa_poblacion values (15,47,'JIQUIPILCO')
		insert into capa_poblacion values (15,48,'JOCOTITLAN')
		insert into capa_poblacion values (15,49,'JOQUICINGO')
		insert into capa_poblacion values (15,50,'JUCHITEPEC')
		insert into capa_poblacion values (15,51,'LERMA')
		insert into capa_poblacion values (15,52,'MALINALCO')
		insert into capa_poblacion values (15,53,'MELCHOR OCAMPO')
		insert into capa_poblacion values (15,54,'METEPEC')
		insert into capa_poblacion values (15,55,'MEXICALTZINGO')
		insert into capa_poblacion values (15,56,'MORELOS')
		insert into capa_poblacion values (15,57,'NAUCALPAN DE JUAREZ')
		insert into capa_poblacion values (15,58,'NEZAHUALCOYOTL')
		insert into capa_poblacion values (15,59,'NEXTLALPAN')
		insert into capa_poblacion values (15,60,'NICOLAS ROMERO')
		insert into capa_poblacion values (15,61,'NOPALTEPEC')
		insert into capa_poblacion values (15,62,'OCOYOACAC')
		insert into capa_poblacion values (15,63,'OCUILAN')
		insert into capa_poblacion values (15,64,'EL ORO')
		insert into capa_poblacion values (15,65,'OTUMBA')
		insert into capa_poblacion values (15,66,'OTZOLOAPAN')
		insert into capa_poblacion values (15,67,'OTZOLOTEPEC')
		insert into capa_poblacion values (15,68,'OZUMBA')
		insert into capa_poblacion values (15,69,'PAPALOTLA')
		insert into capa_poblacion values (15,70,'LA PAZ')
		insert into capa_poblacion values (15,71,'POLOTITLAN')
		insert into capa_poblacion values (15,72,'RAYON')
		insert into capa_poblacion values (15,73,'SAN ANTONIO LA ISLA')
		insert into capa_poblacion values (15,74,'SAN FELIPE DEL PROGRESO')
		insert into capa_poblacion values (15,75,'SAN MARTIN DE LAS PIRAMIDES')
		insert into capa_poblacion values (15,76,'SAN MATEO ATENCO')
		insert into capa_poblacion values (15,77,'SAN SIMON DE GUERRERO')
		insert into capa_poblacion values (15,78,'SANTO TOMAS')
		insert into capa_poblacion values (15,79,'SOYANIQUILPAN DE JUAREZ')
		insert into capa_poblacion values (15,80,'SULTEPEC')
		insert into capa_poblacion values (15,81,'TECAMAC')
		insert into capa_poblacion values (15,82,'TEJUPILCO')
		insert into capa_poblacion values (15,83,'TEMAMATLA')
		insert into capa_poblacion values (15,84,'TEMASCALAPA')
		insert into capa_poblacion values (15,85,'TEMASCALCINGO')
		insert into capa_poblacion values (15,86,'TEMASCALTEPEC')
		insert into capa_poblacion values (15,87,'TEMOAYA')
		insert into capa_poblacion values (15,88,'TENANCINGO')
		insert into capa_poblacion values (15,89,'TENANGO DEL AIRE')
		insert into capa_poblacion values (15,90,'TENANGO DEL VALLE')
		insert into capa_poblacion values (15,91,'TEOLOYUCAN')
		insert into capa_poblacion values (15,92,'TEOTIHUACAN')
		insert into capa_poblacion values (15,93,'TEPETLAOXTOC')
		insert into capa_poblacion values (15,94,'TEPETLIXPA')
		insert into capa_poblacion values (15,95,'TEPOTZOTLAN')
		insert into capa_poblacion values (15,96,'TEQUIXQUIAC')
		insert into capa_poblacion values (15,97,'TEXCALTITLAN')
		insert into capa_poblacion values (15,98,'TEXCALYACAC')
		insert into capa_poblacion values (15,99,'TEXCOCO')
		insert into capa_poblacion values (15,100,'TEZOYUCA')
		insert into capa_poblacion values (15,101,'TIANGUISTENCO')
		insert into capa_poblacion values (15,102,'TIMILPAN')
		insert into capa_poblacion values (15,103,'TLALMANALCO')
		insert into capa_poblacion values (15,104,'TLALNEPANTLA DE BAZ')
		insert into capa_poblacion values (15,105,'TLATLAYA')
		insert into capa_poblacion values (15,106,'TOLUCA')
		insert into capa_poblacion values (15,107,'TONATICO')
		insert into capa_poblacion values (15,108,'TULTEPEC')
		insert into capa_poblacion values (15,109,'TULTITLAN')
		insert into capa_poblacion values (15,110,'VALLE DE BRAVO')
		insert into capa_poblacion values (15,111,'VILLA DE ALLENDE')
		insert into capa_poblacion values (15,112,'VILLA DEL CARBON')
		insert into capa_poblacion values (15,113,'VILLA GUERRERO')
		insert into capa_poblacion values (15,114,'VILLA VICTORIA')
		insert into capa_poblacion values (15,115,'XONACATLAN')
		insert into capa_poblacion values (15,116,'ZACAZONAPAN')
		insert into capa_poblacion values (15,117,'ZACUALPAN')
		insert into capa_poblacion values (15,118,'ZINACANTEPEC')
		insert into capa_poblacion values (15,119,'ZUMPAHUACAN')
		insert into capa_poblacion values (15,120,'ZUMPANGO')
		insert into capa_poblacion values (15,121,'CUAUTITLAN IZCALLI')
		insert into capa_poblacion values (15,122,'VALLE DE CHALCO SOLIDARIDAD')
		insert into capa_poblacion values (15,123,'LUVIANOS')
		insert into capa_poblacion values (15,124,'SAN JOSE DEL RINCON')
		insert into capa_poblacion values (15,125,'TONANITLA')
		insert into capa_poblacion values (16,1,'ACUITZIO DEL CANJE')
		insert into capa_poblacion values (16,2,'AGUILILLA')
		insert into capa_poblacion values (16,3,'ALVARO OBREGON')
		insert into capa_poblacion values (16,4,'ANGAMACUTIRO DE LA UNION')
		insert into capa_poblacion values (16,5,'MINERAL DE ANGANGUEO')
		insert into capa_poblacion values (16,6,'APATZINGAN DE LA CONSTITUCION')
		insert into capa_poblacion values (16,7,'APORO')
		insert into capa_poblacion values (16,8,'AQUILA')
		insert into capa_poblacion values (16,9,'ARIO DE ROSALES')
		insert into capa_poblacion values (16,10,'ARTEAGA')
		insert into capa_poblacion values (16,11,'BRISENAS')
		insert into capa_poblacion values (16,12,'BUENAVISTA TOMATLAN')
		insert into capa_poblacion values (16,13,'CARACUARO DE MORELOS')
		insert into capa_poblacion values (16,14,'COAHUAYANA')
		insert into capa_poblacion values (16,15,'COALCOMAN DE MATAMOROS')
		insert into capa_poblacion values (16,16,'COENEO DE LA LIBERTAD')
		insert into capa_poblacion values (16,17,'CONTEPEC')
		insert into capa_poblacion values (16,18,'COPANDARO DE GALEANA')
		insert into capa_poblacion values (16,19,'COTIJA DE LA PAZ')
		insert into capa_poblacion values (16,20,'CUITZEO DEL PORVENIR')
		insert into capa_poblacion values (16,21,'CHARAPAN')
		insert into capa_poblacion values (16,22,'CHARO')
		insert into capa_poblacion values (16,23,'CHAVINDA')
		insert into capa_poblacion values (16,24,'CHERAN')
		insert into capa_poblacion values (16,25,'CHILCHOTA')
		insert into capa_poblacion values (16,26,'CHINICUILA')
		insert into capa_poblacion values (16,27,'CHUCANDIRO')
		insert into capa_poblacion values (16,28,'CHURINTZIO')
		insert into capa_poblacion values (16,29,'CHURUMUCO DE MORELOS')
		insert into capa_poblacion values (16,30,'ECUANDUREO')
		insert into capa_poblacion values (16,31,'EPITACIO HUERTA')
		insert into capa_poblacion values (16,32,'ERONGARICUARO')
		insert into capa_poblacion values (16,33,'BARRANCA HONDA')
		insert into capa_poblacion values (16,34,'CIUDAD HIDALGO')
		insert into capa_poblacion values (16,35,'LA HUACANA')
		insert into capa_poblacion values (16,36,'HUANDACAREO')
		insert into capa_poblacion values (16,37,'HUANIQUEO DE MORALES')
		insert into capa_poblacion values (16,38,'HUETAMO DE NUNES')
		insert into capa_poblacion values (16,39,'HUIRAMBA')
		insert into capa_poblacion values (16,40,'INDAPARAPEO')
		insert into capa_poblacion values (16,41,'IRIMBO')
		insert into capa_poblacion values (16,42,'IXTLAN')
		insert into capa_poblacion values (16,43,'JACONA DE PLANCARTE')
		insert into capa_poblacion values (16,44,'JIMENEZ')
		insert into capa_poblacion values (16,45,'JIQUILPAN DE JUAREZ')
		insert into capa_poblacion values (16,46,'BENITO JUAREZ')
		insert into capa_poblacion values (16,47,'JUNGAPEO DE JUAREZ')
		insert into capa_poblacion values (16,48,'LAGUNILLAS')
		insert into capa_poblacion values (16,49,'LAZARO CARDENAS')
		insert into capa_poblacion values (16,50,'VILLA MADERO')
		insert into capa_poblacion values (16,51,'MARAVATIO DE OCAMPO')
		insert into capa_poblacion values (16,52,'MARCOS CASTELLANOS')
		insert into capa_poblacion values (16,53,'MORELIA')
		insert into capa_poblacion values (16,54,'VILLA MORELOS')
		insert into capa_poblacion values (16,55,'MUGICA')
		insert into capa_poblacion values (16,56,'NAHUATZEN')
		insert into capa_poblacion values (16,57,'NOCUPETARO')
		insert into capa_poblacion values (16,58,'PUEBLO NUEVO SAN JUAN PARANGARICUTIRO')
		insert into capa_poblacion values (16,59,'NUEVO URECHO')
		insert into capa_poblacion values (16,60,'NUMARAN')
		insert into capa_poblacion values (16,61,'OCAMPO')
		insert into capa_poblacion values (16,62,'PAJACUARAN')
		insert into capa_poblacion values (16,63,'PANINDICUARO')
		insert into capa_poblacion values (16,64,'PARACUARO')
		insert into capa_poblacion values (16,65,'PARACHO DE VERDUZCO')
		insert into capa_poblacion values (16,66,'PATZCUARO')
		insert into capa_poblacion values (16,67,'PENJAMILLO DE DEGOLLADO')
		insert into capa_poblacion values (16,68,'PERIBAN DE RAMOS')
		insert into capa_poblacion values (16,69,'LA PIEDAD CAVADAS')
		insert into capa_poblacion values (16,70,'PUREPERO')
		insert into capa_poblacion values (16,71,'PURUANDIRO')
		insert into capa_poblacion values (16,72,'QUERENDARO')
		insert into capa_poblacion values (16,73,'QUIROGA')
		insert into capa_poblacion values (16,74,'COJUMATLAN DE REGULES')
		insert into capa_poblacion values (16,75,'LOS REYES DE SALGADO')
		insert into capa_poblacion values (16,76,'SAHUAYO DE JOSE MARIA MORELOS')
		insert into capa_poblacion values (16,77,'SAN LUCAS')
		insert into capa_poblacion values (16,78,'SANTA ANA MAYA')
		insert into capa_poblacion values (16,79,'SALVADOR ESCALANTE')
		insert into capa_poblacion values (16,80,'SENGUIO')
		insert into capa_poblacion values (16,81,'SUSUPUATO DE GUERRERO')
		insert into capa_poblacion values (16,82,'TACAMBARO DE CODALLOS')
		insert into capa_poblacion values (16,83,'TANCITARO')
		insert into capa_poblacion values (16,84,'TANGAMANDAPIO')
		insert into capa_poblacion values (16,85,'TANGANCICUARO DE ARISTA')
		insert into capa_poblacion values (16,86,'TANHUATO DE GUERRERO')
		insert into capa_poblacion values (16,87,'TARETAN')
		insert into capa_poblacion values (16,88,'TARIMBARO')
		insert into capa_poblacion values (16,89,'TEPALCATEPEC')
		insert into capa_poblacion values (16,90,'TINGAMBATO')
		insert into capa_poblacion values (16,91,'TINGUINDIN')
		insert into capa_poblacion values (16,92,'TIQUICHEO')
		insert into capa_poblacion values (16,93,'TLALPUJAHUA')
		insert into capa_poblacion values (16,94,'TLAZAZALCA')
		insert into capa_poblacion values (16,95,'TOCUMBO')
		insert into capa_poblacion values (16,96,'TUMBISCATIO DE RUIZ')
		insert into capa_poblacion values (16,97,'TURICATO')
		insert into capa_poblacion values (16,98,'TUXPAN')
		insert into capa_poblacion values (16,99,'TUZANTLA')
		insert into capa_poblacion values (16,100,'TZINTZUNTZAN')
		insert into capa_poblacion values (16,101,'TZITZIO')
		insert into capa_poblacion values (16,102,'URUAPAN DEL PROGRESO')
		insert into capa_poblacion values (16,103,'VENUSTIANO CARRANZA')
		insert into capa_poblacion values (16,104,'VILLAMAR')
		insert into capa_poblacion values (16,105,'VISTAHERMOSA DE NEGRETE')
		insert into capa_poblacion values (16,106,'YURECUARO')
		insert into capa_poblacion values (16,107,'ZACAPU')
		insert into capa_poblacion values (16,108,'ZAMORA DE HIDALGO')
		insert into capa_poblacion values (16,109,'ZINAPARO')
		insert into capa_poblacion values (16,110,'ZINAPECUARO DE FIGUEROA')
		insert into capa_poblacion values (16,111,'ZIRACUARETIRO')
		insert into capa_poblacion values (16,112,'HEROICA ZITACUARO')
		insert into capa_poblacion values (16,113,'JOSE SIXTO VERDUZCO')
		insert into capa_poblacion values (17,1,'AMACUZAC')
		insert into capa_poblacion values (17,2,'ATLATLAHUACAN')
		insert into capa_poblacion values (17,3,'AXOCHIAPAN')
		insert into capa_poblacion values (17,4,'AYALA')
		insert into capa_poblacion values (17,5,'COATLAN DEL RIO')
		insert into capa_poblacion values (17,6,'CUAUTLA MORELOS')
		insert into capa_poblacion values (17,7,'CUERNAVACA')
		insert into capa_poblacion values (17,8,'EMILIANO ZAPATA')
		insert into capa_poblacion values (17,9,'HUITZILAC')
		insert into capa_poblacion values (17,10,'JANTETELCO')
		insert into capa_poblacion values (17,11,'JIUTEPEC')
		insert into capa_poblacion values (17,12,'JOJUTLA DE JUAREZ')
		insert into capa_poblacion values (17,13,'JONACATEPEC')
		insert into capa_poblacion values (17,14,'MAZATEPEC')
		insert into capa_poblacion values (17,15,'MIACATLAN')
		insert into capa_poblacion values (17,16,'OCUITUCO')
		insert into capa_poblacion values (17,17,'PUENTE DE IXTLA')
		insert into capa_poblacion values (17,18,'TEMIXCO')
		insert into capa_poblacion values (17,19,'TEPALCINGO')
		insert into capa_poblacion values (17,20,'TEPOZTLAN')
		insert into capa_poblacion values (17,21,'TETECALA')
		insert into capa_poblacion values (17,22,'TETELA DEL VOLCAN')
		insert into capa_poblacion values (17,23,'TLALNEPANTLA')
		insert into capa_poblacion values (17,24,'TLALTIZAPAN')
		insert into capa_poblacion values (17,25,'TLAQUILTENANGO')
		insert into capa_poblacion values (17,26,'TLAYACAPAN')
		insert into capa_poblacion values (17,27,'TOTOLAPAN')
		insert into capa_poblacion values (17,28,'XOCHITEPEC')
		insert into capa_poblacion values (17,29,'YAUTEPEC')
		insert into capa_poblacion values (17,30,'YECAPIXTLA')
		insert into capa_poblacion values (17,31,'ZACATEPEC')
		insert into capa_poblacion values (17,32,'ZACUALPAN DE AMILPAS')
		insert into capa_poblacion values (17,33,'TEMOAC')
		insert into capa_poblacion values (18,1,'ACAPONETA')
		insert into capa_poblacion values (18,2,'AHUACATLAN')
		insert into capa_poblacion values (18,3,'AMATLAN DE CANAS')
		insert into capa_poblacion values (18,4,'COMPOSTELA')
		insert into capa_poblacion values (18,5,'HUAJICORI')
		insert into capa_poblacion values (18,6,'IXTLAN DEL RIO')
		insert into capa_poblacion values (18,7,'JALA')
		insert into capa_poblacion values (18,8,'JALISCO')
		insert into capa_poblacion values (18,9,'NAYAR')
		insert into capa_poblacion values (18,10,'ROSAMORADA')
		insert into capa_poblacion values (18,11,'RUIZ')
		insert into capa_poblacion values (18,12,'SAN BLAS')
		insert into capa_poblacion values (18,13,'SAN PEDRO LAGUNILLAS')
		insert into capa_poblacion values (18,14,'SANTA MARIA DEL ORO')
		insert into capa_poblacion values (18,15,'SANTIAGO IXCUINTLA')
		insert into capa_poblacion values (18,16,'TECUALA')
		insert into capa_poblacion values (18,17,'TEPIC')
		insert into capa_poblacion values (18,18,'TUXPAN')
		insert into capa_poblacion values (18,19,'LA YESCA')
		insert into capa_poblacion values (18,20,'BAHIA DE BANDERAS')
		insert into capa_poblacion values (19,1,'ABASOLO')
		insert into capa_poblacion values (19,2,'AGUALEGUAS')
		insert into capa_poblacion values (19,3,'LOS ALDAMAS')
		insert into capa_poblacion values (19,4,'ALLENDE')
		insert into capa_poblacion values (19,5,'ANAHUAC')
		insert into capa_poblacion values (19,6,'APODACA')
		insert into capa_poblacion values (19,7,'ARAMBERRI')
		insert into capa_poblacion values (19,8,'BUSTAMANTE')
		insert into capa_poblacion values (19,9,'CADEREYTA JIMENEZ')
		insert into capa_poblacion values (19,10,'CARMEN')
		insert into capa_poblacion values (19,11,'CERRALVO')
		insert into capa_poblacion values (19,12,'CIENEGA DE FLORES')
		insert into capa_poblacion values (19,13,'CHINA')
		insert into capa_poblacion values (19,14,'DOCTOR ARROYO')
		insert into capa_poblacion values (19,15,'DOCTOR COSS')
		insert into capa_poblacion values (19,16,'DOCTOR GONZALEZ')
		insert into capa_poblacion values (19,17,'GALEANA')
		insert into capa_poblacion values (19,18,'GARCIA')
		insert into capa_poblacion values (19,19,'SAN PEDRO GARZA GARCIA')
		insert into capa_poblacion values (19,20,'GENERAL BRAVO')
		insert into capa_poblacion values (19,21,'GENERAL ESCOBEDO')
		insert into capa_poblacion values (19,22,'GENERAL TERAN')
		insert into capa_poblacion values (19,23,'GENERAL TREVINO')
		insert into capa_poblacion values (19,24,'GENERAL ZARAGOZA')
		insert into capa_poblacion values (19,25,'GENERAL ZUAZUA')
		insert into capa_poblacion values (19,26,'GUADALUPE')
		insert into capa_poblacion values (19,27,'LOS HERRERAS')
		insert into capa_poblacion values (19,28,'HIGUERAS')
		insert into capa_poblacion values (19,29,'HUALAHUISES')
		insert into capa_poblacion values (19,30,'ITURBIDE')
		insert into capa_poblacion values (19,31,'JUAREZ')
		insert into capa_poblacion values (19,32,'LAMPAZOS DE NARANJO')
		insert into capa_poblacion values (19,33,'LINARES')
		insert into capa_poblacion values (19,34,'MARIN')
		insert into capa_poblacion values (19,35,'MELCHOR OCAMPO')
		insert into capa_poblacion values (19,36,'MIER Y NORIEGA')
		insert into capa_poblacion values (19,37,'MINA')
		insert into capa_poblacion values (19,38,'MONTEMORELOS')
		insert into capa_poblacion values (19,39,'MONTERREY')
		insert into capa_poblacion values (19,40,'PARAS')
		insert into capa_poblacion values (19,41,'PESQUERIA')
		insert into capa_poblacion values (19,42,'LOS RAMONES')
		insert into capa_poblacion values (19,43,'RAYONES')
		insert into capa_poblacion values (19,44,'SABINAS HIDALGO')
		insert into capa_poblacion values (19,45,'SALINAS VICTORIA')
		insert into capa_poblacion values (19,46,'SAN NICOLAS DE LOS GARZA')
		insert into capa_poblacion values (19,47,'HIDALGO')
		insert into capa_poblacion values (19,48,'SANTA CATARINA')
		insert into capa_poblacion values (19,49,'SANTIAGO')
		insert into capa_poblacion values (19,50,'VALLECILLO')
		insert into capa_poblacion values (19,51,'VILLALDAMA')
		insert into capa_poblacion values (19,52,'COLOMBIA')
		insert into capa_poblacion values (20,1,'ABEJONES')
		insert into capa_poblacion values (20,2,'ACATLAN DE PEREZ FIGUEROA')
		insert into capa_poblacion values (20,3,'ASUNCION CACALOTEPEC')
		insert into capa_poblacion values (20,4,'ASUNCION CUYOTEPEJI')
		insert into capa_poblacion values (20,5,'ASUNCION IXTALTEPEC')
		insert into capa_poblacion values (20,6,'ASUNCION NOCHIXTLAN')
		insert into capa_poblacion values (20,7,'ASUNCION OCOTLAN')
		insert into capa_poblacion values (20,8,'ASUNCION TLACOLULITA')
		insert into capa_poblacion values (20,9,'AYOTZINTEPEC')
		insert into capa_poblacion values (20,10,'BARRIO DE LA SOLEDAD')
		insert into capa_poblacion values (20,11,'CALIHUALA')
		insert into capa_poblacion values (20,12,'CANDELARIA LOXICHA')
		insert into capa_poblacion values (20,13,'CIENEGA DE ZIMATLAN')
		insert into capa_poblacion values (20,14,'CIUDAD IXTEPEC')
		insert into capa_poblacion values (20,15,'COATECAS ALTAS')
		insert into capa_poblacion values (20,16,'COICOYAN DE LAS FLORES')
		insert into capa_poblacion values (20,17,'COMPANIA')
		insert into capa_poblacion values (20,18,'CONCEPCION BUENAVISTA')
		insert into capa_poblacion values (20,19,'CONCEPCION PAPALO')
		insert into capa_poblacion values (20,20,'CONSTANCIA DEL ROSARIO')
		insert into capa_poblacion values (20,21,'COSOLAPA')
		insert into capa_poblacion values (20,22,'COSOLTEPEC')
		insert into capa_poblacion values (20,23,'CUILAPAN DE GUERRERO')
		insert into capa_poblacion values (20,24,'CUYAMECALCO VILLA DE ZARAGOZA')
		insert into capa_poblacion values (20,25,'CHAHUITES')
		insert into capa_poblacion values (20,26,'CHALCATONGO DE HIDALGO')
		insert into capa_poblacion values (20,27,'CHIQUIHUITLAN DE BENITO JUAREZ')
		insert into capa_poblacion values (20,28,'HEROICA CIUDAD DE EJUTLA DE CRESPO')
		insert into capa_poblacion values (20,29,'ELOXOCHITLAN DE FLORES MAGON')
		insert into capa_poblacion values (20,30,'ESPINAL')
		insert into capa_poblacion values (20,31,'TAMAZULAPAN DEL ESPIRITU SANTO ')
		insert into capa_poblacion values (20,32,'FRESNILLO DE TRUJANO')
		insert into capa_poblacion values (20,33,'GUADALUPE ETLA')
		insert into capa_poblacion values (20,34,'GUADALUPE DE RAMIREZ')
		insert into capa_poblacion values (20,35,'GUELATAO DE JUAREZ')
		insert into capa_poblacion values (20,36,'GUEVEA DE HUMBOLDT')
		insert into capa_poblacion values (20,37,'UNION GUERRERO')
		insert into capa_poblacion values (20,38,'VILLA GUERRERO')
		insert into capa_poblacion values (20,39,'HEROICA CIUDAD DE HUAJUAPAN DE LEON')
		insert into capa_poblacion values (20,40,'HUAUTEPEC')
		insert into capa_poblacion values (20,41,'HUAUTLA DE JIMENEZ')
		insert into capa_poblacion values (20,42,'IXTLAN DE JUAREZ')
		insert into capa_poblacion values (20,43,'JUCHITAN DE ZARAGOZA')
		insert into capa_poblacion values (20,44,'LOMA BONITA')
		insert into capa_poblacion values (20,45,'MAGDALENA APASCO')
		insert into capa_poblacion values (20,46,'MAGDALENA JALTEPEC')
		insert into capa_poblacion values (20,47,'SANTA MAGDALENA JICOTLAN')
		insert into capa_poblacion values (20,48,'MAGDALENA MIXTEPEC')
		insert into capa_poblacion values (20,49,'MAGDALENA OCOTLAN')
		insert into capa_poblacion values (20,50,'MAGDALENA PENASCO')
		insert into capa_poblacion values (20,51,'MAGDALENA TEITIPAC')
		insert into capa_poblacion values (20,52,'MAGDALENA TEQUISISTLAN')
		insert into capa_poblacion values (20,53,'MAGDALENA TLACOTEPEC')
		insert into capa_poblacion values (20,54,'MAGDALENA ZAHUATLAN')
		insert into capa_poblacion values (20,55,'MARISCALA DE JUAREZ')
		insert into capa_poblacion values (20,56,'MARTIRES DE TACUBAYA')
		insert into capa_poblacion values (20,57,'MATIAS ROMERO')
		insert into capa_poblacion values (20,58,'MAZATLAN VILLA DE FLORES')
		insert into capa_poblacion values (20,59,'MIAHUATLAN DE PORFIRIO DIAZ')
		insert into capa_poblacion values (20,60,'MIXISTLAN DE LA REFORMA')
		insert into capa_poblacion values (20,61,'MONJAS')
		insert into capa_poblacion values (20,62,'NATIVIDAD')
		insert into capa_poblacion values (20,63,'NAZARENO ETLA')
		insert into capa_poblacion values (20,64,'NEJAPA DE MADERO')
		insert into capa_poblacion values (20,65,'IXPANTEPEC NIEVES')
		insert into capa_poblacion values (20,66,'SANTIAGO NILTEPEC')
		insert into capa_poblacion values (20,67,'OAXACA DE JUAREZ')
		insert into capa_poblacion values (20,68,'OCOTLAN DE MORELOS')
		insert into capa_poblacion values (20,69,'PE')
		insert into capa_poblacion values (20,70,'PINOTEPA DE DON LUIS')
		insert into capa_poblacion values (20,71,'PLUMA HIDALGO')
		insert into capa_poblacion values (20,72,'SAN JOSE DEL PROGRESO')
		insert into capa_poblacion values (20,73,'PUTLA VILLA DE GUERRERO')
		insert into capa_poblacion values (20,74,'SANTA CATARINA QUIOQUITANI')
		insert into capa_poblacion values (20,75,'REFORMA DE PINEDA')
		insert into capa_poblacion values (20,76,'REFORMA')
		insert into capa_poblacion values (20,77,'REYES ETLA')
		insert into capa_poblacion values (20,78,'ROJAS DE CUAUHTEMOC')
		insert into capa_poblacion values (20,79,'SALINA CRUZ')
		insert into capa_poblacion values (20,80,'SAN AGUSTIN AMATENGO')
		insert into capa_poblacion values (20,81,'SAN AGUSTIN ATENANGO')
		insert into capa_poblacion values (20,82,'SAN AGUSTIN CHAYUCO')
		insert into capa_poblacion values (20,83,'SAN AGUSTIN DE LAS JUNTAS')
		insert into capa_poblacion values (20,84,'SAN AGUSTIN ETLA')
		insert into capa_poblacion values (20,85,'SAN AGUSTIN LOXICHA')
		insert into capa_poblacion values (20,86,'SAN AGUSTIN TLACOTEPEC')
		insert into capa_poblacion values (20,87,'SAN AGUSTIN YATARENI')
		insert into capa_poblacion values (20,88,'CABECERA NUEVA')
		insert into capa_poblacion values (20,89,'SAN ANDRES DINICUITI')
		insert into capa_poblacion values (20,90,'SAN ANDRES HUAXPALTEPEC')
		insert into capa_poblacion values (20,91,'SAN ANDRES HUAYAPAM')
		insert into capa_poblacion values (20,92,'SAN ANDRES IXTLAHUACA')
		insert into capa_poblacion values (20,93,'SAN ANDRES LAGUNAS')
		insert into capa_poblacion values (20,94,'SAN ANDRES NUXINO')
		insert into capa_poblacion values (20,95,'SAN ANDRES PAXTLAN')
		insert into capa_poblacion values (20,96,'SAN ANDRES SINAXTLA')
		insert into capa_poblacion values (20,97,'SAN ANDRES SOLAGA')
		insert into capa_poblacion values (20,98,'SAN ANDRES TEOTILALPAM')
		insert into capa_poblacion values (20,99,'SAN ANDRES TEPETLAPA')
		insert into capa_poblacion values (20,100,'SAN ANDRES YAA')
		insert into capa_poblacion values (20,101,'SAN ANDRES ZABACHE')
		insert into capa_poblacion values (20,102,'SAN ANDRES ZAUTLA')
		insert into capa_poblacion values (20,103,'SAN ANTONIO CASTILLO VELASCO')
		insert into capa_poblacion values (20,104,'SAN ANTONIO EL ALTO')
		insert into capa_poblacion values (20,105,'SAN ANTONIO MONTE VERDE')
		insert into capa_poblacion values (20,106,'SAN ANTONIO ACUTLA')
		insert into capa_poblacion values (20,107,'SAN ANTONIO DE LA CAL')
		insert into capa_poblacion values (20,108,'SAN ANTONIO HUITEPEC')
		insert into capa_poblacion values (20,109,'SAN ANTONIO NANAHUATIPAM')
		insert into capa_poblacion values (20,110,'SAN ANTONIO SINICAHUA')
		insert into capa_poblacion values (20,111,'SAN ANTONIO TEPETLAPA')
		insert into capa_poblacion values (20,112,'SAN BALTAZAR CHICHICAPAM')
		insert into capa_poblacion values (20,113,'SAN BALTAZAR LOXICHA')
		insert into capa_poblacion values (20,114,'SAN BALTAZAR YATZACHI EL BAJO')
		insert into capa_poblacion values (20,115,'SAN BARTOLO COYOTEPEC')
		insert into capa_poblacion values (20,116,'SAN BARTOLOME AYAUTLA')
		insert into capa_poblacion values (20,117,'SAN BARTOLOME LOXICHA')
		insert into capa_poblacion values (20,118,'SAN BARTOLOME QUIALANA')
		insert into capa_poblacion values (20,119,'SAN BARTOLOME YUCUANE')
		insert into capa_poblacion values (20,120,'SAN BARTOLOME ZOOGOCHO')
		insert into capa_poblacion values (20,121,'SAN BARTOLO SOYALTEPEC')
		insert into capa_poblacion values (20,122,'SAN BARTOLO YAUTEPEC')
		insert into capa_poblacion values (20,123,'SAN BERNARDO MIXTEPEC')
		insert into capa_poblacion values (20,124,'SAN BLAS ATEMPA')
		insert into capa_poblacion values (20,125,'SAN CARLOS YAUTEPEC')
		insert into capa_poblacion values (20,126,'SAN CRISTOBAL AMATLAN')
		insert into capa_poblacion values (20,127,'SAN CRISTOBAL AMOLTEPEC')
		insert into capa_poblacion values (20,128,'SAN CRISTOBAL LACHIRIOAG')
		insert into capa_poblacion values (20,129,'SAN CRISTOBAL SUCHIXTLAHUACA')
		insert into capa_poblacion values (20,130,'SAN DIONISIO DEL MAR')
		insert into capa_poblacion values (20,131,'SAN DIONISIO OCOTEPEC')
		insert into capa_poblacion values (20,132,'SAN DIONISIO OCOTLAN')
		insert into capa_poblacion values (20,133,'SAN ESTEBAN ATATLAHUCA')
		insert into capa_poblacion values (20,134,'SAN FELIPE JALAPA DE DIAZ')
		insert into capa_poblacion values (20,135,'SAN FELIPE TEJALAPAM')
		insert into capa_poblacion values (20,136,'SAN FELIPE USILA')
		insert into capa_poblacion values (20,137,'SAN FRANCISCO CAHUACUA')
		insert into capa_poblacion values (20,138,'SAN FRANCISCO CAJONOS')
		insert into capa_poblacion values (20,139,'SAN FRANCISCO CHAPULAPA')
		insert into capa_poblacion values (20,140,'SAN FRANCISCO CHINDUA')
		insert into capa_poblacion values (20,141,'SAN FRANCISCO DEL MAR')
		insert into capa_poblacion values (20,142,'SAN FRANCISCO HUEHUETLAN')
		insert into capa_poblacion values (20,143,'SAN FRANCISCO IXHUATAN')
		insert into capa_poblacion values (20,144,'SAN FRANCISCO JALTEPETONGO')
		insert into capa_poblacion values (20,145,'SAN FRANCISCO LACHIGOLO')
		insert into capa_poblacion values (20,146,'SAN FRANCISCO LOGUECHE')
		insert into capa_poblacion values (20,147,'SAN FRANCISCO NUXANO')
		insert into capa_poblacion values (20,148,'SAN FRANCISCO OZOLOTEPEC')
		insert into capa_poblacion values (20,149,'SAN FRANCISCO SOLA')
		insert into capa_poblacion values (20,150,'SAN FRANCISCO TELIXTLAHUACA')
		insert into capa_poblacion values (20,151,'SAN FRANCISCO TEOPAN')
		insert into capa_poblacion values (20,152,'SAN FRANCISCO TLAPANCINGO')
		insert into capa_poblacion values (20,153,'SAN GABRIEL MIXTEPEC')
		insert into capa_poblacion values (20,154,'SAN ILDEFONSO AMATLAN')
		insert into capa_poblacion values (20,155,'SAN ILDEFONSO SOLA')
		insert into capa_poblacion values (20,156,'SAN ILDEFONSO VILLA ALTA')
		insert into capa_poblacion values (20,157,'SAN JACINTO AMILPAS')
		insert into capa_poblacion values (20,158,'SAN JACINTO TLACOTEPEC')
		insert into capa_poblacion values (20,159,'SAN JERONIMO COATLAN')
		insert into capa_poblacion values (20,160,'SAN JERONIMO SILACAYOAPILLA')
		insert into capa_poblacion values (20,161,'SAN JERONIMO SOSOLA')
		insert into capa_poblacion values (20,162,'SAN JERONIMO TAVICHE')
		insert into capa_poblacion values (20,163,'SAN JERONIMO TECOATL')
		insert into capa_poblacion values (20,164,'SAN JORGE NUCHITA')
		insert into capa_poblacion values (20,165,'SAN JOSE AYUQUILA')
		insert into capa_poblacion values (20,166,'SAN JOSE CHILTEPEC')
		insert into capa_poblacion values (20,167,'SAN JOSE DEL PENASCO')
		insert into capa_poblacion values (20,168,'SAN JOSE ESTANCIA GRANDE')
		insert into capa_poblacion values (20,169,'SAN JOSE INDEPENDENCIA')
		insert into capa_poblacion values (20,170,'SAN JOSE LACHIGUIRI')
		insert into capa_poblacion values (20,171,'SAN JOSE TENANGO')
		insert into capa_poblacion values (20,172,'SAN JUAN ACHIUTLA')
		insert into capa_poblacion values (20,173,'SAN JUAN ATEPEC')
		insert into capa_poblacion values (20,174,'ANIMAS TRUJANO')
		insert into capa_poblacion values (20,175,'SAN JUAN BAUTISTA ATATLAHUACA')
		insert into capa_poblacion values (20,176,'SAN JUAN BAUTISTA COIXTLAHUACA')
		insert into capa_poblacion values (20,177,'SAN JUAN BAUTISTA CUICATLAN')
		insert into capa_poblacion values (20,178,'SAN JUAN BAUTISTA GUELACHE')
		insert into capa_poblacion values (20,179,'SAN JUAN BAUTISTA JAYACATLAN')
		insert into capa_poblacion values (20,180,'SAN JUAN BAUTISTA LO DE SOTO')
		insert into capa_poblacion values (20,181,'SAN JUAN BAUTISTA SUCHITEPEC')
		insert into capa_poblacion values (20,182,'SAN JUAN BAUTISTA TLACOATZINTEPEC')
		insert into capa_poblacion values (20,183,'SAN JUAN BAUTISTA TLACHICHILCO')
		insert into capa_poblacion values (20,184,'SAN JUAN BAUTISTA TUXTEPEC')
		insert into capa_poblacion values (20,185,'SAN JUAN CACAHUATEPEC')
		insert into capa_poblacion values (20,186,'SAN JUAN CIENEGUILLA')
		insert into capa_poblacion values (20,187,'SAN JUAN COATZOSPAM')
		insert into capa_poblacion values (20,188,'SAN JUAN COLORADO')
		insert into capa_poblacion values (20,189,'SAN JUAN COMALTEPEC')
		insert into capa_poblacion values (20,190,'SAN JUAN COTZOCON')
		insert into capa_poblacion values (20,191,'SAN JUAN CHICOMEZUCHIL')
		insert into capa_poblacion values (20,192,'SAN JUAN CHILATECA')
		insert into capa_poblacion values (20,193,'SAN JUAN DEL ESTADO')
		insert into capa_poblacion values (20,194,'SAN JUAN DEL RIO')
		insert into capa_poblacion values (20,195,'SAN JUAN DIUXI')
		insert into capa_poblacion values (20,196,'SAN JUAN EVANGELISTA ANALCO')
		insert into capa_poblacion values (20,197,'SAN JUAN GUELAVIA')
		insert into capa_poblacion values (20,198,'SAN JUAN GUICHICOVI')
		insert into capa_poblacion values (20,199,'SAN JUAN IGUALTEPEC')
		insert into capa_poblacion values (20,200,'SAN JUAN JUQUILA MIXES')
		insert into capa_poblacion values (20,201,'SAN JUAN JUQUILA VIJANOS')
		insert into capa_poblacion values (20,202,'SAN JUAN LACHAO')
		insert into capa_poblacion values (20,203,'SAN JUAN LACHIGALLA')
		insert into capa_poblacion values (20,204,'SAN JUAN LAJARCIA')
		insert into capa_poblacion values (20,205,'SAN JUAN LALANA')
		insert into capa_poblacion values (20,206,'SAN JUAN DE LOS CUES')
		insert into capa_poblacion values (20,207,'SAN JUAN MAZATLAN')
		insert into capa_poblacion values (20,208,'SAN JUAN MIXTEPEC DISTR. 08')
		insert into capa_poblacion values (20,209,'SAN JUAN MIXTEPEC DISTR. 26')
		insert into capa_poblacion values (20,210,'SAN JUAN NUMI')
		insert into capa_poblacion values (20,211,'SAN JUAN OZOLOTEPEC')
		insert into capa_poblacion values (20,212,'SAN JUAN PETLAPA')
		insert into capa_poblacion values (20,213,'SAN JUAN QUIAHIJE')
		insert into capa_poblacion values (20,214,'SAN JUAN QUIOTEPEC')
		insert into capa_poblacion values (20,215,'SAN JUAN SAYULTEPEC')
		insert into capa_poblacion values (20,216,'SAN JUAN TABAA')
		insert into capa_poblacion values (20,217,'SAN JUAN TAMAZOLA')
		insert into capa_poblacion values (20,218,'SAN JUAN TEITA')
		insert into capa_poblacion values (20,219,'SAN JUAN TEITIPAC')
		insert into capa_poblacion values (20,220,'SAN JUAN TEPEUXILA')
		insert into capa_poblacion values (20,221,'SAN JUAN TEPOSCOLULA')
		insert into capa_poblacion values (20,222,'SAN JUAN YAEE')
		insert into capa_poblacion values (20,223,'SAN JUAN YATZONA')
		insert into capa_poblacion values (20,224,'SAN JUAN YUCUITA')
		insert into capa_poblacion values (20,225,'SAN LORENZO')
		insert into capa_poblacion values (20,226,'SAN LORENZO ALBARRADAS')
		insert into capa_poblacion values (20,227,'SAN LORENZO CACAOTEPEC')
		insert into capa_poblacion values (20,228,'SAN LORENZO CUAUNECUILTITLA')
		insert into capa_poblacion values (20,229,'SAN LORENZO TEXMELUCAN')
		insert into capa_poblacion values (20,230,'SAN LORENZO VICTORIA')
		insert into capa_poblacion values (20,231,'SAN LUCAS CAMOTLAN')
		insert into capa_poblacion values (20,232,'SAN LUCAS OJITLAN')
		insert into capa_poblacion values (20,233,'SAN LUCAS QUIAVINI')
		insert into capa_poblacion values (20,234,'SAN LUCAS ZOQUIAPAM')
		insert into capa_poblacion values (20,235,'SAN LUIS AMATLAN')
		insert into capa_poblacion values (20,236,'SAN MARCIAL OZOLOTEPEC')
		insert into capa_poblacion values (20,237,'SAN MARCOS ARTEAGA')
		insert into capa_poblacion values (20,238,'SAN MARTIN DE LOS CANSECOS')
		insert into capa_poblacion values (20,239,'SAN MARTIN HUAMELULPAM')
		insert into capa_poblacion values (20,240,'SAN MARTIN ITUNYOSO')
		insert into capa_poblacion values (20,241,'SAN MARTIN LACHILA')
		insert into capa_poblacion values (20,242,'SAN MARTIN PERAS')
		insert into capa_poblacion values (20,243,'SAN MARTIN TILCAJETE')
		insert into capa_poblacion values (20,244,'SAN MARTIN TOXPALAN')
		insert into capa_poblacion values (20,245,'SAN MARTIN ZACATEPEC')
		insert into capa_poblacion values (20,246,'SAN MATEO CAJONOS')
		insert into capa_poblacion values (20,247,'CAPULALPAM DE MENDEZ')
		insert into capa_poblacion values (20,248,'SAN MATEO DEL MAR')
		insert into capa_poblacion values (20,249,'SAN MATEO YOLOXOCHITLAN')
		insert into capa_poblacion values (20,250,'SAN MATEO ETLATONGO')
		insert into capa_poblacion values (20,251,'SAN MATEO NEJAPAN')
		insert into capa_poblacion values (20,252,'SAN MATEO PENASCO')
		insert into capa_poblacion values (20,253,'SAN MATEO PINAS')
		insert into capa_poblacion values (20,254,'SAN MATEO RIO HONDO')
		insert into capa_poblacion values (20,255,'SAN MATEO SINDIHUI')
		insert into capa_poblacion values (20,256,'SAN MATEO TLAPILTEPEC')
		insert into capa_poblacion values (20,257,'SAN MELCHOR BETAZA')
		insert into capa_poblacion values (20,258,'SAN MIGUEL ACHIUTLA')
		insert into capa_poblacion values (20,259,'SAN MIGUEL AHUEHUETITLAN')
		insert into capa_poblacion values (20,260,'SAN MIGUEL ALOAPAM')
		insert into capa_poblacion values (20,261,'SAN MIGUEL AMATITLAN')
		insert into capa_poblacion values (20,262,'SAN MIGUEL AMATLAN')
		insert into capa_poblacion values (20,263,'SAN MIGUEL COATLAN')
		insert into capa_poblacion values (20,264,'SAN MIGUEL CHICAHUA')
		insert into capa_poblacion values (20,265,'SAN MIGUEL CHIMALAPA')
		insert into capa_poblacion values (20,266,'SAN MIGUEL DEL PUERTO')
		insert into capa_poblacion values (20,267,'SAN MIGUEL DEL RIO')
		insert into capa_poblacion values (20,268,'SAN MIGUEL EJUTLA')
		insert into capa_poblacion values (20,269,'SAN MIGUEL EL GRANDE')
		insert into capa_poblacion values (20,270,'SAN MIGUEL HUAUTLA')
		insert into capa_poblacion values (20,271,'SAN MIGUEL MIXTEPEC')
		insert into capa_poblacion values (20,272,'SAN MIGUEL PANIXTLAHUACA')
		insert into capa_poblacion values (20,273,'SAN MIGUEL PERAS')
		insert into capa_poblacion values (20,274,'SAN MIGUEL PIEDRAS')
		insert into capa_poblacion values (20,275,'SAN MIGUEL QUETZALTEPEC')
		insert into capa_poblacion values (20,276,'SAN MIGUEL SANTA FLOR')
		insert into capa_poblacion values (20,277,'VILLA SOLA DE VEGA')
		insert into capa_poblacion values (20,278,'SAN MIGUEL SOYALTEPEC')
		insert into capa_poblacion values (20,279,'SAN MIGUEL SUCHIXTEPEC')
		insert into capa_poblacion values (20,280,'VILLA TALEA DE CASTRO')
		insert into capa_poblacion values (20,281,'SAN MIGUEL TECOMATLAN')
		insert into capa_poblacion values (20,282,'SAN MIGUEL TENANGO')
		insert into capa_poblacion values (20,283,'SAN MIGUEL TEQUIXTEPEC')
		insert into capa_poblacion values (20,284,'SAN MIGUEL TILQUIAPAM')
		insert into capa_poblacion values (20,285,'SAN MIGUEL TLACAMAMA')
		insert into capa_poblacion values (20,286,'SAN MIGUEL TLACOTEPEC')
		insert into capa_poblacion values (20,287,'SAN MIGUEL TULANCINGO')
		insert into capa_poblacion values (20,288,'SAN MIGUEL YOTAO')
		insert into capa_poblacion values (20,289,'SAN NICOLAS')
		insert into capa_poblacion values (20,290,'SAN NICOLAS HIDALGO')
		insert into capa_poblacion values (20,291,'SAN PABLO COATLAN')
		insert into capa_poblacion values (20,292,'SAN PABLO CUATRO VENADOS')
		insert into capa_poblacion values (20,293,'SAN PABLO ETLA')
		insert into capa_poblacion values (20,294,'SAN PABLO HUITZO')
		insert into capa_poblacion values (20,295,'SAN PABLO HUIXTEPEC')
		insert into capa_poblacion values (20,296,'SAN PABLO MACUILTIANGUIS')
		insert into capa_poblacion values (20,297,'SAN PABLO TIJALTEPEC')
		insert into capa_poblacion values (20,298,'SAN PABLO VILLA DE MITLA')
		insert into capa_poblacion values (20,299,'SAN PABLO YAGANIZA')
		insert into capa_poblacion values (20,300,'SAN PEDRO AMUZGOS')
		insert into capa_poblacion values (20,301,'SAN PEDRO APOSTOL')
		insert into capa_poblacion values (20,302,'SAN PEDRO ATOYAC')
		insert into capa_poblacion values (20,303,'SAN PEDRO CAJONOS')
		insert into capa_poblacion values (20,304,'SAN PEDRO CANTAROS')
		insert into capa_poblacion values (20,305,'SAN PEDRO COMITANCILLO')
		insert into capa_poblacion values (20,306,'SAN PEDRO EL ALTO')
		insert into capa_poblacion values (20,307,'SAN PEDRO HUAMELULA')
		insert into capa_poblacion values (20,308,'SAN PEDRO HILOTEPEC')
		insert into capa_poblacion values (20,309,'SAN PEDRO IXCATLAN')
		insert into capa_poblacion values (20,310,'SAN PEDRO IXTLAHUACA')
		insert into capa_poblacion values (20,311,'SAN PEDRO JALTEPETONGO')
		insert into capa_poblacion values (20,312,'SAN PEDRO JICAYAN')
		insert into capa_poblacion values (20,313,'SAN PEDRO JOCOTIPAC')
		insert into capa_poblacion values (20,314,'SAN PEDRO JUCHATENGO')
		insert into capa_poblacion values (20,315,'SAN PEDRO MARTIR')
		insert into capa_poblacion values (20,316,'SAN PEDRO MARTIR QUIECHAPA')
		insert into capa_poblacion values (20,317,'SAN PEDRO MARTIR YUCUXACO')
		insert into capa_poblacion values (20,318,'SAN PEDRO MIXTEPEC DISTR. 22')
		insert into capa_poblacion values (20,319,'SAN PEDRO MIXTEPEC DISTR. 26')
		insert into capa_poblacion values (20,320,'SAN PEDRO MOLINOS')
		insert into capa_poblacion values (20,321,'SAN PEDRO NOPALA')
		insert into capa_poblacion values (20,322,'SAN PEDRO OCOPETATILLO')
		insert into capa_poblacion values (20,323,'SAN PEDRO OCOTEPEC')
		insert into capa_poblacion values (20,324,'SAN PEDRO POCHUTLA')
		insert into capa_poblacion values (20,325,'SAN PEDRO QUIATONI')
		insert into capa_poblacion values (20,326,'SAN PEDRO SOCHIAPAM')
		insert into capa_poblacion values (20,327,'SAN PEDRO TAPANATEPEC')
		insert into capa_poblacion values (20,328,'SAN PEDRO TAVICHE')
		insert into capa_poblacion values (20,329,'SAN PEDRO TEOZACOALCO')
		insert into capa_poblacion values (20,330,'SAN PEDRO TEUTILA')
		insert into capa_poblacion values (20,331,'SAN PEDRO TIDAA')
		insert into capa_poblacion values (20,332,'SAN PEDRO TOPILTEPEC')
		insert into capa_poblacion values (20,333,'SAN PEDRO TOTOLAPA')
		insert into capa_poblacion values (20,334,'VILLA DE TUTUTEPEC DE MELCHOR OCAMPO')
		insert into capa_poblacion values (20,335,'SAN PEDRO YANERI')
		insert into capa_poblacion values (20,336,'SAN PEDRO YOLOX')
		insert into capa_poblacion values (20,337,'SAN PEDRO Y SAN PABLO AYUTLA')
		insert into capa_poblacion values (20,338,'VILLA DE ETLA')
		insert into capa_poblacion values (20,339,'SAN PEDRO Y SAN PABLO TEPOSCOLULA')
		insert into capa_poblacion values (20,340,'SAN PEDRO Y SAN PABLO TEQUIXTEPEC')
		insert into capa_poblacion values (20,341,'SAN PEDRO YUCUNAMA')
		insert into capa_poblacion values (20,342,'SAN RAYMUNDO JALPAN')
		insert into capa_poblacion values (20,343,'SAN SEBASTIAN ABASOLO')
		insert into capa_poblacion values (20,344,'SAN SEBASTIAN COATLAN')
		insert into capa_poblacion values (20,345,'SAN SEBASTIAN IXCAPA')
		insert into capa_poblacion values (20,346,'SAN SEBASTIAN NICANANDUTA')
		insert into capa_poblacion values (20,347,'SAN SEBASTIAN RIO HONDO')
		insert into capa_poblacion values (20,348,'SAN SEBASTIAN TECOMAXTLAHUACA')
		insert into capa_poblacion values (20,349,'SAN SEBASTIAN TEITIPAC')
		insert into capa_poblacion values (20,350,'SAN SEBASTIAN TUTLA')
		insert into capa_poblacion values (20,351,'SAN SIMON ALMOLONGAS')
		insert into capa_poblacion values (20,352,'SAN SIMON ZAHUATLAN')
		insert into capa_poblacion values (20,353,'SANTA ANA')
		insert into capa_poblacion values (20,354,'SANTA ANA ATEIXTLAHUACA')
		insert into capa_poblacion values (20,355,'SANTA ANA CUAUHTEMOC')
		insert into capa_poblacion values (20,356,'SANTA ANA DEL VALLE')
		insert into capa_poblacion values (20,357,'SANTA ANA TAVELA')
		insert into capa_poblacion values (20,358,'SANTA ANA TLAPACOYAN')
		insert into capa_poblacion values (20,359,'SANTA ANA YARENI')
		insert into capa_poblacion values (20,360,'SANTA ANA ZEGACHE')
		insert into capa_poblacion values (20,361,'SANTA CATALINA QUIERI')
		insert into capa_poblacion values (20,362,'SANTA CATARINA CUIXTLA')
		insert into capa_poblacion values (20,363,'SANTA CATARINA IXTEPEJI')
		insert into capa_poblacion values (20,364,'SANTA CATARINA JUQUILA')
		insert into capa_poblacion values (20,365,'SANTA CATARINA LACHATAO')
		insert into capa_poblacion values (20,366,'SANTA CATARINA LOXICHA')
		insert into capa_poblacion values (20,367,'SANTA CATARINA MECHOACAN')
		insert into capa_poblacion values (20,368,'SANTA CATARINA MINAS')
		insert into capa_poblacion values (20,369,'SANTA CATARINA QUIANE')
		insert into capa_poblacion values (20,370,'SANTA CATARINA TAYATA')
		insert into capa_poblacion values (20,371,'SANTA CATARINA TICUA')
		insert into capa_poblacion values (20,372,'SANTA CATARINA YOSONOTU')
		insert into capa_poblacion values (20,373,'SANTA CATARINA ZAPOQUILA')
		insert into capa_poblacion values (20,374,'SANTA CRUZ ACATEPEC')
		insert into capa_poblacion values (20,375,'SANTA CRUZ AMILPAS')
		insert into capa_poblacion values (20,376,'SANTA CRUZ DE BRAVO')
		insert into capa_poblacion values (20,377,'SANTA CRUZ ITUNDUJIA')
		insert into capa_poblacion values (20,378,'SANTA CRUZ MIXTEPEC')
		insert into capa_poblacion values (20,379,'SANTA CRUZ NUNDACO')
		insert into capa_poblacion values (20,380,'SANTA CRUZ PAPALUTLA')
		insert into capa_poblacion values (20,381,'SANTA CRUZ TACACHE DE MINA')
		insert into capa_poblacion values (20,382,'SANTA CRUZ TACAHUA')
		insert into capa_poblacion values (20,383,'SANTA CRUZ TAYATA')
		insert into capa_poblacion values (20,384,'SANTA CRUZ XITLA')
		insert into capa_poblacion values (20,385,'SANTA CRUZ XOXOCOTLAN')
		insert into capa_poblacion values (20,386,'SANTA CRUZ ZENZONTEPEC')
		insert into capa_poblacion values (20,387,'SANTA GERTRUDIS')
		insert into capa_poblacion values (20,388,'SANTA INES DEL MONTE')
		insert into capa_poblacion values (20,389,'SANTA INES YATZECHE')
		insert into capa_poblacion values (20,390,'SANTA LUCIA DEL CAMINO')
		insert into capa_poblacion values (20,391,'SANTA LUCIA MIAHUATLAN')
		insert into capa_poblacion values (20,392,'SANTA LUCIA MONTEVERDE')
		insert into capa_poblacion values (20,393,'SANTA LUCIA OCOTLAN')
		insert into capa_poblacion values (20,394,'SANTA MARIA ALOTEPEC')
		insert into capa_poblacion values (20,395,'SANTA MARIA APAZCO')
		insert into capa_poblacion values (20,396,'SANTA MARIA LA ASUNCION')
		insert into capa_poblacion values (20,397,'HEROICA CIUDAD DE TLAXIACO')
		insert into capa_poblacion values (20,398,'AYOQUEZCO DE ALDAMA')
		insert into capa_poblacion values (20,399,'SANTA MARIA ATZOMPA')
		insert into capa_poblacion values (20,400,'SANTA MARIA CAMOTLAN')
		insert into capa_poblacion values (20,401,'SANTA MARIA COLOTEPEC')
		insert into capa_poblacion values (20,402,'SANTA MARIA CORTIJO')
		insert into capa_poblacion values (20,403,'SANTA MARIA COYOTEPEC')
		insert into capa_poblacion values (20,404,'SANTA MARIA CHACHOAPAM')
		insert into capa_poblacion values (20,405,'VILLA DE CHILAPA DE DIAZ')
		insert into capa_poblacion values (20,406,'SANTA MARIA CHILCHOTLA')
		insert into capa_poblacion values (20,407,'SANTA MARIA CHIMALAPA')
		insert into capa_poblacion values (20,408,'SANTA MARIA DEL ROSARIO')
		insert into capa_poblacion values (20,409,'SANTA MARIA DEL TULE')
		insert into capa_poblacion values (20,410,'SANTA MARIA ECATEPEC')
		insert into capa_poblacion values (20,411,'SANTA MARIA GUELACE')
		insert into capa_poblacion values (20,412,'SANTA MARIA GUIENAGATI')
		insert into capa_poblacion values (20,413,'SANTA MARIA HUATULCO')
		insert into capa_poblacion values (20,414,'SANTA MARIA HUAZOLOTITLAN')
		insert into capa_poblacion values (20,415,'SANTA MARIA IPALAPA')
		insert into capa_poblacion values (20,416,'SANTA MARIA IXCATLAN')
		insert into capa_poblacion values (20,417,'SANTA MARIA JACATEPEC')
		insert into capa_poblacion values (20,418,'SANTA MARIA JALAPA DEL MARQUES')
		insert into capa_poblacion values (20,419,'SANTA MARIA JALTIANGUIS')
		insert into capa_poblacion values (20,420,'SANTA MARIA LACHIXIO')
		insert into capa_poblacion values (20,421,'SANTA MARIA MIXTEQUILLA')
		insert into capa_poblacion values (20,422,'SANTA MARIA NATIVITAS')
		insert into capa_poblacion values (20,423,'SANTA MARIA NDUAYACO')
		insert into capa_poblacion values (20,424,'SANTA MARIA OZOLOTEPEC')
		insert into capa_poblacion values (20,425,'SANTA MARIA PAPALO')
		insert into capa_poblacion values (20,426,'SANTA MARIA PENOLES')
		insert into capa_poblacion values (20,427,'SANTA MARIA PETAPA')
		insert into capa_poblacion values (20,428,'SANTA MARIA QUIEGOLANI')
		insert into capa_poblacion values (20,429,'SANTA MARIA SOLA')
		insert into capa_poblacion values (20,430,'SANTA MARIA TATALTEPEC')
		insert into capa_poblacion values (20,431,'SANTA MARIA TECOMAVACA')
		insert into capa_poblacion values (20,432,'SANTA MARIA TEMAXCALAPA')
		insert into capa_poblacion values (20,433,'SANTA MARIA TEMAXCALTEPEC')
		insert into capa_poblacion values (20,434,'SANTA MARIA TEOPOXCO')
		insert into capa_poblacion values (20,435,'SANTA MARIA TEPANTLALI')
		insert into capa_poblacion values (20,436,'SANTA MARIA TEXCATITLAN')
		insert into capa_poblacion values (20,437,'SANTA MARIA TLAHUITOLTEPEC')
		insert into capa_poblacion values (20,438,'SANTA MARIA TLALIXTAC')
		insert into capa_poblacion values (20,439,'SANTA MARIA TONAMECA')
		insert into capa_poblacion values (20,440,'SANTA MARIA TOTOLAPILLA')
		insert into capa_poblacion values (20,441,'SANTA MARIA XADANI')
		insert into capa_poblacion values (20,442,'SANTA MARIA YALINA')
		insert into capa_poblacion values (20,443,'SANTA MARIA YAVESIA')
		insert into capa_poblacion values (20,444,'SANTA MARIA YOLOTEPEC')
		insert into capa_poblacion values (20,445,'SANTA MARIA YOSOYUA')
		insert into capa_poblacion values (20,446,'SANTA MARIA YUCUHITI')
		insert into capa_poblacion values (20,447,'SANTA MARIA ZACATEPEC')
		insert into capa_poblacion values (20,448,'SANTA MARIA ZANIZA')
		insert into capa_poblacion values (20,449,'SANTA MARIA ZOQUITLAN')
		insert into capa_poblacion values (20,450,'SANTIAGO AMOLTEPEC')
		insert into capa_poblacion values (20,451,'SANTIAGO APOALA')
		insert into capa_poblacion values (20,452,'SANTIAGO APOSTOL')
		insert into capa_poblacion values (20,453,'SANTIAGO ASTATA')
		insert into capa_poblacion values (20,454,'SANTIAGO ATITLAN')
		insert into capa_poblacion values (20,455,'SANTIAGO AYUQUILILLA')
		insert into capa_poblacion values (20,456,'SANTIAGO CACALOXTEPEC')
		insert into capa_poblacion values (20,457,'SANTIAGO CAMOTLAN')
		insert into capa_poblacion values (20,458,'SANTIAGO COMALTEPEC')
		insert into capa_poblacion values (20,459,'SANTIAGO CHAZUMBA')
		insert into capa_poblacion values (20,460,'SANTIAGO CHOAPAN')
		insert into capa_poblacion values (20,461,'SANTIAGO DEL RIO')
		insert into capa_poblacion values (20,462,'SANTIAGO HUAJOLOTITLAN')
		insert into capa_poblacion values (20,463,'SANTIAGO HUAUCLILLA')
		insert into capa_poblacion values (20,464,'SANTIAGO IHUITLAN PLUMAS')
		insert into capa_poblacion values (20,465,'SANTIAGO IXCUINTEPEC')
		insert into capa_poblacion values (20,466,'SANTIAGO IXTAYUTLA')
		insert into capa_poblacion values (20,467,'SANTIAGO JAMILTEPEC')
		insert into capa_poblacion values (20,468,'MESONES HIDALGO')
		insert into capa_poblacion values (20,469,'SANTIAGO JUXTLAHUACA')
		insert into capa_poblacion values (20,470,'SANTIAGO LACHIGUIRI')
		insert into capa_poblacion values (20,471,'SANTIAGO LALOPA')
		insert into capa_poblacion values (20,472,'SANTIAGO LAOLLAGA')
		insert into capa_poblacion values (20,473,'SANTIAGO LAXOPA')
		insert into capa_poblacion values (20,474,'SANTIAGO LLANO GRANDE')
		insert into capa_poblacion values (20,475,'SANTIAGO MATATLAN')
		insert into capa_poblacion values (20,476,'SANTIAGO MILTEPEC')
		insert into capa_poblacion values (20,477,'SANTIAGO MINAS')
		insert into capa_poblacion values (20,478,'SANTIAGO NACALTEPEC')
		insert into capa_poblacion values (20,479,'SANTIAGO NEJAPILLA')
		insert into capa_poblacion values (20,480,'SANTIAGO NUNDICHI')
		insert into capa_poblacion values (20,481,'SANTIAGO NUYOO')
		insert into capa_poblacion values (20,482,'SANTIAGO PINOTEPA NACIONAL')
		insert into capa_poblacion values (20,483,'SANTIAGO SUCHILQUITONGO')
		insert into capa_poblacion values (20,484,'SANTIAGO TAMAZOLA')
		insert into capa_poblacion values (20,485,'SANTIAGO TAPEXTLA')
		insert into capa_poblacion values (20,486,'SANTIAGO TEPETLAPA')
		insert into capa_poblacion values (20,487,'SANTIAGO TENANGO')
		insert into capa_poblacion values (20,488,'SANTIAGO JOCOTEPEC')
		insert into capa_poblacion values (20,489,'SANTIAGO TETEPEC')
		insert into capa_poblacion values (20,490,'SANTIAGO TEXCALCINGO')
		insert into capa_poblacion values (20,491,'SANTIAGO TEXTITLAN')
		insert into capa_poblacion values (20,492,'SANTIAGO TILANTONGO')
		insert into capa_poblacion values (20,493,'SANTIAGO TILLO')
		insert into capa_poblacion values (20,494,'SANTIAGO TLAZOYALTEPEC')
		insert into capa_poblacion values (20,495,'SANTIAGO XANICA')
		insert into capa_poblacion values (20,496,'SANTIAGO XIACUI')
		insert into capa_poblacion values (20,497,'SANTIAGO YAITEPEC')
		insert into capa_poblacion values (20,498,'SANTIAGO YAVEO')
		insert into capa_poblacion values (20,499,'SANTIAGO YOLOMECATL')
		insert into capa_poblacion values (20,500,'SANTIAGO YOSONDUA')
		insert into capa_poblacion values (20,501,'SANTIAGO YUCUYACHI')
		insert into capa_poblacion values (20,502,'SANTIAGO ZACATEPEC')
		insert into capa_poblacion values (20,503,'SANTIAGO ZOOCHILA')
		insert into capa_poblacion values (20,504,'NUEVO ZOQUIAPAM')
		insert into capa_poblacion values (20,505,'SANTO DOMINGO INGENIO')
		insert into capa_poblacion values (20,506,'SANTO DOMINGO ALBARRADAS')
		insert into capa_poblacion values (20,507,'SANTO DOMINGO ARMENTA')
		insert into capa_poblacion values (20,508,'SANTO DOMINGO CHIHUITAN')
		insert into capa_poblacion values (20,509,'SANTO DOMINGO DE 17')
		insert into capa_poblacion values (20,510,'SANTO DOMINGO IXCATLAN')
		insert into capa_poblacion values (20,511,'SANTO DOMINGO NUXAA')
		insert into capa_poblacion values (20,512,'SANTO DOMINGO OZOLOTEPEC')
		insert into capa_poblacion values (20,513,'SANTO DOMINGO PETAPA')
		insert into capa_poblacion values (20,514,'SANTO DOMINGO ROAYAGA')
		insert into capa_poblacion values (20,515,'SANTO DOMINGO TEHUANTEPEC')
		insert into capa_poblacion values (20,516,'SANTO DOMINGO TEOJOMULCO')
		insert into capa_poblacion values (20,517,'SANTO DOMINGO TEPUXTEPEC')
		insert into capa_poblacion values (20,518,'SANTO DOMINGO TLATAYAPAM')
		insert into capa_poblacion values (20,519,'SANTO DOMINGO TOMALTEPEC')
		insert into capa_poblacion values (20,520,'SANTO DOMINGO TONALA')
		insert into capa_poblacion values (20,521,'SANTO DOMINGO TONALTEPEC')
		insert into capa_poblacion values (20,522,'SANTO DOMINGO XAGACIA')
		insert into capa_poblacion values (20,523,'SANTO DOMINGO YANHUITLAN')
		insert into capa_poblacion values (20,524,'SANTO DOMINGO YODOHINO')
		insert into capa_poblacion values (20,525,'SANTO DOMINGO ZANATEPEC')
		insert into capa_poblacion values (20,526,'SANTOS REYES NOPALA')
		insert into capa_poblacion values (20,527,'SANTOS REYES PAPALO')
		insert into capa_poblacion values (20,528,'SANTOS REYES TEPEJILLO')
		insert into capa_poblacion values (20,529,'SANTOS REYES YUCUNA')
		insert into capa_poblacion values (20,530,'SANTO TOMAS JALIEZA')
		insert into capa_poblacion values (20,531,'SANTO TOMAS MAZALTEPEC')
		insert into capa_poblacion values (20,532,'SANTO TOMAS OCOTEPEC')
		insert into capa_poblacion values (20,533,'SANTO TOMAS TAMAZULAPAN')
		insert into capa_poblacion values (20,534,'SAN VICENTE COATLAN')
		insert into capa_poblacion values (20,535,'SAN VICENTE LACHIXIO')
		insert into capa_poblacion values (20,536,'SAN VICENTE NUNU')
		insert into capa_poblacion values (20,537,'SILACAYOAPAN')
		insert into capa_poblacion values (20,538,'SITIO DE XITLAPEHUA')
		insert into capa_poblacion values (20,539,'SOLEDAD ETLA')
		insert into capa_poblacion values (20,540,'VILLA DE TAMAZULAPAN DEL PROGRESO')
		insert into capa_poblacion values (20,541,'TENETZE DE ZARAGOZA')
		insert into capa_poblacion values (20,542,'TANICHE')
		insert into capa_poblacion values (20,543,'TATALTEPEC DE VALDES')
		insert into capa_poblacion values (20,544,'TEOCOCUILCO DE MARCOS PEREZ')
		insert into capa_poblacion values (20,545,'TEOTITLAN DE FLORES MAGON')
		insert into capa_poblacion values (20,546,'TEOTITLAN DEL VALLE')
		insert into capa_poblacion values (20,547,'TEOTONGO')
		insert into capa_poblacion values (20,548,'TEPELMEME VILLA DE MORELOS')
		insert into capa_poblacion values (20,549,'TEZOATLAN DE SEGURA Y LUNA')
		insert into capa_poblacion values (20,550,'SAN JERONIMO TLACOCHAHUAYA')
		insert into capa_poblacion values (20,551,'TLACOLULA DE MATAMOROS')
		insert into capa_poblacion values (20,552,'TLACOTEPEC PLUMAS')
		insert into capa_poblacion values (20,553,'TLALIXTAC DE CABRERA')
		insert into capa_poblacion values (20,554,'TOTONTEPEC VILLA DE MORELOS')
		insert into capa_poblacion values (20,555,'TRINIDAD ZAACHILA')
		insert into capa_poblacion values (20,556,'LA TRINIDAD VISTA HERNOSA')
		insert into capa_poblacion values (20,557,'VILLA TEJUPAM DE LA UNION')
		insert into capa_poblacion values (20,558,'VALERIO TRUJANO')
		insert into capa_poblacion values (20,559,'SAN JUAN BAUTISTA VALLE NACIONAL')
		insert into capa_poblacion values (20,560,'VILLA DIAZ ORDAZ')
		insert into capa_poblacion values (20,561,'YAXE')
		insert into capa_poblacion values (20,562,'MAGDALENA YODOCONO DE PORFIRIO DIAZ')
		insert into capa_poblacion values (20,563,'YOGANA')
		insert into capa_poblacion values (20,564,'YUTANDUCHI DE GUERRERO')
		insert into capa_poblacion values (20,565,'VILLA DE ZAACHILA')
		insert into capa_poblacion values (20,566,'ZAPOTITLAN DEL RIO')
		insert into capa_poblacion values (20,567,'ZAPOTITLAN LAGUNAS')
		insert into capa_poblacion values (20,568,'ZAPOTITLAN PALMAS')
		insert into capa_poblacion values (20,569,'SANTA INES DE ZARAGOZA')
		insert into capa_poblacion values (20,570,'ZIMATLAN DE ALVAREZ')
		insert into capa_poblacion values (21,1,'ACAJETE')
		insert into capa_poblacion values (21,2,'SAN JOSE ACATENO')
		insert into capa_poblacion values (21,3,'ACATLAN DE OSORIO')
		insert into capa_poblacion values (21,4,'ACATZINGO DE HIDALGO')
		insert into capa_poblacion values (21,5,'ACTEOPAN')
		insert into capa_poblacion values (21,6,'AHUACATLAN')
		insert into capa_poblacion values (21,7,'AHUATLAN')
		insert into capa_poblacion values (21,8,'AHUAZOTEPEC')
		insert into capa_poblacion values (21,9,'AHUEHUETITLA')
		insert into capa_poblacion values (21,10,'AJALPAN')
		insert into capa_poblacion values (21,11,'ACAXTLAHUACAN DE ALBINO ZERTUCHE')
		insert into capa_poblacion values (21,12,'ALJOJUCA')
		insert into capa_poblacion values (21,13,'ALTEPEXI')
		insert into capa_poblacion values (21,14,'AMIXTLAN')
		insert into capa_poblacion values (21,15,'AMOZOC DE MOTA')
		insert into capa_poblacion values (21,16,'AQUIXTLA')
		insert into capa_poblacion values (21,17,'ATEMPAN')
		insert into capa_poblacion values (21,18,'SAN MARTIN ATEXCAL')
		insert into capa_poblacion values (21,19,'ATLIXCO')
		insert into capa_poblacion values (21,20,'ATOYATEMPAN')
		insert into capa_poblacion values (21,21,'ATZALA')
		insert into capa_poblacion values (21,22,'SANTIAGO ATZITZIHUACAN')
		insert into capa_poblacion values (21,23,'ATZITZINTLA')
		insert into capa_poblacion values (21,24,'AXUTLA')
		insert into capa_poblacion values (21,25,'AYOTOXCO DE GUERRERO')
		insert into capa_poblacion values (21,26,'SAN ANDRES CALPAN')
		insert into capa_poblacion values (21,27,'CALTEPEC')
		insert into capa_poblacion values (21,28,'CAMOCUAUTLA')
		insert into capa_poblacion values (21,29,'CAXHUACAN')
		insert into capa_poblacion values (21,30,'COATEPEC')
		insert into capa_poblacion values (21,31,'COATZINGO')
		insert into capa_poblacion values (21,32,'SANTA MARIA COHETZALA')
		insert into capa_poblacion values (21,33,'COHUECAN')
		insert into capa_poblacion values (21,34,'SANTA MARIA CORONANGO')
		insert into capa_poblacion values (21,35,'COXCATLAN')
		insert into capa_poblacion values (21,36,'SANTA MARIA COYOMEAPAN')
		insert into capa_poblacion values (21,37,'SAN VICENTE COYOTEPEC')
		insert into capa_poblacion values (21,38,'CUAPIAXTLA DE MADERO')
		insert into capa_poblacion values (21,39,'SAN ESTEBAN CUAUTEMPAN')
		insert into capa_poblacion values (21,40,'CUAUTINCHAN')
		insert into capa_poblacion values (21,41,'SAN JUAN CUAUTLANCINGO')
		insert into capa_poblacion values (21,42,'SAN PEDRO CUAYUCA')
		insert into capa_poblacion values (21,43,'CUETZALAN DEL PROGRESO')
		insert into capa_poblacion values (21,44,'CUYOACO')
		insert into capa_poblacion values (21,45,'CHALCHICOMULA DE SESMA')
		insert into capa_poblacion values (21,46,'CHAPULCO')
		insert into capa_poblacion values (21,47,'CHIAUTLA DE TAPIA')
		insert into capa_poblacion values (21,48,'SAN LORENZO CHIAUTZINGO')
		insert into capa_poblacion values (21,49,'CHICONCUAUTLA')
		insert into capa_poblacion values (21,50,'CHICHIQUILA')
		insert into capa_poblacion values (21,51,'CHIETLA')
		insert into capa_poblacion values (21,52,'CHIGMECATITLAN')
		insert into capa_poblacion values (21,53,'CHIGNAHUAPAN')
		insert into capa_poblacion values (21,54,'CHIGNAUTLA')
		insert into capa_poblacion values (21,55,'CHILA')
		insert into capa_poblacion values (21,56,'CHILA DE LA SAL')
		insert into capa_poblacion values (21,57,'HONEY')
		insert into capa_poblacion values (21,58,'CHILCHOTLA')
		insert into capa_poblacion values (21,59,'CHINANTLA')
		insert into capa_poblacion values (21,60,'DOMINGO ARENAS')
		insert into capa_poblacion values (21,61,'ELOXOCHITLAN')
		insert into capa_poblacion values (21,62,'SAN JUAN EPATLAN')
		insert into capa_poblacion values (21,63,'ESPERANZA')
		insert into capa_poblacion values (21,64,'FRANCISCO Z. MENA')
		insert into capa_poblacion values (21,65,'GENERAL FELIPE ANGELES')
		insert into capa_poblacion values (21,66,'GUADALUPE')
		insert into capa_poblacion values (21,67,'GUADALUPE VICTORIA')
		insert into capa_poblacion values (21,68,'HERMENEGILDO GALEANA')
		insert into capa_poblacion values (21,69,'HUAQUECHULA')
		insert into capa_poblacion values (21,70,'HUATLATLAUCA')
		insert into capa_poblacion values (21,71,'HUACHINANGO')
		insert into capa_poblacion values (21,72,'HUEHUETLA')
		insert into capa_poblacion values (21,73,'HUEHUETLAN EL CHICO')
		insert into capa_poblacion values (21,74,'HUEJOTZINGO')
		insert into capa_poblacion values (21,75,'HUEYAPAN')
		insert into capa_poblacion values (21,76,'HUEYTAMALCO')
		insert into capa_poblacion values (21,77,'HUEYTLALPAN')
		insert into capa_poblacion values (21,78,'HUTZILAN')
		insert into capa_poblacion values (21,79,'SANTA CLARA HUITZILTEPEC')
		insert into capa_poblacion values (21,80,'IGNACIO ALLENDE')
		insert into capa_poblacion values (21,81,'IXCAMILPA DE GUERRERO')
		insert into capa_poblacion values (21,82,'SAN JUAN IXCAQUIXTLA')
		insert into capa_poblacion values (21,83,'IXTACAMAXTITLAN')
		insert into capa_poblacion values (21,84,'IXTEPEC')
		insert into capa_poblacion values (21,85,'IZUCAR DE MATAMOROS')
		insert into capa_poblacion values (21,86,'JALPAN')
		insert into capa_poblacion values (21,87,'JOLALPAN')
		insert into capa_poblacion values (21,88,'JONOTLAN')
		insert into capa_poblacion values (21,89,'JOPALA')
		insert into capa_poblacion values (21,90,'JUAN C. BONILLA')
		insert into capa_poblacion values (21,91,'JUAN GALINDO')
		insert into capa_poblacion values (21,92,'JUAN N. MENDEZ')
		insert into capa_poblacion values (21,93,'LAFRAGUA')
		insert into capa_poblacion values (21,94,'LIBRES')
		insert into capa_poblacion values (21,95,'LA MAGDALENA TLATLAQUITEPEC')
		insert into capa_poblacion values (21,96,'MAZAPILTEPEC DE JUAREZ')
		insert into capa_poblacion values (21,97,'SAN FRANCISCO MIXTLA')
		insert into capa_poblacion values (21,98,'MOLCAXAC')
		insert into capa_poblacion values (21,99,'MORELOS CANADA')
		insert into capa_poblacion values (21,100,'NAUPAN')
		insert into capa_poblacion values (21,101,'NAUZONTLA')
		insert into capa_poblacion values (21,102,'SAN BUENAVENTURA NEALTICAN')
		insert into capa_poblacion values (21,103,'NICOLAS BRAVO')
		insert into capa_poblacion values (21,104,'NOPALUCAN DE LA GRANJA')
		insert into capa_poblacion values (21,105,'OCOTEPEC')
		insert into capa_poblacion values (21,106,'SANTA CLARA OCOYUCAN')
		insert into capa_poblacion values (21,107,'OLINTLA')
		insert into capa_poblacion values (21,108,'ORIENTAL')
		insert into capa_poblacion values (21,109,'PAHUATLAN DE VALLE')
		insert into capa_poblacion values (21,110,'PALMAR DE BRAVO')
		insert into capa_poblacion values (21,111,'PANTEPEC')
		insert into capa_poblacion values (21,112,'PETLALCINGO')
		insert into capa_poblacion values (21,113,'PIAXTLA')
		insert into capa_poblacion values (21,114,'HEROICA PUEBLA DE ZARAGOZA')
		insert into capa_poblacion values (21,115,'QUECHOLAC')
		insert into capa_poblacion values (21,116,'QUIMIXTLAN')
		insert into capa_poblacion values (21,117,'RAFAEL LARA GRAJALES')
		insert into capa_poblacion values (21,118,'LOS REYES DE JUAREZ')
		insert into capa_poblacion values (21,119,'SAN ANDRES CHOLULA')
		insert into capa_poblacion values (21,120,'SAN ANTONIO CANADA')
		insert into capa_poblacion values (21,121,'TOCHIMILTZINGO')
		insert into capa_poblacion values (21,122,'SAN FELIPE TEOTLALCINGO')
		insert into capa_poblacion values (21,123,'SAN FELIPE TEPATLAN')
		insert into capa_poblacion values (21,124,'SAN GABRIEL CHILAC')
		insert into capa_poblacion values (21,125,'SAN GREGORIO ATZOMPA')
		insert into capa_poblacion values (21,126,'SAN JERONIMO TECUANIPAN')
		insert into capa_poblacion values (21,127,'SAN JERONIMO XAYACATLAN')
		insert into capa_poblacion values (21,128,'SAN JOSE CHIAPA')
		insert into capa_poblacion values (21,129,'SAN JOSE MIAHUATLAN')
		insert into capa_poblacion values (21,130,'SAN JUAN ATENCO')
		insert into capa_poblacion values (21,131,'SAN JUAN ATZOMPA')
		insert into capa_poblacion values (21,132,'SAN MARTIN TEXMELUCAN DE LA BASTIDA')
		insert into capa_poblacion values (21,133,'SAN MARTIN TOTOLTEPEC')
		insert into capa_poblacion values (21,134,'SAN MATIAS TLALANCALECA')
		insert into capa_poblacion values (21,135,'SAN MIGUEL IXITLAN')
		insert into capa_poblacion values (21,136,'SAN MIGUEL XOXTLA')
		insert into capa_poblacion values (21,137,'SAN NICOLAS DE B. AIRES')
		insert into capa_poblacion values (21,138,'SAN NICOLAS LOS RANCHOS')
		insert into capa_poblacion values (21,139,'SAN PABLO AMICANO')
		insert into capa_poblacion values (21,140,'CHOLULA DE RIVADABIA')
		insert into capa_poblacion values (21,141,'SAN PEDRO YELOIXTLAHUACAN')
		insert into capa_poblacion values (21,142,'SAN SALVADOR EL SECO')
		insert into capa_poblacion values (21,143,'SAN SALVADOR EL VERDE')
		insert into capa_poblacion values (21,144,'SAN SALVADOR HUIXCOLOTLA')
		insert into capa_poblacion values (21,145,'TLACOTEPEC DE DIAZ')
		insert into capa_poblacion values (21,146,'SANTA CATARINA TLALTEMPAN')
		insert into capa_poblacion values (21,147,'SANTA INES AHUATEMPAN')
		insert into capa_poblacion values (21,148,'SANTA ISABEL CHOLULA')
		insert into capa_poblacion values (21,149,'SANTIAGO MIAHUATLAN')
		insert into capa_poblacion values (21,150,'HUEHUETLAN EL GRANDE')
		insert into capa_poblacion values (21,151,'SANTO TOMAS HUEYOTLIPAN')
		insert into capa_poblacion values (21,152,'SOLTEPEC')
		insert into capa_poblacion values (21,153,'TECALI DE HERRERA')
		insert into capa_poblacion values (21,154,'TECAMACHALCO')
		insert into capa_poblacion values (21,155,'TECOMATLAN')
		insert into capa_poblacion values (21,156,'TEHUACAN')
		insert into capa_poblacion values (21,157,'TEHUITZINGO')
		insert into capa_poblacion values (21,158,'TENAMPULCO')
		insert into capa_poblacion values (21,159,'TEOPANTLAN')
		insert into capa_poblacion values (21,160,'TEOTLALCO')
		insert into capa_poblacion values (21,161,'TEPANCO DE LOPEZ')
		insert into capa_poblacion values (21,162,'TEPANGO DE RODRIGUEZ')
		insert into capa_poblacion values (21,163,'TEPATLAXCO DE HIDALGO')
		insert into capa_poblacion values (21,164,'TEPEACA')
		insert into capa_poblacion values (21,165,'SAN FELIPE TEPEMAXALCO')
		insert into capa_poblacion values (21,166,'TEPEOJUMA')
		insert into capa_poblacion values (21,167,'TEPETZINTLA')
		insert into capa_poblacion values (21,168,'TEPEXCO')
		insert into capa_poblacion values (21,169,'TEPEXI DE RODRIGUEZ')
		insert into capa_poblacion values (21,170,'TEPEYAHUALCO')
		insert into capa_poblacion values (21,171,'TEPEYAHUALCO CUAUHTEMOC')
		insert into capa_poblacion values (21,172,'TETELA DE OCAMPO')
		insert into capa_poblacion values (21,173,'TETELES DE AVILA CASTILLO')
		insert into capa_poblacion values (21,174,'TEZIUTLAN')
		insert into capa_poblacion values (21,175,'TIANGUISMANALCO')
		insert into capa_poblacion values (21,176,'TILAPA')
		insert into capa_poblacion values (21,177,'TLACOTEPEC DE BENITO JUAREZ')
		insert into capa_poblacion values (21,178,'TLACUILOTEPEC')
		insert into capa_poblacion values (21,179,'TLACHICHUCA')
		insert into capa_poblacion values (21,180,'SANTA RITA TLAHUAPAN')
		insert into capa_poblacion values (21,181,'TLALTENANGO')
		insert into capa_poblacion values (21,182,'TLALNEPANTLA')
		insert into capa_poblacion values (21,183,'TLAOLA')
		insert into capa_poblacion values (21,184,'TLAPACOYA')
		insert into capa_poblacion values (21,185,'TLAPANALA')
		insert into capa_poblacion values (21,186,'TLATLAUQUITEPEC')
		insert into capa_poblacion values (21,187,'TLAXCO')
		insert into capa_poblacion values (21,188,'TOCHIMILCO')
		insert into capa_poblacion values (21,189,'TOCHTEPEC')
		insert into capa_poblacion values (21,190,'TOTOLTEPEC DE BENITO JUAREZ')
		insert into capa_poblacion values (21,191,'TULCINGO DEL VALLE')
		insert into capa_poblacion values (21,192,'TUZAMAPAN DE GALEANA')
		insert into capa_poblacion values (21,193,'TZICATLACOYAN')
		insert into capa_poblacion values (21,194,'VENUSTIANO CARRANZA')
		insert into capa_poblacion values (21,195,'VICENTE GUERRERO')
		insert into capa_poblacion values (21,196,'XAYACATLAN DE BRAVO')
		insert into capa_poblacion values (21,197,'XICOTEPEC DE JUAREZ')
		insert into capa_poblacion values (21,198,'XICOTLAN')
		insert into capa_poblacion values (21,199,'SAN JUAN XIUTETELCO')
		insert into capa_poblacion values (21,200,'XOCHIAPULCO')
		insert into capa_poblacion values (21,201,'XOCHILTEPEC')
		insert into capa_poblacion values (21,202,'XOCHITLAN DE ROMERO RUBIO')
		insert into capa_poblacion values (21,203,'XOCHITLAN')
		insert into capa_poblacion values (21,204,'YAONAHUAC')
		insert into capa_poblacion values (21,205,'YEHUALTEPEC')
		insert into capa_poblacion values (21,206,'ZACAPALA')
		insert into capa_poblacion values (21,207,'ZACAPOAXTLA')
		insert into capa_poblacion values (21,208,'ZACATLAN')
		insert into capa_poblacion values (21,209,'ZAPOTITLAN SALINAS')
		insert into capa_poblacion values (21,210,'ZAPOTITLAN DE MENDEZ')
		insert into capa_poblacion values (21,211,'ZARAGOZA')
		insert into capa_poblacion values (21,212,'SANTIAGO ZAUTLA')
		insert into capa_poblacion values (21,213,'ZIHUATEUTLA')
		insert into capa_poblacion values (21,214,'SAN SEBASTIAN ZINACATEPEC')
		insert into capa_poblacion values (21,215,'ZONGOZOTLA')
		insert into capa_poblacion values (21,216,'ZOQUIAPAN')
		insert into capa_poblacion values (21,217,'ZOQUITLAN')
		insert into capa_poblacion values (22,1,'AMEALCO')
		insert into capa_poblacion values (22,2,'PINAL DE AMOLES')
		insert into capa_poblacion values (22,3,'ARROYO SECO')
		insert into capa_poblacion values (22,4,'CADEREYTA DE MONTES')
		insert into capa_poblacion values (22,5,'COLON')
		insert into capa_poblacion values (22,6,'CORREGIDORA')
		insert into capa_poblacion values (22,7,'EZEQUIEL MONTES')
		insert into capa_poblacion values (22,8,'HUIMILPAN')
		insert into capa_poblacion values (22,9,'JALPAN')
		insert into capa_poblacion values (22,10,'LANDA DE MATAMOROS')
		insert into capa_poblacion values (22,11,'EL MARQUES')
		insert into capa_poblacion values (22,12,'PEDRO ESCOBEDO')
		insert into capa_poblacion values (22,13,'PENAMILLER')
		insert into capa_poblacion values (22,14,'QUERETARO')
		insert into capa_poblacion values (22,15,'SAN JOAQUIN')
		insert into capa_poblacion values (22,16,'SAN JUAN DEL RIO')
		insert into capa_poblacion values (22,17,'TEQUISQUIAPAN')
		insert into capa_poblacion values (22,18,'TOLIMAN')
		insert into capa_poblacion values (23,1,'COZUMEL')
		insert into capa_poblacion values (23,2,'FELIPE CARRILLO PUERTO')
		insert into capa_poblacion values (23,3,'ISLA MUJERES')
		insert into capa_poblacion values (23,4,'OTHON P. BLANCO')
		insert into capa_poblacion values (23,5,'BENITO JUAREZ')
		insert into capa_poblacion values (23,6,'JOSE MARIA MORELOS')
		insert into capa_poblacion values (23,7,'LAZARO CARDENAS')
		insert into capa_poblacion values (23,8,'SOLIDARIDAD')
		insert into capa_poblacion values (24,1,'AHUALULCO')
		insert into capa_poblacion values (24,2,'ALAQUINES')
		insert into capa_poblacion values (24,3,'AQUISMON')
		insert into capa_poblacion values (24,4,'ARMADILLO DE LOS INFANTE')
		insert into capa_poblacion values (24,5,'CARDENAS')
		insert into capa_poblacion values (24,6,'CATORCE')
		insert into capa_poblacion values (24,7,'CEDRAL')
		insert into capa_poblacion values (24,8,'CERRITOS')
		insert into capa_poblacion values (24,9,'CERRO DE SAN PEDRO')
		insert into capa_poblacion values (24,10,'CIUDAD DEL MAIZ')
		insert into capa_poblacion values (24,11,'CIUDAD FERNANDEZ')
		insert into capa_poblacion values (24,12,'TANCANHUITZ DE SANTOS')
		insert into capa_poblacion values (24,13,'CIUDAD VALLES')
		insert into capa_poblacion values (24,14,'COXCATLAN')
		insert into capa_poblacion values (24,15,'CHARCAS')
		insert into capa_poblacion values (24,16,'EBANO')
		insert into capa_poblacion values (24,17,'GUADALCAZAR')
		insert into capa_poblacion values (24,18,'HUEHUETLAN')
		insert into capa_poblacion values (24,19,'LAGUNILLAS')
		insert into capa_poblacion values (24,20,'MATEHUALA')
		insert into capa_poblacion values (24,21,'MEXQUITIC DE CARMONA')
		insert into capa_poblacion values (24,22,'MOCTEZUMA')
		insert into capa_poblacion values (24,23,'RAYON')
		insert into capa_poblacion values (24,24,'RIOVERDE')
		insert into capa_poblacion values (24,25,'SALINAS DE HIDALGO')
		insert into capa_poblacion values (24,26,'SAN ANTONIO')
		insert into capa_poblacion values (24,27,'SAN CIRO DE ACOSTA')
		insert into capa_poblacion values (24,28,'SAN LUIS POTOSI')
		insert into capa_poblacion values (24,29,'SAN MARTIN CHALCHICUAUTLA')
		insert into capa_poblacion values (24,30,'SAN NICOLAS TOLENTINO')
		insert into capa_poblacion values (24,31,'SANTA CATARINA')
		insert into capa_poblacion values (24,32,'SANTA MARIA DEL RIO')
		insert into capa_poblacion values (24,33,'SANTO DOMINGO')
		insert into capa_poblacion values (24,34,'SAN VICENTE TANCUAYALAB')
		insert into capa_poblacion values (24,35,'SOLEDAD DE GRACIANO SANCHEZ')
		insert into capa_poblacion values (24,36,'TAMASOPO')
		insert into capa_poblacion values (24,37,'TAMAZUNCHALE')
		insert into capa_poblacion values (24,38,'TAMPACAN')
		insert into capa_poblacion values (24,39,'TAMPAMOLON CORONA')
		insert into capa_poblacion values (24,40,'TAMUIN')
		insert into capa_poblacion values (24,41,'TANLAJAS')
		insert into capa_poblacion values (24,42,'TANQUIAN DE ESCOBEDO')
		insert into capa_poblacion values (24,43,'TIERRA NUEVA')
		insert into capa_poblacion values (24,44,'VANEGAS')
		insert into capa_poblacion values (24,45,'VENADO')
		insert into capa_poblacion values (24,46,'VILLA DE ARRIAGA')
		insert into capa_poblacion values (24,47,'VILLA DE GUADALUPE')
		insert into capa_poblacion values (24,48,'VILLA DE LA PAZ')
		insert into capa_poblacion values (24,49,'VILLA DE RAMOS')
		insert into capa_poblacion values (24,50,'VILLA DE REYES')
		insert into capa_poblacion values (24,51,'VILLA 13')
		insert into capa_poblacion values (24,52,'VILLA JUAREZ')
		insert into capa_poblacion values (24,53,'AXTLA DE TERRAZAS')
		insert into capa_poblacion values (24,54,'XILITLA')
		insert into capa_poblacion values (24,55,'ZARAGOZA')
		insert into capa_poblacion values (24,56,'VILLA DE ARISTA')
		insert into capa_poblacion values (24,57,'NARANJO, EL')
		insert into capa_poblacion values (24,58,'ARANJO, EL')
		insert into capa_poblacion values (25,1,'AHOME')
		insert into capa_poblacion values (25,2,'ANGOSTURA')
		insert into capa_poblacion values (25,3,'BADIRAGUATO')
		insert into capa_poblacion values (25,4,'CONCORDIA')
		insert into capa_poblacion values (25,5,'COSALA')
		insert into capa_poblacion values (25,6,'CULIACAN ROSALES')
		insert into capa_poblacion values (25,7,'CHOIX')
		insert into capa_poblacion values (25,8,'ELOTA')
		insert into capa_poblacion values (25,9,'ESCUINAPA DE HIDALGO')
		insert into capa_poblacion values (25,10,'EL FUERTE')
		insert into capa_poblacion values (25,11,'GUASAVE')
		insert into capa_poblacion values (25,12,'MAZATLAN')
		insert into capa_poblacion values (25,13,'MOCORITO')
		insert into capa_poblacion values (25,14,'ROSARIO')
		insert into capa_poblacion values (25,15,'SALVADOR ALVARADO')
		insert into capa_poblacion values (25,16,'SAN IGNACIO')
		insert into capa_poblacion values (25,17,'SINALOA DE LEYVA')
		insert into capa_poblacion values (25,18,'NAVOLATO')
		insert into capa_poblacion values (26,1,'ACONCHI')
		insert into capa_poblacion values (26,2,'AGUAPRIETA')
		insert into capa_poblacion values (26,3,'ALAMOS')
		insert into capa_poblacion values (26,4,'ALTAR')
		insert into capa_poblacion values (26,5,'ARIVECHI')
		insert into capa_poblacion values (26,6,'ARIZPE')
		insert into capa_poblacion values (26,7,'ATIL')
		insert into capa_poblacion values (26,8,'BACADEHUACHI')
		insert into capa_poblacion values (26,9,'BACANORA')
		insert into capa_poblacion values (26,10,'BASERAC')
		insert into capa_poblacion values (26,11,'BACOACHI')
		insert into capa_poblacion values (26,12,'BACUM')
		insert into capa_poblacion values (26,13,'BANAMICHI')
		insert into capa_poblacion values (26,14,'BAVIACORA')
		insert into capa_poblacion values (26,15,'BAVISPE')
		insert into capa_poblacion values (26,16,'BENJAMIN HILL')
		insert into capa_poblacion values (26,17,'HEROICA CABORCA')
		insert into capa_poblacion values (26,18,'CAJEME')
		insert into capa_poblacion values (26,19,'CANANEA')
		insert into capa_poblacion values (26,20,'CARBO')
		insert into capa_poblacion values (26,21,'LA COLORADA')
		insert into capa_poblacion values (26,22,'CUCURPE')
		insert into capa_poblacion values (26,23,'CUMPAS')
		insert into capa_poblacion values (26,24,'DIVISADEROS')
		insert into capa_poblacion values (26,25,'EMPALME')
		insert into capa_poblacion values (26,26,'ETCHOJOA')
		insert into capa_poblacion values (26,27,'FRONTERAS')
		insert into capa_poblacion values (26,28,'GRANADOS')
		insert into capa_poblacion values (26,29,'HEROICA GUAYMAS')
		insert into capa_poblacion values (26,30,'HERMOSILLO')
		insert into capa_poblacion values (26,31,'HUACHINERA')
		insert into capa_poblacion values (26,32,'HUASABAS')
		insert into capa_poblacion values (26,33,'HUATABAMPO')
		insert into capa_poblacion values (26,34,'HUEPAC')
		insert into capa_poblacion values (26,35,'IMURIS')
		insert into capa_poblacion values (26,36,'MAGDALENA DE KINO')
		insert into capa_poblacion values (26,37,'MAZATLAN')
		insert into capa_poblacion values (26,38,'MOCTEZUMA')
		insert into capa_poblacion values (26,39,'NACO')
		insert into capa_poblacion values (26,40,'NACORI CHICO')
		insert into capa_poblacion values (26,41,'NACOZARI DE GARCIA')
		insert into capa_poblacion values (26,42,'NAVOJOA')
		insert into capa_poblacion values (26,43,'HEROICA NOGALES')
		insert into capa_poblacion values (26,44,'ONAVAS')
		insert into capa_poblacion values (26,45,'OPODEPE')
		insert into capa_poblacion values (26,46,'OQUITOA')
		insert into capa_poblacion values (26,47,'PITIQUITO')
		insert into capa_poblacion values (26,48,'PUERTO PENASCO')
		insert into capa_poblacion values (26,49,'QUIRIEGO')
		insert into capa_poblacion values (26,50,'RAYON')
		insert into capa_poblacion values (26,51,'ROSARIO')
		insert into capa_poblacion values (26,52,'SAHUARIPA')
		insert into capa_poblacion values (26,53,'SAN FELIPE DE JESUS')
		insert into capa_poblacion values (26,54,'SAN JAVIER')
		insert into capa_poblacion values (26,55,'SAN LUIS RIO COLORADO')
		insert into capa_poblacion values (26,56,'SAN MIGUEL DE HORCASITAS')
		insert into capa_poblacion values (26,57,'SAN PEDRO DE LA CUEVA')
		insert into capa_poblacion values (26,58,'SANTA ANA')
		insert into capa_poblacion values (26,59,'SANTA CRUZ')
		insert into capa_poblacion values (26,60,'SARIO')
		insert into capa_poblacion values (26,61,'SOYOPA')
		insert into capa_poblacion values (26,62,'SUAQUI GRANDE')
		insert into capa_poblacion values (26,63,'TEPACHE')
		insert into capa_poblacion values (26,64,'TRINCHERAS')
		insert into capa_poblacion values (26,65,'TURUTAMA')
		insert into capa_poblacion values (26,66,'URES')
		insert into capa_poblacion values (26,67,'VILLA HIDALGO')
		insert into capa_poblacion values (26,68,'VILLA PESQUEIRA')
		insert into capa_poblacion values (26,69,'YECORA')
		insert into capa_poblacion values (26,70,'GENERAL PLUTARCO ELIAS CALLES')
		insert into capa_poblacion values (27,1,'BALANCAN DE DOMINGUEZ')
		insert into capa_poblacion values (27,2,'HEROICA CARDENAS')
		insert into capa_poblacion values (27,3,'CENTLA')
		insert into capa_poblacion values (27,4,'CENTRO')
		insert into capa_poblacion values (27,5,'COMALCALCO')
		insert into capa_poblacion values (27,6,'CUNDUACAN')
		insert into capa_poblacion values (27,7,'EMILIANO ZAPATA')
		insert into capa_poblacion values (27,8,'HUIMANGUILLO')
		insert into capa_poblacion values (27,9,'JALAPA')
		insert into capa_poblacion values (27,10,'JALPA DE MENDEZ')
		insert into capa_poblacion values (27,11,'JONUTA')
		insert into capa_poblacion values (27,12,'MACUSPANA')
		insert into capa_poblacion values (27,13,'NACAJUCA')
		insert into capa_poblacion values (27,14,'PARAISO')
		insert into capa_poblacion values (27,15,'TACOTALPA')
		insert into capa_poblacion values (27,16,'TEAPA')
		insert into capa_poblacion values (27,17,'TENOSIQUE DE PINO SUAREZ')
		insert into capa_poblacion values (28,1,'ABASOLO')
		insert into capa_poblacion values (28,2,'ALDAMA')
		insert into capa_poblacion values (28,3,'ALTAMIRA')
		insert into capa_poblacion values (28,4,'ANTIGUO MORELOS')
		insert into capa_poblacion values (28,5,'BURGOS')
		insert into capa_poblacion values (28,6,'BUSTAMANTE')
		insert into capa_poblacion values (28,7,'CAMARGO')
		insert into capa_poblacion values (28,8,'CASAS')
		insert into capa_poblacion values (28,9,'CIUDAD MADERO')
		insert into capa_poblacion values (28,10,'CRUILLAS')
		insert into capa_poblacion values (28,11,'GOMEZ FARIAS')
		insert into capa_poblacion values (28,12,'GONZALEZ')
		insert into capa_poblacion values (28,13,'GUEMEZ')
		insert into capa_poblacion values (28,14,'GUERRERO')
		insert into capa_poblacion values (28,15,'GUSTAVO DIAZ ORDAZ')
		insert into capa_poblacion values (28,16,'HIDALGO')
		insert into capa_poblacion values (28,17,'JAUMAVE')
		insert into capa_poblacion values (28,18,'JIMENEZ')
		insert into capa_poblacion values (28,19,'LLERA')
		insert into capa_poblacion values (28,20,'MAINERO')
		insert into capa_poblacion values (28,21,'EL MANTE')
		insert into capa_poblacion values (28,22,'MATAMOROS')
		insert into capa_poblacion values (28,23,'MENDEZ')
		insert into capa_poblacion values (28,24,'MIER')
		insert into capa_poblacion values (28,25,'MIGUEL ALEMAN')
		insert into capa_poblacion values (28,26,'MIQUIHUANA')
		insert into capa_poblacion values (28,27,'NUEVO LAREDO')
		insert into capa_poblacion values (28,28,'NUEVO MORELOS')
		insert into capa_poblacion values (28,29,'OCAMPO')
		insert into capa_poblacion values (28,30,'PADILLA')
		insert into capa_poblacion values (28,31,'PALMILLAS')
		insert into capa_poblacion values (28,32,'REYNOSA')
		insert into capa_poblacion values (28,33,'RIO BRAVO')
		insert into capa_poblacion values (28,34,'SAN CARLOS')
		insert into capa_poblacion values (28,35,'SAN FERNANDO')
		insert into capa_poblacion values (28,36,'SAN NICOLAS')
		insert into capa_poblacion values (28,37,'SOTO LA MARINA')
		insert into capa_poblacion values (28,38,'TAMPICO')
		insert into capa_poblacion values (28,39,'TULA')
		insert into capa_poblacion values (28,40,'VALLE HERMOSO')
		insert into capa_poblacion values (28,41,'VICTORIA')
		insert into capa_poblacion values (28,42,'VILLAGRAN')
		insert into capa_poblacion values (28,43,'XICOTENCATL')
		insert into capa_poblacion values (29,1,'AMAXAC DE GUERRERO')
		insert into capa_poblacion values (29,2,'ANTONIO CARBAJAL')
		insert into capa_poblacion values (29,3,'APIZACO')
		insert into capa_poblacion values (29,4,'ATLANGATEPEC')
		insert into capa_poblacion values (29,5,'ATIZAYANCA')
		insert into capa_poblacion values (29,6,'CALPULALPAN')
		insert into capa_poblacion values (29,7,'TEQUIXQUITLA')
		insert into capa_poblacion values (29,8,'CUAPIAXTLA')
		insert into capa_poblacion values (29,9,'CUAXOMULCO')
		insert into capa_poblacion values (29,10,'CHIAUTEMPAN')
		insert into capa_poblacion values (29,11,'DOMINGO ARENAS')
		insert into capa_poblacion values (29,12,'ESPANITA')
		insert into capa_poblacion values (29,13,'HUAMANTLA')
		insert into capa_poblacion values (29,14,'HUEYOTLIPAN')
		insert into capa_poblacion values (29,15,'IXTACUIXTLA')
		insert into capa_poblacion values (29,16,'IXTENCO')
		insert into capa_poblacion values (29,17,'JOSE MARIA MORELOS')
		insert into capa_poblacion values (29,18,'JUAN CUAMATZI')
		insert into capa_poblacion values (29,19,'LARDIZABAL')
		insert into capa_poblacion values (29,20,'LAZARO CARDENAS')
		insert into capa_poblacion values (29,21,'MARIANO ARISTA')
		insert into capa_poblacion values (29,22,'MIGUEL HIDALGO')
		insert into capa_poblacion values (29,23,'NATIVITAS')
		insert into capa_poblacion values (29,24,'PANOTLA')
		insert into capa_poblacion values (29,25,'SAN PABLO DEL MONTE')
		insert into capa_poblacion values (29,26,'SANTA CRUZ TLAXCALA')
		insert into capa_poblacion values (29,27,'TENANCINGO')
		insert into capa_poblacion values (29,28,'TEOLOCHOLCO')
		insert into capa_poblacion values (29,29,'TEPEYANCO')
		insert into capa_poblacion values (29,30,'TERRENATE')
		insert into capa_poblacion values (29,31,'TETLA')
		insert into capa_poblacion values (29,32,'TETLATLAHUCA')
		insert into capa_poblacion values (29,33,'TLAXCALA DE XICOHTENCATL')
		insert into capa_poblacion values (29,34,'TLAXCO')
		insert into capa_poblacion values (29,35,'TOCATLAN')
		insert into capa_poblacion values (29,36,'TOTOLAC')
		insert into capa_poblacion values (29,37,'TRINIDAD SANCHEZ SANTOS')
		insert into capa_poblacion values (29,38,'TZOMPANTEPEC')
		insert into capa_poblacion values (29,39,'XALOZTOC')
		insert into capa_poblacion values (29,40,'XALTOCAN')
		insert into capa_poblacion values (29,41,'XICOHTENCATL')
		insert into capa_poblacion values (29,42,'XICOHTZINCO')
		insert into capa_poblacion values (29,43,'YAUHQUEMEHCAN')
		insert into capa_poblacion values (29,44,'ZACATELCO')
		insert into capa_poblacion values (29,45,'BENITO JUAREZ')
		insert into capa_poblacion values (29,46,'EMILIANO ZAPATA')
		insert into capa_poblacion values (29,47,'LAZARO CARDENAS')
		insert into capa_poblacion values (29,48,'LA MAGDALENA TLALTELULCO')
		insert into capa_poblacion values (29,49,'SAN DAMIAN TEXOLOC')
		insert into capa_poblacion values (29,50,'SAN FRANCISCO TETLANOHCAN')
		insert into capa_poblacion values (29,51,'SAN JERONIMO ZACUALPAN')
		insert into capa_poblacion values (29,52,'SAN JOSE TEACALCO')
		insert into capa_poblacion values (29,53,'SAN JUAN HUACTZINCO')
		insert into capa_poblacion values (29,54,'SAN LORENZO AXOCOMANITLA')
		insert into capa_poblacion values (29,55,'SAN LUCAS TECOPILCO')
		insert into capa_poblacion values (29,56,'SANTA ANA NOPALUCAN')
		insert into capa_poblacion values (29,57,'SANTA APOLONIA TEACALCO')
		insert into capa_poblacion values (29,58,'SANTA CATARINA AYOMETLA')
		insert into capa_poblacion values (29,59,'SANTA CRUZ QUILEHTLA')
		insert into capa_poblacion values (29,60,'SANTA ISABEL XILOXOXTLA')
		insert into capa_poblacion values (30,1,'ACAJETE')
		insert into capa_poblacion values (30,2,'ACATLAN')
		insert into capa_poblacion values (30,3,'ACAYUCAN')
		insert into capa_poblacion values (30,4,'ACTOPAN')
		insert into capa_poblacion values (30,5,'ACULA')
		insert into capa_poblacion values (30,6,'ACULTIZINGO')
		insert into capa_poblacion values (30,7,'VILLA TEJEDA')
		insert into capa_poblacion values (30,8,'ALPATLAHUA')
		insert into capa_poblacion values (30,9,'ALTO LUCERO')
		insert into capa_poblacion values (30,10,'ALTOTONGA')
		insert into capa_poblacion values (30,11,'HEROICA ALVARADO')
		insert into capa_poblacion values (30,12,'AMATITLAN')
		insert into capa_poblacion values (30,13,'NARANJOS AMATLAN')
		insert into capa_poblacion values (30,14,'AMATLAN DE LOS REYES')
		insert into capa_poblacion values (30,15,'ANGEL R. CABADA')
		insert into capa_poblacion values (30,16,'LA ANTIGUA')
		insert into capa_poblacion values (30,17,'APAZAPAN')
		insert into capa_poblacion values (30,18,'AQUILA')
		insert into capa_poblacion values (30,19,'ASTACINGA')
		insert into capa_poblacion values (30,20,'ATLAHUILCO')
		insert into capa_poblacion values (30,21,'ATOYAC')
		insert into capa_poblacion values (30,22,'ATZACAN')
		insert into capa_poblacion values (30,23,'ATZALAN')
		insert into capa_poblacion values (30,24,'AXOCUAPAN')
		insert into capa_poblacion values (30,25,'AYAHUALULCO')
		insert into capa_poblacion values (30,26,'BANDERILLA')
		insert into capa_poblacion values (30,27,'BENITO JUAREZ')
		insert into capa_poblacion values (30,28,'BOCA DEL RIO')
		insert into capa_poblacion values (30,29,'CALCAHUALCO')
		insert into capa_poblacion values (30,30,'CIUDAD MENDOZA')
		insert into capa_poblacion values (30,31,'CARRILLO PUERTO')
		insert into capa_poblacion values (30,32,'CATEMACO')
		insert into capa_poblacion values (30,33,'VILLA DE CAZONES DE HERRERA')
		insert into capa_poblacion values (30,34,'CERRO AZUL')
		insert into capa_poblacion values (30,35,'CITLALTEPEC')
		insert into capa_poblacion values (30,36,'COACOATZINTLA')
		insert into capa_poblacion values (30,37,'COAHUITLAN')
		insert into capa_poblacion values (30,38,'COATEPEC')
		insert into capa_poblacion values (30,39,'COATZACOALCOS')
		insert into capa_poblacion values (30,40,'COATZINTLA')
		insert into capa_poblacion values (30,41,'COETZALA')
		insert into capa_poblacion values (30,42,'COLIPA')
		insert into capa_poblacion values (30,43,'COMAPA')
		insert into capa_poblacion values (30,44,'HEROICA CORDOBA')
		insert into capa_poblacion values (30,45,'COSAMALOAPAN DE CARPIO')
		insert into capa_poblacion values (30,46,'COSAUTLAN DE CARVAJAL')
		insert into capa_poblacion values (30,47,'COSCOMATEPEC DE BRAVO')
		insert into capa_poblacion values (30,48,'COSOLEACAQUE')
		insert into capa_poblacion values (30,49,'COTAXTLA')
		insert into capa_poblacion values (30,50,'COXQUIHUI')
		insert into capa_poblacion values (30,51,'COYUTLA')
		insert into capa_poblacion values (30,52,'CUICHAPA')
		insert into capa_poblacion values (30,53,'CUITLAHUAC')
		insert into capa_poblacion values (30,54,'CHACALTIANGUIS')
		insert into capa_poblacion values (30,55,'CHALMA')
		insert into capa_poblacion values (30,56,'CHICONAMEL')
		insert into capa_poblacion values (30,57,'CHICONQUIACO')
		insert into capa_poblacion values (30,58,'CHICONTEPEC DE TEJEDA')
		insert into capa_poblacion values (30,59,'CHINAMECA')
		insert into capa_poblacion values (30,60,'CHINAMPA DE GOROSTIZA')
		insert into capa_poblacion values (30,61,'LAS CHOAPAS')
		insert into capa_poblacion values (30,62,'CHOCAMAN')
		insert into capa_poblacion values (30,63,'CHONTLA')
		insert into capa_poblacion values (30,64,'CHUMATLAN')
		insert into capa_poblacion values (30,65,'EMILIANO ZAPATA')
		insert into capa_poblacion values (30,66,'ESPINAL')
		insert into capa_poblacion values (30,67,'FILOMENO MATA')
		insert into capa_poblacion values (30,68,'FORTIN DE LAS FLORES')
		insert into capa_poblacion values (30,69,'GUTIERREZ ZAMORA')
		insert into capa_poblacion values (30,70,'13TITLAN')
		insert into capa_poblacion values (30,71,'HUATUSCO DE CHICUELLAR')
		insert into capa_poblacion values (30,72,'HUAYACOCOTLA')
		insert into capa_poblacion values (30,73,'HUEYAPAN DE OCAMPO')
		insert into capa_poblacion values (30,74,'HUILOAPAN DE CUAUHTEMOC')
		insert into capa_poblacion values (30,75,'IGNACIO DE LA LLAVE')
		insert into capa_poblacion values (30,76,'ILAMATLAN')
		insert into capa_poblacion values (30,77,'ISLA')
		insert into capa_poblacion values (30,78,'IXCATEPEC')
		insert into capa_poblacion values (30,79,'IXHUACAN DE LOS REYES')
		insert into capa_poblacion values (30,80,'IXHUATLAN DEL CAFE')
		insert into capa_poblacion values (30,81,'IXHUATLANCILLO')
		insert into capa_poblacion values (30,82,'IXHUATLAN DEL SURESTE')
		insert into capa_poblacion values (30,83,'IXHUATLAN DE MADERO')
		insert into capa_poblacion values (30,84,'IXMATLAHUACAN')
		insert into capa_poblacion values (30,85,'IXTACZOQUITLAN')
		insert into capa_poblacion values (30,86,'JALACINGO')
		insert into capa_poblacion values (30,87,'XALAPA')
		insert into capa_poblacion values (30,88,'JALCOMULCO')
		insert into capa_poblacion values (30,89,'JALTIPAN DE MORELOS')
		insert into capa_poblacion values (30,90,'JAMAPA')
		insert into capa_poblacion values (30,91,'JESUS CARRANZA')
		insert into capa_poblacion values (30,92,'JICO')
		insert into capa_poblacion values (30,93,'JILOTEPEC')
		insert into capa_poblacion values (30,94,'JUAN RODRIGUEZ CLARA')
		insert into capa_poblacion values (30,95,'JUCHIQUE DE FERRER')
		insert into capa_poblacion values (30,96,'LANDERO Y COS')
		insert into capa_poblacion values (30,97,'LERDO DE TEJADA')
		insert into capa_poblacion values (30,98,'MAGDALENA')
		insert into capa_poblacion values (30,99,'MALTRATA')
		insert into capa_poblacion values (30,100,'MANLIO FABIO ALTAMIRANO')
		insert into capa_poblacion values (30,101,'MARIANO ESCOBEDO')
		insert into capa_poblacion values (30,102,'MARTINEZ DE LA TORRE')
		insert into capa_poblacion values (30,103,'MECATLAN')
		insert into capa_poblacion values (30,104,'MECAYAPAN')
		insert into capa_poblacion values (30,105,'MEDELLIN DE BRAVO')
		insert into capa_poblacion values (30,106,'MIAHUATLAN')
		insert into capa_poblacion values (30,107,'LAS MINAS')
		insert into capa_poblacion values (30,108,'MINATITLAN')
		insert into capa_poblacion values (30,109,'MISANTLA')
		insert into capa_poblacion values (30,110,'MIXTLA DE ALTAMIRANO')
		insert into capa_poblacion values (30,111,'MOLOACAN')
		insert into capa_poblacion values (30,112,'NAOLINCO DE VICTORIA')
		insert into capa_poblacion values (30,113,'NARANJAL')
		insert into capa_poblacion values (30,114,'NAUTLA')
		insert into capa_poblacion values (30,115,'NOGALES')
		insert into capa_poblacion values (30,116,'OLUTA')
		insert into capa_poblacion values (30,117,'OMEALCA')
		insert into capa_poblacion values (30,118,'ORIZABA')
		insert into capa_poblacion values (30,119,'OTATITLAN')
		insert into capa_poblacion values (30,120,'OTEAPAN')
		insert into capa_poblacion values (30,121,'OZULUAMA')
		insert into capa_poblacion values (30,122,'PAJAPAN')
		insert into capa_poblacion values (30,123,'PANUCO')
		insert into capa_poblacion values (30,124,'PAPANTLA DE OLARTE')
		insert into capa_poblacion values (30,125,'PASO DEL MACHO')
		insert into capa_poblacion values (30,126,'PASO DE OVEJAS')
		insert into capa_poblacion values (30,127,'LA PERLA')
		insert into capa_poblacion values (30,128,'PEROTE')
		insert into capa_poblacion values (30,129,'PLATON SANCHEZ')
		insert into capa_poblacion values (30,130,'PLAYA VICENTE')
		insert into capa_poblacion values (30,131,'POZA RICA DE 13')
		insert into capa_poblacion values (30,132,'LAS VIGAS DE RAMIREZ')
		insert into capa_poblacion values (30,133,'PUEBLO VIEJO')
		insert into capa_poblacion values (30,134,'PUENTE NACIONAL')
		insert into capa_poblacion values (30,135,'RAFAEL DELGADO')
		insert into capa_poblacion values (30,136,'RAFAEL LUCIO')
		insert into capa_poblacion values (30,137,'REYES')
		insert into capa_poblacion values (30,138,'TENANGO DE RIO BLANCO')
		insert into capa_poblacion values (30,139,'SALTABARRANCA')
		insert into capa_poblacion values (30,140,'SAN ANDRES TENEJAPA')
		insert into capa_poblacion values (30,141,'SAN ANDRES TUXTLA')
		insert into capa_poblacion values (30,142,'SAN JUAN EVANGELISTA')
		insert into capa_poblacion values (30,143,'SANTIAGO TUXTLA')
		insert into capa_poblacion values (30,144,'SAYULA DE ALEMAN')
		insert into capa_poblacion values (30,145,'SOCONUSCO')
		insert into capa_poblacion values (30,146,'SOCHIAPA')
		insert into capa_poblacion values (30,147,'SOLEDAD ATZOMPA')
		insert into capa_poblacion values (30,148,'SOLEDAD DE DOBLADO')
		insert into capa_poblacion values (30,149,'SOTEAPAN')
		insert into capa_poblacion values (30,150,'TAMALIN')
		insert into capa_poblacion values (30,151,'TAMIAHUA')
		insert into capa_poblacion values (30,152,'TAMPICO ALTO')
		insert into capa_poblacion values (30,153,'TANCOCO')
		insert into capa_poblacion values (30,154,'TANTIMA')
		insert into capa_poblacion values (30,155,'TANTOYUCA')
		insert into capa_poblacion values (30,156,'TATATILA')
		insert into capa_poblacion values (30,157,'CASTILLO DE TEAYO')
		insert into capa_poblacion values (30,158,'TECOLUTLA')
		insert into capa_poblacion values (30,159,'TEHUIPANGO')
		insert into capa_poblacion values (30,160,'TEMAPACHE')
		insert into capa_poblacion values (30,161,'TEMPOAL DE SANCHEZ')
		insert into capa_poblacion values (30,162,'TENAMPA')
		insert into capa_poblacion values (30,163,'TENOCHTITLAN')
		insert into capa_poblacion values (30,164,'TEOCELO')
		insert into capa_poblacion values (30,165,'TEPATLAXCO')
		insert into capa_poblacion values (30,166,'TEPETLAN')
		insert into capa_poblacion values (30,167,'TEPETZINTLA')
		insert into capa_poblacion values (30,168,'TEQUILA')
		insert into capa_poblacion values (30,169,'JOSE AZUETA')
		insert into capa_poblacion values (30,170,'TEXCATEPEC')
		insert into capa_poblacion values (30,171,'TEXHUACAN')
		insert into capa_poblacion values (30,172,'TEXISTEPEC')
		insert into capa_poblacion values (30,173,'TEZONAPA')
		insert into capa_poblacion values (30,174,'TIERRA BLANCA')
		insert into capa_poblacion values (30,175,'TIHUATLAN')
		insert into capa_poblacion values (30,176,'TLACOJALPAN')
		insert into capa_poblacion values (30,177,'TLACOLULAN')
		insert into capa_poblacion values (30,178,'TLACOTALPAN')
		insert into capa_poblacion values (30,179,'TLACOTEPEC DE MEJIA')
		insert into capa_poblacion values (30,180,'TACHICHILCO')
		insert into capa_poblacion values (30,181,'TLALIXCOYAN')
		insert into capa_poblacion values (30,182,'TLANELHUAYOCAN')
		insert into capa_poblacion values (30,183,'TLAPACOYAN')
		insert into capa_poblacion values (30,184,'TLAQUILPA')
		insert into capa_poblacion values (30,185,'TLILAPAN')
		insert into capa_poblacion values (30,186,'TOMATLAN')
		insert into capa_poblacion values (30,187,'TANOYAN')
		insert into capa_poblacion values (30,188,'TOTUTLA')
		insert into capa_poblacion values (30,189,'TUXPAN DE RODRIGUEZ CANO')
		insert into capa_poblacion values (30,190,'TUXTILLA')
		insert into capa_poblacion values (30,191,'URSULO GALVAN')
		insert into capa_poblacion values (30,192,'VEGA DE ALATORRE')
		insert into capa_poblacion values (30,193,'HEROICA VERACRUZ')
		insert into capa_poblacion values (30,194,'VILLA ALDAMA')
		insert into capa_poblacion values (30,195,'XOXOCOTLA')
		insert into capa_poblacion values (30,196,'YANGA')
		insert into capa_poblacion values (30,197,'YECUATLA')
		insert into capa_poblacion values (30,198,'ZACUALPAN')
		insert into capa_poblacion values (30,199,'ZARAGOZA')
		insert into capa_poblacion values (30,200,'ZENTLA')
		insert into capa_poblacion values (30,201,'ZONGOLICA')
		insert into capa_poblacion values (30,202,'ZONTECOMATLAN')
		insert into capa_poblacion values (30,203,'ZOZOCOLCO DE HIDALGO')
		insert into capa_poblacion values (30,204,'AGUA DULCE')
		insert into capa_poblacion values (30,205,'HIGO, EL')
		insert into capa_poblacion values (30,206,'NANCHITAL DE LAZARO CARDENAS DEL RIO')
		insert into capa_poblacion values (30,207,'TRES VALLES')
		insert into capa_poblacion values (30,208,'CARLOS A. CARRILLO')
		insert into capa_poblacion values (30,209,'TATAHUICAPAN DE JUAREZ')
		insert into capa_poblacion values (30,210,'UXPANAPA')
		insert into capa_poblacion values (30,211,'SAN RAFAEL')
		insert into capa_poblacion values (30,212,'SANTIAGO SOCHIAPAN')
		insert into capa_poblacion values (31,1,'ABALA')
		insert into capa_poblacion values (31,2,'ACANCEH')
		insert into capa_poblacion values (31,3,'AKIL')
		insert into capa_poblacion values (31,4,'BACA')
		insert into capa_poblacion values (31,5,'BOKOBA')
		insert into capa_poblacion values (31,6,'BUCTZOTZ')
		insert into capa_poblacion values (31,7,'CACALCHEN')
		insert into capa_poblacion values (31,8,'CALOTMUL')
		insert into capa_poblacion values (31,9,'CANSAHCAB')
		insert into capa_poblacion values (31,10,'CANTAMAYEC')
		insert into capa_poblacion values (31,11,'CELESTUN')
		insert into capa_poblacion values (31,12,'CENOTILLO')
		insert into capa_poblacion values (31,13,'CONKAL')
		insert into capa_poblacion values (31,14,'CUNCUNUL')
		insert into capa_poblacion values (31,15,'CUZAMA')
		insert into capa_poblacion values (31,16,'CHACSINKIN')
		insert into capa_poblacion values (31,17,'CHANKOM')
		insert into capa_poblacion values (31,18,'CHAPAB')
		insert into capa_poblacion values (31,19,'CHEMAX')
		insert into capa_poblacion values (31,20,'CHIXCULUB')
		insert into capa_poblacion values (31,21,'CHICHIMILA')
		insert into capa_poblacion values (31,22,'CHIKINDZONOT')
		insert into capa_poblacion values (31,23,'CHOCHOLA')
		insert into capa_poblacion values (31,24,'CHUMAYEL')
		insert into capa_poblacion values (31,25,'DZAN')
		insert into capa_poblacion values (31,26,'DZEMUL')
		insert into capa_poblacion values (31,27,'DZIDZANTUN')
		insert into capa_poblacion values (31,28,'DZILAM DE BRAVO')
		insert into capa_poblacion values (31,29,'DZILAM GONZALEZ')
		insert into capa_poblacion values (31,30,'DZITAS')
		insert into capa_poblacion values (31,31,'DZONCUAICH')
		insert into capa_poblacion values (31,32,'ESPITA')
		insert into capa_poblacion values (31,33,'HALACHO')
		insert into capa_poblacion values (31,34,'HOCABA')
		insert into capa_poblacion values (31,35,'HOCTUN')
		insert into capa_poblacion values (31,36,'HOMUN')
		insert into capa_poblacion values (31,37,'HUHI')
		insert into capa_poblacion values (31,38,'HUNUCMA')
		insert into capa_poblacion values (31,39,'IXIL')
		insert into capa_poblacion values (31,40,'IZAMAL')
		insert into capa_poblacion values (31,41,'KANASIN')
		insert into capa_poblacion values (31,42,'KANTUNIL')
		insert into capa_poblacion values (31,43,'KAUA')
		insert into capa_poblacion values (31,44,'KINCHIL')
		insert into capa_poblacion values (31,45,'KOPOMA')
		insert into capa_poblacion values (31,46,'MAMA')
		insert into capa_poblacion values (31,47,'MANI')
		insert into capa_poblacion values (31,48,'MAXCANU')
		insert into capa_poblacion values (31,49,'MAYAPAN')
		insert into capa_poblacion values (31,50,'MERIDA')
		insert into capa_poblacion values (31,51,'MOCOCHA')
		insert into capa_poblacion values (31,52,'MOTUL DE FELIPE CARRILLO PUERTO')
		insert into capa_poblacion values (31,53,'MUNA')
		insert into capa_poblacion values (31,54,'MUXUPIP')
		insert into capa_poblacion values (31,55,'OPICHEN')
		insert into capa_poblacion values (31,56,'OXKUTZCAB')
		insert into capa_poblacion values (31,57,'PANABA')
		insert into capa_poblacion values (31,58,'PETO')
		insert into capa_poblacion values (31,59,'PROGRESO')
		insert into capa_poblacion values (31,60,'QUINTANA ROO')
		insert into capa_poblacion values (31,61,'RIO LAGARTOS')
		insert into capa_poblacion values (31,62,'SACALUM')
		insert into capa_poblacion values (31,63,'SAMAHIL')
		insert into capa_poblacion values (31,64,'SANAHCAT')
		insert into capa_poblacion values (31,65,'SAN FELIPE')
		insert into capa_poblacion values (31,66,'SANTA ELENA')
		insert into capa_poblacion values (31,67,'SEYE')
		insert into capa_poblacion values (31,68,'SINANCHE')
		insert into capa_poblacion values (31,69,'SOTUTA')
		insert into capa_poblacion values (31,70,'SUCILA')
		insert into capa_poblacion values (31,71,'SUDZAL')
		insert into capa_poblacion values (31,72,'SUMA')
		insert into capa_poblacion values (31,73,'TAHDZIU')
		insert into capa_poblacion values (31,74,'TAHMEX')
		insert into capa_poblacion values (31,75,'TEABO')
		insert into capa_poblacion values (31,76,'TECOH')
		insert into capa_poblacion values (31,77,'TEKAL DE VENEGAS')
		insert into capa_poblacion values (31,78,'TEKANTO')
		insert into capa_poblacion values (31,79,'TECAX DE ALVARO OBREGON')
		insert into capa_poblacion values (31,80,'TEKIT')
		insert into capa_poblacion values (31,81,'TEKOM')
		insert into capa_poblacion values (31,82,'TELCHAC')
		insert into capa_poblacion values (31,83,'TELCHAC PUERTO')
		insert into capa_poblacion values (31,84,'TEMAX')
		insert into capa_poblacion values (31,85,'TEMOZON')
		insert into capa_poblacion values (31,86,'TEPAKAN')
		insert into capa_poblacion values (31,87,'TETIZ')
		insert into capa_poblacion values (31,88,'TEYA')
		insert into capa_poblacion values (31,89,'TICUL')
		insert into capa_poblacion values (31,90,'TIMUCUY')
		insert into capa_poblacion values (31,91,'TINUM')
		insert into capa_poblacion values (31,92,'TIXCACALCUPUL')
		insert into capa_poblacion values (31,93,'TIXKOKOB')
		insert into capa_poblacion values (31,94,'TIXMEUAC')
		insert into capa_poblacion values (31,95,'TIXPEUAL')
		insert into capa_poblacion values (31,96,'TIZIMIN')
		insert into capa_poblacion values (31,97,'TUNKAS')
		insert into capa_poblacion values (31,98,'TZUCACAB')
		insert into capa_poblacion values (31,99,'CUAYMA')
		insert into capa_poblacion values (31,100,'UCU')
		insert into capa_poblacion values (31,101,'UMAN')
		insert into capa_poblacion values (31,102,'VALLADOLID')
		insert into capa_poblacion values (31,103,'XOCCHEL')
		insert into capa_poblacion values (31,104,'YAXCABA')
		insert into capa_poblacion values (31,105,'YAXKUKUL')
		insert into capa_poblacion values (31,106,'YOBAIN')
		insert into capa_poblacion values (32,1,'APOZOL')
		insert into capa_poblacion values (32,2,'SAN PEDRO APULCO')
		insert into capa_poblacion values (32,3,'ATOLINGA')
		insert into capa_poblacion values (32,4,'BENITO JUAREZ')
		insert into capa_poblacion values (32,5,'CALERA')
		insert into capa_poblacion values (32,6,'CANITAS DE FELIPE PESCADOR')
		insert into capa_poblacion values (32,7,'CONCEPCION DEL ORO')
		insert into capa_poblacion values (32,8,'CUAUHTEMOC')
		insert into capa_poblacion values (32,9,'CHALCHIHUITES')
		insert into capa_poblacion values (32,10,'FRESNILLO DE GONZALEZ ECHEVERRIA')
		insert into capa_poblacion values (32,11,'GARCIA DE LA CADENA')
		insert into capa_poblacion values (32,12,'GENARO CODINA')
		insert into capa_poblacion values (32,13,'GENERAL ENRIQUE ESTRADA')
		insert into capa_poblacion values (32,14,'GENERAL FRANCISCO MURGUIA')
		insert into capa_poblacion values (32,15,'GENERAL JOAQUIN AMARO')
		insert into capa_poblacion values (32,16,'GENERAL PANFILO NATERA')
		insert into capa_poblacion values (32,17,'GUADALUPE')
		insert into capa_poblacion values (32,18,'HUANUSCO')
		insert into capa_poblacion values (32,19,'JALPA')
		insert into capa_poblacion values (32,20,'JEREZ DE GARCIA SALINAS')
		insert into capa_poblacion values (32,21,'JIMENEZ DE TEUL')
		insert into capa_poblacion values (32,22,'JUAN ALDAMA')
		insert into capa_poblacion values (32,23,'JUCHIPILA')
		insert into capa_poblacion values (32,24,'LORETO')
		insert into capa_poblacion values (32,25,'LUIS MOYA')
		insert into capa_poblacion values (32,26,'MAZAPIL')
		insert into capa_poblacion values (32,27,'MELCHOR OCAMPO')
		insert into capa_poblacion values (32,28,'MEZQUITAL DEL ORO')
		insert into capa_poblacion values (32,29,'MIGUEL AUZA')
		insert into capa_poblacion values (32,30,'MOMAX')
		insert into capa_poblacion values (32,31,'MONTE ESCOBEDO')
		insert into capa_poblacion values (32,32,'MORELOS')
		insert into capa_poblacion values (32,33,'MOYAHUA')
		insert into capa_poblacion values (32,34,'NOCHISTLAN')
		insert into capa_poblacion values (32,35,'NORIA DE ANGELES')
		insert into capa_poblacion values (32,36,'OJOCALIENTE')
		insert into capa_poblacion values (32,37,'PANUCO')
		insert into capa_poblacion values (32,38,'PINOS')
		insert into capa_poblacion values (32,39,'CIUDAD DE RIO GRANDE')
		insert into capa_poblacion values (32,40,'SAIN ALTO')
		insert into capa_poblacion values (32,41,'EL SALVADOR')
		insert into capa_poblacion values (32,42,'SOMBRERETE')
		insert into capa_poblacion values (32,43,'SUSTICACAN')
		insert into capa_poblacion values (32,44,'TABASCO')
		insert into capa_poblacion values (32,45,'TEPECHITLAN')
		insert into capa_poblacion values (32,46,'TEPETONGO')
		insert into capa_poblacion values (32,47,'TEUL DE GONZALEZ ORTEGA')
		insert into capa_poblacion values (32,48,'TLALTENANGO DE SANCHEZ ROMAN')
		insert into capa_poblacion values (32,49,'VALPARAISO')
		insert into capa_poblacion values (32,50,'VETAGRANDE')
		insert into capa_poblacion values (32,51,'VILLA DE COS')
		insert into capa_poblacion values (32,52,'VILLA GARCIA')
		insert into capa_poblacion values (32,53,'VILLA GONZALEZ ORTEGA')
		insert into capa_poblacion values (32,54,'VILLA HIDALGO')
		insert into capa_poblacion values (32,55,'VILLANUEVA')
		insert into capa_poblacion values (32,56,'ZACATECAS')
		insert into capa_poblacion values (32,57,'TRANCOSO')

END
GO

EXEC CatalogoPoblacion
GO

IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'CatalogoEntidad'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.CatalogoEntidad
GO

CREATE PROCEDURE  dbo.CatalogoEntidad
	
AS
BEGIN
	
	declare @cuenta as bigint
	
	set @cuenta=0
	
	select @cuenta=COUNT(identidad)
	from capa_entidad
	
	if @cuenta<=0 
		begin		
			insert into capa_entidad values(1,'AGUASCALIENTES')
			insert into capa_entidad values(2,'BAJA CALIFORNIA')
			insert into capa_entidad values(3,'BAJA CALIFORNIA SUR')
			insert into capa_entidad values(4,'CAMPECHE')
			insert into capa_entidad values(5,'COAHUILA')
			insert into capa_entidad values(6,'COLIMA')
			insert into capa_entidad values(7,'CHIAPAS')
			insert into capa_entidad values(8,'CHIHUAHUA')
			insert into capa_entidad values(9,'DISTRITO FEDERAL')
			insert into capa_entidad values(10,'DURANGO')
			insert into capa_entidad values(11,'GUANAJUATO')
			insert into capa_entidad values(12,'GUERRERO')
			insert into capa_entidad values(13,'HIDALGO')
			insert into capa_entidad values(14,'JALISCO')
			insert into capa_entidad values(15,'MEXICO')
			insert into capa_entidad values(16,'MICHOACAN')
			insert into capa_entidad values(17,'MORELOS')
			insert into capa_entidad values(18,'NAYARIT')
			insert into capa_entidad values(19,'NUEVO LEON')
			insert into capa_entidad values(20,'OAXACA')
			insert into capa_entidad values(21,'PUEBLA')
			insert into capa_entidad values(22,'QUERETARO')
			insert into capa_entidad values(23,'QUINTANA ROO')
			insert into capa_entidad values(24,'SAN LUIS POTOSI')
			insert into capa_entidad values(25,'SINALOA')
			insert into capa_entidad values(26,'SONORA')
			insert into capa_entidad values(27,'TABASCO')
			insert into capa_entidad values(28,'TAMAULIPAS')
			insert into capa_entidad values(29,'TLAXCALA')
			insert into capa_entidad values(30,'VERACRUZ DE IGNACIO DE LA LLAVE')
			insert into capa_entidad values(31,'YUCATAN')
			insert into capa_entidad values(32,'ZACATECAS')
		end		
END
GO
EXECUTE CatalogoEntidad
GO

/**************************************************************************************************
 * Name          : CedulaBimestral
 * Project       : APSI Nomina
 * Description   : Calcula cedula bimestral de aportaciones IMSS
 * Table name    : empleados, avisos_imss, conceptos
 * Return        : tabla con la cedula bimestral
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 18, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'CedulaBimestral' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[CedulaBimestral]
    END
go


CREATE PROCEDURE [dbo].[CedulaBimestral]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mesNon INT ,
    @mesPar INT ,
    @tipo INT ,
    @proceso VARCHAR(250) ,
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT,
    @cedula VARCHAR(25)
AS 
    SET NOCOUNT ON
    
    DECLARE @rpu CHAR(1)
    
    SELECT  @rpu = ISNULL(empresa.Rpu, 'N') 
    FROM    dbo.empresas AS empresa
    WHERE   empresa.empresa = @empresa
    
    IF @cedula = 'CedulaBimestre21'
       OR @cedula = 'CedulaBimestre22'
       OR @cedula = 'CedulaBimestre24'
       OR @cedula = 'CedulaBimestre25'
       BEGIN
         SELECT calculoBimestre.empresa,
                calculoBimestre.codigo,
                calculoBimestre.nombre,
                calculoBimestre.ap_paterno,
                calculoBimestre.ap_materno,
                calculoBimestre.afiliacion,
                calculoBimestre.digvera,
                calculoBimestre.curp,
                calculoBimestre.rfcalfa,
                calculoBimestre.rfcnum,
                calculoBimestre.rfchomo,
                calculoBimestre.serial,
                CASE WHEN calculoBimestre.diastr = 0 AND calculoBimestre.mov = ' ' THEN NULL ELSE calculoBimestre.fch_mov END AS fch_mov ,
                calculoBimestre.mov AS mov,
                CASE WHEN calculoBimestre.mov <> 'B' AND calculoBimestre.mov IS NOT NULL THEN calculoBimestre.saldiaint ELSE NULL END AS saldiaint ,
                CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.diastr END AS diastr ,
                CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.incap END AS incap ,
                CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.ausen END AS ausen ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.retiro END AS retiro ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejez END AS cesantiaVejez ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezPatron END AS cesantiaVejezPatron ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezTrabajador END AS cesantiaVejezTrabajador ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.aportacionInfonavit END AS aportacionInfonavit ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.numeroCredito ELSE NULL END AS numeroCredito,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.descuento ELSE NULL END AS descuento ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.amortizacion ELSE NULL END AS amortizacion ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.tipoCredito ELSE NULL END AS tipoCredito ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 AND calculoBimestre.amortizacion >= 0 THEN calculoBimestre.seguroVivienda ELSE 0 END AS seguroVivienda ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaInicioDescuento ELSE NULL END AS fechaInicioDescuento ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaOtorgamiento ELSE NULL END AS fechaOtorgamiento ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaSuspension ELSE NULL END AS fechaSuspension ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.ntd ELSE NULL END AS ntd ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.info ELSE NULL END AS info ,
                calculoBimestre.tipo ,
                calculoBimestre.mes,
                CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitSinCredito ELSE 0 END AS infonavitSinCredito ,
                CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitConCredito ELSE 0 END AS infonavitConCredito ,
                calculoBimestre.salarioDF,
                RTRIM(calculoBimestre.rfcalfa) + calculoBimestre.rfcnum + RTRIM(calculoBimestre.rfchomo) AS RFC ,
                RTRIM(calculoBimestre.rfcalfa) + '-' + calculoBimestre.rfcnum+ '-' + RTRIM(calculoBimestre.rfchomo) AS RFCGuion ,
                calculoBimestre.pensionEmpleado AS pensionEmpleado,
                calculoBimestre.jornadaEmpleado AS jornadaEmpleado,
                calculoBimestre.tipo AS tipo,
                CASE WHEN calculoBimestre.diastr = 0 AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.sumaRCV END AS sumaRCV ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN RTRIM(LTRIM(CONVERT(VARCHAR(9), calculoBimestre.descuento))) + ' ' + CASE calculoBimestre.tipoCredito WHEN 1 THEN '%' WHEN 2 THEN 'C.F.' WHEN 3 THEN 'V.S.M.' END END AS descuentoCedula ,
                CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfoanvit ELSE 0 END AS sumaAportacionInfoanvit ,
                CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitSinCredito ELSE 0 END AS sumaAportacionInfonavitSinCredito ,
                CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitConCredito ELSE 0 END AS sumaAportacionInfonavitConCredito ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacion ELSE 0 END AS sumaAmortiacion ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacionMasSeguro ELSE 0 END AS sumaAmortizacionMasSeguro ,
                calculoBimestre.sumaTotalInfonavit AS sumaTotalInfonavit,
                calculoBimestre.sumaTotal AS sumaTotal,
                calculoBimestre.acreditado AS acreditado,
                calculoBimestre.cuentaEmpleado AS cuentaEmpleado,
                CASE WHEN @cedula = 'CedulaBimestre21' AND @rpu = 'S' THEN calculoBimestre.rpu ELSE NULL END AS rpu,
                CASE WHEN @cedula = 'CedulaBimestre21' AND @rpu = 'S' THEN dbo.rpu.nombre ELSE NULL END AS nombreMunicipio ,
                CASE WHEN @cedula = 'CedulaBimestre21' AND @rpu = 'S' THEN dbo.rpu.referencia ELSE NULL END AS referenciaMunicipio,
                CASE WHEN @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.centro ELSE NULL END AS centro,
                CASE WHEN @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.centroNombre ELSE NULL END AS centroNombre,
                calculoBimestre.tipoNomina,
                calculoBimestre.manoObra,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.seguroDesempleo END AS seguroDesempleo,
                calculoBimestre.consecutivo
         FROM [dbo].[LlenaCedulaBimestral](@empresa, @codigo, @ayo, @mesNon, @mesPar, @proceso, @fechaProceso, @horaProceso, @simulaReforma) AS calculoBimestre
              LEFT JOIN dbo.rpu ON calculoBimestre.empresa = dbo.rpu.empresa AND calculoBimestre.rpu = dbo.rpu.rpu
         WHERE   calculoBimestre.tipo > @tipo
         ORDER BY calculoBimestre.empresa ,
                  CASE WHEN @cedula = 'CedulaBimestre21' AND @rpu = 'S' THEN calculoBimestre.rpu ELSE '' END,
                  CASE WHEN @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.centro ELSE '' END,
                  CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.ap_paterno ELSE '' END,
                  CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.ap_materno ELSE '' END,
                  CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.nombre ELSE '' END,
                  CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.tipo ELSE 0 END,
                  CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.mes ELSE '' END,
                  CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.serial ELSE 0 END
       END
       
    IF @cedula = 'CedulaBimestre23'
       OR @cedula = 'CedulaBimestre26'
       OR @cedula = 'CedulaBimestre27'
       BEGIN
         SELECT calculoBimestre.empresa ,
                calculoBimestre.centro ,
                calculoBimestre.centroNombre ,
                SUM(calculoBimestre.diastr) AS diastr ,
                SUM(calculoBimestre.incap) AS incap ,
                SUM(calculoBimestre.ausen) AS ausen ,
                SUM(calculoBimestre.retiro) AS retiro ,
                SUM(calculoBimestre.cesantiaVejez) AS cesantiaVejez ,
                SUM(calculoBimestre.cesantiaVejezPatron) AS cesantiaVejezPatron ,
                SUM(calculoBimestre.cesantiaVejezTrabajador) AS cesantiaVejezTrabajador ,
                SUM(calculoBimestre.sumaRCV) AS sumaRCV ,
                SUM(calculoBimestre.aportacionInfonavit) AS aportacionInfonavit ,
                SUM(calculoBimestre.amortizacion) AS amortizacion ,
                SUM(calculoBimestre.seguroVivienda) AS seguroVivienda ,
                SUM(calculoBimestre.aportacionInfonavit + calculoBimestre.seguroVivienda + calculoBimestre.amortizacion) AS sumaInfoanvit ,
                SUM(CASE WHEN calculoBimestre.acreditado IS NULL THEN 0 ELSE calculoBimestre.acreditado END) AS acreditado,
                SUM(cuentaEmpleado) AS cuentaEmpleado ,
                SUM(calculoBimestre.seguroDesempleo) AS seguroDesempleo,
                SUM(calculoBimestre.infonavitSinCredito) AS infonavitSinCredito,
                SUM(calculoBimestre.infonavitConCredito) AS infonavitConCredito,
                SUM(CASE WHEN calculoBimestre.noAcreditado IS NULL THEN 0 ELSE calculoBimestre.noAcreditado END) AS noAcreditado
                
         FROM [dbo].[LlenaCedulaBimestral](@empresa, @codigo, @ayo, @mesNon, @mesPar, @proceso, @fechaProceso, @horaProceso, @simulaReforma) AS calculoBimestre
         WHERE calculoBimestre.tipo = 2
               OR calculoBimestre.tipo = 3
         GROUP BY calculoBimestre.empresa ,
                  calculoBimestre.centro ,
                  calculoBimestre.centroNombre
         ORDER BY calculoBimestre.empresa ,
                  calculoBimestre.centro
       END

    IF @cedula = 'CedulaBimestre211'
       BEGIN
         SELECT calculoBimestre.empresa,
                calculoBimestre.codigo,
                calculoBimestre.nombre,
                calculoBimestre.ap_paterno,
                calculoBimestre.ap_materno,
                calculoBimestre.afiliacion,
                calculoBimestre.digvera,
                calculoBimestre.curp,
                calculoBimestre.rfcalfa,
                calculoBimestre.rfcnum,
                calculoBimestre.rfchomo,
                calculoBimestre.serial,
                CASE WHEN calculoBimestre.diastr = 0 AND calculoBimestre.mov = ' ' THEN NULL ELSE calculoBimestre.fch_mov END AS fch_mov ,
                calculoBimestre.mov AS mov,
                CASE WHEN calculoBimestre.mov <> 'B' AND calculoBimestre.mov IS NOT NULL THEN calculoBimestre.saldiaint ELSE NULL END AS saldiaint ,
                CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.diastr END AS diastr ,
                CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.incap END AS incap ,
                CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.ausen END AS ausen ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.retiro END AS retiro ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejez END AS cesantiaVejez ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezPatron END AS cesantiaVejezPatron ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezTrabajador END AS cesantiaVejezTrabajador ,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.aportacionInfonavit END AS aportacionInfonavit ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.numeroCredito ELSE NULL END AS numeroCredito,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.descuento ELSE NULL END AS descuento ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.amortizacion ELSE NULL END AS amortizacion ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.tipoCredito ELSE NULL END AS tipoCredito ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 AND calculoBimestre.amortizacion >= 0 THEN calculoBimestre.seguroVivienda ELSE 0 END AS seguroVivienda ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaInicioDescuento ELSE NULL END AS fechaInicioDescuento ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaOtorgamiento ELSE NULL END AS fechaOtorgamiento ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaSuspension ELSE NULL END AS fechaSuspension ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.ntd ELSE NULL END AS ntd ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.info ELSE NULL END AS info ,
                calculoBimestre.tipo ,
                calculoBimestre.mes,
                CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitSinCredito ELSE 0 END AS infonavitSinCredito ,
                CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitConCredito ELSE 0 END AS infonavitConCredito ,
                calculoBimestre.salarioDF,
                RTRIM(calculoBimestre.rfcalfa) + calculoBimestre.rfcnum + RTRIM(calculoBimestre.rfchomo) AS RFC ,
                RTRIM(calculoBimestre.rfcalfa) + '-' + calculoBimestre.rfcnum+ '-' + RTRIM(calculoBimestre.rfchomo) AS RFCGuion ,
                calculoBimestre.pensionEmpleado AS pensionEmpleado,
                calculoBimestre.jornadaEmpleado AS jornadaEmpleado,
                calculoBimestre.tipo AS tipo,
                CASE WHEN calculoBimestre.diastr = 0 AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.sumaRCV END AS sumaRCV ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN RTRIM(LTRIM(CONVERT(VARCHAR(9), calculoBimestre.descuento))) + ' ' + CASE calculoBimestre.tipoCredito WHEN 1 THEN '%' WHEN 2 THEN 'C.F.' WHEN 3 THEN 'V.S.M.' END END AS descuentoCedula ,
                CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfoanvit ELSE 0 END AS sumaAportacionInfoanvit ,
                CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitSinCredito ELSE 0 END AS sumaAportacionInfonavitSinCredito ,
                CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitConCredito ELSE 0 END AS sumaAportacionInfonavitConCredito ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacion ELSE 0 END AS sumaAmortiacion ,
                CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacionMasSeguro ELSE 0 END AS sumaAmortizacionMasSeguro ,
                calculoBimestre.sumaTotalInfonavit AS sumaTotalInfonavit,
                calculoBimestre.sumaTotal AS sumaTotal,
                calculoBimestre.acreditado AS acreditado,
                calculoBimestre.cuentaEmpleado AS cuentaEmpleado,
                CASE WHEN @rpu = 'S' THEN calculoBimestre.rpu ELSE NULL END AS rpu,
                CASE WHEN @rpu = 'S' THEN dbo.rpu.nombre ELSE NULL END AS nombreMunicipio ,
                CASE WHEN @rpu = 'S' THEN dbo.rpu.referencia ELSE NULL END AS referenciaMunicipio,
                '' AS centro, --calculoBimestre.centro ELSE NULL END AS centro,
                '' AS centroNombre, --calculoBimestre.centroNombre ELSE NULL END AS centroNombre,
                calculoBimestre.tipoNomina,
                calculoBimestre.manoObra,
                CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.seguroDesempleo END AS seguroDesempleo,
                calculoBimestre.consecutivo
         FROM [dbo].[LlenaCedulaBimestralSinInfonavit](@empresa, @codigo, @ayo, @mesNon, @mesPar, @proceso, @fechaProceso, @horaProceso, @simulaReforma) AS calculoBimestre
              LEFT JOIN dbo.rpu ON calculoBimestre.empresa = dbo.rpu.empresa AND calculoBimestre.rpu = dbo.rpu.rpu
         WHERE   calculoBimestre.tipo > @tipo
         ORDER BY calculoBimestre.empresa ,
                  CASE WHEN @rpu = 'S' THEN calculoBimestre.rpu ELSE '' END,
                  --calculoBimestre.centro,
                  calculoBimestre.ap_paterno,
                  calculoBimestre.ap_materno,
                  calculoBimestre.nombre,
                  calculoBimestre.tipo,
                  calculoBimestre.mes,
                  calculoBimestre.serial
       END
GO

/**************************************************************************************************
 * Name          : CedulaBimestral
 * Project       : APSI Nomina
 * Description   : Calcula cedula bimestral de aportaciones IMSS
 * Table name    : empleados, avisos_imss, conceptos
 * Return        : tabla con la cedula bimestral
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 18, 2010
 * Modification  : Mircoles, Noviembre 24, 2021
 **************************************************************************************************/

IF OBJECT_ID('dbo.CedulaBimestralUMA') IS NOT NULL
   DROP PROCEDURE dbo.CedulaBimestralUMA
GO

CREATE PROCEDURE dbo.CedulaBimestralUMA
@empresa NUMERIC(5),
@codigo NUMERIC(8,0),
@ayo INT,
@mesNon INT,
@mesPar INT,
@tipo INT,
@proceso VARCHAR(250),
@fechaProceso DATETIME,
@horaProceso VARCHAR(8),
@simulaReforma INT,
@cedula VARCHAR(35),
@filtroInfonavit INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito

AS 

  SET NOCOUNT ON
  
  --DECLARE @rpu CHAR(1)
  --DECLARE @EsMultiple INT

  --SELECT  @rpu = ISNULL(empresa.Rpu, 'N') 
  --FROM    dbo.empresas AS empresa
  --WHERE   empresa.empresa = @empresa
  
  --SET @EsMultiple = CHARINDEX('"', @proceso)

  DECLARE @cedulaBimestral TABLE
          (empresa INT NOT NULL DEFAULT 0,
           codigo INT NOT NULL DEFAULT 0,
           nombre VARCHAR(50) NOT NULL DEFAULT 0,
           ap_paterno VARCHAR(50) NOT NULL DEFAULT 0,
           ap_materno VARCHAR(50) NULL,
           afiliacion VARCHAR(10) NULL,
           digvera CHAR(1) NULL,
           curp VARCHAR(18) NULL,
           rfcalfa VARCHAR(4) NULL,
           rfcnum CHAR(6) NULL,
           rfchomo VARCHAR(3) NULL,
           serial INT NOT NULL DEFAULT 0,
           fch_mov DATETIME NULL,
           mov VARCHAR(3) NULL,
           saldiaint FLOAT NOT NULL DEFAULT 0,
           diastr INT NOT NULL DEFAULT 0,
           incap INT NOT NULL DEFAULT 0,
           ausen FLOAT NOT NULL DEFAULT 0,
           retiro FLOAT NOT NULL DEFAULT 0,

           --cesantiaVejez FLOAT NOT NULL DEFAULT 0,
           --cesantiaVejezPatron FLOAT NOT NULL DEFAULT 0,
           --cesantiaVejezTrabajador FLOAT NOT NULL DEFAULT 0,

           cesantiaVejez FLOAT,
           cesantiaVejezPatron FLOAT,
           cesantiaVejezTrabajador FLOAT,


           aportacionInfonavit NUMERIC(12,2),
           numeroCredito CHAR(10),
           descuento FLOAT,
           amortizacion NUMERIC(12,2),
           tipoCredito INT,
           seguroVivienda NUMERIC(5,2),
           fechaInicioDescuento DATETIME,
           fechaOtorgamiento DATETIME,
           fechaSuspension DATETIME,
           ntd INT,
           info INT,
           tipo INT NOT NULL DEFAULT 0,
           mes INT NOT NULL DEFAULT 0,
           infonavitSinCredito NUMERIC(12,2),
           infonavitConCredito NUMERIC(12,2),
           salarioDF NUMERIC(12,2),
           salarioRegion NUMERIC(12,2),
           sumaRCV NUMERIC(12,2),
           sumaAportacionInfoanvit NUMERIC(12,2),
           sumaAportacionInfonavitSinCredito NUMERIC(12,2),
           sumaAportacionInfonavitConCredito NUMERIC(12,2),
           sumaAmortizacion NUMERIC(12,2),
           cuentaEmpleado INT,
           consecutivo INT IDENTITY,
           pensionEmpleado VARCHAR(4),
           jornadaEmpleado VARCHAR(3),
           articulo33Empleado VARCHAR(6),
           sumaAmortizacionMasSeguro NUMERIC(12,2),
           sumaTotalInfonavit NUMERIC(12,2),
           sumaTotal NUMERIC(12,2),
           acreditado INT,
           centro VARCHAR(15),
           centroNombre VARCHAR(30),
           rpu VARCHAR(3),
           tipoNomina INT,
           manoObra CHAR(1) ,
           seguroDesempleo NUMERIC(12,2),
           noAcreditado INT,
	       lic INT,
	       serial1 INT,
           reg_pat CHAR(11),
           nombreEmpresa VARCHAR(70),
           referencia VARCHAR(70),
           direccion VARCHAR(50),
           colonia VARCHAR(50),
           poblacion VARCHAR(50),
           zona_geografica CHAR(1),
           actividad VARCHAR(100),
           cod_postal VARCHAR(5),
           prima_rt NUMERIC(7,5),
           rfc CHAR(13),
           registros INT,
           altas INT,
           bajas INT,
           ms INT,
	       finGrupo INT DEFAULT 0
		   , tblCVRango INT
          )

  DECLARE @diasFaltaTope INT
  DECLARE @fiNon DATETIME
  DECLARE @ffNon DATETIME
  DECLARE @fiPar DATETIME
  DECLARE @ffPar DATETIME
  DECLARE @esBimestre CHAR(1)
  DECLARE @salarioRegionA FLOAT
  DECLARE @salarioRegionB FLOAT
  DECLARE @salarioRegionC FLOAT
  DECLARE @salarioRegion FLOAT
  DECLARE @salarioDF FLOAT
  DECLARE @areaGeografica CHAR(1)
  DECLARE @topeDF FLOAT
  DECLARE @topeRegion FLOAT
  DECLARE @retiro FLOAT
  DECLARE @cvArt168II FLOAT
  DECLARE @cvPat168II FLOAT
  DECLARE @cvTra168II FLOAT
  DECLARE @infonavit FLOAT
  DECLARE @ayoEmpresa INT
  DECLARE @cDiasLab CHAR(1)
  DECLARE @cRetenido CHAR(1)
  DECLARE @cPropCred CHAR(1)
  DECLARE @cConvenio VARCHAR(30)
  DECLARE @seguroVivienda INT
  DECLARE @Rpu CHAR(3)
  DECLARE @seguroDesempleo FLOAT
  DECLARE @fechaAplicaUMA DATETIME
  DECLARE @fechaAplicaSiroc DATETIME
  DECLARE @fechaOperacion DATETIME
  DECLARE @mesEmpresa INT
  DECLARE @FechaFinita DATETIME
  DECLARE @EsRpu CHAR(1)
  DECLARE @EsRpuEspecial INT
  DECLARE @reg_pat VARCHAR(11)
  DECLARE @EsMultiple INT

  DECLARE @TblDatosPatron TABLE(empresa INT
                                , rpu CHAR(3)
                                , reg_pat CHAR(11)
                                , nombre VARCHAR(70)
                                , referencia VARCHAR(70)
                                , direccion VARCHAR(50)
                                , colonia VARCHAR(50)
                                , poblacion VARCHAR(50)
                                , zona_geografica CHAR(1)
                                , actividad VARCHAR(100)
                                , cod_postal VARCHAR(5)
                                , prima_rt NUMERIC(7, 5)
                                , rfc CHAR(13)
							      , registros INT
                                , altas INT
                                , bajas INT
                                , ms INT
								, tblCVRango1 INT
								, tblCVRango2 INT
								, tblCVRango3 INT
								, tblCVRango4 INT
								, tblCVRango5 INT
								, tblCVRango6 INT
								, tblCVRango7 INT
								, tblCVRango8 INT)

  SET @EsRpuEspecial = dbo.EsRpuEspecial(@empresa)
  SET @FechaFinita = '29991231'
  SET @fechaAplicaSiroc = CONVERT(DATETIME, '20170901')
  SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
  SET @diasFaltaTope = 7
  SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
  SET @ffNon = dbo.fin_mes(@mesNon, @ayo) 
  SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
  SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

  IF @mesPar / 2 = FLOOR(@mesPar / 2) AND @mesNon < @mesPar
      BEGIN
          SET @esBimestre = 'S'
      END
  ELSE
      BEGIN
          SET @esBimestre = 'N'
      END


  -- Obtiene Area Geografica
  SELECT @areaGeografica = empresa.zona_geografica ,
         @ayoEmpresa = empresa.ayo_operacion ,
         @EsRpu = ISNULL(empresa.Rpu, 'N'),
         @mesEmpresa = empresa.mes_operacion,
         @Rpu = LEFT(empresa.registro_patronal,3),
         @reg_pat = empresa.registro_patronal
  FROM dbo.empresas AS empresa
  WHERE empresa.empresa = @empresa

  SET @fechaOperacion = CONVERT(DATETIME, LTRIM(STR(@ayoEmpresa)) + RIGHT(100 + @mesEmpresa,2) + '01')

  -- Obtiene Salario Minimo
  SELECT  @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
          @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
          @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
  FROM    [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo

  SET @salarioDF = @salarioRegionA

  SET @salarioRegion = CASE @areaGeografica
                         WHEN 'A' THEN @salarioRegionA
                         WHEN 'B' THEN @salarioRegionB
                         WHEN 'C' THEN @salarioRegionC
                         ELSE 0
                       END

  SET @topeDF = ROUND(@salarioDF * 25, 2)
  SET @topeRegion = @salarioRegion

  -- Obtiene Primas IMSS
  SELECT  @retiro = primasImss.cvArt168I,
          @cvArt168II = primasImss.cvArt168II,
          @cvPat168II = primasImss.cvPat168II,
          @cvTra168II = primasImss.cvTra168ii,
          @infonavit = primasImss.infonavitPorciento,
          @seguroDesempleo = ISNULL(primasImss.seguroDesempleoPorciento,0)
  FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss

  -- saca parametros infonavit
  SELECT @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 THEN 'N' ELSE 'S' END,
         @cRetenido = CASE WHEN concepto.hrs_min3 = 999 THEN 'S' ELSE 'N' END,
         @cPropCred = CASE WHEN concepto.marca2 = 'M' THEN 'N' ELSE 'S' END,
         @cConvenio = concepto.variable1
  FROM dbo.conceptos AS concepto
  WHERE concepto.empresa = @empresa
        AND concepto.num_conc = 112

  SET @EsMultiple = CHARINDEX('"', @proceso)   
  IF @EsRpuEspecial = 1
     BEGIN
       INSERT @TblDatosPatron (empresa
                               , rpu
                               , reg_pat
                               , nombre
                               , referencia
                               , direccion
                               , colonia
                               , poblacion
                               , zona_geografica
                               , actividad
                               , cod_postal
                               , prima_rt
                               , rfc)
              SELECT r.empresa
                     , r.rpu
                     , r.reg_pat
                     , r.nombre
                     , r.referencia
                     , r.direccion
                     , r.colonia
                     , r.poblacion
                     , r.zona_geografica
                     , r.actividad
                     , r.cod_postal
                     , rp.primaRt
                     , r.rfc
	          FROM dbo.rpu AS r
			       CROSS APPLY (SELECT TOP 1
                                       rp.primaRt
                                FROM dbo.Rpu_PrimaRT AS rp
								WHERE rp.empresa = r.empresa
                                      AND rp.rpu = r.rpu
									  AND rp.fecha <= @fiNon
							    ORDER BY rp.fecha DESC) AS rp
			  WHERE r.empresa = @empresa

       DELETE tdr
	   FROM @TblDatosPatron AS tdr
	   WHERE NOT EXISTS (SELECT 1
                         FROM dbo.AvisosImssTemporalCalculo AS aItc 
                         WHERE aItc.rpu = tdr.rpu
                               AND aItc.empresa = tdr.empresa
                               AND aItc.fch_mov >= @fiNon
                               AND aItc.fch_mov <= @ffPar
                               AND aItc.horaProceso = @horaproceso
                               AND aItc.fechaProceso = @fechaproceso
                               AND aItc.proceso = @proceso)
	 END
  ELSE
     IF @EsRpu = 'N' OR @EsMultiple > 0
        BEGIN
          INSERT @TblDatosPatron (empresa
                                  , rpu
                                  , reg_pat
                                  , nombre
                                  , referencia
                                  , direccion
                                  , colonia
                                  , poblacion
                                  , zona_geografica
                                  , actividad
                                  , cod_postal
                                  , prima_rt
                                  , rfc)
                 SELECT empresa.empresa
                        , LEFT(empresa.registro_patronal,3) AS rpu
                        , empresa.registro_patronal AS reg_pat
                        , empresa.nombre_empresa AS nombre_empresa
                        , empresa.referencia AS referencia
                        , empresa.direccion_empresa AS direccion
                        , empresa.colonia_empresa AS colinia
                        , empresa.poblacion_empresa AS poblacion
                        , empresa.zona_geografica AS zona_geografica
                        , empresa.actividad_empresa AS actividad
                        , empresa.codigo_postal_empresa AS cod_postal
                        , prima_rt.prima_rt --@prima_rt AS prima_rt
                        , empresa.rfc_empresa AS rfc
                 FROM dbo.empresas AS empresa
				      INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = empresa.empresa
					  CROSS APPLY (SELECT TOP 1 prima_rt.prima_rt
                                   FROM dbo.primas_rt AS prima_rt
                                   WHERE prima_rt.empresa = empresa.empresa
                                         AND prima_rt.fecha_inicial <= @fiNon
                                         AND prima_rt.fecha_final >= @ffPar
                                   ORDER BY fecha_inicial DESC
                                            , fecha_final DESC) AS prima_rt
                 --WHERE empresa.empresa = @empresa
        END
     ELSE
        BEGIN
          INSERT @TblDatosPatron (empresa
                                  , rpu
                                  , reg_pat
                                  , nombre
                                  , referencia
                                  , direccion
                                  , colonia
                                  , poblacion
                                  , zona_geografica
                                  , actividad
                                  , cod_postal
                                  , prima_rt
                                  , rfc)
                 SELECT r.empresa
                        , r.rpu
                        , @reg_pat AS reg_pat
                        , r.nombre
                        , r.referencia
                        , r.direccion
                        , r.colonia
                        , r.poblacion
                        , @areaGeografica AS zona_geografica
                        , r.actividad
                        , r.cod_postal
                        , r.prima_rt AS primaRt
                        , r.rfc
	             FROM dbo.rpu AS r
			     WHERE r.empresa = @empresa
        END

/*
  -- Registro empleado
  INSERT  @cedulaBimestral
          ( empresa ,
            codigo ,
            nombre ,
            ap_paterno ,
            ap_materno ,
            afiliacion ,
            digvera ,
            curp ,
            rfcalfa ,
            rfcnum ,
            rfchomo ,
            saldiaint ,
            numeroCredito ,
            tipo ,
            salarioDF ,
            pensionEmpleado ,
            jornadaEmpleado ,
            centro ,
            centroNombre ,
            rpu,
            tipoNomina,
            manoObra
          )
          SELECT  DISTINCT
                  dbo.empleados.empresa ,
                  dbo.empleados.codigo ,
                  dbo.empleados.nombre ,
                  dbo.empleados.ap_paterno ,
                  dbo.empleados.ap_materno ,
                  dbo.empleados.afiliacion ,
                  dbo.empleados.digvera ,
                  dbo.empleados.curp ,
                  dbo.empleados.rfcalfa ,
                  dbo.empleados.rfcnum ,
                  dbo.empleados.rfchomo ,
                  ISNULL(( SELECT TOP 1
                                  aItc.saldiaint
                           FROM   dbo.AvisosImssTemporalCalculo AS aItc
                           WHERE  aItc.empresa = @empresa
                                  AND aItc.codigo = dbo.empleados.codigo
                                  AND aItc.ayo_operacion = @ayo
                                  AND ( aItc.mes_operacion = @mesNon
                                        OR aItc.mes_operacion = @mesPar
                                      )
                                  AND aItc.diastr > 0
                                  AND aItc.horaProceso = @horaProceso
                                  AND aItc.fechaProceso = @fechaProceso
                                  AND aItc.proceso = @proceso
                           ORDER BY aItc.fch_mov ASC ,
                                  aItc.serial ASC
                         ), 0) AS saldiaint ,
                  SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000 + i.numcredito)), 2, 10) ,
                  1 AS tipo ,
                  @salarioDF AS salarioDF ,
                  ( SELECT TOP 1
                              CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                   THEN 'P/IV'
                                   WHEN dbo.excepciones.excepcion1 = 'CV'
                                   THEN 'P/CV'
                                   ELSE NULL
                              END
                    FROM      dbo.excepciones
                    WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                              AND dbo.excepciones.codigo = dbo.empleados.codigo
                              AND ( dbo.excepciones.excepcion1 = 'IV'
                                    OR dbo.excepciones.excepcion1 = 'CV'
                                  )
                  ) AS pensionEmpleado ,
                  CASE WHEN dbo.empleados.jornada >= 1
                            AND dbo.empleados.jornada <= 5 THEN 'S/R'
                       WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                       ELSE NULL
                  END AS jornadaEmpleado ,
                  dbo.centros.centro ,
                  dbo.centros.nomdepto ,
                  CASE WHEN @EsRpu = 'S' THEN ISNULL(aItc.rpu, @Rpu) ELSE @Rpu END, --CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                  dbo.Llaves.tiponom,
                  dbo.empleados.manoobra
          --FROM    dbo.empresas
          --        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
          FROM dbo.empleados 
               INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                   AND dbo.empleados.codigo = aItc.codigo

               INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = dbo.empleados.empresa
												      AND CASE WHEN @EsMultiple > 0 
                                                             THEN '' 
                                                             ELSE tdp.rpu 
                                                        END = CASE WHEN @EsMultiple > 0 
                                                                   THEN '' 
                                                                   ELSE CASE WHEN @EsRpuEspecial = 1 
                                                                             THEN ISNULL(aItc.rpu, @Rpu) 
                                                                             ELSE tdp.rpu --@Rpu 
                                                                        END 
                                                              END

                  INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                           AND dbo.empleados.codigo = dbo.Llaves.codigo
                  INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                            AND dbo.Llaves.empresa = dbo.centros.empresa
                  OUTER APPLY (SELECT TOP 1
                                      'Si' AS TieneCredito
										, i.numcredito
                               FROM dbo.infonavit AS i
                               WHERE i.empresa = dbo.empleados.empresa
			                           AND i.codigo = dbo.empleados.codigo
                                     AND i.fecha <= @ffPar
	                                   AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
	                                   AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

          WHERE   aItc.mes_operacion >= @mesNon
                  AND aItc.mes_operacion <= @mesPar
                  AND aItc.ayo_operacion = @ayo
                  AND dbo.empleados.cotiza_imss = 'S'
                  AND dbo.empleados.borrado = 'N'
					AND CASE WHEN @fiNon >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fiNon >= @fechaOperacion THEN 'S' ELSE '' END
                  AND aItc.empresa >= CASE WHEN @empresa = 0
                                           THEN 0
                                           ELSE @empresa
                                      END
                  --AND aItc.empresa <= CASE WHEN @empresa = 0
                  --                         THEN 9999
                  --                         ELSE @empresa
                  --                    END
                  AND aItc.codigo >= CASE WHEN @codigo = 0
                                          THEN 0
                                          ELSE @codigo
                                     END
                  AND aItc.codigo <= CASE WHEN @codigo = 0
                                          THEN 99999999
                                          ELSE @codigo
                                     END
                  AND aItc.horaProceso = @horaProceso
                  AND aItc.fechaProceso = @fechaProceso
                  AND aItc.proceso = @proceso
                  AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                            WHEN 2 THEN 'Si'
                                            WHEN 3 THEN 'No'
                                                   ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END
  */

  -- Registro Avisos
  INSERT  @cedulaBimestral
          ( empresa ,
            codigo ,
            nombre ,
            ap_paterno ,
            ap_materno ,
            afiliacion ,
            digvera ,
            curp ,
            rfcalfa ,
            rfcnum ,
            rfchomo ,
            serial ,
            fch_mov ,
            mov ,
            saldiaint ,
            diastr ,
            incap ,
            ausen ,
            retiro ,
            cesantiaVejez ,
            cesantiaVejezPatron ,
            cesantiaVejezTrabajador ,
            aportacionInfonavit ,
            amortizacion ,
            mes ,
            tipo ,
            pensionEmpleado ,
            jornadaEmpleado ,
            centro ,
            centroNombre ,
            rpu,
            tipoNomina,
            manoObra ,
            seguroDesempleo,
            lic
			, tblCVRango
          )
          SELECT  dbo.empleados.empresa ,
                  dbo.empleados.codigo ,
                  dbo.empleados.nombre ,
                  dbo.empleados.ap_paterno ,
                  dbo.empleados.ap_materno ,
                  dbo.empleados.afiliacion ,
                  dbo.empleados.digvera ,
                  dbo.empleados.curp ,
                  dbo.empleados.rfcalfa ,
                  dbo.empleados.rfcnum ,
                  dbo.empleados.rfchomo ,
                  aItc.serial ,
                  aItc.fch_mov ,
                  CASE aItc.mov
                       WHEN 'IM' THEN ' '
                       WHEN 'RI' THEN 'R'
                       WHEN 'MS' THEN 'M/S'
                       WHEN 'UM' THEN 'UMA'
                       ELSE aItc.mov
                  END AS mov ,
                  [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                          CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                          salarioMinimo.topeRegion,
                                          dbo.empleados.art39,
                                          aItc.mov) AS salario ,
                  aItc.diastr ,
                  aItc.incap ,
                  aItc.ausen ,
                  [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                        CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                        salarioMinimo.topeRegion,
                                                        dbo.empleados.art39,
                                                        aItc.mov),
                                           aItc.diastr, 0,
                                           aItc.ausen,
                                           @retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           0, @retiro, 0) AS retiro ,
                  [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                        CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                        salarioMinimo.topeRegion,
                                                        dbo.empleados.art39,
                                                        aItc.mov),
                                           aItc.diastr,
                                           aItc.incap,
                                           aItc.ausen,
                                           --@cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           --0, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                                           tblCV.cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           0, tblCV.cvPat168II, tblCV.cvTra168II) AS cesantiaVejez ,
                  [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                        CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                        salarioMinimo.topeRegion,
                                                        dbo.empleados.art39,
                                                        aItc.mov),
                                           aItc.diastr,
                                           aItc.incap,
                                           aItc.ausen,
                                           --@cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           --1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                                           tblCV.cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           1, tblCV.cvPat168II, tblCV.cvTra168II) AS cesantiaVejezPatron ,
                  [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                        CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                        salarioMinimo.topeRegion,
                                                        dbo.empleados.art39,
                                                        aItc.mov),
                                           aItc.diastr,
                                           aItc.incap,
                                           aItc.ausen,
                                           --@cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           --2, @cvPat168II, @cvTra168II) AS cesantiaVejez ,
                                           tblCV.cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           2, tblCV.cvPat168II, tblCV.cvTra168II) AS cesantiaVejezTrabajador ,
                  [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                        CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                        salarioMinimo.topeRegion,
                                                        dbo.empleados.art39,
                                                        aItc.mov),
                                           aItc.diastr, 0,
                                           aItc.ausen,
                                           @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           0, @infonavit, 0) AS aportacionInfonavit ,
                  0 AS amortizacion , 
                  aItc.mes_operacion ,
                  2 AS tipo ,
                  ( SELECT TOP 1
                              CASE WHEN dbo.excepciones.excepcion1 = 'IV'
                                   THEN 'P/IV'
                                   WHEN dbo.excepciones.excepcion1 = 'CV'
                                   THEN 'P/CV'
                                   ELSE NULL
                              END
                    FROM      dbo.excepciones
                    WHERE     dbo.excepciones.empresa = dbo.empleados.empresa
                              AND dbo.excepciones.codigo = dbo.empleados.codigo
                              AND ( dbo.excepciones.excepcion1 = 'IV'
                                    OR dbo.excepciones.excepcion1 = 'CV'
                                  )
                  ) AS pensionEmpleado ,
                  CASE WHEN dbo.empleados.jornada >= 1
                            AND dbo.empleados.jornada <= 5 THEN 'S/R'
                       WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                       ELSE NULL
                  END AS jornadaEmpleado ,
                  dbo.centros.centro ,
                  dbo.centros.nomdepto ,
                  --CASE WHEN @EsRpu = 'S' THEN ISNULL(aItc.rpu, @Rpu) ELSE @Rpu END, --CASE WHEN @rpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                  CASE WHEN @EsMultiple > 0
                       THEN LTRIM(RTRIM(tdp.empresa))
                       ELSE CASE WHEN @EsRpu = 'S' 
                                 THEN ISNULL(aItc.rpu, @Rpu) 
                                 ELSE @Rpu 
                            END
                  END, --CASE WHEN @EsRpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,

                  dbo.Llaves.tiponom,
                  dbo.empleados.manoobra,
                  [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                        CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                        salarioMinimo.topeRegion,
                                                        dbo.empleados.art39,
                                                        aItc.mov),
                                           aItc.diastr, 0,
                                           aItc.ausen,
                                           @seguroDesempleo, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, salarioMinimo.salarioRegion,
                                           0, @seguroDesempleo, 0) AS seguroDesempleo,
                  aItc.lic 
				  , tblCV.rango
--, i.TieneCredito
--, CASE @filtroInfonavit WHEN 1 THEN 'Todos'
--                                          WHEN 2 THEN 'Si'
--                                          WHEN 3 THEN 'No'
--                                          ELSE 'Ninguno' END 
--, CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END
--, i.fecha
--, i.ffPar AS ffPar
--, i.fechaSuspension
--, i.ffFinita
--, i.fch_termino
          --FROM    dbo.empresas
          --        INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
          FROM dbo.empleados
               --INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
               --                                                    AND dbo.empleados.codigo = aItc.codigo
               INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON aItc.empresa = dbo.empleados.empresa
                                                                   AND aItc.codigo = dbo.empleados.codigo
																   AND aItc.fch_mov >= @fiNon
																   AND aItc.fch_mov <= @ffPar
                                                                   AND aItc.horaProceso = @horaproceso
                                                                   AND aItc.fechaProceso = @fechaproceso
                                                                   AND aItc.proceso = @proceso
                                                                   AND ((aItc.mov = 'IM' AND aItc.diastr > 0)
                                                                        OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'UM' AND aItc.diastr IS NOT NULL))

               OUTER APPLY (SELECT CASE WHEN aItc.mov = 'B' THEN 0 ELSE rango END rango
			                       , cvArt168II
                                   , cvPat168II
                                   , cvTra168II
			                FROM dbo.NOM_FUN_ObtienePrimaCVPatron2023(aItc.empresa, aItc.fch_mov, YEAR(aItc.fch_mov), aItc.saldiaint, @cvArt168II, @cvPat168II, @cvTra168II)
							--WHERE aItc.mov <> 'B'
							--      AND (aItc.diastr - aItc.ausen - aItc.incap) > 0
						   ) AS tblCV

               INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = aItc.empresa
                                                    AND CASE WHEN @EsMultiple > 0 
                                                             THEN '' 
                                                             ELSE tdp.rpu 
                                                        END = CASE WHEN @EsMultiple > 0 
                                                                   THEN '' 
                                                                   ELSE CASE WHEN @EsRpuEspecial = 1 
                                                                             THEN ISNULL(aItc.rpu, @Rpu) 
                                                                             ELSE aItc.rpu --@Rpu 
                                                                        END 
                                                              END

               INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                        AND dbo.empleados.codigo = dbo.Llaves.codigo
               INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                         AND dbo.Llaves.empresa = dbo.centros.empresa
               CROSS APPLY (SELECT TOP 1 
                                   CASE tdp.zona_geografica WHEN 'A' THEN salarioMinimo.zona_a
                                                            WHEN 'B' THEN salarioMinimo.zona_b
                                                            WHEN 'C' THEN salarioMinimo.zona_c
                                                            ELSE @salarioRegion
                                   END AS salarioRegion,
                                   salarioMinimo.zona_a AS topeRegion
                            FROM dbo.salarios_minimos AS salarioMinimo
                            WHERE salarioMinimo.fecha_ini <= aItc.fch_mov
                            ORDER BY salarioMinimo.fecha_ini DESC) AS salarioMinimo

               OUTER APPLY (SELECT TOP 1
                                   'Si' AS TieneCredito
--, i.fecha
--, @ffPar AS ffPar
--, i.fechaSuspension
--, @FechaFinita As ffFinita
--, i.fch_termino
                            FROM dbo.infonavit AS i
                            WHERE i.empresa = dbo.empleados.empresa
                                  AND i.codigo = dbo.empleados.codigo
                                  AND i.fecha <= @ffPar
                                  AND ISNULL(i.fechaSuspension, @FechaFinita) >= @fiNon
                                  AND ISNULL(i.fch_termino, @FechaFinita) >= @fiNon) AS i

          WHERE --aItc.mes_operacion >= @mesNon
                --AND aItc.mes_operacion <= @mesPar
                --AND aItc.ayo_operacion = @ayo
                --AND 
				dbo.empleados.cotiza_imss = 'S'
                AND dbo.empleados.borrado = 'N'
                AND CASE WHEN @fiNon >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fiNon >= @fechaOperacion THEN 'S' ELSE '' END
                --AND aItc.empresa >= CASE WHEN @empresa = 0
                --                         THEN 0
                --                         ELSE @empresa
                --                    END
                --AND aItc.empresa <= CASE WHEN @empresa = 0
                --                         THEN 9999
                --                         ELSE @empresa
                --                    END
                AND aItc.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END
                AND aItc.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END
                --AND aItc.horaProceso = @horaProceso
                --AND aItc.fechaProceso = @fechaProceso
                --AND aItc.proceso = @proceso
                --AND (
                --     (aItc.mov = 'IM' AND aItc.diastr > 0)
                --      OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                --      OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                --      OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                --      OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                --      OR (aItc.mov = 'UM' AND aItc.diastr IS NOT NULL)
                --    )
                AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                          WHEN 2 THEN 'Si'
                                          WHEN 3 THEN 'No'
                                          ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(i.TieneCredito, 'No') END

          ORDER BY aItc.codigo,
			       aItc.fch_mov,
                  aItc.serial

  IF @esBimestre = 'S'
     BEGIN
       DELETE cedulaBimestral
       FROM @cedulaBimestral AS cedulaBimestral
       WHERE (cedulaBimestral.mov = 'IM'
              OR cedulaBimestral.mov = ' '
			 )
             AND cedulaBimestral.fch_mov = @fiPar
             AND cedulaBimestral.diastr = 0
     END

  -- Registro Amortizacion
  SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                             WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                             WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                             ELSE 0
                        END

  UPDATE cedulaBimestre
  SET cuentaEmpleado = 1
  FROM @cedulaBimestral AS cedulaBimestre
       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaBimestre.empresa AND CASE WHEN @EsMultiple > 0 THEN '' ELSE tdp.rpu END = CASE WHEN @EsMultiple > 0 THEN '' ELSE cedulaBimestre.rpu END
  WHERE CASE WHEN @EsRpuEspecial = 1
             THEN cedulaBimestre.rpu 
             ELSE '' 
        END + RIGHT(100000000 + cedulaBimestre.codigo,8) + RIGHT(100000000 + cedulaBimestre.consecutivo,8) 
        = (SELECT TOP 1 
                  CASE WHEN @EsRpuEspecial = 1
                       THEN cedulaBimestre2.rpu 
                       ELSE ''
                  END + RIGHT(100000000 + cedulaBimestre2.codigo,8) + RIGHT(100000000 + cedulaBimestre2.consecutivo,8)
           FROM @cedulaBimestral AS cedulaBimestre2
           WHERE cedulaBimestre2.empresa = cedulaBimestre.empresa
                 AND cedulaBimestre2.tipo > 1
                 AND cedulaBimestre2.codigo = cedulaBimestre.codigo 
                 AND CASE WHEN @EsRpuEspecial = 1
                          THEN cedulaBimestre2.rpu 
                          ELSE '' 
                     END = CASE WHEN @EsRpuEspecial = 1
                                THEN cedulaBimestre.rpu 
                                ELSE '' 
                           END)
                                                                           
  UPDATE cedula
  SET cedula.numeroCredito = SUBSTRING(RTRIM(CONVERT(CHAR(11), 10000000000 + dbo.temporalAmortizacion.numcredito)), 2, 10),
      cedula.descuento = dbo.TemporalAmortizacion.descuento,
      cedula.tipoCredito = dbo.temporalAmortizacion.tipo_cred,
      cedula.fechaInicioDescuento = dbo.infonavit.fecha,
      cedula.fechaOtorgamiento = dbo.infonavit.fch_otorga,
      cedula.fechaSuspension = dbo.infonavit.fch_termino,
      cedula.amortizacion = ISNULL(dbo.temporalAmortizacion.amortizacion, 0),
      cedula.seguroVivienda = CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda ELSE 0 END,
      cedula.sumaTotalinfonavit = cedulaInfonavit.aportacionInfonavit + CASE WHEN ISNULL(dbo.temporalAmortizacion.amortizacion, 0) > 0 THEN @seguroVivienda + ISNULL(dbo.temporalAmortizacion.amortizacion, 0) ELSE 0 END,
      cedula.acreditado = CASE WHEN ISNULL(dbo.temporalAmortizacion.numcredito, 0) > 0 THEN 1 ELSE 0 END,
      cedula.noAcreditado = CASE WHEN ISNULL(dbo.temporalAmortizacion.numcredito, 0) > 0 THEN 0 ELSE 1 END
  FROM @cedulaBimestral AS cedula
       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedula.empresa AND CASE WHEN @EsMultiple > 0 THEN '' ELSE tdp.rpu END = CASE WHEN @EsMultiple > 0 THEN '' ELSE cedula.rpu END
       LEFT JOIN dbo.temporalAmortizacion ON dbo.temporalAmortizacion.empresa = cedula.empresa
                                             AND dbo.temporalAmortizacion.codigo = cedula.codigo
       LEFT JOIN dbo.infonavit ON dbo.infonavit.empresa = dbo.temporalAmortizacion.empresa
                                  AND dbo.infonavit.codigo = temporalAmortizacion.codigo
                                  AND dbo.infonavit.fecha <= @ffPar
                                  AND dbo.infonavit.fch_termino >= @fiNon
       INNER JOIN (SELECT cedulaAportacion.empresa,
                          cedulaAportacion.codigo,
                          SUM(ISNULL(cedulaAportacion.aportacionInfonavit,0)) AS aportacionInfonavit 
                   FROM @cedulaBimestral AS cedulaAportacion
                   WHERE cedulaAportacion.tipo = 2
                   GROUP BY cedulaAportacion.empresa,
                            cedulaAportacion.codigo) AS cedulaInfonavit ON cedulaInfonavit.codigo = cedula.codigo
                                                                          AND cedulaInfonavit.empresa = cedula.empresa
  WHERE cedula.cuentaEmpleado = 1

  UPDATE cedulaBimestre
  SET cedulaBimestre.infonavitSinCredito = cedulaBimestre.aportacionInfonavit
  FROM @cedulaBimestral AS cedulaBimestre
  WHERE cedulaBimestre.tipo = 2

  UPDATE cedulaBimestre
  SET cedulaBimestre.infonavitSinCredito = 0 ,
      cedulaBimestre.infonavitConCredito = cedulaBimestre.aportacionInfonavit
  FROM @cedulaBimestral AS cedulaBimestre
       INNER JOIN @cedulaBimestral AS cedulaBimestreCredito ON cedulaBimestreCredito.empresa = cedulaBimestre.empresa
                                                               AND cedulaBimestreCredito.codigo = cedulaBimestre.codigo
  WHERE cedulaBimestre.tipo = 2
        AND cedulaBimestreCredito.cuentaEmpleado = 1
        AND cedulaBimestreCredito.tipoCredito >= 1
        AND cedulaBimestreCredito.tipoCredito <= 3
        AND cedulaBimestreCredito.amortizacion >= 0

  UPDATE cedulaBimestre
  SET cedulaBimestre.sumaRCV = cedulaBimestre.retiro + cedulaBimestre.cesantiaVejez 
  FROM @cedulaBimestral AS cedulaBimestre
  WHERE cedulaBimestre.tipo = 2

  UPDATE RpuPatron
  SET RpuPatron.registros = cedulaBimestral.registros
      , RpuPatron.altas   = cedulaBimestral.altas
      , RpuPatron.bajas   = cedulaBimestral.bajas
      , RpuPatron.ms      = cedulaBimestral.ms
      , RpuPatron.tblCVRango1 = cedulaBimestral.tblCVRango1
      , RpuPatron.tblCVRango2 = cedulaBimestral.tblCVRango2
      , RpuPatron.tblCVRango3 = cedulaBimestral.tblCVRango3
      , RpuPatron.tblCVRango4 = cedulaBimestral.tblCVRango4
      , RpuPatron.tblCVRango5 = cedulaBimestral.tblCVRango5
      , RpuPatron.tblCVRango6 = cedulaBimestral.tblCVRango6
      , RpuPatron.tblCVRango7 = cedulaBimestral.tblCVRango7
      , RpuPatron.tblCVRango8 = cedulaBimestral.tblCVRango8
  FROM @TblDatosPatron AS RpuPatron
       CROSS APPLY (SELECT COUNT(DISTINCT cedulaBimestral.codigo) AS registros
                           , COUNT(CASE WHEN cedulaBimestral.mov = 'A' OR cedulaBimestral.mov = 'R' THEN 1 ELSE NULL END) AS altas
                           , COUNT(CASE WHEN cedulaBimestral.mov = 'B' THEN 1 ELSE NULL END) AS bajas
                           , COUNT(CASE WHEN cedulabimestral.mov = 'M/S' THEN 1 ELSE NULL END) AS ms
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 1 THEN 1 ELSE NULL END) AS tblCVRango1
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 2 THEN 1 ELSE NULL END) AS tblCVRango2
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 3 THEN 1 ELSE NULL END) AS tblCVRango3
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 4 THEN 1 ELSE NULL END) AS tblCVRango4
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 5 THEN 1 ELSE NULL END) AS tblCVRango5
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 6 THEN 1 ELSE NULL END) AS tblCVRango6
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 7 THEN 1 ELSE NULL END) AS tblCVRango7
                           , COUNT(CASE WHEN cedulabimestral.tblCVRango = 8 THEN 1 ELSE NULL END) AS tblCVRango8
                    FROM @cedulaBimestral AS cedulaBimestral
                    WHERE cedulaBimestral.empresa = RpuPatron.empresa
                          AND CASE WHEN @EsMultiple > 0
                                   THEN ''
                                   ELSE CASE WHEN @EsRpu = 'S' 
                                             THEN ISNULL(cedulaBimestral.rpu, @Rpu) 
                                             ELSE @Rpu 
                                        END
                              END = CASE WHEN @EsMultiple > 0
                                         THEN ''
                                         ELSE RpuPatron.rpu
                                    END
                   ) AS cedulaBimestral

  UPDATE cedulaBimestral
  SET cedulaBimestral.serial = cedulaBimestral.serial1
  FROM (SELECT TOP 2147483647
               cedulaBimestral.serial
               , ROW_NUMBER() OVER (PARTITION BY cedulaBimestral.empresa
                                                 , cedulaBimestral.rpu					  
                                    ORDER BY cedulaBimestral.empresa
									           , cedulaBimestral.rpu
									           , cedulaBimestral.ap_paterno
                                             , cedulaBimestral.ap_materno
                                             , cedulaBimestral.nombre 
                                             , cedulaBimestral.tipo 				
                                             ) AS serial1
        FROM @cedulaBimestral AS cedulaBimestral
             INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaBimestral.empresa AND CASE WHEN @EsMultiple > 0 THEN '' ELSE tdp.rpu END = CASE WHEN @EsMultiple > 0 THEN '' ELSE cedulaBimestral.rpu END
        WHERE cedulaBimestral.tipo > 1
        ORDER BY cedulaBimestral.empresa ,
                 cedulaBimestral.rpu,
                 cedulaBimestral.ap_paterno,
                 cedulaBimestral.ap_materno,
                 cedulaBimestral.nombre,
                 cedulaBimestral.tipo,
                 cedulaBimestral.mes,
                 cedulaBimestral.serial
       ) AS cedulaBimestral


  UPDATE cedulaBimestral
  SET cedulaBimestral.finGrupo = cedulaBimestral.empresa
  FROM @cedulaBimestral AS cedulaBimestral
       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaBimestral.empresa AND CASE WHEN @EsMultiple > 0 THEN '' ELSE tdp.rpu END = CASE WHEN @EsMultiple > 0 THEN '' ELSE cedulaBimestral.rpu END

       CROSS APPLY (SELECT MAX(cedulaBimestral2.serial) AS serial
                    FROM @cedulaBimestral AS cedulaBimestral2
                    WHERE cedulaBimestral2.empresa = cedulaBimestral.empresa
                          AND CASE WHEN @EsMultiple > 0
	                                 THEN ''
                                   ELSE CASE WHEN @EsRpu = 'S' 
                                             THEN ISNULL(cedulaBimestral2.rpu, @Rpu) 
                                             ELSE @Rpu 
                                        END
                              END = CASE WHEN @EsMultiple > 0
                                         THEN ''
                                         ELSE CASE WHEN @EsRpu = 'S' 
                                                   THEN tdp.rpu
                                                   ELSE @Rpu
                                              END
                                    END
                   ) AS cedulaBimestral2
  WHERE cedulaBimestral.serial = cedulaBimestral2.serial

  /*
  UPDATE cedulaBimestral
  SET cedulaBimestral.reg_pat = RpuPatron.reg_pat,
      cedulaBimestral.nombreEmpresa = RpuPatron.nombre,
      cedulaBimestral.referencia = RpuPatron.referencia,
      cedulaBimestral.direccion = RpuPatron.direccion,
      cedulaBimestral.colonia = RpuPatron.colonia,
      cedulaBimestral.poblacion = RpuPatron.poblacion,
      cedulaBimestral.zona_geografica = RpuPatron.zona_geografica,
      cedulaBimestral.actividad = RpuPatron.actividad,
      cedulaBimestral.cod_postal = RpuPatron.cod_postal,
      cedulaBimestral.rfc = RpuPatron.rfc,
      cedulaBimestral.registros = RpuPatron.registros,
      cedulaBimestral.altas = RpuPatron.altas,
      cedulaBimestral.bajas = RpuPatron.bajas,
      cedulaBimestral.ms = RpuPatron.ms             
	FROM @cedulaBimestral AS cedulaBimestral
       CROSS APPLY (SELECT TOP 1
                             RpuPatron.reg_pat         
                           , RpuPatron.nombre          
                           , RpuPatron.referencia      
                           , RpuPatron.direccion       
                           , RpuPatron.colonia         
                           , RpuPatron.poblacion       
                           , RpuPatron.zona_geografica 
                           , RpuPatron.actividad       
                           , RpuPatron.cod_postal      
                           , RpuPatron.rfc             
                           , RpuPatron.registros       
                           , RpuPatron.altas           
                           , RpuPatron.bajas           
                           , RpuPatron.ms              
                    FROM @TblDatosPatron AS RpuPatron
					  WHERE RpuPatron.empresa = cedulaBimestral.empresa
		                    AND RpuPatron.rpu = CASE WHEN @EsRpu = 'S' THEN ISNULL(cedulaBimestral.rpu, @Rpu) ELSE @Rpu END) AS RpuPatron
	WHERE cedulaBimestral.serial1 = 1

  UPDATE cedulaBimestral
  SET cedulaBimestral.reg_pat = RpuPatronAnterior.reg_pat,
      cedulaBimestral.nombreEmpresa = RpuPatronAnterior.nombre,
      cedulaBimestral.referencia = RpuPatronAnterior.referencia,
      cedulaBimestral.direccion = RpuPatronAnterior.direccion,
      cedulaBimestral.colonia = RpuPatronAnterior.colonia,
      cedulaBimestral.poblacion = RpuPatronAnterior.poblacion,
      cedulaBimestral.zona_geografica = RpuPatronAnterior.zona_geografica,
      cedulaBimestral.actividad = RpuPatronAnterior.actividad,
      cedulaBimestral.cod_postal = RpuPatronAnterior.cod_postal,
      cedulaBimestral.rfc = RpuPatronAnterior.rfc
	FROM @cedulaBimestral AS cedulaBimestral
	     CROSS APPLY (SELECT TOP 1
                           RpuPatronAnterior.reg_pat         
                           , RpuPatronAnterior.nombre          
                           , RpuPatronAnterior.referencia      
                           , RpuPatronAnterior.direccion       
                           , RpuPatronAnterior.colonia         
                           , RpuPatronAnterior.poblacion       
                           , RpuPatronAnterior.zona_geografica 
                           , RpuPatronAnterior.actividad       
                           , RpuPatronAnterior.cod_postal      
                           , RpuPatronAnterior.prima_rt        
                           , RpuPatronAnterior.rfc             
                    FROM @TblDatosPatron AS RpuPatronAnterior
                    WHERE (RpuPatronAnterior.empresa > cedulaBimestral.empresa
					         OR CASE WHEN @EsMultiple > 0
                                   THEN ''
                                   ELSE RpuPatronAnterior.rpu
                              END > CASE WHEN @EsMultiple > 0
                                         THEN ''
                                         ELSE CASE WHEN @EsRpu = 'S' 
                                                   THEN ISNULL(cedulaBimestral.rpu, @Rpu) 
                                                   ELSE @Rpu 
                                              END
                                    END)
                          AND cedulaBimestral.finGrupo > 0
                    ORDER BY RpuPatronAnterior.empresa ASC
                             , RpuPatronAnterior.rpu ASC
                         ) AS RpuPatronAnterior
  */

  IF @cedula = 'CedulaBimestre21'
     OR @cedula = 'CedulaBimestre22'
     OR @cedula = 'CedulaBimestre24'
     OR @cedula = 'CedulaBimestre25'
     OR @cedula = 'CedulaBimestre21_RpuEspecial'
     BEGIN
       SELECT calculoBimestre.empresa,
              calculoBimestre.codigo,
              calculoBimestre.nombre,
              calculoBimestre.ap_paterno,
              calculoBimestre.ap_materno,
              calculoBimestre.afiliacion,
              calculoBimestre.digvera,
              calculoBimestre.curp,
              calculoBimestre.rfcalfa,
              calculoBimestre.rfcnum,
              calculoBimestre.rfchomo,
              calculoBimestre.serial,
              CASE WHEN calculoBimestre.diastr = 0 AND calculoBimestre.mov = ' ' THEN NULL ELSE calculoBimestre.fch_mov END AS fch_mov ,
              calculoBimestre.mov AS mov,
              CASE WHEN calculoBimestre.mov <> 'B' AND calculoBimestre.mov IS NOT NULL THEN calculoBimestre.saldiaint ELSE NULL END AS saldiaint ,
              CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.diastr END AS diastr ,
              CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE CASE WHEN ISNULL(calculoBimestre.incap,0) - ISNULL(calculoBimestre.lic,0) = 0 THEN NULL ELSE ISNULL(calculoBimestre.incap,0) - ISNULL(calculoBimestre.lic,0) END END AS incap ,
              CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.ausen END AS ausen ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.retiro END AS retiro ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejez END AS cesantiaVejez ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezPatron END AS cesantiaVejezPatron ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezTrabajador END AS cesantiaVejezTrabajador ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.aportacionInfonavit END AS aportacionInfonavit ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.numeroCredito ELSE NULL END AS numeroCredito,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.descuento ELSE NULL END AS descuento ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.amortizacion ELSE NULL END AS amortizacion ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.tipoCredito ELSE NULL END AS tipoCredito ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 AND calculoBimestre.amortizacion >= 0 THEN calculoBimestre.seguroVivienda ELSE 0 END AS seguroVivienda ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaInicioDescuento ELSE NULL END AS fechaInicioDescuento ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaOtorgamiento ELSE NULL END AS fechaOtorgamiento ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaSuspension ELSE NULL END AS fechaSuspension ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.ntd ELSE NULL END AS ntd ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.info ELSE NULL END AS info ,
              calculoBimestre.tipo ,
              calculoBimestre.mes,
              CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitSinCredito ELSE 0 END AS infonavitSinCredito ,
              CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitConCredito ELSE 0 END AS infonavitConCredito ,
              calculoBimestre.salarioDF,
              RTRIM(calculoBimestre.rfcalfa) + calculoBimestre.rfcnum + RTRIM(calculoBimestre.rfchomo) AS RFC ,
              RTRIM(calculoBimestre.rfcalfa) + '-' + calculoBimestre.rfcnum+ '-' + RTRIM(calculoBimestre.rfchomo) AS RFCGuion ,
              calculoBimestre.pensionEmpleado AS pensionEmpleado,
              calculoBimestre.jornadaEmpleado AS jornadaEmpleado,
              calculoBimestre.tipo AS tipo,
              CASE WHEN calculoBimestre.diastr = 0 AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.sumaRCV END AS sumaRCV ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN RTRIM(LTRIM(CONVERT(VARCHAR(9), calculoBimestre.descuento))) + ' ' + CASE calculoBimestre.tipoCredito WHEN 1 THEN '%' WHEN 2 THEN 'C.F.' WHEN 3 THEN 'FD' END END AS descuentoCedula ,
              CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfoanvit ELSE 0 END AS sumaAportacionInfoanvit ,
              CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitSinCredito ELSE 0 END AS sumaAportacionInfonavitSinCredito ,
              CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitConCredito ELSE 0 END AS sumaAportacionInfonavitConCredito ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacion ELSE 0 END AS sumaAmortiacion ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacionMasSeguro ELSE 0 END AS sumaAmortizacionMasSeguro ,
              calculoBimestre.sumaTotalInfonavit AS sumaTotalInfonavit,
              calculoBimestre.sumaTotal AS sumaTotal,
              calculoBimestre.acreditado AS acreditado,
              calculoBimestre.cuentaEmpleado AS cuentaEmpleado,
              CASE WHEN (@cedula = 'CedulaBimestre21' AND @EsRpu = 'S') OR @EsMultiple > 0 THEN calculoBimestre.rpu ELSE NULL END AS rpu,
              CASE WHEN @cedula = 'CedulaBimestre21' AND @EsRpu = 'S' THEN RpuPatron.nombre ELSE NULL END AS nombreMunicipio ,
              CASE WHEN @cedula = 'CedulaBimestre21' AND @EsRpu = 'S' THEN RpuPatron.referencia ELSE NULL END AS referenciaMunicipio,
              CASE WHEN @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.centro ELSE NULL END AS centro,
              CASE WHEN @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.centroNombre ELSE NULL END AS centroNombre,
              calculoBimestre.tipoNomina,
              calculoBimestre.manoObra,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.seguroDesempleo END AS seguroDesempleo,
              calculoBimestre.consecutivo,
              CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.lic END AS lic,
              calculoBimestre.serial1,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.reg_pat IS NULL THEN RpuPatronAnterior.reg_pat ELSE RpuPatron.reg_pat END AS reg_pat,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.nombre IS NULL THEN RpuPatronAnterior.nombre ELSE RpuPatron.nombre END AS nombreEmpresa,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.referencia IS NULL THEN RpuPatronAnterior.referencia ELSE RpuPatron.referencia END AS referencia,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.direccion IS NULL THEN RpuPatronAnterior.direccion ELSE RpuPatron.direccion END AS direccion, 
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.colonia IS NULL THEN RpuPatronAnterior.colonia ELSE RpuPatron.colonia END AS colonia,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.poblacion IS NULL THEN RpuPatronAnterior.poblacion ELSE RpuPatron.poblacion END AS poblacion,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.zona_geografica IS NULL THEN RpuPatronAnterior.zona_geografica ELSE RpuPatron.zona_geografica END AS zona_geografica,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.actividad IS NULL THEN RpuPatronAnterior.actividad ELSE RpuPatron.actividad END AS actividad,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.cod_postal IS NULL THEN RpuPatronAnterior.cod_postal ELSE RpuPatron.cod_postal END AS cod_postal,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.prima_rt IS NULL THEN RpuPatronAnterior.prima_rt ELSE RpuPatron.prima_rt END AS prima_rt,
              CASE WHEN calculoBimestre.finGrupo > 0 AND NOT RpuPatronAnterior.rfc IS NULL THEN RpuPatronAnterior.rfc ELSE RpuPatron.rfc END AS rfcEmpresa,
              RpuPatron.registros,
              RpuPatron.altas,
              RpuPatron.bajas,
              RpuPatron.ms,
              calculoBimestre.finGrupo
			  , tblCVrango
			  , RpuPatron.tblCVRango1
			  , RpuPatron.tblCVRango2
			  , RpuPatron.tblCVRango3
			  , RpuPatron.tblCVRango4
			  , RpuPatron.tblCVRango5
			  , RpuPatron.tblCVRango6
			  , RpuPatron.tblCVRango7
			  , RpuPatron.tblCVRango8
       --FROM [dbo].[LlenaCedulaBimestralUMA](@empresa, @codigo, @ayo, @mesNon, @mesPar, @proceso, @fechaProceso, @horaProceso, @simulaReforma, @filtroInfonavit) AS calculoBimestre
	   FROM @cedulaBimestral AS calculoBimestre
              CROSS APPLY (SELECT TOP 1
                                    CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.reg_pat         ELSE NULL END AS reg_pat
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.nombre          ELSE NULL END AS nombre
                                  , CASE WHEN calculoBimestre.serial = 1 THEN ISNULL(RpuPatron.referencia, RpuPatron.nombre) ELSE NULL END AS referencia
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.direccion       ELSE NULL END AS direccion
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.colonia         ELSE NULL END AS colonia
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.poblacion       ELSE NULL END AS poblacion
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.zona_geografica ELSE NULL END AS zona_geografica
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.actividad       ELSE NULL END AS actividad
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.cod_postal      ELSE NULL END AS cod_postal
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.prima_rt        ELSE NULL END AS prima_rt
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.rfc             ELSE NULL END AS rfc
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.registros       ELSE 0    END AS registros
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.altas           ELSE NULL END AS altas
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.bajas           ELSE NULL END AS bajas
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.ms              ELSE NULL END AS ms
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango1     ELSE NULL END AS tblCVRango1
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango2     ELSE NULL END AS tblCVRango2
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango3     ELSE NULL END AS tblCVRango3
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango4     ELSE NULL END AS tblCVRango4
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango5     ELSE NULL END AS tblCVRango5
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango6     ELSE NULL END AS tblCVRango6
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango7     ELSE NULL END AS tblCVRango7
                                  , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango8     ELSE NULL END AS tblCVRango8
                           FROM @TblDatosPatron AS RpuPatron
						   WHERE RpuPatron.empresa = calculoBimestre.empresa
                                 AND CASE WHEN @EsMultiple > 0
                                          THEN ''
                                          ELSE RpuPatron.rpu
                                     END = CASE WHEN @EsMultiple > 0
                                                THEN ''
                                                ELSE CASE WHEN @EsRpu = 'S' 
                                                          THEN ISNULL(calculoBimestre.rpu, @Rpu) 
                                                          ELSE @Rpu 
                                                     END
                                           END) AS RpuPatron

              OUTER APPLY (SELECT TOP 1
                                    RpuPatronAnterior.reg_pat         
                                  , RpuPatronAnterior.nombre          
                                  , RpuPatronAnterior.referencia      
                                  , RpuPatronAnterior.direccion       
                                  , RpuPatronAnterior.colonia         
                                  , RpuPatronAnterior.poblacion       
                                  , RpuPatronAnterior.zona_geografica 
                                  , RpuPatronAnterior.actividad       
                                  , RpuPatronAnterior.cod_postal      
                                  , RpuPatronAnterior.prima_rt        
                                  , RpuPatronAnterior.rfc
                           FROM @TblDatosPatron AS RpuPatronAnterior
                           WHERE (RpuPatronAnterior.empresa > calculoBimestre.empresa
						          OR CASE WHEN @EsMultiple > 0
                                          THEN ''
                                          ELSE RpuPatronAnterior.rpu
                                     END > CASE WHEN @EsMultiple > 0
                                                THEN ''
                                                ELSE CASE WHEN @EsRpu = 'S' 
                                                          THEN ISNULL(calculoBimestre.rpu, @Rpu) 
                                                          ELSE @Rpu 
                                                     END
                                           END)
                                 AND calculoBimestre.finGrupo > 0
                           ORDER BY RpuPatronAnterior.empresa ASC
                                    , RpuPatronAnterior.rpu ASC
                          ) AS RpuPatronAnterior

       WHERE calculoBimestre.tipo > @tipo
       ORDER BY calculoBimestre.empresa ,
                CASE WHEN @cedula = 'CedulaBimestre21' AND @EsRpu = 'S' THEN calculoBimestre.rpu ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre25' THEN calculoBimestre.centro ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.ap_paterno ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.ap_materno ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.nombre ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.afiliacion ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.digvera ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.tipo ELSE 0 END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.mes ELSE '' END,
                CASE WHEN @cedula = 'CedulaBimestre21' OR @cedula = 'CedulaBimestre22' OR @cedula = 'CedulaBimestre24' OR @cedula = 'CedulaBimestre25' OR @cedula = 'CedulaBimestre21_RpuEspecial' THEN calculoBimestre.serial ELSE 0 END
     END

  IF @cedula = 'CedulaBimestre23'
     OR @cedula = 'CedulaBimestre26'
     OR @cedula = 'CedulaBimestre27'
     BEGIN
       SELECT calculoBimestre.empresa ,
              calculoBimestre.centro ,
              calculoBimestre.centroNombre ,
              SUM(calculoBimestre.diastr) AS diastr ,
              SUM(calculoBimestre.incap) AS incap ,
              SUM(calculoBimestre.ausen) AS ausen ,
              SUM(calculoBimestre.retiro) AS retiro ,
              SUM(calculoBimestre.cesantiaVejez) AS cesantiaVejez ,
              SUM(calculoBimestre.cesantiaVejezPatron) AS cesantiaVejezPatron ,
              SUM(calculoBimestre.cesantiaVejezTrabajador) AS cesantiaVejezTrabajador ,
              SUM(calculoBimestre.sumaRCV) AS sumaRCV ,
              SUM(calculoBimestre.aportacionInfonavit) AS aportacionInfonavit ,
              SUM(calculoBimestre.amortizacion) AS amortizacion ,
              SUM(calculoBimestre.seguroVivienda) AS seguroVivienda ,
              SUM(calculoBimestre.aportacionInfonavit + calculoBimestre.seguroVivienda + calculoBimestre.amortizacion) AS sumaInfoanvit ,
              SUM(CASE WHEN calculoBimestre.acreditado IS NULL THEN 0 ELSE calculoBimestre.acreditado END) AS acreditado,
              SUM(cuentaEmpleado) AS cuentaEmpleado ,
              SUM(calculoBimestre.seguroDesempleo) AS seguroDesempleo,
              SUM(calculoBimestre.infonavitSinCredito) AS infonavitSinCredito,
              SUM(calculoBimestre.infonavitConCredito) AS infonavitConCredito,
              SUM(CASE WHEN calculoBimestre.noAcreditado IS NULL THEN 0 ELSE calculoBimestre.noAcreditado END) AS noAcreditado,
              CASE WHEN primerCentro.centro = calculoBimestre.centro THEN 1 ELSE 0 END AS serial,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.reg_pat IS NULL THEN RpuPatronAnterior.reg_pat ELSE RpuPatron.reg_pat END AS reg_pat,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.nombre IS NULL THEN RpuPatronAnterior.nombre ELSE RpuPatron.nombre END AS nombreEmpresa,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.referencia IS NULL THEN RpuPatronAnterior.referencia ELSE RpuPatron.referencia END AS referencia,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.direccion IS NULL THEN RpuPatronAnterior.direccion ELSE RpuPatron.direccion END AS direccion, 
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.colonia IS NULL THEN RpuPatronAnterior.colonia ELSE RpuPatron.colonia END AS colonia,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.poblacion IS NULL THEN RpuPatronAnterior.poblacion ELSE RpuPatron.poblacion END AS poblacion,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.zona_geografica IS NULL THEN RpuPatronAnterior.zona_geografica ELSE RpuPatron.zona_geografica END AS zona_geografica,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.actividad IS NULL THEN RpuPatronAnterior.actividad ELSE RpuPatron.actividad END AS actividad,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.cod_postal IS NULL THEN RpuPatronAnterior.cod_postal ELSE RpuPatron.cod_postal END AS cod_postal,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.prima_rt IS NULL THEN RpuPatronAnterior.prima_rt ELSE RpuPatron.prima_rt END AS prima_rt,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.rfc IS NULL THEN RpuPatronAnterior.rfc ELSE RpuPatron.rfc END AS rfcEmpresa,
              CASE WHEN ultimoCentro.centro = calculoBimestre.centro THEN 1 ELSE 0 END AS finGrupo
			  , RpuPatron.tblCVRango1
			  , RpuPatron.tblCVRango2
			  , RpuPatron.tblCVRango3
			  , RpuPatron.tblCVRango4
			  , RpuPatron.tblCVRango5
			  , RpuPatron.tblCVRango6
			  , RpuPatron.tblCVRango7
			  , RpuPatron.tblCVRango8
              
       --FROM [dbo].[LlenaCedulaBimestralUMA](@empresa, @codigo, @ayo, @mesNon, @mesPar, @proceso, @fechaProceso, @horaProceso, @simulaReforma, @filtroInfonavit) AS calculoBimestre
	   FROM @cedulaBimestral AS calculoBimestre
		    CROSS APPLY (SELECT MIN(calculoBimestrecc.centro) AS centro
                         FROM  @cedulaBimestral AS calculoBimestrecc) AS primerCentro
		    CROSS APPLY (SELECT MAX(calculoBimestrecc.centro) AS centro
                         FROM  @cedulaBimestral AS calculoBimestrecc) AS ultimoCentro
		    
            CROSS APPLY (SELECT TOP 1
                                  CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.reg_pat ELSE NULL END AS reg_pat
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.nombre ELSE NULL END AS nombre
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN ISNULL(RpuPatron.referencia, RpuPatron.nombre) ELSE NULL END AS referencia
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.direccion ELSE NULL END AS direccion
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.colonia ELSE NULL END AS colonia
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.poblacion ELSE NULL END AS poblacion
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.zona_geografica ELSE NULL END AS zona_geografica
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.actividad ELSE NULL END AS actividad
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.cod_postal ELSE NULL END AS cod_postal
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.prima_rt ELSE NULL END AS prima_rt
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.rfc ELSE NULL END AS rfc
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.registros       ELSE 0    END AS registros
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.altas           ELSE NULL END AS altas
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.bajas           ELSE NULL END AS bajas
                                , CASE WHEN primerCentro.centro = calculoBimestre.centro THEN RpuPatron.ms              ELSE NULL END AS ms
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango1     ELSE NULL END AS tblCVRango1
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango2     ELSE NULL END AS tblCVRango2
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango3     ELSE NULL END AS tblCVRango3
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango4     ELSE NULL END AS tblCVRango4
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango5     ELSE NULL END AS tblCVRango5
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango6     ELSE NULL END AS tblCVRango6
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango7     ELSE NULL END AS tblCVRango7
                                , CASE WHEN calculoBimestre.serial = 1 THEN RpuPatron.tblCVRango8     ELSE NULL END AS tblCVRango8

                         FROM @TblDatosPatron AS RpuPatron
					     WHERE RpuPatron.empresa = calculoBimestre.empresa
                               AND CASE WHEN @EsMultiple > 0
                                        THEN ''
                                        ELSE RpuPatron.rpu
                                   END = CASE WHEN @EsMultiple > 0
                                              THEN ''
                                              ELSE CASE WHEN @EsRpu = 'S' 
                                                        THEN ISNULL(calculoBimestre.rpu, @Rpu) 
                                                        ELSE @Rpu 
                                                   END
                                         END) AS RpuPatron
            
            OUTER APPLY (SELECT TOP 1
                                  RpuPatronAnterior.reg_pat         
                                , RpuPatronAnterior.nombre          
                                , RpuPatronAnterior.referencia      
                                , RpuPatronAnterior.direccion       
                                , RpuPatronAnterior.colonia         
                                , RpuPatronAnterior.poblacion       
                                , RpuPatronAnterior.zona_geografica 
                                , RpuPatronAnterior.actividad       
                                , RpuPatronAnterior.cod_postal      
                                , RpuPatronAnterior.prima_rt        
                                , RpuPatronAnterior.rfc             
                         FROM @TblDatosPatron AS RpuPatronAnterior
                         WHERE (RpuPatronAnterior.empresa > calculoBimestre.empresa
					          OR CASE WHEN @EsMultiple > 0
                                        THEN ''
                                        ELSE RpuPatronAnterior.rpu
                                   END > CASE WHEN @EsMultiple > 0
                                              THEN ''
                                              ELSE CASE WHEN @EsRpu = 'S' 
                                                        THEN ISNULL(calculoBimestre.rpu, @Rpu) 
                                                        ELSE @Rpu 
                                                   END
                                         END)
                               AND ultimoCentro.centro = calculoBimestre.centro
                         ORDER BY RpuPatronAnterior.empresa ASC
                                  , RpuPatronAnterior.rpu ASC
                        ) AS RpuPatronAnterior

       WHERE calculoBimestre.tipo = 2
             OR calculoBimestre.tipo = 3
       GROUP BY calculoBimestre.empresa
                , calculoBimestre.centro
                , calculoBimestre.centroNombre
				, CASE WHEN primerCentro.centro = calculoBimestre.centro THEN 1 ELSE 0 END
				, CASE WHEN ultimoCentro.centro = calculoBimestre.centro THEN 1 ELSE 0 END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.reg_pat IS NULL THEN RpuPatronAnterior.reg_pat ELSE RpuPatron.reg_pat END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.nombre IS NULL THEN RpuPatronAnterior.nombre ELSE RpuPatron.nombre END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.referencia IS NULL THEN RpuPatronAnterior.referencia ELSE RpuPatron.referencia END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.direccion IS NULL THEN RpuPatronAnterior.direccion ELSE RpuPatron.direccion END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.colonia IS NULL THEN RpuPatronAnterior.colonia ELSE RpuPatron.colonia END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.poblacion IS NULL THEN RpuPatronAnterior.poblacion ELSE RpuPatron.poblacion END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.zona_geografica IS NULL THEN RpuPatronAnterior.zona_geografica ELSE RpuPatron.zona_geografica END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.actividad IS NULL THEN RpuPatronAnterior.actividad ELSE RpuPatron.actividad END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.cod_postal IS NULL THEN RpuPatronAnterior.cod_postal ELSE RpuPatron.cod_postal END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.prima_rt IS NULL THEN RpuPatronAnterior.prima_rt ELSE RpuPatron.prima_rt END
                , CASE WHEN ultimoCentro.centro = calculoBimestre.centro AND NOT RpuPatronAnterior.rfc IS NULL THEN RpuPatronAnterior.rfc ELSE RpuPatron.rfc END
			  , RpuPatron.tblCVRango1
			  , RpuPatron.tblCVRango2
			  , RpuPatron.tblCVRango3
			  , RpuPatron.tblCVRango4
			  , RpuPatron.tblCVRango5
			  , RpuPatron.tblCVRango6
			  , RpuPatron.tblCVRango7
			  , RpuPatron.tblCVRango8

       ORDER BY calculoBimestre.empresa ,
                calculoBimestre.centro
     END

  IF @cedula = 'CedulaBimestre211'
     BEGIN
       SELECT calculoBimestre.empresa,
              calculoBimestre.codigo,
              calculoBimestre.nombre,
              calculoBimestre.ap_paterno,
              calculoBimestre.ap_materno,
              calculoBimestre.afiliacion,
              calculoBimestre.digvera,
              calculoBimestre.curp,
              calculoBimestre.rfcalfa,
              calculoBimestre.rfcnum,
              calculoBimestre.rfchomo,
              calculoBimestre.serial,
              CASE WHEN calculoBimestre.diastr = 0 AND calculoBimestre.mov = ' ' THEN NULL ELSE calculoBimestre.fch_mov END AS fch_mov ,
              calculoBimestre.mov AS mov,
              CASE WHEN calculoBimestre.mov <> 'B' AND calculoBimestre.mov IS NOT NULL THEN calculoBimestre.saldiaint ELSE NULL END AS saldiaint ,
              CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.diastr END AS diastr ,
              CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.incap END AS incap ,
              CASE WHEN (calculoBimestre.diastr = 0 OR calculoBimestre.diastr IS NULL) AND (calculoBimestre.mov = ' ' OR calculoBimestre.mov IS NULL OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.ausen END AS ausen ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.retiro END AS retiro ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejez END AS cesantiaVejez ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezPatron END AS cesantiaVejezPatron ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.cesantiaVejezTrabajador END AS cesantiaVejezTrabajador ,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.aportacionInfonavit END AS aportacionInfonavit ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.numeroCredito ELSE NULL END AS numeroCredito,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.descuento ELSE NULL END AS descuento ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.amortizacion ELSE NULL END AS amortizacion ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.tipoCredito ELSE NULL END AS tipoCredito ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 AND calculoBimestre.amortizacion >= 0 THEN calculoBimestre.seguroVivienda ELSE 0 END AS seguroVivienda ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaInicioDescuento ELSE NULL END AS fechaInicioDescuento ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaOtorgamiento ELSE NULL END AS fechaOtorgamiento ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.fechaSuspension ELSE NULL END AS fechaSuspension ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.ntd ELSE NULL END AS ntd ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.info ELSE NULL END AS info ,
              calculoBimestre.tipo ,
              calculoBimestre.mes,
              CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitSinCredito ELSE 0 END AS infonavitSinCredito ,
              CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitConCredito ELSE 0 END AS infonavitConCredito ,
              calculoBimestre.salarioDF,
              RTRIM(calculoBimestre.rfcalfa) + calculoBimestre.rfcnum + RTRIM(calculoBimestre.rfchomo) AS RFC ,
              RTRIM(calculoBimestre.rfcalfa) + '-' + calculoBimestre.rfcnum+ '-' + RTRIM(calculoBimestre.rfchomo) AS RFCGuion ,
              calculoBimestre.pensionEmpleado AS pensionEmpleado,
              calculoBimestre.jornadaEmpleado AS jornadaEmpleado,
              calculoBimestre.tipo AS tipo,
              CASE WHEN calculoBimestre.diastr = 0 AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.sumaRCV END AS sumaRCV ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN RTRIM(LTRIM(CONVERT(VARCHAR(9), calculoBimestre.descuento))) + ' ' + CASE calculoBimestre.tipoCredito WHEN 1 THEN '%' WHEN 2 THEN 'C.F.' WHEN 3 THEN 'FD' END END AS descuentoCedula ,
              CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfoanvit ELSE 0 END AS sumaAportacionInfoanvit ,
              CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitSinCredito ELSE 0 END AS sumaAportacionInfonavitSinCredito ,
              CASE WHEN calculoBimestre.tipo = 2 THEN sumaAportacionInfonavitConCredito ELSE 0 END AS sumaAportacionInfonavitConCredito ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacion ELSE 0 END AS sumaAmortiacion ,
              CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN sumaAmortizacionMasSeguro ELSE 0 END AS sumaAmortizacionMasSeguro ,
              calculoBimestre.sumaTotalInfonavit AS sumaTotalInfonavit,
              calculoBimestre.sumaTotal AS sumaTotal,
              calculoBimestre.acreditado AS acreditado,
              calculoBimestre.cuentaEmpleado AS cuentaEmpleado,
              CASE WHEN @rpu = 'S' THEN calculoBimestre.rpu ELSE NULL END AS rpu,
              CASE WHEN @rpu = 'S' THEN dbo.rpu.nombre ELSE NULL END AS nombreMunicipio ,
              CASE WHEN @rpu = 'S' THEN dbo.rpu.referencia ELSE NULL END AS referenciaMunicipio,
              '' AS centro, --calculoBimestre.centro ELSE NULL END AS centro,
              '' AS centroNombre, --calculoBimestre.centroNombre ELSE NULL END AS centroNombre,
              calculoBimestre.tipoNomina,
              calculoBimestre.manoObra,
              CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.seguroDesempleo END AS seguroDesempleo,
              calculoBimestre.consecutivo
       --FROM [dbo].[LlenaCedulaBimestralSinInfonavit](@empresa, @codigo, @ayo, @mesNon, @mesPar, @proceso, @fechaProceso, @horaProceso, @simulaReforma) AS calculoBimestre
	   FROM @cedulaBimestral AS calculoBimestre
            LEFT JOIN dbo.rpu ON calculoBimestre.empresa = dbo.rpu.empresa AND calculoBimestre.rpu = dbo.rpu.rpu
       WHERE   calculoBimestre.tipo > @tipo
       ORDER BY calculoBimestre.empresa ,
                CASE WHEN @rpu = 'S' THEN calculoBimestre.rpu ELSE '' END,
                --calculoBimestre.centro,
                calculoBimestre.ap_paterno,
                calculoBimestre.ap_materno,
                calculoBimestre.nombre,
                calculoBimestre.tipo,
                calculoBimestre.mes,
                calculoBimestre.serial
     END
GO

/**************************************************************************************************
 * Name          : CedulaMensualPoliza
 * Project       : APSI Nomina
 * Description   : Calcula cedula mensual cuotas IMSS
 * Table name    : empleados, avisos_imss, conceptos
 * Return        : tabla con la cedula mensual
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Octubre 06, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.CedulaMensualPoliza') IS NOT NULL
   DROP  PROCEDURE [dbo].[CedulaMensualPoliza]
GO


CREATE PROCEDURE [dbo].[CedulaMensualPoliza]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mes INT ,
    @tipo INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) 
AS 
    SELECT  [dbo].[LlenaCedulaMensual].codigo ,
            [dbo].[LlenaCedulaMensual].nombre , [dbo].[LlenaCedulaMensual].ap_paterno , [dbo].[LlenaCedulaMensual].ap_materno ,
            [dbo].[LlenaCedulaMensual].centro ,
            SUM([dbo].[LlenaCedulaMensual].diastr) AS diastr ,
            SUM([dbo].[LlenaCedulaMensual].incap) AS incap ,
            SUM([dbo].[LlenaCedulaMensual].ausen) AS ausen ,
            AvisosImssSueldo.saldiaint ,
            AvisosImssSueldo.sueldo ,
            AvisosImssUltimoAviso.mov ,
            AvisosImssUltimoAviso.fch_mov ,
            SUM(gmpTrabajador) AS gmpTrabajador ,
            SUM(gmpPatron) AS gmpPatron ,
            SUM(cuotaFija) AS cuotaFija ,
            SUM(exccedenteTrabajador) AS exccedenteTrabajador ,
            SUM(excedentePatron) AS excedentePatron ,
            SUM(prestacionesTrabajador) AS prestacionesTrabajador ,
            SUM(prestacionesPatron) AS prestacionesPatron ,
            SUM(invalidezVidaTrabajador) AS invalidezVidaTrabajador ,
            SUM(invalidezVidaPatron) AS invalidezVidaPatron ,
            SUM(retiro) AS retiro ,
            SUM(cesantiaVejezTrabajador) AS cesantiaVejezTrabajador ,
            SUM(cesantiaVejezPatron) AS cesantiaVejezPatron ,
            SUM(rt) AS rt,
            SUM(guarderias) AS guarderias ,
            SUM(infonavit) AS infonavit ,
            SUM([dbo].[TemporalAmortizacion].amortizacion) AS amortizacion
            
    FROM    [dbo].[LlenaCedulaMensual](@empresa, @codigo, @ayo, @mes, @proceso,@fechaProceso, @horaProceso, 0)
            INNER JOIN dbo.avisos_imss AS AvisosImssSueldo ON AvisosImssSueldo.empresa = @empresa
                                                              AND [dbo].[LlenaCedulaMensual].codigo = AvisosImssSueldo.codigo
                                                              AND STR(AvisosImssSueldo.ayo_operacion)
                                                                  + STR(AvisosImssSueldo.mes_operacion)
                                                                  + STR(AvisosImssSueldo.serial) = (SELECT TOP 1 STR(avisos_imss2.ayo_operacion)
                                                                                                                 + STR(avisos_imss2.mes_operacion)
                                                                                                                 + STR(avisos_imss2.serial)
                                                                                                    FROM dbo.avisos_imss AS avisos_imss2
                                                                                                    WHERE avisos_imss2.empresa = @empresa
                                                                                                          AND [dbo].[LlenaCedulaMensual].codigo = avisos_imss2.codigo
                                                                                                          AND (avisos_imss2.ayo_operacion = @ayo
                                                                                                                AND avisos_imss2.mes_operacion = @mes)
                                                                                                          AND avisos_imss2.mov <> 'B'
                                                                                                    ORDER BY avisos_imss2.ayo_operacion DESC ,
                                                                                                             avisos_imss2.mes_operacion DESC ,
                                                                                                             avisos_imss2.serial DESC
                                                                                                    )
            INNER JOIN dbo.avisos_imss AS AvisosImssUltimoAviso ON AvisosImssUltimoAviso.empresa = @empresa
                                                              AND [dbo].[LlenaCedulaMensual].codigo = AvisosImssUltimoAviso.codigo
                                                              AND STR(AvisosImssUltimoAviso.ayo_operacion)
                                                                  + STR(AvisosImssUltimoAviso.mes_operacion)
                                                                  + STR(AvisosImssUltimoAviso.serial) = (SELECT TOP 1 STR(avisos_imss3.ayo_operacion)
                                                                                                                      + STR(avisos_imss3.mes_operacion)
                                                                                                                      + STR(avisos_imss3.serial)
                                                                                                         FROM dbo.avisos_imss AS avisos_imss3
                                                                                                         WHERE [dbo].[LlenaCedulaMensual].empresa = @empresa
                                                                                                               AND [dbo].[LlenaCedulaMensual].codigo = avisos_imss3.codigo
                                                                                                               AND (avisos_imss3.ayo_operacion = @ayo
                                                                                                                    AND avisos_imss3.mes_operacion = @mes)
                                                                                                         ORDER BY avisos_imss3.ayo_operacion DESC ,
                                                                                                                  avisos_imss3.mes_operacion DESC ,
                                                                                                                  avisos_imss3.serial DESC
                                                                                                        )    
            LEFT JOIN [dbo].[TemporalAmortizacion] ON [dbo].[TemporalAmortizacion].empresa = @empresa AND [dbo].[LlenaCedulaMensual].codigo = [dbo].[TemporalAmortizacion].codigo
    GROUP BY [dbo].[LlenaCedulaMensual].codigo , 
             [dbo].[LlenaCedulaMensual].nombre , 
             [dbo].[LlenaCedulaMensual].ap_paterno , 
             [dbo].[LlenaCedulaMensual].ap_materno ,
             [dbo].[LlenaCedulaMensual].centro ,
             AvisosImssSueldo.saldiaint ,
             AvisosImssSueldo.sueldo ,
             AvisosImssUltimoAviso.mov ,
             AvisosImssUltimoAviso.fch_mov 
    ORDER BY [dbo].[LlenaCedulaMensual].codigo
GO

/**************************************************************************************************
 * Name          : CedulaMensual
 * Project       : APSI Nomina
 * Description   : Calcula cedula mensual cuotas IMSS
 * Table name    : empleados, avisos_imss, conceptos
 * Return        : tabla con la cedula mensual
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Marzo 10, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.CedulaMensual') IS NOT NULL 
    DROP  PROCEDURE [dbo].[CedulaMensual]
GO


CREATE PROCEDURE [dbo].[CedulaMensual]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mes INT ,
    @tipo INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simularReforma INT,
    @cedula VARCHAR(25)
AS 
    SET NOCOUNT ON
    
    DECLARE @rpu CHAR(1)
    
    SELECT  @rpu = ISNULL(empresa.Rpu, 'N') 
    FROM    dbo.empresas AS empresa
    WHERE   empresa.empresa = @empresa
    
    IF @cedula = 'CedulaMensual11'
       OR @cedula = 'CedulaMensual12'
       OR @cedula = 'CedulaMensual14'
       OR @cedula = 'CedulaMensual15'
       OR @cedula = 'CedulaMensual17'
       BEGIN
         SELECT dbo.LlenaCedulaMensual.codigo ,
                dbo.LlenaCedulaMensual.nombre ,
                dbo.LlenaCedulaMensual.ap_paterno ,
                dbo.LlenaCedulaMensual.ap_materno ,
                dbo.LlenaCedulaMensual.afiliacion ,
                dbo.LlenaCedulaMensual.digvera ,
                dbo.LlenaCedulaMensual.curp ,
                dbo.LlenaCedulaMensual.art39 ,
                dbo.LlenaCedulaMensual.jornada ,
                dbo.LlenaCedulaMensual.rfcalfa ,
                dbo.LlenaCedulaMensual.rfcnum ,
                dbo.LlenaCedulaMensual.rfchomo ,
                CASE WHEN dbo.LlenaCedulaMensual.mov = ' ' THEN NULL ELSE dbo.LlenaCedulaMensual.fch_mov END AS fch_mov ,
                dbo.LlenaCedulaMensual.mov ,
                CASE WHEN dbo.LlenaCedulaMensual.mov <> 'B' THEN dbo.LlenaCedulaMensual.salario ELSE NULL END AS salario ,
                CASE WHEN (dbo.LlenaCedulaMensual.diastr = 0 OR dbo.LlenaCedulaMensual.diastr IS NULL) AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov IS NULL OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.diastr END AS diastr ,
                CASE WHEN (dbo.LlenaCedulaMensual.diastr = 0 OR dbo.LlenaCedulaMensual.diastr IS NULL) AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov IS NULL OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.incap END AS incap ,
                CASE WHEN (dbo.LlenaCedulaMensual.diastr = 0 OR dbo.LlenaCedulaMensual.diastr IS NULL) AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov IS NULL OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.ausen END AS ausen ,
                dbo.LlenaCedulaMensual.primaRT ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.cuotaFija END AS cuotaFija ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.excedente END AS excedente ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.excedentePatron END AS excedentePatron ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.exccedenteTrabajador END AS exccedenteTrabajador ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.prestacionesDinero END AS prestacionesDinero ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.prestacionesPatron END AS prestacionesPatron ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.prestacionesTrabajador END AS prestacionesTrabajador ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.gmp END AS gmp ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.gmpPatron END AS gmpPatron ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.gmpTrabajador END AS gmpTrabajador ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.rt END AS rt ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.invalidezVida END AS invalidezVida ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.invalidezVidaPatron END AS invalidezVidaPatron ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.invalidezVidaTrabajador END AS invalidezVidaTrabajador ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND ( dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.guarderias END AS guarderias ,
                dbo.LlenaCedulaMensual.numeroIncapacidad ,
                dbo.LlenaCedulaMensual.nombreConcepto ,
                dbo.LlenaCedulaMensual.tipo ,
                dbo.LlenaCedulaMensual.tieneArt33 ,
                dbo.LlenaCedulaMensual.tieneSemanaReducida ,
                dbo.LlenaCedulaMensual.tienejornadaReducida ,
                dbo.LlenaCedulaMensual.salarioRegion ,
                dbo.LlenaCedulaMensual.salarioDF ,
                RTRIM(dbo.LlenaCedulaMensual.rfcalfa) + dbo.LlenaCedulaMensual.rfcnum + RTRIM(dbo.LlenaCedulaMensual.rfchomo) AS RFC ,
                RTRIM(dbo.LlenaCedulaMensual.rfcalfa) + '-' + dbo.LlenaCedulaMensual.rfcnum + '-' + RTRIM(dbo.LlenaCedulaMensual.rfchomo) AS RFCGuion ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND ( dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.sumaPrimas END AS sumaPrimas ,
                dbo.LlenaCedulaMensual.cuentaEmpleado ,
                dbo.LlenaCedulaMensual.pensionEmpleado ,
                dbo.LlenaCedulaMensual.jornadaEmpleado ,
                dbo.LlenaCedulaMensual.articulo33Empleado ,
                dbo.LlenaCedulaMensual.diaFalta ,
                dbo.LlenaCedulaMensual.diaIncapacidad ,
                dbo.LlenaCedulaMensual.sumaPrimasPatron ,
                dbo.LlenaCedulaMensual.sumaPrimasTrabajador ,
                dbo.LlenaCedulaMensual.sumaPrimasPatronMasTrabajador ,
                CASE WHEN @cedula = 'CedulaMensual11' AND @rpu = 'S' THEN dbo.LlenaCedulaMensual.rpu ELSE NULL END AS rpu ,
                CASE WHEN @cedula = 'CedulaMensual11' AND @rpu = 'S' THEN dbo.rpu.nombre ELSE NULL END AS nombreMunicipio ,
                dbo.rpu.referencia AS referenciaMunicipio ,
                CASE WHEN @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN dbo.LlenaCedulaMensual.centro ELSE NULL END AS centro,
                CASE WHEN @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN dbo.LlenaCedulaMensual.centroNombre ELSE NULL END AS centroNombre,
                dbo.LlenaCedulaMensual.tipoNomina ,
                dbo.LlenaCedulaMensual.manoObra,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.cesantiaVejez END AS cesantiaVejez ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.cesantiaVejezPatron END AS cesantiaVejezPatron ,
                CASE WHEN dbo.LlenaCedulaMensual.diastr = 0 AND (dbo.LlenaCedulaMensual.mov = ' ' OR dbo.LlenaCedulaMensual.mov = 'B') THEN NULL ELSE dbo.LlenaCedulaMensual.cesantiaVejezTrabajador END AS cesantiaVejezTrabajador
         FROM [dbo].[LlenaCedulaMensual](@empresa, @codigo, @ayo, @mes, @proceso,@fechaProceso, @horaProceso, @simularReforma)
              LEFT JOIN dbo.rpu ON dbo.LlenaCedulaMensual.empresa = dbo.rpu.empresa
                                 AND dbo.LlenaCedulaMensual.rpu = dbo.rpu.rpu
         WHERE   tipo > @tipo
         ORDER BY dbo.LlenaCedulaMensual.empresa ,
                  CASE WHEN @cedula = 'CedulaMensual11' AND @rpu = 'S' THEN dbo.LlenaCedulaMensual.rpu ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN centro ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN dbo.LlenaCedulaMensual.ap_paterno ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN dbo.LlenaCedulaMensual.ap_materno ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN dbo.LlenaCedulaMensual.nombre ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN dbo.LlenaCedulaMensual.tipo ELSE NULL END
       END
       
    IF @cedula = 'CedulaMensual13'
       OR @cedula = 'CedulaMensual16'
       BEGIN
         SELECT centro ,
                centroNombre ,
                '' AS primaRT ,  -- primaRT,
                SUM(ISNULL(cuentaEmpleado,0)) AS empleado ,
                SUM(ISNULL(cuotaFija,0)) AS cuotaFija ,
                SUM(ISNULL(excedente,0)) AS excedente ,
                SUM(ISNULL(prestacionesDinero,0)) AS prestacionesDinero ,
                SUM(ISNULL(gmp,0)) AS gmp ,
                SUM(ISNULL(rt,0)) AS rt ,
                SUM(ISNULL(invalidezVida,0)) AS invalidezVida ,
                SUM(ISNULL(guarderias,0)) AS guarderias ,
                SUM(ISNULL(sumaPrimas,0)) AS sumaPrimas,
                SUM(ISNULL(excedentePatron,0)) AS excedentePatron ,
                SUM(ISNULL(exccedenteTrabajador,0)) AS exccedenteTrabajador ,
                SUM(ISNULL(prestacionesPatron,0)) AS prestacionesPatron ,
                SUM(ISNULL(prestacionesTrabajador,0)) AS prestacionesTrabajador ,
                SUM(ISNULL(gmpPatron,0)) AS gmpPatron ,
                SUM(ISNULL(gmpTrabajador,0)) AS gmpTrabajador ,
                SUM(ISNULL(invalidezVidaPatron,0)) AS invalidezVidaPatron ,
                SUM(ISNULL(invalidezVidaTrabajador,0)) AS invalidezVidaTrabajador ,
                SUM(ISNULL(sumaPrimasPatron,0)) AS sumaPrimasPatron,
                SUM(ISNULL(sumaPrimasTrabajador,0)) AS sumaPrimasTrabajador,
                SUM(ISNULL(sumaPrimasPatronMasTrabajador,0)) AS sumaPrimasPatronMasTrabajador,
                SUM(ISNULL(cesantiaVejezPatron,0)) AS cesantiaVejezPatron,
                SUM(ISNULL(cesantiaVejezTrabajador,0)) AS cesantiaVejezTrabajador
         FROM [dbo].[LlenaCedulaMensual](@empresa, 0, @ayo, @mes, @proceso, @fechaProceso, @horaProceso, @simularReforma)
         WHERE   tipo = 2
         GROUP BY centro ,
                  centroNombre
         ORDER BY centro
       END
       
    IF @cedula = 'CedulaMensual112'
       BEGIN
         SELECT cedulaMensual.codigo ,
                cedulaMensual.nombre ,
                cedulaMensual.ap_paterno ,
                cedulaMensual.ap_materno ,
                cedulaMensual.afiliacion ,
                cedulaMensual.digvera ,
                cedulaMensual.curp ,
                cedulaMensual.art39 ,
                cedulaMensual.jornada ,
                cedulaMensual.rfcalfa ,
                cedulaMensual.rfcnum ,
                cedulaMensual.rfchomo ,
                CASE WHEN cedulaMensual.mov = ' ' THEN NULL ELSE cedulaMensual.fch_mov END AS fch_mov ,
                cedulaMensual.mov ,
                CASE WHEN cedulaMensual.mov <> 'B' THEN cedulaMensual.salario ELSE NULL END AS salario ,
                CASE WHEN (cedulaMensual.diastr = 0 OR cedulaMensual.diastr IS NULL) AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov IS NULL OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.diastr END AS diastr ,
                CASE WHEN (cedulaMensual.diastr = 0 OR cedulaMensual.diastr IS NULL) AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov IS NULL OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.incap END AS incap ,
                CASE WHEN (cedulaMensual.diastr = 0 OR cedulaMensual.diastr IS NULL) AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov IS NULL OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.ausen END AS ausen ,
                cedulaMensual.primaRT ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.cuotaFija END AS cuotaFija ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.excedente END AS excedente ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B' ) THEN NULL ELSE cedulaMensual.excedentePatron END AS excedentePatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.exccedenteTrabajador END AS exccedenteTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.prestacionesDinero END AS prestacionesDinero ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.prestacionesPatron END AS prestacionesPatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.prestacionesTrabajador END AS prestacionesTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.gmp END AS gmp ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.gmpPatron END AS gmpPatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.gmpTrabajador END AS gmpTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.rt END AS rt ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.invalidezVida END AS invalidezVida ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.invalidezVidaPatron END AS invalidezVidaPatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.invalidezVidaTrabajador END AS invalidezVidaTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.guarderias END AS guarderias ,
                cedulaMensual.numeroIncapacidad ,
                cedulaMensual.nombreConcepto ,
                cedulaMensual.tipo ,
                cedulaMensual.tieneArt33 ,
                cedulaMensual.tieneSemanaReducida ,
                cedulaMensual.tienejornadaReducida ,
                cedulaMensual.salarioRegion ,
                cedulaMensual.salarioDF ,
                RTRIM(cedulaMensual.rfcalfa) + cedulaMensual.rfcnum + RTRIM(cedulaMensual.rfchomo) AS RFC ,
                RTRIM(cedulaMensual.rfcalfa) + '-' + cedulaMensual.rfcnum + '-' + RTRIM(cedulaMensual.rfchomo) AS RFCGuion ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.sumaPrimas END AS sumaPrimas ,
                cedulaMensual.cuentaEmpleado ,
                cedulaMensual.pensionEmpleado ,
                cedulaMensual.jornadaEmpleado ,
                cedulaMensual.articulo33Empleado ,
                cedulaMensual.diaFalta ,
                cedulaMensual.diaIncapacidad ,
                cedulaMensual.sumaPrimasPatron ,
                cedulaMensual.sumaPrimasTrabajador ,
                cedulaMensual.sumaPrimasPatronMasTrabajador ,
                cedulaMensual.rpu ,
                dbo.rpu.nombre AS nombreMunicipio ,
                dbo.rpu.referencia AS referenciaMunicipio ,
                cedulaMensual.centro ,
                cedulaMensual.centroNombre ,
                cedulaMensual.tipoNomina ,
                cedulaMensual.manoObra ,
                cedulaMensual.aportacionInfonavit ,
                cedulaMensual.numeroCredito ,
                cedulaMensual.descuento ,
                cedulaMensual.amortizacion ,
                cedulaMensual.tipoCredito ,
                cedulaMensual.seguroVivienda ,
                cedulaMensual.fechaInicioDescuento ,
                cedulaMensual.fechaOtorgamiento ,
                cedulaMensual.fechaSuspension ,
                cedulaMensual.ntd ,
                cedulaMensual.info ,
                cedulaMensual.mes ,
                cedulaMensual.infonavitSinCredito ,
                cedulaMensual.infonavitConCredito ,
                cedulaMensual.sumaAportacionInfoanvit ,
                cedulaMensual.sumaAportacionInfonavitSinCredito ,
                cedulaMensual.sumaAportacionInfonavitConCredito ,
                cedulaMensual.sumaAmortizacion ,
                cedulaMensual.sumaAmortizacionMasSeguro ,
                cedulaMensual.sumaTotalInfonavit ,
                cedulaMensual.sumaTotal ,
                cedulaMensual.acreditado ,
                RTRIM(LTRIM(CONVERT(VARCHAR(9), cedulaMensual.descuento))) + ' ' + CASE cedulaMensual.tipoCredito WHEN 1 THEN '%' WHEN 2 THEN 'C.F.' WHEN 3 THEN 'V.S.M.' END AS descuentoCedula,
                RIGHT(100 + DAY(cedulaMensual.fechaInicioDescuento),2) + '/' + RIGHT(100 + MONTH(cedulaMensual.fechaInicioDescuento),2) + '/' + RIGHT(10000 + YEAR(cedulaMensual.fechaInicioDescuento),4) AS inicioDescuento,
                RIGHT(100 + DAY(cedulaMensual.fechaOtorgamiento),2) + '/' + RIGHT(100 + MONTH(cedulaMensual.fechaOtorgamiento),2) + '/' + RIGHT(10000 + YEAR(cedulaMensual.fechaOtorgamiento),4) AS otorgamiento
         FROM [dbo].[LlenaCedulaMensualInfonavit](@empresa, @codigo, @ayo, @mes, @proceso,@fechaProceso, @horaProceso, @simularReforma) AS cedulaMensual
              LEFT JOIN dbo.rpu ON cedulaMensual.empresa = dbo.rpu.empresa AND cedulaMensual.rpu = dbo.rpu.rpu
         WHERE cedulaMensual.tipo > @tipo
         ORDER BY cedulaMensual.empresa ,
                  cedulaMensual.rpu ,
                  cedulaMensual.ap_paterno ,
                  cedulaMensual.ap_materno ,
                  cedulaMensual.nombre ,
                  cedulaMensual.tipo 
    END
GO

/**************************************************************************************************
 * Name          : CedulaMensual
 * Project       : APSI Nomina
 * Description   : Calcula cedula mensual cuotas IMSS
 * Table name    : empleados, avisos_imss, conceptos
 * Return        : tabla con la cedula mensual
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Marzo 10, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.CedulaMensualUMA') IS NOT NULL 
    DROP  PROCEDURE [dbo].[CedulaMensualUMA]
GO
CREATE PROCEDURE [dbo].[CedulaMensualUMA]
@empresa NUMERIC(5) ,
@codigo NUMERIC(8, 0) ,
@ayo INT ,
@mes INT ,
@tipo INT ,
@proceso VARCHAR(250),
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8) ,
@simularReforma INT,
@cedula VARCHAR(35)

AS 

  SET NOCOUNT ON
    
  DECLARE @cedulaMensual TABLE
          (codigo INT NOT NULL DEFAULT 0 ,
           nombre VARCHAR(50) NOT NULL DEFAULT ' ' ,
           ap_paterno VARCHAR(50) NOT NULL DEFAULT ' ' ,
           ap_materno VARCHAR(50) NULL ,
           afiliacion VARCHAR(10) NULL ,
           digvera CHAR(1) NULL ,
           curp VARCHAR(18) NULL ,
           art39 DECIMAL(6, 3) NULL ,
           jornada INT NOT NULL DEFAULT 0 ,
           rfcalfa VARCHAR(4) NULL ,
           rfcnum CHAR(6) NULL ,
           rfchomo VARCHAR(3) NULL ,
           fch_mov DATETIME NULL ,
           mov VARCHAR(3) NULL ,
           salario NUMERIC(12,2) NULL ,
           diastr INT NULL ,
           lic INT NULL,
           incap INT NULL ,
           ausen INT NULL ,
           primaRT NUMERIC(8,5) NULL ,
           cuotaFija NUMERIC(12,2) NULL ,
           excedente NUMERIC(12,2) NULL ,
           excedentePatron NUMERIC(12,2) NULL ,
           exccedenteTrabajador NUMERIC(12,2) NULL ,
           prestacionesDinero NUMERIC(12,2) NULL ,
           prestacionesPatron NUMERIC(12,2) NULL ,
           prestacionesTrabajador NUMERIC(12,2) NULL ,
           gmp NUMERIC(12,2) NULL ,
           gmpPatron NUMERIC(12,2) NULL ,
           gmpTrabajador NUMERIC(12,2) NULL ,
           rt NUMERIC(12,2) NULL ,
           invalidezVida NUMERIC(12,2) NULL ,
           invalidezVidaPatron NUMERIC(12,2) NULL ,
           invalidezVidaTrabajador NUMERIC(12,2) NULL ,
           guarderias NUMERIC(12,2) NULL ,
           numeroIncapacidad VARCHAR(12) NULL ,
           nombreConcepto VARCHAR(30) NULL ,
           empresa INT NOT NULL DEFAULT 0 ,
           tipo INT NOT NULL DEFAULT 0 ,
           tieneArt33 CHAR(1) ,
           tieneSemanaReducida CHAR(1) ,
           tieneJornadaReducida CHAR(2) ,
           salarioRegion NUMERIC(8, 2) ,
           salarioDF NUMERIC(8, 2) ,
           sumaPrimas NUMERIC(12,2) ,
           cuentaEmpleado INT ,
           consecutivo INT IDENTITY ,
           pensionEmpleado VARCHAR(4) ,
           jornadaEmpleado VARCHAR(3) ,
           articulo33Empleado VARCHAR(6) ,
           centro VARCHAR(15) ,
           centroNombre VARCHAR(30) ,
           diaFalta INT ,
           diaIncapacidad INT ,
           diaLicencia INT ,
           sumaPrimasPatron NUMERIC(12,2) ,
           sumaPrimasTrabajador NUMERIC(12,2) ,
           sumaPrimasPatronMasTrabajador NUMERIC(12,2) ,
           cesantiaVejez NUMERIC(12,2) NULL ,
           cesantiaVejezPatron NUMERIC(12,2) NULL ,
           cesantiaVejezTrabajador NUMERIC(12,2) NULL ,
           retiro NUMERIC(12,2) NULL ,
           infonavit NUMERIC(12,2) NULL ,
           rpu VARCHAR(3),
           tipoNomina INT,
           manoObra CHAR(1),
           aportacionInfonavit NUMERIC(12,2),
           infonavitSinCredito NUMERIC(12,2),
           infonavitConCredito NUMERIC(12,2),
           folioObra INT,
           nombreObra VARCHAR(50),
           fechaInicioObra DATETIME,
           fechaFinObra DATETIME,
           diasObra INT,
		   serial INT,
		   finGrupo INT DEFAULT 0
		  )

  DECLARE @TblDatosPatron TABLE(empresa INT
                                , rpu CHAR(3)
                                , reg_pat CHAR(11)
                                , nombre VARCHAR(70)
                                , referencia VARCHAR(70)
                                , direccion VARCHAR(50)
                                , colonia VARCHAR(50)
                                , poblacion VARCHAR(50)
                                , zona_geografica CHAR(1)
                                , actividad VARCHAR(100)
                                , cod_postal VARCHAR(5)
                                , prima_rt NUMERIC(7, 5)
                                , rfc CHAR(13)
								, registros INT
                                , altas INT
                                , bajas INT
                                , ms INT)

  DECLARE @salarioRegionA NUMERIC(12,2)
  DECLARE @salarioRegionB NUMERIC(12,2)
  DECLARE @salarioRegionC NUMERIC(12,2)
  DECLARE @salarioRegion NUMERIC(12,2)
  DECLARE @salarioDF NUMERIC(12,2)
  DECLARE @areaGeografica CHAR(1)
  DECLARE @eymArt25 NUMERIC(8,5)
  DECLARE @eymPat25 NUMERIC(8,5)
  DECLARE @eymTra25 NUMERIC(8,5)
  DECLARE @eymArt106I NUMERIC(8,5)
  DECLARE @eymArt1062 NUMERIC(8,5)
  DECLARE @eymPat1062 NUMERIC(8,5)
  DECLARE @eymTra1062 NUMERIC(8,5)
  DECLARE @eymArt107 NUMERIC(8,5)
  DECLARE @eymPat107 NUMERIC(8,5)
  DECLARE @eymTra107 NUMERIC(8,5)
  DECLARE @ivArt147 NUMERIC(8,5)
  DECLARE @ivPat147 NUMERIC(8,5)
  DECLARE @ivTra147 NUMERIC(8,5)
  DECLARE @cvArt168II NUMERIC(8,5)
  DECLARE @cvPat168II NUMERIC(8,5)
  DECLARE @cvTra168II NUMERIC(8,5)
  DECLARE @patronPagaIMSS CHAR(1)
  DECLARE @topeDF NUMERIC(12,2)
  DECLARE @topeRegion NUMERIC(12,2)
  DECLARE @fi DATETIME
  DECLARE @ff DATETIME
  DECLARE @prima_rt NUMERIC(8,5)
  DECLARE @ayoEmpresa INT
  --DECLARE @diasFaltaTope INT
  DECLARE @cvArt168I NUMERIC(8,5)
  DECLARE @infonavit NUMERIC(8,5)
  DECLARE @art211 NUMERIC(8,5)
  DECLARE @mesPago CHAR(6)
  DECLARE @mesAplicaUMA CHAR(6)
  DECLARE @fechaAplicaSiroc DATETIME
  DECLARE @fechaOperacion DATETIME
  DECLARE @mesEmpresa INT
  DECLARE @EsRpu CHAR(1)
  DECLARE @fechaInicio DATETIME
  DECLARE @fechaTermino DATETIME
  DECLARE @Rpu CHAR(3)
  DECLARE @EsRpuEspecial INT
  DECLARE @reg_pat VARCHAR(11)
  DECLARE @EsMultiple INT

  SET @EsRpuEspecial = dbo.EsRpuEspecial(@empresa)
  SET @fechaInicio = CONVERT(DATETIME, RIGHT(10000 + @ayo,4) + RIGHT(100 + @mes,2) + '01')
  SET @fechaTermino = (SELECT fechaFin FROM [dbo].[ObtieneRangoFecha](@fechaInicio, 7))
  SET @fechaAplicaSiroc = CONVERT(DATETIME, '20170901')
  SET @mesPago = RIGHT(STR(@ayo),4) + RIGHT(STR(100 + @mes),2)
  SET @mesAplicaUMA = '201701'
  --SET @diasFaltaTope = 7
  SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
  SET @ff = dbo.fin_mes(@mes, @ayo)

  -- Obtiene Area Geografica
  SELECT @areaGeografica = dbo.empresas.zona_geografica ,
         @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
         @ayoEmpresa = dbo.empresas.ayo_operacion ,
         @EsRpu = ISNULL(dbo.empresas.Rpu, 'N'),
         @mesEmpresa = dbo.empresas.mes_operacion,
		 @Rpu = LEFT(dbo.empresas.registro_patronal,3),
		 @reg_pat = dbo.empresas.registro_patronal
  FROM dbo.empresas
  WHERE dbo.empresas.empresa = @empresa

  SET @fechaOperacion = CONVERT(DATETIME, LTRIM(STR(@ayoEmpresa)) + RIGHT(100 + @mesEmpresa,2) + '01')

  -- Obtiene Salario Minimo
  SELECT @salarioRegionA = ISNULL(zona_a, 0) ,
         @salarioRegionB = ISNULL(zona_b, 0) ,
         @salarioRegionC = ISNULL(zona_c, 0)
  FROM [dbo].[GetMinimumWage](@mes, @ayo)
        
  SET @salarioDF = @salarioRegionA
        
  SET @salarioRegion = CASE @areaGeografica
                            WHEN 'A' THEN @salarioRegionA
                            WHEN 'B' THEN @salarioRegionB
                            WHEN 'C' THEN @salarioRegionC
                            ELSE 0
                       END
                     
  SET @topeDF = ROUND(@salarioDF * 25, 2)
  SET @topeRegion = @salarioRegion

  -- Obtiene Primas IMSS
  SELECT @eymArt25 = primasImss.eymart25 ,
         @eymPat25 = primasImss.eympat25 , 
         @eymTra25 = primasImss.eymtra25, 
         @eymArt106I = primasImss.eymart106I ,
         @eymArt1062 = primasImss.eymart1062 ,
         @eymPat1062 = primasImss.eympat1062 , 
         @eymTra1062 = primasImss.eymtra1062 , 
         @eymArt107 = primasImss.eymart107 ,
         @eymPat107 = primasImss.eympat107 , 
         @eymTra107 = primasImss.eymtra107 , 
         @ivArt147 = primasImss.ivart147 ,
         @ivPat147 = primasImss.ivpat147 , 
         @ivTra147 = primasImss.ivtra147 , 
         @cvArt168II = primasImss.cvart168II ,
         @cvPat168II = primasImss.cvpat168II , 
         @cvTra168II = primasImss.cvtra168ii , 
         @cvArt168I = primasImss.cvArt168I ,
         @infonavit = primasImss.infonavitPorciento ,
         @art211 = primasImss.art211
  FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simularReforma) AS primasImss

  -- Obtiene Prima RT
  SELECT @prima_rt = dbo.primas_rt.prima_rt
  FROM dbo.primas_rt
  WHERE dbo.primas_rt.empresa = @empresa
        AND dbo.primas_rt.fecha_inicial <= @fi
        AND dbo.primas_rt.fecha_final >= @ff

  SET @EsMultiple = CHARINDEX('"', @proceso)

  IF @EsRpuEspecial = 1
     BEGIN
       INSERT @TblDatosPatron (empresa
                               , rpu
                               , reg_pat
                               , nombre
                               , referencia
                               , direccion
                               , colonia
                               , poblacion
                               , zona_geografica
                               , actividad
                               , cod_postal
                               , prima_rt
                               , rfc)
              SELECT r.empresa
                     , r.rpu
                     , r.reg_pat
                     , r.nombre
                     , r.referencia
                     , r.direccion
                     , r.colonia
                     , r.poblacion
                     , r.zona_geografica
                     , r.actividad
                     , r.cod_postal
                     , rp.primaRt
                     , r.rfc
	          FROM dbo.rpu AS r
			       CROSS APPLY (SELECT TOP 1
                                       rp.primaRt
                                FROM dbo.Rpu_PrimaRT AS rp
								WHERE rp.empresa = r.empresa
                                      AND rp.rpu = r.rpu
									  AND rp.fecha <= @fechaInicio
							    ORDER BY rp.fecha DESC) AS rp
			  WHERE r.empresa = @empresa

       DELETE tdr
	   FROM @TblDatosPatron AS tdr
	   WHERE NOT EXISTS (SELECT 1
                         FROM dbo.AvisosImssTemporalCalculo AS aItc 
                         WHERE aItc.rpu = tdr.rpu
                               AND aItc.empresa = tdr.empresa
                               AND aItc.fch_mov >= @fechaInicio
                               AND aItc.fch_mov <= @fechaTermino
                               AND aItc.horaProceso = @horaproceso
                               AND aItc.fechaProceso = @fechaproceso
                               AND aItc.proceso = @proceso)

	 END
  ELSE
     IF @EsRpu = 'N' OR @EsMultiple > 0
        BEGIN
          INSERT @TblDatosPatron (empresa
                                  , rpu
                                  , reg_pat
                                  , nombre
                                  , referencia
                                  , direccion
                                  , colonia
                                  , poblacion
                                  , zona_geografica
                                  , actividad
                                  , cod_postal
                                  , prima_rt
                                  , rfc)
                 SELECT empresa.empresa
                        , LEFT(empresa.registro_patronal,3) AS rpu
                        , empresa.registro_patronal AS reg_pat
                        , empresa.nombre_empresa AS nombre_empresa
                        , empresa.referencia AS referencia
                        , empresa.direccion_empresa AS direccion
                        , empresa.colonia_empresa AS colinia
                        , empresa.poblacion_empresa AS poblacion
                        , empresa.zona_geografica AS zona_geografica
                        , empresa.actividad_empresa AS actividad
                        , empresa.codigo_postal_empresa AS cod_postal
                        , prima_rt.prima_rt --@prima_rt AS prima_rt
                        , empresa.rfc_empresa AS rfc
                 FROM dbo.empresas AS empresa
				      INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = empresa.empresa
					  CROSS APPLY (SELECT TOP 1 prima_rt.prima_rt
                                   FROM dbo.primas_rt AS prima_rt
                                   WHERE prima_rt.empresa = empresa.empresa
                                         AND prima_rt.fecha_inicial <= @fi
                                         AND prima_rt.fecha_final >= @ff
                                   ORDER BY fecha_inicial DESC
                                            , fecha_final DESC) AS prima_rt
                 --WHERE empresa.empresa = @empresa
        END
     ELSE
        BEGIN
          INSERT @TblDatosPatron (empresa
                                  , rpu
                                  , reg_pat
                                  , nombre
                                  , referencia
                                  , direccion
                                  , colonia
                                  , poblacion
                                  , zona_geografica
                                  , actividad
                                  , cod_postal
                                  , prima_rt
                                  , rfc)
                 SELECT r.empresa
                        , r.rpu
                        , @reg_pat AS reg_pat
                        , r.nombre
                        , r.referencia
                        , r.direccion
                        , r.colonia
                        , r.poblacion
                        , @areaGeografica AS zona_geografica
                        , r.actividad
                        , r.cod_postal
                        , @prima_rt AS primaRt
                        , r.rfc
	             FROM dbo.rpu AS r
			     WHERE r.empresa = @empresa
        END

  INSERT @cedulaMensual
         (codigo ,
          nombre ,
          ap_paterno ,
          ap_materno ,
          afiliacion ,
          digvera ,
          curp ,
          art39 ,
          jornada ,
          rfcalfa ,
          rfcnum ,
          rfchomo ,
          fch_mov ,
          mov ,
          salario ,
          lic ,
          diastr ,
          incap ,
          ausen ,
          primaRT ,
          cuotaFija ,
          excedente ,
          excedentePatron ,
          exccedenteTrabajador ,
          prestacionesDinero ,
          prestacionesPatron ,
          prestacionesTrabajador ,
          gmp ,
          gmpPatron ,
          gmpTrabajador ,
          rt ,
          invalidezVida ,
          invalidezVidaPatron ,
          invalidezVidaTrabajador ,
          guarderias ,
          empresa ,
          tipo ,
          salarioRegion ,
          salarioDF ,
          tieneArt33 ,
          tieneSemanaReducida ,
          tieneJornadaReducida ,
          pensionEmpleado ,
          jornadaEmpleado ,
          articulo33Empleado ,
          centro ,
          centroNombre ,
          cesantiaVejez ,
          cesantiaVejezPatron ,
          cesantiaVejezTrabajador ,
          retiro ,
          infonavit ,
          rpu,
          tipoNomina,
          manoObra,
          aportacioninfonavit)

          SELECT dbo.empleados.codigo ,
                 dbo.empleados.nombre ,
                 dbo.empleados.ap_paterno ,
                 dbo.empleados.ap_materno ,
                 dbo.empleados.afiliacion ,
                 dbo.empleados.digvera ,
                 dbo.empleados.curp ,
                 dbo.empleados.art39 ,
                 dbo.empleados.jornada ,
                 dbo.empleados.rfcalfa ,
                 dbo.empleados.rfcnum ,
                 dbo.empleados.rfchomo ,
                 aItc.fch_mov ,

                 CASE aItc.mov
                      WHEN 'IM' THEN ' '
                      WHEN 'RI' THEN 'R'
                      WHEN 'MS' THEN 'M/S'
                      WHEN 'UM' THEN 'UMA'
                      ELSE aItc.mov
                 END AS mov ,

                 [dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                         CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                         sm.salarioRegion, --@topeRegion,
                                         dbo.empleados.art39,
                                         aItc.mov) AS salario ,

                 aItc.lic ,
                 aItc.diastr ,
                 aItc.incap ,
                 aItc.ausen ,
                 tdp.prima_rt AS primaRT, --@prima_rt AS primaRT ,

                 [dbo].[CalculaCuotaImssUMA](CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END,
                                             aItc.diastr,
                                             aItc.incap, 0,
                                             @eymArt106I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, @eymArt106I, 0 ) AS cuotaFija ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap, 0,
                                             @eymArt1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, @eymPat1062, @eymTra1062) AS excedente ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap, 0,
                                             @eymPat1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             1, @eymPat1062, @eymTra1062) AS excedentePatron ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap, 0,
                                             @eymTra1062, 'S', CASE WHEN @mesPago >= @mesAplicaUMA THEN aItc.umaDiario ELSE @salarioDF END, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             2, @eymPat1062, @eymTra1062) AS exccedenteTrabajador ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap, 0,
                                             @eymArt107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, @eymPat107, @eymTra107) AS prestacionesDinero ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap, 0,
                                             @eymPat107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             1, @eymPat107, @eymTra107) AS prestacionesPatron ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap, 0,
                                             @eymTra107, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             2, @eymPat107, @eymTra107) AS prestacionesTrabajador ,

                 CASE WHEN dbo.empleados.pension_iv_cv = 'C' 
				      THEN 0
                      ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                               CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                               sm.salarioRegion, --@topeRegion,
                                                                               dbo.empleados.art39,
                                                                               aItc.mov),
                                                       aItc.diastr,
                                                       aItc.incap,
                                                       0, @eymArt25, 'N',
                                                       0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                                       0, @eymPat25, @eymTra25)
                 END AS gmp ,

                 CASE WHEN dbo.empleados.pension_iv_cv = 'C' 
				      THEN 0
                      ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                               CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                               sm.salarioRegion, --@topeRegion,
                                                                               dbo.empleados.art39,
                                                                               aItc.mov),
                                                       aItc.diastr,
                                                       aItc.incap,
                                                       0, @eymPat25, 'N',
                                                       0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                                       1, @eymPat25, @eymTra25)
                 END AS gmpPatron ,

                 CASE WHEN dbo.empleados.pension_iv_cv = 'C' 
				      THEN 0
                      ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                               CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                               sm.salarioRegion, --@topeRegion,
                                                                               dbo.empleados.art39,
                                                                               aItc.mov),
                                                       aItc.diastr,
                                                       aItc.incap,
                                                       0, @eymTra25, 'N',
                                                       0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                                       2, @eymPat25, @eymTra25)
                 END AS gmpTrabajador ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap,
                                             aItc.ausen,
                                             --@prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             tdp.prima_rt, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, @prima_rt, 0) AS rt ,

                 CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' 
				      THEN 0
                      ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                               CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                               sm.salarioRegion, --@topeRegion,
                                                                               dbo.empleados.art39,
                                                                               aItc.mov),
                                                       aItc.diastr,
                                                       aItc.incap,
                                                       aItc.ausen,
                                                       @ivArt147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                                       0, @ivPat147, @ivTra147)
                 END AS invalidezVida ,

                 CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' 
				      THEN 0
                      ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                               CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                               sm.salarioRegion, --@topeRegion,
                                                                               dbo.empleados.art39,
                                                                               aItc.mov),
                                                       aItc.diastr,
                                                       aItc.incap,
                                                       aItc.ausen,
                                                       @ivPat147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                                       1, @ivPat147, @ivTra147)
                 END AS invalidezVidaPatron ,

                 CASE WHEN dbo.empleados.pension_iv_cv = 'I' OR dbo.empleados.pension_iv_cv = 'C' 
				      THEN 0
                      ELSE [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                               CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                               sm.salarioRegion, --@topeRegion,
                                                                               dbo.empleados.art39,
                                                                               aItc.mov),
                                                       aItc.diastr,
                                                       aItc.incap,
                                                       aItc.ausen,
                                                       @ivTra147, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                                       2, @ivPat147, @ivTra147)
                 END AS invalidezVidaTrabajador ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap,
                                             aItc.ausen,
                                             @art211, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, @art211, 0) AS guarderias ,

                 dbo.empleados.empresa, --dbo.empresas.empresa ,
                 2 AS tipo ,
                 sm.salarioRegion, --@salarioRegion ,
                 @salarioDF ,

                 CASE WHEN dbo.empleados.art39 > 0 THEN '+' ELSE ' ' END AS tieneArticulo33 ,
                 CASE WHEN dbo.empleados.jornada >= 1 AND dbo.empleados.jornada <= 5 THEN '*' ELSE ' ' END AS tieneSemanaReducida ,
                 CASE WHEN dbo.empleados.jornada = 6 THEN '**' ELSE '  ' END AS tieneJornadaReducida ,

                 (SELECT TOP 1
                         CASE WHEN dbo.excepciones.excepcion1 = 'IV' THEN 'P/IV'
                              WHEN dbo.excepciones.excepcion1 = 'CV' THEN 'P/CV'
                              ELSE NULL
                         END
                  FROM dbo.excepciones
                  WHERE dbo.excepciones.empresa = dbo.empleados.empresa
                        AND dbo.excepciones.codigo = dbo.empleados.codigo
                        AND (dbo.excepciones.excepcion1 = 'IV' OR dbo.excepciones.excepcion1 = 'CV') ) AS pensionEmpleado ,

                 CASE WHEN dbo.empleados.jornada >= 1 AND dbo.empleados.jornada <= 5 THEN 'S/R'
                       WHEN dbo.empleados.jornada = 6 THEN 'J/R'
                       ELSE NULL
                 END AS jornadaEmpleado ,

                 CASE WHEN dbo.empleados.art39 > 0 THEN 'ART.33' ELSE NULL END AS articulo33Empleado ,

                 dbo.Llaves.centro ,
                 dbo.centros.nomdepto ,
                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion, 
																	 0, --dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap,
                                             aItc.ausen,
                                             --@cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             --0, @cvPat168II, @cvTra168II
                                             tblCV.cvArt168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, tblCV.cvPat168II, tblCV.cvTra168II
											) AS cesantiaVejez ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap,
                                             aItc.ausen,
                                             --@cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             --1, @cvPat168II, @cvTra168II) AS cesantiaVejezPatron ,
                                             tblCV.cvPat168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             1, tblCV.cvPat168II, tblCV.cvTra168II
											) AS cesantiaVejezPatron ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion,
                                                                     dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr,
                                             aItc.incap,
                                             aItc.ausen,
                                             tblCV.cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             --2, @cvPat168II, @cvTra168II
                                             --@cvTra168II, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             2, tblCV.cvPat168II, tblCv.cvTra168II
											) AS cesantiaVejezTrabajador ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion, 
																	 0, --dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr, 0,
                                             aItc.ausen,
                                             @cvArt168I, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, @cvArt168II, 0) AS retiro ,

                 [dbo].[CalculaCuotaImssUMA]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                     CASE WHEN @mesPago >= @mesAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,
                                                                     sm.salarioRegion, --@topeRegion, 
																	 0, --dbo.empleados.art39,
                                                                     aItc.mov),
                                             aItc.diastr, 0,
                                             aItc.ausen,
                                             @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                             0, @infonavit, 0) AS infonavit ,

                 CASE WHEN @EsMultiple > 0
				      THEN LTRIM(RTRIM(tdp.empresa))
			          ELSE CASE WHEN @EsRpu = 'S' 
		                        THEN ISNULL(aItc.rpu, @Rpu) 
			                    ELSE @Rpu 
				           END
                 END, --CASE WHEN @EsRpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                 dbo.Llaves.tiponom,
                 dbo.empleados.manoobra,

                 [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,
                                                                  @topeDF,
                                                                  sm.salarioRegion, --@topeRegion,
																  0,
                                                                  aItc.mov),
                                          aItc.diastr, 0,
                                          aItc.ausen,
                                          @infonavit, 'N', 0, aItc.sueldo, aItc.fch_mov, @simularReforma, sm.salarioRegion, --@salarioRegion,
                                          0, @infonavit, 0) AS aportacionInfonavit 

          FROM dbo.empleados
		       --INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = dbo.empleados.empresa
               INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                   AND dbo.empleados.codigo = aItc.codigo
																   AND aItc.fch_mov >= @fechaInicio   -- AND MONTH(aItc.fch_mov) = @mes
																   AND aItc.fch_mov <= @fechaTermino  -- AND YEAR(aItc.fch_mov) = @ayo
                                                                   AND aItc.horaProceso = @horaproceso
                                                                   AND aItc.fechaProceso = @fechaproceso
                                                                   AND aItc.proceso = @proceso
                                                                   AND ((aItc.mov = 'IM' AND aItc.diastr > 0)
                                                                        OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                                                                        OR (aItc.mov = 'UM' AND aItc.diastr IS NOT NULL))

               OUTER APPLY (SELECT CASE WHEN aItc.mov = 'B' THEN 0 ELSE rango END rango
			                       , cvArt168II
                                   , cvPat168II
                                   , cvTra168II
			                FROM dbo.NOM_FUN_ObtienePrimaCVPatron2023(aItc.empresa, aItc.fch_mov, YEAR(aItc.fch_mov), aItc.saldiaint, @cvArt168II, @cvPat168II, @cvTra168II)
						   ) AS tblCV
		       
			   INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = dbo.empleados.empresa
													AND CASE WHEN @EsMultiple > 0 
													         THEN '' 
														     ELSE tdp.rpu 
														END = CASE WHEN @EsMultiple > 0 
														           THEN '' 
																   ELSE CASE WHEN @EsRpuEspecial = 1 
													                         THEN ISNULL(aItc.rpu, @Rpu) 
														                     ELSE aItc.rpu --@Rpu 
													                    END 
															  END
               INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa AND dbo.empleados.codigo = dbo.Llaves.codigo
               INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa AND dbo.Llaves.clase = dbo.clases.clase
               INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro AND dbo.Llaves.empresa = dbo.centros.empresa
               CROSS APPLY (SELECT TOP 1
	                               CASE tdp.zona_geografica WHEN 'A' THEN sm.zona_a
                                                            WHEN 'B' THEN sm.zona_b
                                                            WHEN 'C' THEN sm.zona_c
                                                            ELSE @salarioRegion
                                   END AS salarioRegion
                            FROM dbo.salarios_minimos AS sm
				            WHERE sm.fecha_ini <= aItc.fch_mov
				            ORDER BY sm.fecha_ini DESC) AS sm

          WHERE --dbo.empleados.empresa >= CASE WHEN @empresa = 0 THEN 0 ELSE @empresa END
                --AND dbo.empleados.empresa <= CASE WHEN @empresa = 0 THEN 9999 ELSE @empresa END
                --AND 
				dbo.empleados.cotiza_imss = 'S'
                AND dbo.empleados.borrado = 'N'
                AND dbo.empleados.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END
                AND dbo.empleados.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END

  -- Cuota Fija   106 I
  -- Exec.        106 II
  -- Pd.          107
  -- Gmp          25
  -- RT           71
  -- Iv           147
  -- Gps          211  

  INSERT @cedulaMensual
         (codigo ,
          nombre ,
          ap_paterno ,
          ap_materno ,
          afiliacion ,
          digvera ,
          fch_mov ,
          mov ,
          empresa ,
          numeroIncapacidad ,
          nombreConcepto ,
          tipo ,
          centro ,
          centroNombre ,
          diaFalta ,
          diaIncapacidad ,
          diaLicencia ,
          rpu,
          tipoNomina,
          manoObra)

          SELECT dbo.empleados.codigo ,
                 dbo.empleados.nombre ,
                 dbo.empleados.ap_paterno ,
                 dbo.empleados.ap_materno ,
                 dbo.empleados.afiliacion ,
                 dbo.empleados.digvera ,
                 CASE WHEN dbo.deducciones.fchinicio <= @fi THEN @fi ELSE dbo.deducciones.fchinicio END AS 'fchinicio',
                 dbo.deducciones.tipoinc ,
                 dbo.empleados.empresa ,
                 dbo.deducciones.numeroinc ,
                 [dbo].[NOM_FUN_ObtieneDescripcionIncidencia](dbo.deducciones.empresa, dbo.deducciones.num_conc, dbo.deducciones.justificar, dbo.deducciones.inicsubs, dbo.deducciones.clase, dbo.deducciones.centro) AS nombreConcepto,
                 3 AS tipo ,
                 dbo.Llaves.centro ,
                 dbo.centros.nomdepto ,

                 CASE WHEN dbo.deducciones.num_conc = 108
                           THEN CASE WHEN dbo.deducciones.fchinicio <= @fi
                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @fi
                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                          THEN DATEDIFF(dd, @fi, dbo.deducciones.fchinicio + dbo.deducciones.dias)
                                          ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                         AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                                         THEN dbo.deducciones.dias
                                                         ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                                        AND dbo.deducciones.fchinicio <= @ff
                                                                        AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                   THEN DATEDIFF(dd, dbo.deducciones.fchinicio, @ff) + 1
                                                                   ELSE CASE WHEN dbo.deducciones.fchinicio <= @fi
                                                                                  AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                                  THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                                                  ELSE 0
                                                                        END
                                                              END
                                               END
                                END
                           ELSE NULL
                 END ,

                 CASE WHEN dbo.deducciones.num_conc >= 109
                           AND dbo.deducciones.num_conc <= 111
                           THEN CASE WHEN dbo.deducciones.fchinicio <= @fi
                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @fi
                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                          THEN DATEDIFF(dd, @fi, dbo.deducciones.fchinicio + dbo.deducciones.dias)
                                          ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                         AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                                         THEN dbo.deducciones.dias
                                                         ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                                        AND dbo.deducciones.fchinicio <= @ff
                                                                        AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                        THEN DATEDIFF(dd, dbo.deducciones.fchinicio, @ff) + 1
                                                                        ELSE CASE WHEN dbo.deducciones.fchinicio <= @fi
                                                                                       AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                                       THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                                                       ELSE 0
                                                                             END
                                                              END
                                               END
                                END
                           ELSE NULL
                 END ,

                 CASE WHEN dbo.deducciones.num_conc = 109 AND dbo.deducciones.inicsubs = '4'
                           THEN CASE WHEN dbo.deducciones.fchinicio <= @fi
                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @fi
                                          AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                          THEN DATEDIFF(dd, @fi, dbo.deducciones.fchinicio + dbo.deducciones.dias)
                                          ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                         AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                                         THEN dbo.deducciones.dias
                                                         ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                                        AND dbo.deducciones.fchinicio <= @ff
                                                                        AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                        THEN DATEDIFF(dd, dbo.deducciones.fchinicio, @ff) + 1
                                                                        ELSE CASE WHEN dbo.deducciones.fchinicio <= @fi
                                                                                       AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                                                                       THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                                                       ELSE 0
                                                                             END
                                                              END
                                               END
                                END
                           ELSE 0
                 END AS diaLicencia ,

                 --CASE WHEN @EsRpu = 'S' THEN ISNULL(aItc.rpu, @Rpu) ELSE @Rpu END AS rpu,   -- CASE WHEN @EsRpu = 'S' THEN dbo.empleados.rpu ELSE NULL END,
                 CASE WHEN @EsMultiple > 0
				      THEN LTRIM(RTRIM(tdp.empresa))
			          ELSE CASE WHEN @EsRpu = 'S' 
		                        THEN ISNULL(aItc.rpu, @Rpu) 
			                    ELSE @Rpu 
				           END 
                 END AS rpu,
                 dbo.Llaves.tiponom,
                 dbo.empleados.manoobra

          FROM dbo.empleados 
		       --INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = dbo.empleados.empresa
               LEFT JOIN dbo.deducciones ON dbo.empleados.empresa = dbo.deducciones.empresa AND dbo.empleados.codigo = dbo.deducciones.codigo

			   CROSS APPLY (SELECT TOP 1
			                       aItc.rpu
                            FROM dbo.AvisosImssTemporalCalculo AS aItc
                            WHERE --@EsRpu = 'S' AND 
							      aItc.empresa = dbo.empleados.empresa
                                  AND aItc.codigo = dbo.empleados.codigo
								  AND aItc.mov <> 'B'
								  AND aItc.diastr > 0
                                  AND ((dbo.deducciones.fchinicio <= aItc.fch_mov AND dbo.deducciones.fchtermino >= aItc.fch_mov AND dbo.deducciones.fchinicio <= aItc.fch_mov + aItc.diastr - 1)
                                       OR (dbo.deducciones.fchinicio >= aItc.fch_mov AND dbo.deducciones.fchtermino <= aItc.fch_mov + aItc.diastr - 1)
                                       OR (dbo.deducciones.fchinicio >= aItc.fch_mov AND dbo.deducciones.fchinicio <= aItc.fch_mov + aItc.diastr - 1 AND dbo.deducciones.fchtermino >= aItc.fch_mov + aItc.diastr - 1)
                                       OR (dbo.deducciones.fchinicio <= aItc.fch_mov AND dbo.deducciones.fchtermino >= aItc.fch_mov + aItc.diastr - 1))                     
                                  AND aItc.horaProceso = @horaproceso
                                  AND aItc.fechaProceso = @fechaproceso
                                  AND aItc.proceso = @proceso) AS aItc
		       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = dbo.empleados.empresa
			                                        --AND tdp.rpu = CASE WHEN @EsRpuEspecial = 1 THEN ISNULL(aItc.rpu, @Rpu) ELSE @Rpu END
													AND CASE WHEN @EsMultiple > 0 
													         THEN '' 
														     ELSE tdp.rpu 
														END = CASE WHEN @EsMultiple > 0 
														           THEN '' 
																   ELSE CASE WHEN @EsRpuEspecial = 1 
													                         THEN ISNULL(aItc.rpu, @Rpu) 
														                     ELSE @Rpu 
													                    END 
															  END

               LEFT JOIN dbo.conceptos ON dbo.deducciones.empresa = dbo.conceptos.empresa
                                          AND dbo.deducciones.num_conc = dbo.conceptos.num_conc
                                          AND dbo.deducciones.clase = dbo.conceptos.clase
                                          AND dbo.deducciones.centro = dbo.conceptos.centro
               INNER JOIN dbo.Llaves ON dbo.deducciones.empresa = dbo.Llaves.empresa AND dbo.deducciones.codigo = dbo.Llaves.codigo
               INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro AND dbo.Llaves.empresa = dbo.centros.empresa

          WHERE ((dbo.deducciones.fchinicio <= @fi AND dbo.deducciones.fchtermino >= @fi AND dbo.deducciones.fchinicio <= @ff)
                 OR (dbo.deducciones.fchinicio >= @fi AND dbo.deducciones.fchtermino <= @ff)
                 OR (dbo.deducciones.fchinicio >= @fi AND dbo.deducciones.fchinicio <= @ff AND dbo.deducciones.fchtermino >= @ff)
                 OR (dbo.deducciones.fchinicio <= @fi AND dbo.deducciones.fchtermino >= @ff))
                --AND dbo.deducciones.empresa >= CASE WHEN @empresa = 0 THEN 0 ELSE @empresa END
                --AND dbo.deducciones.empresa <= CASE WHEN @empresa = 0 THEN 9999 ELSE @empresa END
                AND dbo.empleados.cotiza_imss = 'S'
                AND dbo.empleados.borrado = 'N'
                AND CASE WHEN @fi >= @fechaOperacion THEN dbo.empleados.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                AND dbo.deducciones.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END
                AND dbo.deducciones.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END
                AND dbo.deducciones.num_conc >= 108
                AND dbo.deducciones.num_conc <= 111

--select @EsRpu, * from @cedulaMensual order by empresa, codigo

  IF @fi >= @fechaAplicaSiroc
     BEGIN
       INSERT @cedulaMensual
              (codigo,
               nombre,
               ap_paterno,
               ap_materno,
               afiliacion ,
               digvera ,
               empresa,
               tipo,
               centro,
               centroNombre,
               rpu,
               tipoNomina,
               manoObra,
               folioObra,
               nombreObra,
               fechaInicioObra,
               fechaFinObra,
               diasObra)

               SELECT oe.codigo,
                      e.nombre,
                      e.ap_paterno,
                      e.ap_materno,
                      e.afiliacion ,
                      e.digvera ,
                      oe.empresa,
                      4 AS tipo,
                      ll.centro,
                      c.nomdepto AS centroNombre,
                      e.rpu,
                      ll.tiponom AS tipoNomina,
                      e.manoObra,
                      oe.Obra AS folioObra,
                      o.nombre AS nombreObra,
                      oe.fecha_i AS fechaInicioObra,
                      oe.fecha_f AS fechaFinObra,
                      CASE WHEN oe.fecha_i <= @fi AND oe.fecha_f >= @fi AND oe.fecha_f <= @ff
                                THEN DATEDIFF(dd, @fi, oe.fecha_f) + 1
                                ELSE CASE WHEN oe.fecha_i >= @fi AND oe.fecha_f <= @ff
                                               THEN DATEDIFF(dd, oe.fecha_i, oe.fecha_f) + 1
                                               ELSE CASE WHEN oe.fecha_i >= @fi AND oe.fecha_i <= @ff AND oe.fecha_f >= @ff
                                                              THEN DATEDIFF(dd, oe.fecha_i, @ff) + 1
                                                              ELSE CASE WHEN oe.fecha_i <= @fi AND oe.fecha_f >= @ff
                                                                             THEN DATEDIFF(dd,@fi,@ff)+ 1
                                                                             ELSE 0
                                                                   END
                                                    END
                                     END
                      END AS diasObra

               FROM dbo.Obras_emps AS oe
		            INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = oe.empresa
                    INNER JOIN dbo.Obras AS o ON oe.obra = o.obra AND oe.empresa = o.empresa
                    INNER JOIN dbo.empleados AS e ON oe.codigo = e.codigo AND oe.empresa = e.empresa
                    INNER JOIN dbo.Llaves AS ll ON e.codigo = ll.codigo AND e.empresa = ll.empresa
                    INNER JOIN dbo.centros AS c ON LTRIM(RTRIM(ll.centro)) = LTRIM(RTRIM(c.centro)) AND ll.empresa = c.empresa

               WHERE ((oe.fecha_i <= @fi AND oe.fecha_f >= @fi AND oe.fecha_i <= @ff)
                      OR (oe.fecha_i >= @fi AND oe.fecha_f <= @ff)
                      OR (oe.fecha_i >= @fi AND oe.fecha_i <= @ff AND oe.fecha_f >= @ff)
                      OR (oe.fecha_i <= @fi AND oe.fecha_f >= @ff))
                     --AND oe.empresa >= CASE WHEN @empresa = 0 THEN 0 ELSE @empresa END
                     --AND oe.empresa <= CASE WHEN @empresa = 0 THEN 9999 ELSE @empresa END
                     AND e.cotiza_imss = 'S'
                     AND e.borrado = 'N'
                     AND CASE WHEN @fi >= @fechaOperacion THEN e.activo ELSE '' END = CASE WHEN @fi >= @fechaOperacion THEN 'S' ELSE '' END
                     AND oe.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END
                     AND oe.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END
     END

  UPDATE cedulaMensual
  SET sumaPrimas = cuotaFija + excedente + prestacionesDinero + gmp + rt + invalidezVida + guarderias ,
      sumaPrimasPatron = cuotaFija + excedentePatron + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron + guarderias ,
      sumaPrimasTrabajador = exccedenteTrabajador + prestacionesTrabajador + gmpTrabajador + invalidezVidaTrabajador ,
      sumaPrimasPatronMasTrabajador = cuotaFija + excedentePatron + prestacionesPatron + gmpPatron + rt + invalidezVidaPatron + guarderias + exccedenteTrabajador + prestacionesTrabajador + gmpTrabajador + invalidezVidaTrabajador
  FROM @cedulaMensual AS cedulaMensual
       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaMensual.empresa
  WHERE --empresa = @empresa
        --AND 
		tipo = 2
        
  UPDATE cedulaMensual
  SET cuentaEmpleado = 1
  FROM @cedulaMensual AS cedulaMensual
       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaMensual.empresa AND CASE WHEN @EsMultiple > 0 THEN '' ELSE tdp.rpu END = CASE WHEN @EsMultiple > 0 THEN '' ELSE cedulaMensual.rpu END
  WHERE --cedulaMensual.empresa = @empresa
        --AND --cedulaMensual.codigo + cedulaMensual.consecutivo 
            CASE WHEN @EsRpuEspecial = 1
                 THEN cedulaMensual.rpu 
                 ELSE '' 
            END + RIGHT(100000000 + cedulaMensual.codigo,8) + RIGHT(100000000 + cedulaMensual.consecutivo,8) 
           = (SELECT TOP 1
                     --cedulaMensual2.codigo + cedulaMensual2.consecutivo
                     CASE WHEN @EsRpuEspecial = 1
                          THEN cedulaMensual2.rpu 
                          ELSE '' 
                     END + RIGHT(100000000 + cedulaMensual2.codigo,8) + RIGHT(100000000 + cedulaMensual2.consecutivo,8) 
              FROM @cedulaMensual AS cedulaMensual2
              WHERE cedulaMensual2.empresa = cedulaMensual.empresa
                    AND cedulaMensual2.tipo > 1
                    AND cedulaMensual2.codigo = cedulaMensual.codigo
                    AND CASE WHEN @EsRpuEspecial = 1
                             THEN cedulaMensual2.rpu 
                             ELSE '' 
                        END = CASE WHEN @EsRpuEspecial = 1
                                   THEN cedulaMensual.rpu 
                                   ELSE '' 
                              END)

  UPDATE cedulaMensual
  SET cedulaMensual.serial = cedulaMensual.serial1
  FROM  (SELECT TOP 2147483647
                serial
                , ROW_NUMBER() OVER (PARTITION BY cedulaMensual.empresa
												  , cedulaMensual.rpu
                                     ORDER BY cedulaMensual.empresa
									          , cedulaMensual.rpu
									          , cedulaMensual.ap_paterno
                                              , cedulaMensual.ap_materno
                                              , cedulaMensual.nombre 
                                              , cedulaMensual.tipo 				
											 ) AS serial1
         FROM @cedulaMensual AS cedulaMensual
		      INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaMensual.empresa AND CASE WHEN @EsMultiple > 0  THEN '' ELSE tdp.rpu END = CASE WHEN @EsMultiple > 0  THEN '' ELSE cedulaMensual.rpu END
         ORDER BY cedulaMensual.empresa
                  , cedulaMensual.rpu
                  , cedulaMensual.ap_paterno
                  , cedulaMensual.ap_materno
                  , cedulaMensual.nombre 
                  , cedulaMensual.tipo 				
        ) AS cedulaMensual

  UPDATE RpuPatron
  SET RpuPatron.registros = cedulaMensual.registros
      , RpuPatron.altas   = cedulaMensual.altas
      , RpuPatron.bajas   = cedulaMensual.bajas
      , RpuPatron.ms      = cedulaMensual.ms
  FROM @TblDatosPatron AS RpuPatron
      CROSS APPLY (SELECT COUNT(DISTINCT cedulaMensual.codigo) AS registros
                          , COUNT(CASE WHEN cedulaMensual.mov = 'A' OR cedulaMensual.mov = 'R' THEN 1 ELSE NULL END) AS altas
                          , COUNT(CASE WHEN cedulaMensual.mov = 'B' THEN 1 ELSE NULL END) AS bajas
                          , COUNT(CASE WHEN cedulaMensual.mov = 'M/S' THEN 1 ELSE NULL END) AS ms
                   FROM @cedulaMensual AS cedulaMensual
                   WHERE cedulaMensual.empresa = RpuPatron.empresa
                         AND CASE WHEN @EsMultiple > 0
				                  THEN ''
			                      ELSE CASE WHEN @EsRpu = 'S' 
			                                THEN ISNULL(cedulaMensual.rpu, @Rpu) 
                                            ELSE @Rpu 
	                                   END
                             END = CASE WHEN @EsMultiple > 0
						                THEN ''
				                        ELSE RpuPatron.rpu
	                               END
                  ) AS cedulaMensual

  UPDATE cedulaMensual
  SET cedulaMensual.finGrupo = cedulaMensual.empresa
  FROM @cedulaMensual AS cedulaMensual
       INNER JOIN @TblDatosPatron AS tdp ON tdp.empresa = cedulaMensual.empresa AND CASE WHEN @EsMultiple > 0 THEN '' ELSE tdp.rpu END = CASE WHEN @EsMultiple > 0 THEN '' ELSE cedulaMensual.rpu END
       CROSS APPLY (SELECT MAX(cedulaMensual2.serial) AS serial
                    FROM @cedulaMensual AS cedulaMensual2
                    WHERE cedulaMensual2.empresa = cedulaMensual.empresa
                          AND CASE WHEN @EsMultiple > 0
				                   THEN ''
			                       ELSE CASE WHEN @EsRpu = 'S' 
			                                 THEN ISNULL(cedulaMensual2.rpu, @Rpu) 
                                             ELSE @Rpu 
	                                   END
                              END = CASE WHEN @EsMultiple > 0
						                 THEN ''
				                         ELSE CASE WHEN @EsRpu = 'S' 
										           THEN tdp.rpu
                                                   ELSE @Rpu
											  END
	                                END
                   ) AS cedulaMensual2
  WHERE cedulaMensual.serial = cedulaMensual2.serial

    IF @cedula = 'CedulaMensual11'
       OR @cedula = 'CedulaMensual12'
       OR @cedula = 'CedulaMensual14'
       OR @cedula = 'CedulaMensual15'
       OR @cedula = 'CedulaMensual17'
	   OR @cedula = 'CedulaMensual11_RpuEspecial'
       BEGIN
         SELECT cedulaMensual.codigo ,
                cedulaMensual.nombre ,
                cedulaMensual.ap_paterno ,
                cedulaMensual.ap_materno ,
                cedulaMensual.afiliacion ,
                cedulaMensual.digvera ,
                cedulaMensual.curp ,
                cedulaMensual.art39 ,
                cedulaMensual.jornada ,
                cedulaMensual.rfcalfa ,
                cedulaMensual.rfcnum ,
                cedulaMensual.rfchomo ,
                CASE WHEN cedulaMensual.mov = ' ' THEN NULL ELSE cedulaMensual.fch_mov END AS fch_mov ,
                cedulaMensual.mov ,
                CASE WHEN cedulaMensual.mov <> 'B' THEN cedulaMensual.salario ELSE NULL END AS salario ,
                CASE WHEN (cedulaMensual.diastr = 0 OR cedulaMensual.diastr IS NULL) AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov IS NULL OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.diastr END AS diastr ,
                CASE WHEN (cedulaMensual.diastr = 0 OR cedulaMensual.diastr IS NULL) AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov IS NULL OR cedulaMensual.mov = 'B') THEN NULL ELSE CASE WHEN ISNULL(cedulaMensual.incap,0) - ISNULL(cedulaMensual.lic,0) = 0 THEN NULL ELSE ISNULL(cedulaMensual.incap,0) - ISNULL(cedulaMensual.lic,0) END END AS incap ,
                CASE WHEN (cedulaMensual.diastr = 0 OR cedulaMensual.diastr IS NULL) AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov IS NULL OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.ausen END AS ausen ,
                cedulaMensual.primaRT ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.cuotaFija END AS cuotaFija ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.excedente END AS excedente ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.excedentePatron END AS excedentePatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.exccedenteTrabajador END AS exccedenteTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.prestacionesDinero END AS prestacionesDinero ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.prestacionesPatron END AS prestacionesPatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.prestacionesTrabajador END AS prestacionesTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.gmp END AS gmp ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.gmpPatron END AS gmpPatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.gmpTrabajador END AS gmpTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.rt END AS rt ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.invalidezVida END AS invalidezVida ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.invalidezVidaPatron END AS invalidezVidaPatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.invalidezVidaTrabajador END AS invalidezVidaTrabajador ,
                CASE WHEN cedulaMensual.diastr = 0 AND ( cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.guarderias END AS guarderias ,
                cedulaMensual.numeroIncapacidad ,
                cedulaMensual.nombreConcepto ,
                cedulaMensual.tipo ,
                cedulaMensual.tieneArt33 ,
                cedulaMensual.tieneSemanaReducida ,
                cedulaMensual.tienejornadaReducida ,
                CASE WHEN CedulaMensual.serial = 1 THEN cedulaMensual.salarioRegion ELSE NULL END AS salarioRegion,
                CASE WHEN CedulaMensual.serial = 1 THEN cedulaMensual.salarioDF ELSE NULL END AS salarioDF,
                RTRIM(cedulaMensual.rfcalfa) + cedulaMensual.rfcnum + RTRIM(cedulaMensual.rfchomo) AS RFC ,
                RTRIM(cedulaMensual.rfcalfa) + '-' + cedulaMensual.rfcnum + '-' + RTRIM(cedulaMensual.rfchomo) AS RFCGuion ,
                CASE WHEN cedulaMensual.diastr = 0 AND ( cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.sumaPrimas END AS sumaPrimas ,
                cedulaMensual.cuentaEmpleado ,
                cedulaMensual.pensionEmpleado ,
                cedulaMensual.jornadaEmpleado ,
                cedulaMensual.articulo33Empleado ,
                cedulaMensual.diaFalta ,
                CASE WHEN ISNULL(cedulaMensual.diaIncapacidad,0) - ISNULL(cedulaMensual.diaLicencia,0) = 0 THEN NULL ELSE ISNULL(cedulaMensual.diaIncapacidad,0) - ISNULL(cedulaMensual.diaLicencia,0) END AS diaIncapacidad,
                cedulaMensual.sumaPrimasPatron ,
                cedulaMensual.sumaPrimasTrabajador ,
                cedulaMensual.sumaPrimasPatronMasTrabajador ,
                CASE WHEN (@cedula = 'CedulaMensual11' AND @EsRpu = 'S') OR @EsMultiple > 0 THEN cedulaMensual.rpu ELSE NULL END AS rpu ,
                CASE WHEN @cedula = 'CedulaMensual11' AND @EsRpu = 'S' THEN RpuPatron.nombre ELSE NULL END AS nombreMunicipio ,
                RpuPatron.referencia AS referenciaMunicipio ,
                CASE WHEN @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN cedulaMensual.centro ELSE NULL END AS centro,
                CASE WHEN @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN cedulaMensual.centroNombre ELSE NULL END AS centroNombre,
                cedulaMensual.tipoNomina ,
                cedulaMensual.manoObra,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.cesantiaVejez END AS cesantiaVejez ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.cesantiaVejezPatron END AS cesantiaVejezPatron ,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.cesantiaVejezTrabajador END AS cesantiaVejezTrabajador,
                CASE WHEN cedulaMensual.diastr = 0 AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.aportacionInfonavit END AS aportacionInfonavit,
                folioObra,
                nombreObra,
                fechaInicioObra,
                fechaFinObra,
                diasObra,
                CASE WHEN (cedulaMensual.diastr = 0 OR cedulaMensual.diastr IS NULL) AND (cedulaMensual.mov = ' ' OR cedulaMensual.mov IS NULL OR cedulaMensual.mov = 'B') THEN NULL ELSE cedulaMensual.lic END AS lic ,
                ISNULL(cedulaMensual.diaLicencia,0) AS diaLicencia,
				serial,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.reg_pat IS NULL THEN RpuPatronAnterior.reg_pat ELSE RpuPatron.reg_pat END AS reg_pat,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.nombre IS NULL THEN RpuPatronAnterior.nombre ELSE RpuPatron.nombre END AS nombreEmpresa,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.referencia IS NULL THEN RpuPatronAnterior.referencia ELSE RpuPatron.referencia END AS referencia,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.direccion IS NULL THEN RpuPatronAnterior.direccion ELSE RpuPatron.direccion END AS direccion, 
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.colonia IS NULL THEN RpuPatronAnterior.colonia ELSE RpuPatron.colonia END AS colonia,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.poblacion IS NULL THEN RpuPatronAnterior.poblacion ELSE RpuPatron.poblacion END AS poblacion,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.zona_geografica IS NULL THEN RpuPatronAnterior.zona_geografica ELSE RpuPatron.zona_geografica END AS zona_geografica,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.actividad IS NULL THEN RpuPatronAnterior.actividad ELSE RpuPatron.actividad END AS actividad,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.cod_postal IS NULL THEN RpuPatronAnterior.cod_postal ELSE RpuPatron.cod_postal END AS cod_postal,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.prima_rt IS NULL THEN RpuPatronAnterior.prima_rt ELSE RpuPatron.prima_rt END AS prima_rt,
                CASE WHEN cedulaMensual.finGrupo > 0 AND NOT RpuPatronAnterior.rfc IS NULL THEN RpuPatronAnterior.rfc ELSE RpuPatron.rfc END AS rfcEmpresa,
                RpuPatron.registros,
                RpuPatron.altas,
                RpuPatron.bajas,
                RpuPatron.ms,
				cedulaMensual.finGrupo
		 FROM @cedulaMensual AS cedulaMensual
              CROSS APPLY (SELECT TOP 1
                                    CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.reg_pat ELSE NULL END AS reg_pat
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.nombre ELSE NULL END AS nombre
                                  , CASE WHEN CedulaMensual.serial = 1 THEN ISNULL(RpuPatron.referencia, RpuPatron.nombre) ELSE NULL END AS referencia
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.direccion ELSE NULL END AS direccion
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.colonia ELSE NULL END AS colonia
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.poblacion ELSE NULL END AS poblacion
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.zona_geografica ELSE NULL END AS zona_geografica
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.actividad ELSE NULL END AS actividad
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.cod_postal ELSE NULL END AS cod_postal
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.prima_rt ELSE NULL END AS prima_rt
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.rfc ELSE NULL END AS rfc
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.registros       ELSE 0    END AS registros
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.altas           ELSE NULL END AS altas
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.bajas           ELSE NULL END AS bajas
                                  , CASE WHEN CedulaMensual.serial = 1 THEN RpuPatron.ms              ELSE NULL END AS ms
                           FROM @TblDatosPatron AS RpuPatron
						   --WHERE RpuPatron.empresa = cedulaMensual.empresa
                           --      AND CASE WHEN @EsMultiple > 0
                           --               THEN ''
                           --               ELSE RpuPatron.rpu
                           --          END = CASE WHEN @EsMultiple > 0
                           --                     THEN ''
                           --                     ELSE CASE WHEN @EsRpu = 'S' 
                           --                               THEN ISNULL(cedulaMensual.rpu, @Rpu) 
                           --                               ELSE @Rpu 
                           --                          END
                           --                END
                           WHERE CASE WHEN @EsMultiple > 0
                                      THEN LTRIM(RTRIM(STR(RpuPatron.empresa)))
                                      ELSE RpuPatron.rpu
                                 END = CASE WHEN @EsMultiple > 0
                                            THEN LTRIM(RTRIM(STR(cedulaMensual.empresa)))
                                            ELSE CASE WHEN @EsRpu = 'S' 
                                                      THEN ISNULL(cedulaMensual.rpu, @Rpu) 
                                                      ELSE @Rpu 
                                                 END
                                       END
                          ) AS RpuPatron

              OUTER APPLY (SELECT TOP 1
                                    RpuPatronAnterior.reg_pat         
                                  , RpuPatronAnterior.nombre          
                                  , RpuPatronAnterior.referencia      
                                  , RpuPatronAnterior.direccion       
                                  , RpuPatronAnterior.colonia         
                                  , RpuPatronAnterior.poblacion       
                                  , RpuPatronAnterior.zona_geografica 
                                  , RpuPatronAnterior.actividad       
                                  , RpuPatronAnterior.cod_postal      
                                  , RpuPatronAnterior.prima_rt        
                                  , RpuPatronAnterior.rfc             
                           FROM @TblDatosPatron AS RpuPatronAnterior
                           --WHERE (RpuPatronAnterior.empresa > cedulaMensual.empresa
						   --       OR CASE WHEN @EsMultiple > 0
                           --               THEN ''
                           --               ELSE RpuPatronAnterior.rpu
                           --          END > CASE WHEN @EsMultiple > 0
                           --                     THEN ''
                           --                     ELSE CASE WHEN @EsRpu = 'S' 
                           --                               THEN ISNULL(cedulaMensual.rpu, @Rpu) 
                           --                               ELSE @Rpu 
                           --                          END
                           --                END)
                           --      AND cedulaMensual.finGrupo > 0
                           WHERE CASE WHEN @EsMultiple > 0
                                      THEN LTRIM(RTRIM(STR(RpuPatronAnterior.empresa)))
                                      ELSE RpuPatronAnterior.rpu
                                 END > CASE WHEN @EsMultiple > 0
                                            THEN LTRIM(RTRIM(STR(cedulaMensual.empresa)))
                                            ELSE CASE WHEN @EsRpu = 'S' 
                                                      THEN ISNULL(cedulaMensual.rpu, @Rpu) 
                                                      ELSE @Rpu 
                                                 END
                                       END
                                 AND cedulaMensual.finGrupo > 0
                           ORDER BY RpuPatronAnterior.empresa ASC
                                    , RpuPatronAnterior.rpu ASC
                          ) AS RpuPatronAnterior

         WHERE   cedulaMensual.tipo > @tipo
--AND (cedulaMensual.serial = 1 OR  cedulaMensual.finGrupo > 0)

         ORDER BY cedulaMensual.empresa ,
                  CASE WHEN @cedula = 'CedulaMensual11' AND @EsRpu = 'S' THEN cedulaMensual.rpu ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' THEN cedulaMensual.centro ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' OR @cedula = 'CedulaMensual11_RpuEspecial' THEN cedulaMensual.ap_paterno ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' OR @cedula = 'CedulaMensual11_RpuEspecial' THEN cedulaMensual.ap_materno ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' OR @cedula = 'CedulaMensual11_RpuEspecial' THEN cedulaMensual.nombre ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' OR @cedula = 'CedulaMensual11_RpuEspecial' THEN cedulaMensual.afiliacion ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' OR @cedula = 'CedulaMensual11_RpuEspecial' THEN cedulaMensual.digvera ELSE NULL END,
                  CASE WHEN @cedula = 'CedulaMensual11' OR @cedula = 'CedulaMensual12' OR @cedula = 'CedulaMensual14' OR @cedula = 'CedulaMensual15' OR @cedula = 'CedulaMensual17' OR @cedula = 'CedulaMensual11_RpuEspecial' THEN cedulaMensual.tipo ELSE NULL END
       END

    IF @cedula = 'CedulaMensual13'
       OR @cedula = 'CedulaMensual16'
       BEGIN
         SELECT cedulaMensual.centro ,
                cedulaMensual.centroNombre ,
                '' AS primaRT ,  -- primaRT,
                SUM(ISNULL(cedulaMensual.cuentaEmpleado,0)) AS empleado ,
                SUM(ISNULL(cedulaMensual.cuotaFija,0)) AS cuotaFija ,
                SUM(ISNULL(cedulaMensual.excedente,0)) AS excedente ,
                SUM(ISNULL(cedulaMensual.prestacionesDinero,0)) AS prestacionesDinero ,
                SUM(ISNULL(cedulaMensual.gmp,0)) AS gmp ,
                SUM(ISNULL(cedulaMensual.rt,0)) AS rt ,
                SUM(ISNULL(cedulaMensual.invalidezVida,0)) AS invalidezVida ,
                SUM(ISNULL(cedulaMensual.guarderias,0)) AS guarderias ,
                SUM(ISNULL(cedulaMensual.sumaPrimas,0)) AS sumaPrimas,
                SUM(ISNULL(cedulaMensual.excedentePatron,0)) AS excedentePatron ,
                SUM(ISNULL(cedulaMensual.exccedenteTrabajador,0)) AS exccedenteTrabajador ,
                SUM(ISNULL(cedulaMensual.prestacionesPatron,0)) AS prestacionesPatron ,
                SUM(ISNULL(cedulaMensual.prestacionesTrabajador,0)) AS prestacionesTrabajador ,
                SUM(ISNULL(cedulaMensual.gmpPatron,0)) AS gmpPatron ,
                SUM(ISNULL(cedulaMensual.gmpTrabajador,0)) AS gmpTrabajador ,
                SUM(ISNULL(cedulaMensual.invalidezVidaPatron,0)) AS invalidezVidaPatron ,
                SUM(ISNULL(cedulaMensual.invalidezVidaTrabajador,0)) AS invalidezVidaTrabajador ,
                SUM(ISNULL(cedulaMensual.sumaPrimasPatron,0)) AS sumaPrimasPatron,
                SUM(ISNULL(cedulaMensual.sumaPrimasTrabajador,0)) AS sumaPrimasTrabajador,
                SUM(ISNULL(cedulaMensual.sumaPrimasPatronMasTrabajador,0)) AS sumaPrimasPatronMasTrabajador,
                SUM(ISNULL(cedulaMensual.cesantiaVejezPatron,0)) AS cesantiaVejezPatron,
                SUM(ISNULL(cedulaMensual.cesantiaVejezTrabajador,0)) AS cesantiaVejezTrabajador,
				cedulaMensual.empresa,
				CASE WHEN primerCentro.centro = cedulaMensual.centro THEN 1 ELSE 0 END AS serial,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.reg_pat IS NULL THEN RpuPatronAnterior.reg_pat ELSE RpuPatron.reg_pat END AS reg_pat,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.nombre IS NULL THEN RpuPatronAnterior.nombre ELSE RpuPatron.nombre END AS nombreEmpresa,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.referencia IS NULL THEN RpuPatronAnterior.referencia ELSE RpuPatron.referencia END AS referencia,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.direccion IS NULL THEN RpuPatronAnterior.direccion ELSE RpuPatron.direccion END AS direccion, 
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.colonia IS NULL THEN RpuPatronAnterior.colonia ELSE RpuPatron.colonia END AS colonia,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.poblacion IS NULL THEN RpuPatronAnterior.poblacion ELSE RpuPatron.poblacion END AS poblacion,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.zona_geografica IS NULL THEN RpuPatronAnterior.zona_geografica ELSE RpuPatron.zona_geografica END AS zona_geografica,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.actividad IS NULL THEN RpuPatronAnterior.actividad ELSE RpuPatron.actividad END AS actividad,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.cod_postal IS NULL THEN RpuPatronAnterior.cod_postal ELSE RpuPatron.cod_postal END AS cod_postal,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.prima_rt IS NULL THEN RpuPatronAnterior.prima_rt ELSE RpuPatron.prima_rt END AS prima_rt,
                CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.rfc IS NULL THEN RpuPatronAnterior.rfc ELSE RpuPatron.rfc END AS rfcEmpresa,
				CASE WHEN ultimoCentro.centro = cedulaMensual.centro THEN 1 ELSE 0 END AS finGrupo
				
		 FROM @cedulaMensual AS cedulaMensual
		      CROSS APPLY (SELECT MIN(cedulaMensualcc.centro) AS centro
                           FROM  @cedulaMensual AS cedulaMensualcc) AS primerCentro
		      CROSS APPLY (SELECT MAX(cedulaMensualcc.centro) AS centro
                           FROM  @cedulaMensual AS cedulaMensualcc) AS ultimoCentro

		      
              CROSS APPLY (SELECT TOP 1
                                    CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.reg_pat ELSE NULL END AS reg_pat
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.nombre ELSE NULL END AS nombre
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN ISNULL(RpuPatron.referencia, RpuPatron.nombre) ELSE NULL END AS referencia
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.direccion ELSE NULL END AS direccion
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.colonia ELSE NULL END AS colonia
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.poblacion ELSE NULL END AS poblacion
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.zona_geografica ELSE NULL END AS zona_geografica
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.actividad ELSE NULL END AS actividad
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.cod_postal ELSE NULL END AS cod_postal
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.prima_rt ELSE NULL END AS prima_rt
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.rfc ELSE NULL END AS rfc
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.registros       ELSE 0    END AS registros
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.altas           ELSE NULL END AS altas
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.bajas           ELSE NULL END AS bajas
                                  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN RpuPatron.ms              ELSE NULL END AS ms
                           FROM @TblDatosPatron AS RpuPatron
						   WHERE RpuPatron.empresa = cedulaMensual.empresa
                                 AND CASE WHEN @EsMultiple > 0
                                          THEN ''
                                          ELSE RpuPatron.rpu
                                     END = CASE WHEN @EsMultiple > 0
                                                THEN ''
                                                ELSE CASE WHEN @EsRpu = 'S' 
                                                          THEN ISNULL(cedulaMensual.rpu, @Rpu) 
                                                          ELSE @Rpu 
                                                     END
                                           END) AS RpuPatron
              
              OUTER APPLY (SELECT TOP 1
                                    RpuPatronAnterior.reg_pat         
                                  , RpuPatronAnterior.nombre          
                                  , RpuPatronAnterior.referencia      
                                  , RpuPatronAnterior.direccion       
                                  , RpuPatronAnterior.colonia         
                                  , RpuPatronAnterior.poblacion       
                                  , RpuPatronAnterior.zona_geografica 
                                  , RpuPatronAnterior.actividad       
                                  , RpuPatronAnterior.cod_postal      
                                  , RpuPatronAnterior.prima_rt        
                                  , RpuPatronAnterior.rfc             
                           FROM @TblDatosPatron AS RpuPatronAnterior
                           WHERE (RpuPatronAnterior.empresa > cedulaMensual.empresa
						          OR CASE WHEN @EsMultiple > 0
                                          THEN ''
                                          ELSE RpuPatronAnterior.rpu
                                     END > CASE WHEN @EsMultiple > 0
                                                THEN ''
                                                ELSE CASE WHEN @EsRpu = 'S' 
                                                          THEN ISNULL(cedulaMensual.rpu, @Rpu) 
                                                          ELSE @Rpu 
                                                     END
                                           END)
                                 AND ultimoCentro.centro = cedulaMensual.centro
                           ORDER BY RpuPatronAnterior.empresa ASC
                                    , RpuPatronAnterior.rpu ASC
                          ) AS RpuPatronAnterior

              
         WHERE cedulaMensual.tipo = 2
         GROUP BY cedulaMensual.empresa
                  , cedulaMensual.centro
                  , cedulaMensual.centroNombre
				  , CASE WHEN primerCentro.centro = cedulaMensual.centro THEN 1 ELSE 0 END
				  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro THEN 1 ELSE 0 END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.reg_pat IS NULL THEN RpuPatronAnterior.reg_pat ELSE RpuPatron.reg_pat END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.nombre IS NULL THEN RpuPatronAnterior.nombre ELSE RpuPatron.nombre END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.referencia IS NULL THEN RpuPatronAnterior.referencia ELSE RpuPatron.referencia END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.direccion IS NULL THEN RpuPatronAnterior.direccion ELSE RpuPatron.direccion END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.colonia IS NULL THEN RpuPatronAnterior.colonia ELSE RpuPatron.colonia END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.poblacion IS NULL THEN RpuPatronAnterior.poblacion ELSE RpuPatron.poblacion END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.zona_geografica IS NULL THEN RpuPatronAnterior.zona_geografica ELSE RpuPatron.zona_geografica END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.actividad IS NULL THEN RpuPatronAnterior.actividad ELSE RpuPatron.actividad END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.cod_postal IS NULL THEN RpuPatronAnterior.cod_postal ELSE RpuPatron.cod_postal END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.prima_rt IS NULL THEN RpuPatronAnterior.prima_rt ELSE RpuPatron.prima_rt END
                  , CASE WHEN ultimoCentro.centro = cedulaMensual.centro AND NOT RpuPatronAnterior.rfc IS NULL THEN RpuPatronAnterior.rfc ELSE RpuPatron.rfc END
				
         ORDER BY cedulaMensual.empresa
                  , cedulaMensual.centro
       END
GO

IF OBJECT_ID('dbo.ChecaAccesoEmpleado') IS NOT NULL 
    DROP PROCEDURE dbo.ChecaAccesoEmpleado
GO
CREATE PROCEDURE dbo.ChecaAccesoEmpleado
    @empresa INT ,
    @codigo INT ,
    @nss VARCHAR(10) ,
    @digitoVerificador VARCHAR(1) ,
    @apellidoPaterno VARCHAR(30) ,
    @apellidoMaterno VARCHAR(30) ,
    @nombre VARCHAR(30) ,
    @usuario VARCHAR(50)
AS 
    SET NOCOUNT ON 

    DECLARE @existeEmpleado INT
    DECLARE @tieneAcceso INT
    DECLARE @centroCostoEmpleado VARCHAR(50)
    DECLARE @tipoNominaEmpleado INT
    DECLARE @sistema VARCHAR(50)

    SET @centroCostoEmpleado = ''
    SET @tipoNominaEmpleado = 0
    SET @sistema = 'NO'

    IF EXISTS ( SELECT  dbo.empleados.codigo
                FROM    dbo.empleados
                WHERE   dbo.empleados.empresa = @empresa
                        AND ( dbo.empleados.codigo = @codigo
                              OR ( dbo.empleados.afiliacion = @nss
                                   AND dbo.empleados.digvera = @digitoVerificador
                                 )
                              OR ( dbo.empleados.ap_paterno = @apellidoPaterno
                                   AND dbo.empleados.ap_materno = @apellidoMaterno
                                   AND dbo.empleados.nombre = @nombre
                                 )
                            ) ) 
        BEGIN
        -- Existe Empleado
            SET @existeEmpleado = 1
        END
    ELSE 
        BEGIN
        -- NO Existe Empleado
            SET @existeEmpleado = 0
        END

    IF @existeEmpleado = 1 
        BEGIN
            IF EXISTS ( SELECT  dbo.empleados.codigo
                        FROM    dbo.empleados
                                INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                         AND dbo.empleados.codigo = dbo.Llaves.codigo
                        WHERE   dbo.empleados.empresa = @empresa
                                AND ( dbo.empleados.codigo = @codigo
                                      OR ( dbo.empleados.afiliacion = @nss
                                           AND dbo.empleados.digvera = @digitoVerificador
                                         )
                                      OR ( dbo.empleados.ap_paterno = @apellidoPaterno
                                           AND dbo.empleados.ap_materno = @apellidoMaterno
                                           AND dbo.empleados.nombre = @nombre
                                         )
                                    )
                                AND dbo.Llaves.centro IN (
                                SELECT  costCenter
                                FROM    [dbo].[GetCostCenterByProfile](@usuario,
                                                              dbo.Llaves.centro,
															  --@centroCostoEmpleado,
                                                              @empresa,
                                                              @sistema) )
                                AND dbo.Llaves.tiponom IN (
                                SELECT  typePayroll
                                FROM    [dbo].[GetTypePayrollByProfile](@usuario,
                                                              dbo.Llaves.tiponom,
															  --@tipoNominaEmpleado,
                                                              @empresa,
                                                              @sistema) ) ) 
                BEGIN
                    SET @tieneAcceso = 1
                END
            ELSE 
                SET @tieneAcceso = 0
        END
    ELSE 
        BEGIN
            SET @tieneAcceso = 2
        END
    
    SELECT  ISNULL(@tieneAcceso, 0) AS accesoEmpleado
GO

IF OBJECT_ID('dbo.ChecaBanco') IS NOT NULL
   DROP PROCEDURE dbo.ChecaBanco
GO
CREATE PROCEDURE dbo.ChecaBanco
@banco INT

AS

DECLARE @existeBanco INT

IF EXISTS (SELECT dbo.bancos.banco
           FROM dbo.bancos
           WHERE dbo.bancos.banco = @banco)
   SET @existeBanco = 1
ELSE
   SET @existeBanco = 0

SELECT @existeBanco AS existeBanco
GO

IF OBJECT_ID('dbo.ChecaCentroCostos') IS NOT NULL
   DROP PROCEDURE dbo.ChecaCentroCostos
GO
CREATE PROCEDURE dbo.ChecaCentroCostos
@empresa INT ,
@centroCostos VARCHAR(15)

AS

DECLARE @existeCentroCosto INT

IF EXISTS (SELECT dbo.centros.centro
           FROM dbo.centros
           WHERE dbo.centros.empresa = @empresa
                 AND RTRIM(LTRIM(dbo.centros.centro)) = RTRIM(LTRIM(@centroCostos)))
   SET @existeCentroCosto = 1
ELSE
   SET @existeCentroCosto = 0

SELECT @existeCentroCosto AS existeCentroCosto
GO

IF OBJECT_ID('dbo.ChecaClase') IS NOT NULL
   DROP PROCEDURE dbo.ChecaClase
GO
CREATE PROCEDURE dbo.ChecaClase
@empresa INT ,
@clase VARCHAR(2)

AS

DECLARE @existeClase INT

IF EXISTS (SELECT dbo.clases.clase
           FROM dbo.clases
           WHERE dbo.clases.empresa = @empresa
                 AND dbo.clases.clase = @clase)
   SET @existeClase = 1
ELSE
   SET @existeClase = 0

SELECT @existeClase AS existeClase
GO

IF OBJECT_ID('dbo.ChecaEmpleado') IS NOT NULL 
    DROP PROCEDURE dbo.ChecaEmpleado
GO
CREATE PROCEDURE dbo.ChecaEmpleado
    @empresa INT ,
    @codigo INT ,
    @nss VARCHAR(10) ,
    @digitoVerificador VARCHAR(1) ,
    @apellidoPaterno VARCHAR(30) ,
    @apellidoMaterno VARCHAR(30) ,
    @nombre VARCHAR(30)
AS 
    DECLARE @existeEmpleado INT

    IF @codigo > 0 
        IF EXISTS ( SELECT  dbo.empleados.codigo
                    FROM    dbo.empleados
                    WHERE   dbo.empleados.empresa = @empresa
                            AND dbo.empleados.codigo = @codigo ) 
            SET @existeEmpleado = 1
        ELSE 
            SET @existeEmpleado = 0
    ELSE 
        IF LEN(@nss + @digitoVerificador) > 0 
            IF EXISTS ( SELECT  dbo.empleados.codigo
                        FROM    dbo.empleados
                        WHERE   dbo.empleados.empresa = @empresa
                                AND dbo.empleados.afiliacion
                                + dbo.empleados.digvera = @nss
                                + @digitoVerificador ) 
                SET @existeEmpleado = 1
            ELSE 
                SET @existeEmpleado = 0
        ELSE 
            IF LEN(@apellidoPaterno + @apellidoMaterno + @nombre) > 0 
                IF EXISTS ( SELECT  dbo.empleados.codigo
                            FROM    dbo.empleados
                            WHERE   dbo.empleados.empresa = @empresa
                                    AND RTRIM(LTRIM(dbo.empleados.ap_paterno))
                                    + RTRIM(LTRIM(dbo.empleados.ap_materno))
                                    + RTRIM(LTRIM(dbo.empleados.nombre)) = RTRIM(LTRIM(@apellidoPaterno))
                                    + RTRIM(LTRIM(@apellidoMaterno))
                                    + RTRIM(LTRIM(@nombre)) ) 
                    SET @existeEmpleado = 1
                ELSE 
                    SET @existeEmpleado = 0

    SELECT  @existeEmpleado AS existeEmpleado
GO

IF OBJECT_ID('dbo.ChecaHorario') IS NOT NULL
   DROP PROCEDURE dbo.ChecaHorario
GO
CREATE PROCEDURE dbo.ChecaHorario
@empresa INT ,
@horario INT

AS

DECLARE @existeHorario INT

IF EXISTS (SELECT dbo.horarios_catalogo.horario
           FROM dbo.horarios_catalogo
           WHERE dbo.horarios_catalogo.empresa = @empresa
                 AND dbo.horarios_catalogo.horario = @horario)
   SET @existeHorario = 1
ELSE
   SET @existeHorario = 0

SELECT @existeHorario AS existeHorario
GO

IF OBJECT_ID('dbo.ChecaSupervisor') IS NOT NULL
   DROP PROCEDURE dbo.ChecaSupervisor
GO
CREATE PROCEDURE dbo.ChecaSupervisor
@empresa INT ,
@supervisor INT

AS

DECLARE @existeSupervisor INT

IF EXISTS (SELECT dbo.supervisores.supervisor
           FROM dbo.supervisores
           WHERE dbo.supervisores.empresa = @empresa
                 AND dbo.supervisores.supervisor = @supervisor)
   SET @existeSupervisor = 1
ELSE
   SET @existeSupervisor = 0

SELECT @existeSupervisor AS existeSupervisor
GO

IF OBJECT_ID('dbo.ChecaTabulador') IS NOT NULL
   DROP PROCEDURE dbo.ChecaTabulador
GO
CREATE PROCEDURE dbo.ChecaTabulador
@empresa INT ,
@tabulador INT

AS

DECLARE @existeTabulador INT

IF EXISTS (SELECT dbo.tabulador.ocupacion
           FROM dbo.tabulador
           WHERE dbo.tabulador.empresa = @empresa
                 AND dbo.tabulador.ocupacion = @tabulador)
   SET @existeTabulador = 1
ELSE
   SET @existeTabulador = 0

SELECT @existeTabulador AS existeTabulador
GO

IF OBJECT_ID('dbo.ChecaTipoContrato') IS NOT NULL
   DROP PROCEDURE dbo.ChecaTipoContrato
GO
CREATE PROCEDURE dbo.ChecaTipoContrato
@tipoContrato INT

AS

DECLARE @existeTipoContrato INT

IF EXISTS (SELECT dbo.CatalogoTipoContrato.idClave
           FROM dbo.CatalogoTipoContrato
           WHERE dbo.CatalogoTipoContrato.idClave = @tipoContrato)
   SET @existeTipoContrato = 1
ELSE
   SET @existeTipoContrato = 0

SELECT @existeTipoContrato AS existeTipoContrato
GO

IF OBJECT_ID('dbo.ChecaTipoRegimen') IS NOT NULL
   DROP PROCEDURE dbo.ChecaTipoRegimen
GO
CREATE PROCEDURE dbo.ChecaTipoRegimen
@tipoRegimen INT

AS

DECLARE @existeTipoRegimen INT

IF EXISTS (SELECT dbo.CatalogoRegimenContratacionTrabajador.idClave
           FROM dbo.CatalogoRegimenContratacionTrabajador
           WHERE dbo.CatalogoRegimenContratacionTrabajador.idClave = @tipoRegimen)
   SET @existeTipoRegimen = 1
ELSE
   SET @existeTipoRegimen = 0

SELECT @existeTipoRegimen AS existeTipoRegimen
GO

/**************************************************************************************************
 * Name          : ComprobanteAfore
 * Project       : APSI Nomina
 * Description   : Calcula cedula bimestral de aportaciones IMSS
 * Table name    : empleados, avisos_imss, conceptos
 * Return        : tabla con la cedula bimestral
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 18, 2010
 **************************************************************************************************/

IF OBJECT_ID('dbo.ComprobanteAfore') IS NOT NULL 
    DROP PROCEDURE [dbo].[ComprobanteAfore]
GO

CREATE PROCEDURE [dbo].[ComprobanteAfore]
    @empresa NUMERIC(5) ,
    @ayo INT ,
    @mesNon INT ,
    @mesPar INT ,
    @procesoName VARCHAR(100) ,
    @headerComprobante INT ,
    @ordenNombre INT ,
    @ordenCodigo INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT
AS 
    DECLARE @case VARCHAR(250)
    SET @case = CASE @headerComprobante
                  WHEN 3
                  THEN 'calculoBimestre.codigo '
                       + CASE WHEN @ordenCodigo = 1 THEN 'ASC'
                              WHEN @ordenCodigo = 0 THEN 'DESC'
                              ELSE 'ASC'
                         END
                  WHEN 5
                  THEN 'calculoBimestre.ap_paterno + calculoBimestre.ap_materno + calculoBimestre.nombre '
                       + CASE WHEN @ordenNombre = 1 THEN 'ASC'
                              WHEN @ordenNombre = 0 THEN 'DESC'
                              ELSE 'ASC'
                         END
                  WHEN 7
                  THEN 'calculoBimestre.centro + STR(calculoBimestre.codigo) '
                       + CASE WHEN @ordenCodigo = 1 THEN 'ASC'
                              WHEN @ordenCodigo = 0 THEN 'DESC'
                              ELSE 'ASC'
                         END
                  WHEN 8
                  THEN 'calculoBimestre.centro + STR(calculoBimestre.codigo) '
                       + CASE WHEN @ordenCodigo = 1 THEN 'ASC'
                              WHEN @ordenCodigo = 0 THEN 'DESC'
                              ELSE 'ASC'
                         END
                  ELSE 'calculoBimestre.codigo '
                       + CASE WHEN @ordenCodigo = 1 THEN 'ASC'
                              WHEN @ordenCodigo = 0 THEN 'DESC'
                              ELSE 'ASC'
                         END
                END

    EXECUTE('SELECT  calculoBimestre.empresa ,
    calculoBimestre.codigo ,
    calculoBimestre.nombre ,
    calculoBimestre.ap_paterno ,
    calculoBimestre.ap_materno ,
    calculoBimestre.afiliacion ,
    calculoBimestre.digvera ,
    calculoBimestre.curp ,
    calculoBimestre.rfcalfa ,
    calculoBimestre.rfcnum ,
    calculoBimestre.rfchomo ,
    calculoBimestre.retiro ,
    calculoBimestre.cesantiaVejez ,
    calculoBimestre.aportacionInfonavit ,
    calculoBimestre.numeroCredito ,
    calculoBimestre.descuento ,
    calculoBimestre.amortizacion ,
    calculoBimestre.tipoCredito ,
    calculoBimestre.seguroVivienda ,
    calculoBimestre.fechaInicioDescuento ,
    calculoBimestre.fechaOtorgamiento ,
    calculoBimestre.fechaSuspension ,
    RTRIM(LTRIM(CONVERT(VARCHAR(9), calculoBimestre.descuento))) + '' ''
    + CASE calculoBimestre.tipoCredito
    WHEN 1 THEN ''%''
    WHEN 2 THEN ''C.F.''
    WHEN 3 THEN ''V.S.M.''
    END AS descuentoCedula ,
    calculoBimestre.cvArt168II ,
    calculoBimestre.seguroDesempleoCuota ,
    calculoBimestre.seguroDesempleoPorciento ,
    calculoBimestre.infonavitporciento
    FROM    [dbo].[LlenaComprobanteAfore](' + @empresa + ',' + @ayo + ',' + @mesNon + ',' + @mesPar + ',' +
    '''' + @procesoName + '''' + ',' + '''' + @proceso + '''' + ',' + '''' + @fechaProceso + '''' + ',' + '''' + @horaProceso + '''' + ',' + @simulaReforma + ') AS calculoBimestre
    ORDER BY calculoBimestre.empresa ,' +
    @case)
GO

IF OBJECT_ID('dbo.CatalogoSeguridadHigiene') IS NULL 
    CREATE TABLE dbo.SeguridadHigiene
        (
          Empresa INTEGER ,
          Codigo INTEGER ,
          Caso INTEGER ,
          Ayo_Operacion INTEGER ,
          LugarAccidente VARCHAR(1000) ,
          HoraAccidente CHAR(10) ,
          DanosMateriales VARCHAR(1000) ,
          LesionesAnteriores CHAR(1) ,
          DeclaracionAccidentado VARCHAR(2000) ,
          Testigo1 VARCHAR(50) ,
          Testigo2 VARCHAR(50) ,
          ClasificacionAccidente INTEGER ,
          DescripcionAccidente VARCHAR(2000) ,
          ComiteInvestigacion VARCHAR(1000) ,
          MedidasPreventivas VARCHAR(2000) ,
          Responsable VARCHAR(100) ,
          Fecha DATETIME ,
          TipoAccidente INTEGER ,
          Agente INTEGER ,
          CondicionInsegura INTEGER ,
          ActoInseguro INTEGER ,
          TipoLesion INTEGER ,
          ParteAfectada INTEGER
        )
GO
IF OBJECT_ID('dbo.CatalogoSeguridadHigiene') IS NULL 
    BEGIN
        CREATE TABLE dbo.CatalogoSeguridadHigiene
            (
              Empresa INTEGER ,
              Tipo INTEGER ,
              Folio INTEGER ,
              Descripcion VARCHAR(50)
            )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 1, 'OBJETO PUNZANTE' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 2, 'PRENSADO ENTRE O EL' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 3, 'OBJETO SOBRESALIDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 4, 'OBJETO CAYENDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 5, 'LEVANTANDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 6, 'TRANSPORTANDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 7, 'EMPUJANDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 8, 'JALANDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 9, 'MANEJANDO EQUIPO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 10, 'CADA A NIVEL' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 11, 'CADA DESDE ALTURA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 12, 'QUEMADURA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 13, 'GOLPEADO POR' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 14, ' GOLPEADO CONTRA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 15, 'ATRAPADO POR' )
 
        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 16, 'ATRAPADO CONTRA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 17, 'INHALANDO PRODUCTO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 18, 'ABSORCIO DE PRODUCTO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 1, 19, 'INGIRIENDO PRODUCTO' )

    ----

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 1, 'BANDA TRANSPORTADORA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 2, 'CALDERA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 3, 'ELEVADORES' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 4, 'TOLVA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 5, 'GUSANO TRANSPORTADOR' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 6, 'INTERRUPTOR ELECTRICO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 7, 'MOTOR ELECTRICO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 8, 'BOMBA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 9, 'HERRAMIENTA DE MANO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 10, 'VEHICULO DE TRANSPORTE' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 11, 'PRODUCTOS QUIMICOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 12, 'POLVOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 13, 'HORNOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 14, 'SILOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 15, 'TUBERIA VALVULA DRENAJES' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 16, 'SUPERFICIE DE TRABAJO PISO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 17, 'AGUA RESIDUAL' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 2, 18, 'OBJETO PESADO' )

    ---

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 1, 'GUARDA INADECUADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 2, 'DISEO INADECUADO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 3, 'FALTA DE GUARDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 4, 'F. PROCEDIMIENTO O INADECUADO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 5, 'EQUIPO O AGENTE DEFECTUOSO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 6, 'FALTA DE ORDEN' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 7, 'FALTA DE LIMPIEZA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 8, 'HERRAMIENTA DEFECTUOSA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 9, 'ILUMINACION INADECUADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 10, 'VENTILACION INADECUADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 11, 'RUIDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 12, 'ROPA O TRAJE INSEGURO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 13, 'PISO RESBALOSO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 14, 'PASILLOS OBSTRUIDOS' )
  
        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 15, 'ESTIBA INADECUADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 16, 'ALMACENAJE INADECUADO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 17, 'OBJETO SOBRESALIENDO DEL PISO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 18, 'EQ CONTRA INCENDIO OBSTRUIDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 3, 19, 'PUERTA EMERTICA OBSTRUIDA' )

    ---

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 1, 'FALTA DE SUPERVISION' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 2, 'FALTA DE CONOCIMIENTO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 3, 'FALTA DE HABILIDAD' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 4, 'FALTA DE CAPACITACION' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 5, 'DEFECTO FISICO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 6, 'DESINTERES DE SEGUIR NORMAS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 7, 'FALTA DE EXPERIENCIA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 8, 'ACTITUD INADECUADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 9, 'OPERANDO SIN AUTORIZACION' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 10, 'USANDO VELOCIDAD MUY LENTA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 11, 'USANDO VELOCIDAD MUY RAPIDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 12, 'ELIMINANDO DISPOSITIVOS DE SEGURIDAD' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 13, 'NO USANDO EQUIPO DE SEGURIDAD' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 14, 'USANDO EQUIPO INSEGURO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 15, 'USANDO HERRAMIENTAS DEFECTOUSAS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 16, 'USANDO HERRAMIENTA INADECUADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 17, 'CARGAR EN FORMA INSEGURA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 18, 'POSICION INADECUADA DEL CUERPO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 19, 'HACIENDO MEZCLAS INSEGURAS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 20, 'TRABAJANDO CON EQUIPO EN MOVIMIENTO' )
  
        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 21, 'DISTRAYENDOSE' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 22, 'VIOLAR PROCEDMIENTO DE TRABAJO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 23, 'METODO DE TRABAJO DEFICIENTE' )
 
        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 24, 'BROMEANDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 4, 25, 'ESTADO INCONVENIENTE DE SALUD' )

    ----

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 1, 'CORTADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 2, 'LUXACION' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 3, 'FRACTURA ABRAGADA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 4, 'FRACTURA EXPUESTA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 5, 'FRACTURA MULTIPLE' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 6, 'HEMORRAGIA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 7, 'QUEMADURA TERMICA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 8, 'QUEMADURA CLINICA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 9, 'QUEMADURA POR RADIACION' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 10, 'AMPUTACION' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 11, 'DAO A LOS OJOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 12, 'ASFICIA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 13, 'INTOXICACION' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 14, 'RASPON' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 15, 'HERIDA POR DESGARRE' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 5, 16, 'CONTUSION O GOLPE' )

    -----

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 1, 'CRANEO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 2, 'CARA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 3, 'AMBOS OJOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 4, 'OJO DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 5, 'OJO IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 5, 'CUELLO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 6, 'AMBOS HOMBROS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 7, 'HOMBRO DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 8, 'TORAX' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 9, 'AMBOS BRAZOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 10, 'BRAZO DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 11, 'BRAZO IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 12, 'AMBOS CUBITOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 13, 'CUBITO DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 14, 'CUBITO IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 15, 'AMBOS RADIOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 16, 'RADIO DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 17, 'RADIO IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 18, 'AMBAS MANOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 19, 'MANO DERECHA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 20, 'MANO IZQUIERDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 21, 'DEDO DE MANO DERECHA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 22, 'DEDO DE MANO IZQUIERDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 23, 'AMBAS MUECAS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 24, 'MUECA DERECHA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 25, 'MUECA IZQUIERDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 26, 'AMBOS MUSLOS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 27, 'MUSLO DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 28, 'MUSLO IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 29, 'AMBAS RODILLAS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 30, 'RODILLA DERECHA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 31, 'RODILLA IZQUIERDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 32, 'ABDOMEN' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 33, 'ESPALDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 34, 'CADERA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 35, 'AMBAS TIBIAS' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 36, 'TIBIA DERECHA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 37, 'TIBIA IZQUIERDA' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 38, 'AMBOS PERONE' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 39, 'PERONE DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 40, 'PERONE IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 41, 'AMBOS PIES' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 42, 'PIE DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 43, 'PIE IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 44, 'DEDO DE PIE DERECHO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 45, 'DEDO DE PIE IZQUIERDO' )

        INSERT  INTO dbo.CatalogoSeguridadHigiene
        VALUES  ( 1, 6, 46, 'CUERO CABELLUDO' )

    END
GO

/**************************************************************************************************
 * Name          : DepuraSeleccionElementos
 * Project       : APSI Nomina
 * Description   : Borra temporal con los elementos seleccionados
 * Table name    : SeleccionElementos
 * Return        : 
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Viernes, Julio 02, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'DepuraSeleccionElementos' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[DepuraSeleccionElementos]
    END
GO


CREATE PROCEDURE [dbo].[DepuraSeleccionElementos]
    @empresa INT ,
    @procesoId INT ,
    @procesoName VARCHAR(100) ,
    @tipoNomina INT ,
    @nomina CHAR(3)
AS 
    DELETE  dbo.SeleccionElementos
    WHERE   dbo.SeleccionElementos.empresa = @empresa
            AND ( dbo.SeleccionElementos.procesoId = @procesoId
                  OR dbo.SeleccionElementos.procesoName = @procesoName
                )
            AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
            AND dbo.SeleccionElementos.nomina = @nomina
GO

IF OBJECT_ID('dbo.DepuraTablaAvisosImssTemporalCalculo') IS NOT NULL 
    DROP PROCEDURE dbo.DepuraTablaAvisosImssTemporalCalculo
GO
CREATE PROCEDURE dbo.DepuraTablaAvisosImssTemporalCalculo
    @empresa INT ,
    @proceso VARCHAR(250) ,
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS 
  DECLARE @posicion INT
  SET @posicion = CHARINDEX('"', @proceso)
  IF @posicion > 0
     SET @posicion = @posicion - 1
  ELSE
     SET @posicion = LEN(@proceso)

--SELECT LTRIM(RTRIM(SUBSTRING(@proceso,1,@posicion))), *
--FROM dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso)

  DELETE  aItc
  FROM    dbo.AvisosImssTemporalCalculo AS aItc
          INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = aItc.empresa
  WHERE LTRIM(RTRIM(SUBSTRING(aItc.proceso,1,@posicion))) = LTRIM(RTRIM(SUBSTRING(@proceso,1,@posicion)))

  --aItc.empresa = @empresa
  --AND aItc.proceso = @proceso
  ----AND aItc.fechaProceso = @fechaProceso
  ----AND aItc.horaProceso = @horaProceso
GO

IF EXISTS ( SELECT  syscolumns.name
            FROM    syscolumns
                    LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
            WHERE   syscolumns.name = 'rfcnum'
                    AND sysobjects.name = 'empleados'
                    AND syscolumns.type = 39 ) 
    BEGIN
        UPDATE  dbo.empleados
        SET     dbo.empleados.rfcnum = SUBSTRING('000000'
                                                 + dbo.empleados.rfcnum, 1, 6)
        WHERE   LEN(LTRIM(RTRIM(dbo.empleados.rfcnum))) > 0
                AND LEN(LTRIM(RTRIM(dbo.empleados.rfcnum))) < 0
    END
GO

IF OBJECT_ID('dbo.NOM_PRO_CartomicroAutorizaVPA') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_CartomicroAutorizaVPA
GO
CREATE PROCEDURE dbo.NOM_PRO_CartomicroAutorizaVPA
@Empresa INT
, @Codigo INT
, @Estatus CHAR(1)
, @FechaAprobacion DATETIME
, @Usuario VARCHAR(100)

AS 

   SET NOCOUNT ON

   UPDATE vpa
   SET vpa.Estatus = @Estatus
       , vpa.FechaAprobacion = @FechaAprobacion
	   , vpa.Usuario = @Usuario
   FROM dbo.Solicitud_VPA AS vpa
   WHERE vpa.Empresa = @Empresa
         AND vpa.Codigo = @Codigo
GO

IF OBJECT_ID('dbo.NOM_PRO_CartomicroObtieneVPA') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_CartomicroObtieneVPA
GO
CREATE PROCEDURE dbo.NOM_PRO_CartomicroObtieneVPA
@empresa INT

AS

  SET NOCOUNT ON

  SELECT vpa.Codigo
         , e.ap_paterno
         , e.ap_materno
         , e.nombre
         , vpa.Disfrute
         , vpa.CategoriaActual
         , vpa.SueldoNetoActual
         , vpa.CategoriaSiguiente
         , vpa.SueldoNetoNuevo
  FROM dbo.Solicitud_VPA AS vpa
       INNER JOIN dbo.empleados AS e ON e.empresa = vpa.empresa AND e.codigo = vpa.Codigo
  WHERE vpa.Empresa = @empresa
        AND vpa.Estatus = 'S' 
        AND vpa.Nomina = 'S'
        AND vpa.Tipo = 'MS'
GO

IF EXISTS (SELECT 1 FROM sys.objects WHERE type_desc LIKE '%CONSTRAINT' AND OBJECT_NAME(OBJECT_ID)='CK__empleados__manoo__395884C4')
   BEGIN
     ALTER TABLE dbo.empleados DROP CONSTRAINT CK__empleados__manoo__395884C4
   END
GO

IF EXISTS (SELECT dbo.bancos.nombre
           FROM dbo.bancos
           WHERE dbo.bancos.banco = 11)
   UPDATE dbo.bancos
   SET dbo.bancos.nombre = 'SCOTIABANK INVERLAT'
   WHERE dbo.bancos.banco = 11
ELSE
   INSERT dbo.bancos
           ( banco, nombre )
   VALUES  ( 11, -- banco - int
             'SCOTIABANK INVERLAT'  -- nombre - varchar(30)
             )
GO

UPDATE dbo.primas_imss
SET eymart1062 = 1.5
    , eympat1062 = 1.1
	, eymtra1062 = 0.40
WHERE periodo >= '20210101' AND eymart1062 = 2.15
GO

If OBJECT_ID('dbo.sp_saca_codigo_mes_operacion_fun_a') Is NOT NULL
  Drop Procedure dbo.sp_saca_codigo_mes_operacion_fun_a
Go



create procedure dbo.sp_saca_codigo_mes_operacion_fun_a
@nempresa numeric(5,0),
@nmes_operacion int,
@nayo_operacion int

as

select distinct avisos_imss.codigo, 
                       empleados.fchantigua, 
                       empleados.fchalta, 
                       llaves.clase, 
                       llaves.tiponom, 
                       empleados.jornada,
                       empleados.art39, 
                       empleados.ap_paterno, 
                       empleados.ap_materno, 
                       empleados.nombre, 
                       empleados.afiliacion, 
                       empleados.digvera, 
                       empleados.varia_imss,
                       empleados.varia_next,
                       empleados.var_sigmes,
                       empleados.tiposal,
                       llaves.centro,
                       empleados.manoobra,
                       empleados.rfcalfa,
                       empleados.rfcnum,
                       empleados.rfchomo,
                       empleados.curp

from avisos_imss
inner join empleados on empleados.empresa = avisos_imss.empresa and 
                                      empleados.codigo = avisos_imss.codigo
inner join llaves on llaves.empresa = avisos_imss.empresa and 
                              llaves.codigo = avisos_imss.codigo
where avisos_imss.empresa = @nempresa and 
           avisos_imss.ayo_operacion = @nayo_operacion and 
           avisos_imss.mes_operacion = @nmes_operacion and 
           empleados.borrado = 'N'
		   AND empleados.activo = 'S'
go

IF OBJECT_ID('dbo.asp_fun_d_datos_libres') IS NOT NULL
   DROP PROCEDURE dbo.asp_fun_d_datos_libres
GO
CREATE PROCEDURE dbo.asp_fun_d_datos_libres
@empresa NUMERIC(5,0),
@codigo  NUMERIC(8,0)

AS 
  
  SET NOCOUNT ON

  SELECT campo_02,
         campo_03,
         campo_04,
         campo_05,
         campo_07,
         campo_08,
         campo_10,
         campo_11,
         campo__09,
         campo__10,
         campo__11,
         campo__12,
         campo__13,
         campo__14,
         campo__15
  FROM dbo.clasificacion_empleados
  WHERE empresa = @empresa and codigo = @codigo
GO

IF OBJECT_ID('dbo.sp_agrega_empleados_fun_d') IS NOT NULL 
    DROP PROCEDURE dbo.sp_agrega_empleados_fun_d
GO
CREATE PROCEDURE dbo.sp_agrega_empleados_fun_d
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @nmcamov INT ,
    @cnombre VARCHAR(50) ,
    @cap_paterno VARCHAR(50) ,
    @cap_materno VARCHAR(50) ,
    @cafiliacion VARCHAR(10) ,
    @cdigvera CHAR(1) ,
    @ccurp VARCHAR(18) ,
    @dfchantigua DATETIME ,
    @dfchalta DATETIME ,
    @nsueldo DECIMAL(12, 2) ,
    @nsaldiaint DECIMAL(10, 2) ,
    @nsaldiaiv DECIMAL(10, 2) ,
    @nart39 DECIMAL(7, 4) ,
    @ntiposal INT ,
    @njornada INT ,
    @nvaria_imss DECIMAL(8, 2) ,
    @nvaria_next DECIMAL(8, 2) ,
    @cvar_sigmes CHAR(15) ,
    @nturno INT ,
    @csig_bim CHAR(1) ,
    @nhoradia DECIMAL(5, 2) ,
    @cfinikito CHAR(1) ,
    @ntipo_emp INT ,
    @ccta_bco_no VARCHAR(20) ,
    @nplanta INT ,
    @csindicato CHAR(1) ,
    @cmanoobra CHAR(1) ,
    @ndiastr INT ,
    @nfactorsd DECIMAL(7, 4) ,
    @ninc INT ,
    @naus INT ,
    @crfcalfa VARCHAR(4) ,
    @nrfcnum CHAR(6) ,
    @crfchomo VARCHAR(3) ,
    @csexo CHAR(1) ,
    @dfchnac DATETIME ,
    @clugnac VARCHAR(40) ,
    @cedonac VARCHAR(4) ,
    @ntipo_deposito INT ,
    @cactivo CHAR(1) ,
    @cpassword_empleado VARCHAR(15) ,
    @dfch_baja DATETIME ,
    @cborrado CHAR(1) ,
    @cultmov CHAR(2) ,
    @dultfchmov DATETIME ,
    @cnomina CHAR(1) ,
    @cisr2006 VARCHAR(10) ,
    @ccentro CHAR(15) ,
    @cclase CHAR(2) ,
    @nsupervisor INT ,
    @nocupacion INT ,
    @nhorario INT ,
    @ntiponom INT ,
    @nbanco INT ,
    @cdomicilio VARCHAR(40) ,
    @ccolonia VARCHAR(40) ,
    @cpoblacion VARCHAR(40) ,
    @numf INT ,
    @ncodpostal NUMERIC(5) ,
    @nafore INT ,
    @cedocivil CHAR(1) ,
    @ctelefono VARCHAR(30) ,
    @cnacional VARCHAR(15) ,
    @cinegi VARCHAR(2) ,
    @cemail VARCHAR(100) ,
    @nserial INT ,
    @nmes_operacion INT ,
    @nayo_operacion INT ,
    @dfch_mov DATETIME ,
    @dfch_real DATETIME ,
    @cmov VARCHAR(2) ,
    @nincap INT ,
    @nausen DECIMAL(5, 2) ,
    @cmot_baja VARCHAR(30) ,
    @nclave_baja INT ,
    @cexcep_cv VARCHAR(10) ,
    @cexcep_iv VARCHAR(10) ,
    @cexcep_imss VARCHAR(10) ,
    @cexcep_a115 VARCHAR(10) ,
    @cexcep_cho VARCHAR(10) ,
    @nisr_chofer DECIMAL(10, 4) ,
    @cexcep_ach VARCHAR(10) ,
    @nisr_achofer DECIMAL(10, 4) ,
    @cfuncion VARCHAR(5) ,
    @copcion VARCHAR(5) ,
    @ccotiza_imss VARCHAR(1) ,
    @cpagar_nomina VARCHAR(1) ,
    @crpu CHAR(3) ,
    @ctipo_cap CHAR(1) ,
    @lsw CHAR(1) ,
    @cmulti_ofi CHAR(1) ,
    @chistoria CHAR(1) ,
    @ccta VARCHAR(25) ,
    @discapacitado CHAR(1) ,
    @empresaReferencia INT ,
    @codigoReferencia INT ,
    @importaCreditoInfonavit INT ,
    @clabe VARCHAR(20) ,
    @tipoRegimen INT ,
    @tipoContrato INT ,
    @mailEmpleado VARCHAR(100) ,
    @cuentaValesDespensa VARCHAR(20) ,
    @numeroExterior VARCHAR(25) ,
    @numeroInterior VARCHAR(25) ,
    @municipio VARCHAR(100) ,
    @localidad VARCHAR(100) ,
    @claveSat VARCHAR(3) ,
    @porcientoSat NUMERIC(7,3),
    @claveEstado VARCHAR(3),
    @nss VARCHAR(15),
    @origen CHAR(2),
	@regimenFiscal INT
AS 
    SET NOCOUNT ON

    DECLARE @nerr_ins_emp INT
    DECLARE @nerr_ins_lla INT
    DECLARE @nerr_ins_dat INT
    DECLARE @nerr_ins_avi INT
    DECLARE @nerr_ins_pcv INT
    DECLARE @nerr_ins_piv INT
    DECLARE @nerr_ins_nim INT
    DECLARE @nerr_ins_115 INT
    DECLARE @nerr_ins_dis INT
    DECLARE @errorInfonavit INT
    DECLARE @errorInfonavitCambios INT
--declare @nerr_ins_cho int
--declare @nerr_ins_ach int

    DECLARE @periodoNomina INT
    DECLARE @ayoNomina INT

    SET @nerr_ins_emp = 0
    SET @nerr_ins_lla = 0
    SET @nerr_ins_dat = 0
    SET @nerr_ins_avi = 0
    SET @nerr_ins_pcv = 0
    SET @nerr_ins_piv = 0
    SET @nerr_ins_nim = 0
    SET @nerr_ins_115 = 0
    SET @nerr_ins_dis = 0
    SET @errorInfonavit = 0
--set @nerr_ins_cho = 0
--set @nerr_ins_ach = 0

    SELECT @periodoNomina = ISNULL(dbo.Periodos.periodo,0) ,
           @ayoNomina = ISNULL(dbo.Periodos.ayo_operacion,0)
    FROM dbo.Periodos
    WHERE dbo.Periodos.empresa = @nempresa
          AND dbo.Periodos.tiponom = @ntiponom
          AND dbo.Periodos.estatus = 'A'
          

          
    BEGIN TRANSACTION
    INSERT  INTO dbo.empleados
            ( empresa ,
              codigo ,
              mcamov ,
              nombre ,
              ap_paterno ,
              ap_materno ,
              afiliacion ,
              digvera ,
              curp ,
              fchantigua ,
              fchalta ,
              sueldo ,
              saldiaint ,
              saldiaiv ,
              art39 ,
              tiposal ,
              jornada ,
              varia_imss ,
              varia_next ,
              var_sigmes ,
              turno ,
              sig_bim ,
              horadia ,
              finikito ,
              tipo_emp ,
              cta_bco_no ,
              planta ,
              sindicato ,
              manoobra ,
              diastr ,
              factorsd ,
              inc ,
              aus ,
              rfcalfa ,
              rfcnum ,
              rfchomo ,
              sexo ,
              fchnac ,
              lugnac ,
              edonac ,
              tipo_deposito ,
              activo ,
              fch_baja ,
              borrado ,
              ultmov ,
              ultfchmov ,
              nomina ,
              isr2006 ,
              cotiza_imss ,
              pagar_nomina ,
              rpu ,
              nivelacionisr ,
              multiple ,
              cuenta
              --mail
            )
    VALUES  ( @nempresa ,
              @ncodigo ,
              @nmcamov ,
              @cnombre ,
              @cap_paterno ,
              @cap_materno ,
              @cafiliacion ,
              @cdigvera ,
              @ccurp ,
              @dfchantigua ,
              @dfchalta ,
              @nsueldo ,
              @nsaldiaint ,
              @nsaldiaiv ,
              @nart39 ,
              @ntiposal ,
              @njornada ,
              @nvaria_imss ,
              @nvaria_next ,
              @cvar_sigmes ,
              @nturno ,
              @csig_bim ,
              @nhoradia ,
              @cfinikito ,
              @ntipo_emp ,
              @ccta_bco_no ,
              @nplanta ,
              @csindicato ,
              @cmanoobra ,
              @ndiastr ,
              @nfactorsd ,
              @ninc ,
              @naus ,
              @crfcalfa ,
              @nrfcnum ,
              @crfchomo ,
              @csexo ,
              @dfchnac ,
              @clugnac ,
              @cedonac ,
              @ntipo_deposito ,
              @cactivo ,
              @dfch_baja ,
              @cborrado ,
              @cultmov ,
              @dultfchmov ,
              @cnomina ,
              @cisr2006 ,
              @ccotiza_imss ,
              @cpagar_nomina ,
              @crpu ,
              ' ' ,
              @cmulti_ofi ,
              @ccta
              --@mailEmpleado
            )
    SELECT  @nerr_ins_emp = @@error

      /*select @cisr2006 as 'isr2006', @ccentro as centro, @cclase as 'clase'*/

    INSERT  INTO dbo.llaves
            ( empresa ,
              codigo ,
              clase ,
              supervisor ,
              ocupacion ,
              horario ,
              tiponom ,
              banco ,
              centro
            )
    VALUES  ( @nempresa ,
              @ncodigo ,
              @cclase ,
              @nsupervisor ,
              @nocupacion ,
              @nhorario ,
              @ntiponom ,
              @nbanco ,
              @ccentro
            )
    SELECT  @nerr_ins_lla = @@error

    INSERT  INTO dbo.datosemps
            ( empresa ,
              codigo ,
              domicilio ,
              colonia ,
              poblacion ,
              umf ,
              codpostal ,
              afore ,
              edocivil ,
              telefono ,
              nacional ,
              inegi ,
              cta_vales ,
              email ,
              numeroExterior ,
              numeroInterior ,
              municipio ,
              localidad
            )
    VALUES  ( @nempresa ,
              @ncodigo ,
              @cdomicilio ,
              @ccolonia ,
              @cpoblacion ,
              @numf ,
              @ncodpostal ,
              @nafore ,
              @cedocivil ,
              @ctelefono ,
              @cnacional ,
              @cinegi ,
              @cuentaValesDespensa ,
              @mailEmpleado ,
              @numeroExterior ,
              @numeroInterior ,
              @municipio ,
              @localidad
            )
    SELECT  @nerr_ins_dat = @@error

    IF @chistoria = 'N' 
        BEGIN
            INSERT  INTO dbo.avisos_imss
                    ( empresa ,
                      codigo ,
                      serial ,
                      mes_operacion ,
                      ayo_operacion ,
                      fch_mov ,
                      fch_real ,
                      mov ,
                      saldiaint ,
                      saldiaiv ,
                      sueldo ,
                      diastr ,
                      incap ,
                      ausen ,
                      mot_baja ,
                      clave_baja ,
                      rpu ,
                      origen
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      @nserial ,
                      @nmes_operacion ,
                      @nayo_operacion ,
                      @dfch_mov ,
                      @dfch_real ,
                      @cmov ,
                      @nsaldiaint ,
                      @nsaldiaiv ,
                      @nsueldo ,
                      @ndiastr ,
                      @nincap ,
                      @nausen ,
                      @cmot_baja ,
                      @nclave_baja ,
                      @crpu ,
                      @origen
                    )
            SELECT  @nerr_ins_avi = @@error
        END

    IF @cexcep_cv = 'CV' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'CV' ,
                      0
                    )
            SELECT  @nerr_ins_pcv = @@error
        END

    IF @cexcep_iv = 'IV' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'IV' ,
                      0
                    )
            SELECT  @nerr_ins_piv = @@error
        END

    IF @cexcep_imss = 'NOIMSS' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'NOIMSS' ,
                      0
                    )
            SELECT  @nerr_ins_nim = @@error
        END

    IF @cexcep_a115 = '115' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      '115' ,
                      0
                    )
            SELECT  @nerr_ins_115 = @@error
        END

      --if @cexcep_cho = 'CHOFER'
      --   begin
      --      insert into excepciones
      --      (empresa  , codigo  , excepcion1, excepcion2)
      --      values
      --      (@nempresa, @ncodigo, 'CHOFER'  , @nisr_chofer)
      --      select @nerr_ins_cho = @@error
      --   end

      --if @cexcep_ach = 'ACHOFER'
      --   begin
      --      insert into excepciones
      --      (empresa  , codigo  , excepcion1, excepcion2)
      --      values
      --      (@nempresa, @ncodigo, 'ACHOFER'  , @nisr_achofer)
      --      select @nerr_ins_ach = @@error
      --   end

    IF EXISTS ( SELECT  dbo.EmpleadoAdicional.codigo
                FROM    dbo.EmpleadoAdicional
                WHERE   dbo.EmpleadoAdicional.empresa = @nempresa
                        AND dbo.EmpleadoAdicional.codigo = @ncodigo ) 
        BEGIN
            UPDATE  empleadoAdicional
            SET     empleadoAdicional.discapacitado = @discapacitado ,
                    empleadoAdicional.clabe = @clabe ,
                    empleadoAdicional.tipoRegimen = @tipoRegimen ,
                    empleadoAdicional.tipoContrato = @tipoContrato ,
                    empleadoAdicional.claveSat = @claveSat ,
                    empleadoAdicional.porcientoSat = @porcientoSat,
                    empleadoAdicional.claveEstado = @claveEstado,
                    empleadoAdicional.nss = @nss,
					empleadoAdicional.regimenFiscal = @regimenFiscal
            FROM dbo.EmpleadoAdicional AS empleadoAdicional
            WHERE   empleadoAdicional.empresa = @nempresa
                    AND empleadoAdicional.codigo = @ncodigo
            SELECT  @nerr_ins_dis = @@ERROR
        END
    ELSE 
        BEGIN
            INSERT  dbo.EmpleadoAdicional
                    ( empresa ,
                      codigo ,
                      discapacitado ,
                      clabe ,
                      tipoRegimen ,
                      tipoContrato ,
                      claveSat ,
                      porcientoSat,
                      claveEstado,
                      nss,
					  regimenFiscal
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      @discapacitado ,
                      @clabe ,
                      @tipoRegimen ,
                      @tipoContrato ,
                      @claveSat ,
                      @porcientoSat,
                      @claveEstado,
                      @nss,
					  @regimenFiscal
                    )
            SELECT  @nerr_ins_dis = @@ERROR
        END
    
    IF @importaCreditoInfonavit = 1 
        BEGIN
            IF NOT EXISTS ( SELECT  dbo.infonavit.codigo
                            FROM    dbo.infonavit
                            WHERE   dbo.infonavit.empresa = @nempresa
                                    AND dbo.infonavit.codigo = @ncodigo ) 
                BEGIN                      
                    INSERT  dbo.infonavit
                            ( empresa ,
                              codigo ,
                              tipo_cred ,
                              numcredito ,
                              descuento ,
                              amortizacion_cedula ,
                              amortizacion_retenido ,
                              amortizacion_sigmes ,
                              fecha ,
                              fch_otorga ,
                              fch_termino ,
                              seguro_vivienda ,
                              fechaSuspension
                            )
                            SELECT  @nempresa AS empresa ,
                                    @ncodigo AS codigo, --dbo.infonavit.codigo ,
                                    dbo.infonavit.tipo_cred ,
                                    dbo.infonavit.numcredito ,
                                    dbo.infonavit.descuento ,
                                    0 AS amortizacion_cedula ,
                                    0 AS amortizacion_retenido ,
                                    0 AS amortizacion_sigmes ,
                                    @dfchalta AS fecha ,
                                    dbo.infonavit.fch_otorga ,
                                    dbo.infonavit.fch_termino ,
                                    dbo.infonavit.seguro_vivienda ,
                                    dbo.infonavit.fechaSuspension
                            FROM    dbo.infonavit
                            WHERE   dbo.infonavit.empresa = @empresaReferencia
                                    AND dbo.infonavit.codigo = @codigoReferencia
		                            AND dbo.infonavit.fechaSuspension IS NULL

                    SELECT  @errorInfonavit = @@ERROR
                    
                    INSERT  dbo.infonavit_cambios
                            ( empresa ,
                              codigo ,
                              fecha ,
                              tipo_cred ,
                              descuento ,
                              cambio ,
                              periodo ,
                              ayo_operacion ,
                              numcredito
                            ) 
                            SELECT  @nempresa AS empresa ,
                                    @ncodigo AS codigo, --dbo.infonavit.codigo ,
                                    @dfchalta AS fecha ,
                                    dbo.infonavit.tipo_cred ,
                                    dbo.infonavit.descuento ,
                                    'ICV' AS cambio ,
                                    @periodoNomina AS periodo ,
                                    @ayoNomina AS ayo_operacion ,
                                    dbo.infonavit.numcredito
                            FROM    dbo.infonavit
                            WHERE   dbo.infonavit.empresa = @empresaReferencia
                                    AND dbo.infonavit.codigo = @codigoReferencia
		                            AND dbo.infonavit.fechaSuspension IS NULL

                    SELECT @errorInfonavitCambios = @@ERROR
                END
        END

    IF @nerr_ins_emp <> 0
        OR @nerr_ins_lla <> 0
        OR @nerr_ins_dat <> 0
        OR @nerr_ins_avi <> 0
        OR @nerr_ins_pcv <> 0
        OR @nerr_ins_piv <> 0
        OR @nerr_ins_nim <> 0
        OR @nerr_ins_115 <> 0
        OR @nerr_ins_dis <> 0
        OR @errorInfonavit <> 0
        OR @errorInfonavitCambios <> 0
   --@nerr_ins_cho <> 0
   --@nerr_ins_ach <> 0
        BEGIN
            ROLLBACK TRANSACTION
        END
    ELSE 
        BEGIN
            COMMIT TRANSACTION
        END
GO

IF OBJECT_ID('dbo.sp_modifica_empleados_fun_d') IS NOT NULL 
    DROP PROCEDURE dbo.sp_modifica_empleados_fun_d
GO
CREATE PROCEDURE dbo.sp_modifica_empleados_fun_d
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @nmcamov INT ,
    @cnombre VARCHAR(50) ,
    @cap_paterno VARCHAR(50) ,
    @cap_materno VARCHAR(50) ,
    @cafiliacion VARCHAR(10) ,
    @cdigvera CHAR(1) ,
    @ccurp VARCHAR(18) ,
    @dfchantigua DATETIME ,
    @dfchalta DATETIME ,
    @nsueldo DECIMAL(12, 2) ,
    @nsaldiaint DECIMAL(10, 2) ,
    @nsaldiaiv DECIMAL(10, 2) ,
    @nart39 DECIMAL(7, 4) ,
    @ntiposal INT ,
    @njornada INT ,
    @nvaria_imss DECIMAL(8, 2) ,
    @nvaria_next DECIMAL(8, 2) ,
    @cvar_sigmes CHAR(15) ,
    @nturno INT ,
    @csig_bim CHAR(1) ,
    @nhoradia DECIMAL(5, 2) ,
    @cfinikito CHAR(1) ,
    @ntipo_emp INT ,
    @ccta_bco_no VARCHAR(20) ,
    @nplanta INT ,
    @csindicato CHAR(1) ,
    @cmanoobra CHAR(1) ,
    @ndiastr INT ,
    @nfactorsd DECIMAL(7, 4) ,
    @ninc INT ,
    @naus INT ,
    @crfcalfa VARCHAR(4) ,
    @nrfcnum CHAR(6) ,
    @crfchomo VARCHAR(3) ,
    @csexo CHAR(1) ,
    @dfchnac DATETIME ,
    @clugnac VARCHAR(40) ,
    @cedonac VARCHAR(4) ,
    @ntipo_deposito INT ,
    @cactivo CHAR(1) ,
    @cpassword_empleado VARCHAR(15) ,
    @dfch_baja DATETIME ,
    @cborrado CHAR(1) ,
    @cultmov CHAR(2) ,
    @dultfchmov DATETIME ,
    @cnomina CHAR(1) ,
    @cisr2006 VARCHAR(10) ,
    @ccentro CHAR(15) ,
    @cclase CHAR(2) ,
    @nsupervisor INT ,
    @nocupacion INT ,
    @nhorario INT ,
    @ntiponom INT ,
    @nbanco INT ,
    @cdomicilio VARCHAR(40) ,
    @ccolonia VARCHAR(40) ,
    @cpoblacion VARCHAR(40) ,
    @numf INT ,
    @ncodpostal NUMERIC(5) ,
    @nafore INT ,
    @cedocivil CHAR(1) ,
    @ctelefono VARCHAR(30) ,
    @cnacional VARCHAR(15) ,
    @cinegi VARCHAR(2) ,
    @cemail VARCHAR(100) ,
    @nserial INT ,
    @nmes_operacion INT ,
    @nayo_operacion INT ,
    @dfch_mov DATETIME ,
    @dfch_real DATETIME ,
    @cmov VARCHAR(2) ,
    @nincap INT ,
    @nausen DECIMAL(5, 2) ,
    @cmot_baja VARCHAR(30) ,
    @nclave_baja INT ,
    @cexcep_cv VARCHAR(10) ,
    @cexcep_iv VARCHAR(10) ,
    @cexcep_imss VARCHAR(10) ,
    @cexcep_a115 VARCHAR(10) ,
    @cexcep_cho VARCHAR(10) ,
    @nisr_chofer DECIMAL(10, 4) ,
    @cexcep_ach VARCHAR(10) ,
    @nisr_achofer DECIMAL(10, 4) ,
    @cfuncion VARCHAR(5) ,
    @copcion VARCHAR(5) ,
    @ccotiza_imss VARCHAR(1) ,
    @cpagar_nomina VARCHAR(1) ,
    @crpu CHAR(3) ,
    @ctipo_cap CHAR(1) ,
    @lsw CHAR(1) ,
    @cmulti_ofi CHAR(1) ,
    @chistoria CHAR(1) ,
    @cCta VARCHAR(25) ,
    @discapacitado CHAR(1) ,
    @empresaReferencia INT ,
    @codigoReferencia INT ,
    @importaCreditoInfonavit INT ,
    @clabe VARCHAR(20) ,
    @tipoRegimen INT ,
    @tipoContrato INT ,
    @mailEmpleado VARCHAR(100) ,
    @cuentaValesDespensa VARCHAR(20) ,
    @numeroExterior VARCHAR(25) ,
    @numeroInterior VARCHAR(25) ,
    @municipio VARCHAR(100) ,
    @localidad VARCHAR(100) ,
    @claveSat VARCHAR(3) ,
    @porcientoSat NUMERIC(7,3),
    @claveEstado VARCHAR(3),
    @nss VARCHAR(15),
    @origen CHAR(2),
	@regimenFiscal INT
AS 
    DECLARE @nerr_upd_emp INT
    DECLARE @nerr_upd_lla INT
    DECLARE @nerr_upd_dat INT
    DECLARE @nerr_upd_avi INT
    DECLARE @nerr_ins_pcv INT
    DECLARE @nerr_ins_piv INT
    DECLARE @nerr_ins_nim INT
    DECLARE @nerr_ins_115 INT
    DECLARE @nerr_ins_dis INT
    --DECLARE @nerr_ins_cho INT
    --DECLARE @nerr_ins_ach INT

    DECLARE @cultmov_emp CHAR(2)
    DECLARE @dultfch_emp DATETIME
    DECLARE @dfch_baja_emp DATETIME

    DECLARE @nerr_gral INT

    SET @nerr_upd_emp = 0
    SET @nerr_upd_lla = 0
    SET @nerr_upd_dat = 0
    SET @nerr_upd_avi = 0
    SET @nerr_ins_pcv = 0
    SET @nerr_ins_piv = 0
    SET @nerr_ins_nim = 0
    SET @nerr_ins_115 = 0
    SET @nerr_ins_dis = 0
    --SET @nerr_ins_cho = 0
    --SET @nerr_ins_ach = 0
    SET @nerr_gral = 0


    DELETE  FROM dbo.estatus
    WHERE   dbo.estatus.empresa = @nempresa
            AND dbo.estatus.codigo = @ncodigo
    --SELECT  'estatus'
    
    BEGIN TRANSACTION
    IF @ctipo_cap = 'A'
        OR @ctipo_cap = 'M'
        OR ( @ctipo_cap = 'B'
             AND @lsw = 'T'
           )
        OR ( @ctipo_cap = 'H'
             AND @lsw = 'T'
           ) 
        BEGIN
            SELECT  @cultmov_emp = dbo.empleados.ultmov ,
                    @dultfch_emp = dbo.empleados.ultfchmov ,
                    @dfch_baja_emp = dbo.empleados.fch_baja
            FROM    dbo.empleados
            WHERE   dbo.empleados.empresa = @nempresa
                    AND dbo.empleados.codigo = @ncodigo
            SELECT  @nerr_gral = @@error

            IF @ctipo_cap = 'H'
                AND @lsw = 'T' 
                BEGIN
                    SET @dfch_baja = NULL
                    SELECT  @nerr_gral = @@error
                END
            ELSE 
                BEGIN
                    SET @dfch_baja = @dfch_baja_emp
                    SELECT  @nerr_gral = @@error
                END

            IF @ctipo_cap <> 'H'
                AND @lsw <> 'T' 
                IF @cultmov_emp <> 'A'
                    AND @cultmov_emp <> 'IM' 
                    BEGIN
                        SET @cultmov = @cultmov_emp
                        SET @dultfchmov = @dultfch_emp
                        SELECT  @nerr_gral = @@error
                    END

            IF @ctipo_cap = 'H'
                AND @lsw = 'T' 
                BEGIN
                    UPDATE  dbo.empleados
                    SET     dbo.empleados.finikito = 'F'
                    WHERE   dbo.empleados.empresa = @nempresa
                            AND dbo.empleados.codigo = @ncodigo
                    SELECT  @nerr_gral = @@error
                END

            UPDATE  dbo.empleados
            SET     dbo.empleados.mcamov = @nmcamov ,
                    dbo.empleados.nombre = @cnombre ,
                    dbo.empleados.ap_paterno = @cap_paterno ,
                    dbo.empleados.ap_materno = @cap_materno ,
                    dbo.empleados.afiliacion = @cafiliacion ,
                    dbo.empleados.digvera = @cdigvera ,
                    dbo.empleados.curp = @ccurp ,
                    dbo.empleados.fchantigua = @dfchantigua ,
                    dbo.empleados.fchalta = @dfchalta ,
                    dbo.empleados.saldiaiv = @nsaldiaiv ,
                    dbo.empleados.art39 = @nart39 ,
                    dbo.empleados.tiposal = @ntiposal ,
                    dbo.empleados.jornada = @njornada ,
                    dbo.empleados.varia_imss = @nvaria_imss ,
                    dbo.empleados.varia_next = @nvaria_next ,
                    dbo.empleados.var_sigmes = @cvar_sigmes ,
                    dbo.empleados.turno = @nturno ,
                    dbo.empleados.sig_bim = @csig_bim ,
                    dbo.empleados.horadia = @nhoradia ,
                    dbo.empleados.tipo_emp = @ntipo_emp ,
                    dbo.empleados.cta_bco_no = @ccta_bco_no ,
                    dbo.empleados.planta = @nplanta ,
                    dbo.empleados.sindicato = @csindicato ,
                    dbo.empleados.manoobra = @cmanoobra ,
                    dbo.empleados.diastr = @ndiastr ,
                    dbo.empleados.factorsd = @nfactorsd ,
                    dbo.empleados.inc = @ninc ,
                    dbo.empleados.aus = @naus ,
                    dbo.empleados.rfcalfa = @crfcalfa ,
                    dbo.empleados.rfcnum = @nrfcnum ,
                    dbo.empleados.rfchomo = @crfchomo ,
                    dbo.empleados.sexo = @csexo ,
                    dbo.empleados.fchnac = @dfchnac ,
                    dbo.empleados.lugnac = @clugnac ,
                    dbo.empleados.edonac = @cedonac ,
                    dbo.empleados.tipo_deposito = @ntipo_deposito ,
                    dbo.empleados.activo = @cactivo ,
                    dbo.empleados.fch_baja = @dfch_baja ,
                    dbo.empleados.borrado = @cborrado ,
                    dbo.empleados.ultmov = @cultmov ,
                    dbo.empleados.ultfchmov = @dultfchmov ,
                    dbo.empleados.nomina = @cnomina ,
                    dbo.empleados.isr2006 = @cisr2006 ,
                    dbo.empleados.cotiza_imss = @ccotiza_imss ,
                    dbo.empleados.pagar_nomina = @cpagar_nomina ,
                    dbo.empleados.rpu = @crpu ,
                    dbo.empleados.multiple = @cmulti_ofi ,
                    dbo.empleados.cuenta = @cCta 
                    --dbo.empleados.mail = @mailEmpleado
            WHERE   dbo.empleados.empresa = @nempresa
                    AND dbo.empleados.codigo = @ncodigo
            SELECT  @nerr_upd_emp = @@error
            SELECT  @nerr_upd_emp AS '1'

            SELECT  @cultmov_emp = dbo.empleados.ultmov
            FROM    dbo.empleados
            WHERE   dbo.empleados.empresa = @nempresa
                    AND dbo.empleados.codigo = @ncodigo

            IF @cultmov_emp = 'IM'
                OR @cultmov_emp = 'A' 
                BEGIN
                    UPDATE  dbo.empleados
                    SET     dbo.empleados.sueldo = @nsueldo ,
                            dbo.empleados.saldiaint = @nsaldiaint
                    WHERE   dbo.empleados.empresa = @nempresa
                            AND dbo.empleados.codigo = @ncodigo
                            
                    UPDATE  dbo.avisos_imss
                    SET     dbo.avisos_imss.sueldo = @nsueldo ,
                            dbo.avisos_imss.saldiaint = @nsaldiaint ,
                            dbo.avisos_imss.rpu = @crpu
                    WHERE   dbo.avisos_imss.empresa = @nempresa
                            AND dbo.avisos_imss.codigo = @ncodigo
                            AND dbo.avisos_imss.serial = 1
                            AND dbo.avisos_imss.mes_operacion = @nmes_operacion
                            AND dbo.avisos_imss.ayo_operacion = @nayo_operacion
                END
            ELSE 
                UPDATE  dbo.avisos_imss
                SET     dbo.avisos_imss.sueldo = @nsueldo ,
                        dbo.avisos_imss.saldiaint = @nsaldiaint ,
                        dbo.avisos_imss.rpu = @crpu
                WHERE   dbo.avisos_imss.empresa = @nempresa
                        AND dbo.avisos_imss.codigo = @ncodigo
                        AND dbo.avisos_imss.serial = 1
                        AND dbo.avisos_imss.mes_operacion = @nmes_operacion
                        AND dbo.avisos_imss.ayo_operacion = @nayo_operacion   
        END
    ELSE 
        BEGIN
            UPDATE  dbo.empleados
            SET     dbo.empleados.mcamov = @nmcamov ,
                    dbo.empleados.nombre = @cnombre ,
                    dbo.empleados.ap_paterno = @cap_paterno ,
                    dbo.empleados.ap_materno = @cap_materno ,
                    dbo.empleados.afiliacion = @cafiliacion ,
                    dbo.empleados.digvera = @cdigvera ,
                    dbo.empleados.curp = @ccurp ,
                    dbo.empleados.fchantigua = @dfchantigua ,
                    dbo.empleados.fchalta = @dfchalta ,
                    dbo.empleados.sueldo = @nsueldo ,
                    dbo.empleados.saldiaint = @nsaldiaint ,
                    dbo.empleados.saldiaiv = @nsaldiaiv ,
                    dbo.empleados.art39 = @nart39 ,
                    dbo.empleados.tiposal = @ntiposal ,
                    dbo.empleados.jornada = @njornada ,
                    dbo.empleados.varia_imss = @nvaria_imss ,
                    dbo.empleados.varia_next = @nvaria_next ,
                    dbo.empleados.var_sigmes = @cvar_sigmes ,
                    dbo.empleados.turno = @nturno ,
                    dbo.empleados.sig_bim = @csig_bim ,
                    dbo.empleados.horadia = @nhoradia ,
                    dbo.empleados.tipo_emp = @ntipo_emp ,
                    dbo.empleados.cta_bco_no = @ccta_bco_no ,
                    dbo.empleados.planta = @nplanta ,
                    dbo.empleados.sindicato = @csindicato ,
                    dbo.empleados.manoobra = @cmanoobra ,
                    dbo.empleados.diastr = @ndiastr ,
                    dbo.empleados.factorsd = @nfactorsd ,
                    dbo.empleados.inc = @ninc ,
                    dbo.empleados.aus = @naus ,
                    dbo.empleados.rfcalfa = @crfcalfa ,
                    dbo.empleados.rfcnum = @nrfcnum ,
                    dbo.empleados.rfchomo = @crfchomo ,
                    dbo.empleados.sexo = @csexo ,
                    dbo.empleados.fchnac = @dfchnac ,
                    dbo.empleados.lugnac = @clugnac ,
                    dbo.empleados.edonac = @cedonac ,
                    dbo.empleados.tipo_deposito = @ntipo_deposito ,
                    dbo.empleados.activo = @cactivo ,
                    dbo.empleados.borrado = @cborrado ,
                    dbo.empleados.nomina = @cnomina ,
                    dbo.empleados.isr2006 = @cisr2006 ,
                    dbo.empleados.cotiza_imss = @ccotiza_imss ,
                    dbo.empleados.pagar_nomina = @cpagar_nomina ,
                    dbo.empleados.rpu = @crpu 
                    --dbo.empleados.mail = @mailEmpleado
            WHERE   dbo.empleados.empresa = @nempresa
                    AND dbo.empleados.codigo = @ncodigo
            SELECT  @nerr_upd_emp = @@error
            SELECT  @nerr_upd_emp AS '2'


            IF @ctipo_cap = 'H'
                AND @lsw = 'F' 
                UPDATE  dbo.empleados
                SET     dbo.empleados.fch_baja = @dfch_baja ,
                        dbo.empleados.ultmov = @cultmov ,
                        dbo.empleados.ultfchmov = @dultfchmov
                WHERE   dbo.empleados.empresa = @nempresa
                        AND dbo.empleados.codigo = @ncodigo
        END


    IF EXISTS ( SELECT  dbo.Llaves.codigo
                FROM    dbo.llaves
                WHERE   dbo.Llaves.empresa = @nempresa
                        AND dbo.Llaves.codigo = @ncodigo ) 
        BEGIN
            UPDATE  dbo.llaves
            SET     dbo.Llaves.clase = @cclase ,
                    dbo.Llaves.supervisor = @nsupervisor ,
                    dbo.Llaves.ocupacion = @nocupacion ,
                    dbo.Llaves.horario = @nhorario ,
                    dbo.Llaves.tiponom = @ntiponom ,
                    dbo.Llaves.banco = @nbanco ,
                    dbo.Llaves.centro = @ccentro
            WHERE   dbo.Llaves.empresa = @nempresa
                    AND dbo.Llaves.codigo = @ncodigo
            SELECT  @nerr_upd_lla = @@error
            SELECT  @nerr_upd_lla AS '3'
        END             
    ELSE 
        BEGIN              
            INSERT  INTO dbo.llaves
                    ( empresa ,
                      codigo ,
                      clase ,
                      supervisor ,
                      ocupacion ,
                      horario ,
                      tiponom ,
                      banco ,
                      centro
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      @cclase ,
                      @nsupervisor ,
                      @nocupacion ,
                      @nhorario ,
                      @ntiponom ,
                      @nbanco ,
                      @ccentro
                    )
            SELECT  @nerr_upd_lla = @@error
            SELECT  @nerr_upd_lla AS '3'
        END
       

    IF EXISTS ( SELECT  dbo.datosemps.codigo
                FROM    dbo.datosemps
                WHERE   dbo.datosemps.empresa = @nempresa
                        AND dbo.datosemps.codigo = @ncodigo ) 
        BEGIN
            UPDATE  dbo.datosemps
            SET     dbo.datosemps.domicilio = @cdomicilio ,
                    dbo.datosemps.colonia = @ccolonia ,
                    dbo.datosemps.poblacion = @cpoblacion ,
                    dbo.datosemps.umf = @numf ,
                    dbo.datosemps.codpostal = @ncodpostal ,
                    dbo.datosemps.afore = @nafore ,
                    dbo.datosemps.edocivil = @cedocivil ,
                    dbo.datosemps.telefono = @ctelefono ,
                    dbo.datosemps.nacional = @cnacional ,
                    dbo.datosemps.inegi = @cinegi ,
                    dbo.datosemps.cta_vales = @cuentaValesDespensa ,
                    dbo.datosemps.email = @mailEmpleado ,
                    dbo.datosemps.numeroExterior = @numeroExterior ,
                    dbo.datosemps.numeroInterior = @numeroInterior ,
                    dbo.datosemps.municipio = @municipio ,
                    dbo.datosemps.localidad = @localidad
                    
            WHERE   dbo.datosemps.empresa = @nempresa
                    AND dbo.datosemps.codigo = @ncodigo
            SELECT  @nerr_upd_dat = @@error
            SELECT  @nerr_upd_dat AS '4'
        END               
    ELSE 
        BEGIN
            INSERT  INTO dbo.datosemps
                    ( empresa ,
                      codigo ,
                      domicilio ,
                      colonia ,
                      poblacion ,
                      umf ,
                      codpostal ,
                      afore ,
                      edocivil ,
                      telefono ,
                      nacional ,
                      inegi ,
                      cta_vales ,
                      email ,
                      numeroExterior ,
                      numeroInterior ,
                      municipio ,
                      localidad
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      @cdomicilio ,
                      @ccolonia ,
                      @cpoblacion ,
                      @numf ,
                      @ncodpostal ,
                      @nafore ,
                      @cedocivil ,
                      @ctelefono ,
                      @cnacional ,
                      @cinegi ,
                      @cuentaValesDespensa ,
                      @mailEmpleado ,
                      @numeroExterior ,
                      @numeroInterior ,
                      @municipio ,
                      @localidad
                    )
            SELECT  @nerr_upd_dat = @@error
            SELECT  @nerr_upd_dat AS '4'
        END
             
                 
    IF @lsw = 'T' 
        BEGIN
            DELETE  FROM dbo.avisos_imss
            WHERE   dbo.avisos_imss.empresa = @nempresa
                    AND dbo.avisos_imss.codigo = @ncodigo
                    AND dbo.avisos_imss.serial = 1
                    AND dbo.avisos_imss.mes_operacion = @nmes_operacion
                    AND dbo.avisos_imss.ayo_operacion = @nayo_operacion
            INSERT  INTO dbo.avisos_imss
                    ( empresa ,
                      codigo ,
                      serial ,
                      mes_operacion ,
                      ayo_operacion ,
                      fch_mov ,
                      fch_real ,
                      mov ,
                      saldiaint ,
                      saldiaiv ,
                      sueldo ,
                      diastr ,
                      incap ,
                      ausen ,
                      mot_baja ,
                      clave_baja ,
                      rpu ,
                      origen
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      1 ,
                      @nmes_operacion ,
                      @nayo_operacion ,
                      @dfch_mov ,
                      @dfch_real ,
                      @cmov ,
                      @nsaldiaint ,
                      @nsaldiaiv ,
                      @nsueldo ,
                      @ndiastr ,
                      @nincap ,
                      @nausen ,
                      @cmot_baja ,
                      NULL ,
                      @crpu ,
                      @origen
                    )
            SELECT  @nerr_upd_avi = @@error
            SELECT  @nerr_upd_avi AS '5'
        END


    DELETE  FROM dbo.excepciones
    WHERE   dbo.excepciones.empresa = @nempresa
            AND dbo.excepciones.codigo = @ncodigo
            AND dbo.excepciones.excepcion1 IN ( 'CV', 'IV', 'NOIMSS', '115', 'CHOFER',
                                'ACHOFER' )


    IF @cexcep_cv = 'CV' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'CV' ,
                      0
                    )
            SELECT  @nerr_ins_pcv = @@error
            SELECT  @nerr_ins_pcv AS '6'
        END


    IF @cexcep_iv = 'IV' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'IV' ,
                      0
                    )
            SELECT  @nerr_ins_piv = @@error
            SELECT  @nerr_ins_piv AS '7'
        END


    IF @cexcep_imss = 'NOIMSS' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'NOIMSS' ,
                      0
                    )
            SELECT  @nerr_ins_nim = @@error
            SELECT  @nerr_ins_nim AS '8'
        END


    IF @cexcep_a115 = '115' 
        BEGIN
            INSERT  INTO dbo.excepciones
                    ( empresa ,
                      codigo ,
                      excepcion1 ,
                      excepcion2
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      '115' ,
                      0
                    )
            SELECT  @nerr_ins_115 = @@error
            SELECT  @nerr_ins_115 AS '9'
        END


    --IF @cexcep_cho = 'CHOFER' 
    --    BEGIN
    --        INSERT  INTO excepciones
    --                ( empresa ,
    --                  codigo ,
    --                  excepcion1 ,
    --                  excepcion2
    --                )
    --        VALUES  ( @nempresa ,
    --                  @ncodigo ,
    --                  'CHOFER' ,
    --                  @nisr_chofer
    --                )
    --        SELECT  @nerr_ins_cho = @@error
    --        SELECT  @nerr_ins_cho AS '10'
    --    END


    --IF @cexcep_ach = 'ACHOFER' 
    --    BEGIN
    --        INSERT  INTO excepciones
    --                ( empresa ,
    --                  codigo ,
    --                  excepcion1 ,
    --                  excepcion2
    --                )
    --        VALUES  ( @nempresa ,
    --                  @ncodigo ,
    --                  'ACHOFER' ,
    --                  @nisr_achofer
    --                )
    --        SELECT  @nerr_ins_ach = @@error
    --        SELECT  @nerr_ins_ach AS '11'
    --    END

    IF EXISTS ( SELECT  dbo.EmpleadoAdicional.codigo
                FROM    dbo.EmpleadoAdicional
                WHERE   dbo.EmpleadoAdicional.empresa = @nempresa
                        AND dbo.EmpleadoAdicional.codigo = @ncodigo ) 
        BEGIN
            UPDATE  dbo.EmpleadoAdicional
            SET     dbo.EmpleadoAdicional.discapacitado = @discapacitado ,
                    dbo.EmpleadoAdicional.clabe = @clabe ,
                    dbo.EmpleadoAdicional.tipoRegimen = @tipoRegimen ,
                    dbo.EmpleadoAdicional.tipoContrato = @tipoContrato ,
                    dbo.EmpleadoAdicional.claveSat = @claveSat ,
                    dbo.EmpleadoAdicional.porcientoSat =  @porcientoSat,
                    dbo.EmpleadoAdicional.claveEstado = @claveEstado,
                    dbo.EmpleadoAdicional.nss = @nss,
					dbo.EmpleadoAdicional.regimenFiscal = @regimenFiscal
            WHERE   dbo.EmpleadoAdicional.empresa = @nempresa
                    AND dbo.EmpleadoAdicional.codigo = @ncodigo
            SELECT  @nerr_ins_dis = @@ERROR
        END
    ELSE 
        BEGIN
            INSERT  dbo.EmpleadoAdicional
                    ( empresa ,
                      codigo ,
                      discapacitado ,
                      clabe ,
                      tipoRegimen ,
                      tipoContrato ,
                      claveSat ,
                      porcientoSat,
                      claveEstado,
                      nss,
					  regimenFiscal
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      @discapacitado ,
                      @clabe ,
                      @tipoRegimen ,
                      @tipoContrato ,
                      @claveSat ,
                      @porcientoSat,
                      @claveEstado,
                      @nss,
					  @regimenFiscal
                    )
            SELECT  @nerr_ins_dis = @@ERROR
        END
    

    IF @nerr_upd_emp <> 0
        OR @nerr_upd_lla <> 0
        OR @nerr_upd_dat <> 0
        OR @nerr_upd_avi <> 0
        OR @nerr_ins_pcv <> 0
        OR @nerr_ins_piv <> 0
        OR @nerr_ins_nim <> 0
        OR @nerr_ins_115 <> 0
        OR @nerr_ins_dis <> 0
        --OR @nerr_ins_cho <> 0
        --OR @nerr_ins_ach <> 0 
        BEGIN
            ROLLBACK TRANSACTION
            INSERT  INTO dbo.estatus
                    ( empresa ,
                      codigo ,
                      grabo ,
                      funcion ,
                      opcion
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'F' ,
                      @cfuncion ,
                      @copcion
                    )
        END
    ELSE 
        BEGIN
            COMMIT TRANSACTION
            INSERT  INTO dbo.estatus
                    ( empresa ,
                      codigo ,
                      grabo ,
                      funcion ,
                      opcion
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      'T' ,
                      @cfuncion ,
                      @copcion
                    )
        END
GO

IF OBJECT_ID('dbo.Fun_L_SeguridadHigieneXls') IS NOT NULL 
    DROP PROCEDURE dbo.Fun_L_SeguridadHigieneXls
GO
--exec dbo.Fun_L_SeguridadHigieneXls 1,2012
CREATE PROCEDURE dbo.Fun_L_SeguridadHigieneXls
    @nEmpresa INTEGER ,
    @nEjercicio INTEGER
AS /*
DECLARE @nEmpresa   INTEGER
DECLARE @nEjercicio INTEGER

SET @nEmpresa = 1
SET @nEjercicio = 2012
*/

    SET NOCOUNT ON 

    SELECT  Casos_Rt.Codigo ,
            RTRIM(Empleados.Ap_Paterno) + ' ' + RTRIM(Empleados.Ap_Materno)
            + ' ' + RTRIM(Empleados.Nombre) AS Nombre ,
            Empleados.Afiliacion ,
            Llaves.Centro ,
            Tabulador.Actividad ,
            Casos_Rt.Caso ,
            CASE WHEN Casos_Rt.St1_Accidente = 1 THEN 'Accidente'
                 ELSE 'Recaida'
            END AS St1_Tipo ,
            Casos_Rt.St1_Fecha ,
            Casos_Rt.St1_Trayecto ,
            ResumenCaso.Dias ,
            CASE WHEN Casos_Rt.St2_Accidente = 1 THEN 'Accidente'
                 ELSE 'Enfermedad'
            END AS St2_Tipo ,
            St2_Fecha ,
            CASE Casos_Rt.St3_Accidente
              WHEN 1 THEN 'Sin ST-3'
              WHEN 2 THEN 'Incapacidad P/Parcial'
              WHEN 3 THEN 'Incapacidad P/Total'
              ELSE 'Defuncin'
            END AS St3_Tipo ,
            St3_Valuacion ,
            SeguridadHigiene.LugarAccidente ,
            SeguridadHigiene.HoraAccidente ,
            CASE WHEN SeguridadHigiene.LesionesAnteriores = 1 THEN 'S'
                 ELSE 'N'
            END AS LesionesAnteriores ,
            SeguridadHigiene.DeclaracionAccidentado ,
            SeguridadHigiene.Testigo1 ,
            SeguridadHigiene.Testigo2 ,
            CASE SeguridadHigiene.ClasificacionAccidente
              WHEN 1 THEN 'CASI ACCIDENTE'
              WHEN 2 THEN 'LESION LEVE'
              WHEN 3 THEN 'INCAPACITANTE'
              ELSE 'DAOS MATERIALES'
            END AS Clasificacion ,
            SeguridadHigiene.DescripcionAccidente ,
            SeguridadHigiene.ComiteInvestigacion ,
            SeguridadHigiene.MedidasPreventivas ,
            SeguridadHigiene.Responsable ,
            SeguridadHigiene.Fecha ,
            TipoAccidente.Descripcion AS TipoAccidente ,
            Agente.Descripcion AS Agente ,
            Condicion.Descripcion AS CondicionInsegura ,
            Acto.Descripcion AS ActoInseguro ,
            Lesion.Descripcion AS TipoLesion ,
            Parte.Descripcion AS ParteAfectada
    FROM    dbo.Casos_Rt
            INNER JOIN dbo.Empleados ON Empleados.Codigo = Casos_Rt.Codigo
                                        AND Empleados.Empresa = Casos_Rt.Empresa
            INNER JOIN dbo.Llaves ON Llaves.Codigo = Casos_Rt.Codigo
                                     AND Llaves.Empresa = Casos_Rt.Empresa
            INNER JOIN dbo.Tabulador ON Tabulador.Ocupacion = Llaves.Ocupacion
                                        AND Tabulador.Empresa = Llaves.Empresa
            INNER JOIN dbo.SeguridadHigiene ON SeguridadHigiene.Codigo = Casos_Rt.Codigo
                                               AND SeguridadHigiene.Caso = Casos_Rt.Caso
                                               AND SeguridadHigiene.Ayo_Operacion = Casos_Rt.Ayo_Operacion
                                               AND SeguridadHigiene.Empresa = Casos_Rt.Empresa
            INNER JOIN dbo.CatalogoSeguridadHigiene AS TipoAccidente ON TipoAccidente.Tipo = 1
                                                              AND TipoAccidente.Folio = SeguridadHigiene.TipoAccidente
                                                              AND TipoAccidente.Empresa = SeguridadHigiene.Empresa
            INNER JOIN dbo.CatalogoSeguridadHigiene AS Agente ON Agente.Tipo = 2
                                                              AND Agente.Folio = SeguridadHigiene.Agente
                                                              AND Agente.Empresa = SeguridadHigiene.Empresa
            INNER JOIN dbo.CatalogoSeguridadHigiene AS Condicion ON Condicion.Tipo = 3
                                                              AND Condicion.Folio = SeguridadHigiene.CondicionInsegura
                                                              AND Condicion.Empresa = SeguridadHigiene.Empresa
            INNER JOIN dbo.CatalogoSeguridadHigiene AS Acto ON Acto.Tipo = 4
                                                              AND Acto.Folio = SeguridadHigiene.ActoInseguro
                                                              AND Acto.Empresa = SeguridadHigiene.Empresa
            INNER JOIN dbo.CatalogoSeguridadHigiene AS Lesion ON Lesion.Tipo = 5
                                                              AND Lesion.Folio = SeguridadHigiene.TipoLesion
                                                              AND Lesion.Empresa = SeguridadHigiene.Empresa
            INNER JOIN dbo.CatalogoSeguridadHigiene AS Parte ON Parte.Tipo = 6
                                                              AND Parte.Folio = SeguridadHigiene.ParteAfectada
                                                              AND Parte.Empresa = SeguridadHigiene.Empresa
            LEFT JOIN ( SELECT  Codigo ,
                                Caso ,
                                SUM(Dias) AS Dias
                        FROM    dbo.Incapacidades_Rt
                        WHERE   Ayo_Operacion = @nEjercicio
                                AND Empresa = @nEmpresa
                        GROUP BY Codigo ,
                                Caso
                      ) AS ResumenCaso ON ResumenCaso.Codigo = Casos_Rt.Codigo
                                          AND ResumenCaso.Caso = Casos_Rt.Caso
    WHERE   Casos_Rt.Ayo_Operacion = @nEjercicio
            AND Casos_Rt.Empresa = @nEmpresa
GO

IF OBJECT_ID('dbo.GetCatalogCostCenter') IS NOT NULL 
    DROP PROCEDURE dbo.GetCatalogCostCenter
GO
CREATE PROCEDURE dbo.GetCatalogCostCenter
    @companyId udtInteger ,
    @costCenter udtName ,
    @user udtName ,
    @system udtName

AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    SET XACT_ABORT ON
    BEGIN TRY

        SELECT  centros.centro ,
                centros.nomdepto ,
                LTRIM(RTRIM(centros.centro)) + '.- ' + centros.nomdepto AS cadena
        FROM    centros
        WHERE   centros.empresa = @companyId
                AND centros.centro IN (
                SELECT  costCenter
                FROM    [dbo].[GetCostCenterByProfile](@user, @costCenter,
                                                       @companyId, @system) )
        ORDER BY centros.centro

    END TRY
    
    BEGIN CATCH

        DECLARE @ErrorSeverity udtInteger
        DECLARE @ErrorState udtInteger
        DECLARE @ErrorMessage udtStringSize2048

        SET @ErrorSeverity = ERROR_SEVERITY()
        SET @ErrorState = ERROR_STATE()
        SET @ErrorMessage = 'State: ' + LTRIM(RTRIM(STR(@ErrorState)))
            + CHAR(13) + CHAR(10) + 'Severity: '
            + LTRIM(RTRIM(STR(@ErrorSeverity))) + CHAR(13) + CHAR(10)
            + 'Error number:  ' + LTRIM(RTRIM(STR(ERROR_NUMBER()))) + CHAR(13)
            + CHAR(10) + 'Message: ' + ERROR_MESSAGE() + CHAR(13) + CHAR(10)
            + 'Procedure: ' + ERROR_PROCEDURE() + CHAR(13) + CHAR(10)
            + 'Line: ' + LTRIM(RTRIM(STR(ERROR_LINE())))

        RAISERROR ( @ErrorMessage, @ErrorSeverity, @ErrorState )

    END CATCH                    
GO

IF OBJECT_ID('dbo.GetCostCenterByProfile') IS NOT NULL 
    DROP FUNCTION dbo.GetCostCenterByProfile
GO
CREATE FUNCTION [dbo].[GetCostCenterByProfile]
    (
      @user udtName ,
      @costCenter udtName ,
      @companyId udtInteger ,
      @system udtName 
    )
RETURNS @costCenterTable TABLE ( costCenter udtName )

AS 
    BEGIN
    
        DECLARE @profileId udtInteger
        DECLARE @costCenterTableTmp TABLE ( costCenter udtName )
        
        
        SET @profileId = ISNULL(( SELECT    p.idperfil
                                  FROM      [dbo].[perfiles] AS p
                                            INNER JOIN [dbo].[perfil_usuarios] AS u ON p.idperfil = u.idperfil
                                            --OUTER APPLY (SELECT TOP 1 1 AS existe
                                            --             FROM dbo.perfil_centro AS pc
                                            --             WHERE pc.idperfil = p.idperfil) AS pc
                                  WHERE     u.usuario = @user
                                            AND p.sistema = @system
                                ), 0)
                         
        IF @profileId > 0 
            --IF ( SELECT COUNT(*)
            --     FROM   dbo.perfil_centro
            --     WHERE  idperfil = @profileId
            --   ) = 0 
            IF NOT EXISTS ( SELECT  dbo.perfil_centro.centro
                            FROM    dbo.perfil_centro
                            WHERE   dbo.perfil_centro.idperfil = @profileId
                                    AND dbo.perfil_centro.empresa = @companyId -- Agregada 30/05/2017 JCMM
                          ) 
                BEGIN               

                    IF @costCenter = ''
                        OR @costCenter = ' ' 
                        INSERT  INTO @costCenterTableTmp
                                SELECT  dbo.centros.centro
                                FROM    [dbo].[centros]
                                WHERE   dbo.centros.empresa = @companyId
                                ORDER BY dbo.centros.centro
                    ELSE 
                        INSERT  INTO @costCenterTableTmp
                                SELECT  dbo.centros.centro
                                FROM    [dbo].[centros]
                                WHERE   dbo.centros.empresa = @companyId
                                        AND dbo.centros.centro = @costCenter
                                ORDER BY dbo.centros.centro
                END 
            ELSE 
                BEGIN
                    IF @costCenter = ''
                        OR @costCenter = ' ' 
                        INSERT  INTO @costCenterTableTmp
                                SELECT  dbo.perfil_centro.centro
                                FROM    [dbo].[perfil_centro]
                                WHERE   dbo.perfil_centro.idperfil = @profileId
                                        AND dbo.perfil_centro.empresa = @companyId -- Agregada 30/05/2017 JCMM
                
                    ELSE 
                        INSERT  INTO @costCenterTableTmp
                                SELECT  dbo.perfil_centro.centro
                                FROM    [dbo].[perfil_centro]
                                WHERE   dbo.perfil_centro.centro = @costCenter
                                        AND dbo.perfil_centro.idperfil = @profileId
                                        AND dbo.perfil_centro.empresa = @companyId -- Agregada 30/05/2017 JCMM
                END
                
        -- Agrega Centro General 
        INSERT  @costCenterTableTmp
                ( costCenter 
                            
                )
                SELECT '               ' -- General
                FROM @costCenterTable AS costCenterTable
                WHERE NOT EXISTS (SELECT costCenterTable.costCenter
                                  FROM @costCenterTable AS costCenterTable
                                  WHERE costCenterTable.costCenter = '               ')
                
        -- Agrega Centro Total
        INSERT  @costCenterTableTmp
                ( costCenter 
                            
                )
                SELECT '99999999999997 ' -- Total
                FROM @costCenterTable AS costCenterTable
                WHERE NOT EXISTS (SELECT costCenterTable.costCenter
                                  FROM @costCenterTable AS costCenterTable
                                  WHERE costCenterTable.costCenter = '99999999999997 ')
                                  
        INSERT @costCenterTable
                ( costCenter )
                SELECT costCenterTableTmp.costCenter
                FROM @costCenterTableTmp AS costCenterTableTmp
                ORDER BY costCenterTableTmp.costCenter
        RETURN
    END
GO

/**************************************************************************************************
 * Name          : GetPermanentAuthorization
 * Project       : APSISISTEMAS
 * Description   : Finds existing records
 * Table name    : GetAbsentism
 * Copyright     : APSI SA, de CV 2010 - 2015. All rights reserved
 * Company       : APSI SA, de CV
 * Author        : adan.sanchez@apsi.com.mx
 * Creation date : martes, 12 de octubre de 2010
 **************************************************************************************************/
IF OBJECT_ID('dbo.GetPermanentAuthorization') IS NOT NULL
    DROP PROCEDURE dbo.GetPermanentAuthorization
GO
CREATE PROCEDURE dbo.GetPermanentAuthorization(
    @companyId AS udtInteger,
    @employeeId AS udtStringSize1024,
    @startPosition AS udtInteger,
    @elementsToRetrieve AS udtInteger
)

AS
SET NOCOUNT ON
SET DATEFORMAT MDY
DECLARE @selectClause AS NVARCHAR(4000)
DECLARE @whereClause AS udtStringSize1024
DECLARE @orderByClause AS udtStringSize512
DECLARE @totalRecords AS udtInteger
DECLARE @startPositionPlusOneElement AS udtInteger
DECLARE @whereClauseUsed AS udtBoolean
DECLARE @debugFlag AS udtBoolean
SET XACT_ABORT ON
BEGIN TRANSACTION
    BEGIN TRY
    
        -- Set the debug flag
        SET @debugFlag = 0
        
        -- Initialize the local variables
        SET @whereClauseUsed = 0
        SET @whereClause = ''
        SET @orderByClause = ''
        
        -- Count all the existing records
        SET @selectClause = 'SELECT COUNT(*) FROM empleados as a '
        
        -- Search criteria: empresa
        IF @companyId > 0 BEGIN
    
            IF @whereClauseUsed = 0 BEGIN
               
                SET @whereClause = @whereClause + 'WHERE '
                SET @whereClauseUsed = 1
    
            END ELSE
                  
                SET @whereClause = @whereClause + ' AND '
                         
            SET @whereClause = @whereClause + 'a.empresa = ' + LTRIM(RTRIM(STR(@companyId)))
                 
        END
        
        -- Search criteria: codigo
        IF len(@employeeId) > 0 BEGIN
    
            IF @whereClauseUsed = 0 BEGIN
               
                SET @whereClause = @whereClause + 'WHERE '
                SET @whereClauseUsed = 1
    
            END ELSE
                  
                SET @whereClause = @whereClause + ' AND '
                         
            SET @whereClause = @whereClause + 'a.codigo in(' + LTRIM(RTRIM(@employeeId)) + ')'
                 
        END
        
        --Print @whereClause
        CREATE TABLE #GetemployessCounter (
            TotalRecords Integer
        )
        
        IF @debugFlag = 1
            SELECT @selectClause + @whereClause
        ELSE
            INSERT INTO #GetemployessCounter EXECUTE (@selectClause + @whereClause)
    
        -- Set the total records indicador
        SELECT TOP 1 @totalRecords = TotalRecords FROM #GetemployessCounter
        SET @totalRecords = ISNULL(@totalRecords, 0)
        SET @whereClauseUsed = 0
        
        DROP TABLE #GetemployessCounter
        
        -- Check the element per page indicator
        IF @elementsToRetrieve < 1
            SET @elementsToRetrieve = @totalRecords
    
        -- Check the initial position
        IF @startPosition < 1
            SET @startPosition = 0
            
        SET @whereClauseUsed = 0
    
        IF @startPosition > 1 BEGIN
    
            SET @startPositionPlusOneElement = @startPosition + @elementsToRetrieve - 1
            
            IF @startPositionPlusOneElement < 1
                SET @startPositionPlusOneElement = 1
    
            IF @startPositionPlusOneElement > @totalRecords BEGIN
                SET @startPositionPlusOneElement = @totalRecords
                SET @elementsToRetrieve = @totalRecords - @startPosition + 1
            END
            
            IF @startPosition = @totalRecords
                SET @elementsToRetrieve = 1
    
            IF @startPosition > @totalRecords
                SET @startPosition = @totalRecords
    
            IF @elementsToRetrieve >= @totalRecords AND @startPosition > 1
                SET @elementsToRetrieve = @totalRecords - @startPosition + 1
    
            SET @selectClause = 'SELECT empresa,
                                        registro_patronal,
                                        poblacion_empresa,
                                        codigo,nombre,
                                        ap_paterno,
                                        ap_materno,
                                        afiliacion,
                                        digvera,
                                        sexo,
                                        fchnac,
                                        domicilio,
                                        colonia,
                                        municipio,
                                        umf,
                                        codpostal, ' + 
                                        RTRIM(LTRIM(STR(@totalRecords))) + ' AS TotalRecords 
                                 FROM (SELECT TOP ' + 
                                              LTRIM(RTRIM(STR(@elementsToRetrieve))) + ' 
                                              empresa,
                                              registro_patronal,
                                              poblacion_empresa,
                                              codigo,
                                              nombre,
                                              ap_paterno,
                                              ap_materno,
                                              afiliacion,
                                              digvera,
                                              sexo,
                                              fchnac,
                                              domicilio,
                                              colonia,
                                              municipio,
                                              umf,
                                              codpostal 
                                       FROM (SELECT TOP ' + 
                                                    LTRIM(RTRIM(STR(@startPositionPlusOneElement))) + ' 
                                                    e.empresa,
                                                    substring(e.registro_patronal,1,3) + ''-'' + substring(e.registro_patronal,4,07) + ''-'' + substring(e.registro_patronal,11,01) as registro_patronal,
                                                    e.poblacion_empresa,
                                                    a.codigo,
                                                    a.nombre,
                                                    a.ap_paterno,
                                                    a.ap_materno,
                                                    a.afiliacion,
                                                    a.digvera,
                                                    a.sexo,
                                                    a.fchnac,
                                                    b.domicilio,
                                                    b.colonia,
                                                    b.municipio,
                                                    b.umf,
                                                    codpostal
                                                    
                                             FROM empresas as e 
                                                  INNER JOIN empleados as a ON e.empresa = a.empresa 
                                                  INNER JOIN datosemps as b ON a.empresa = b.empresa 
                                                                               AND a.codigo = b.codigo  '
                                                                               
            SET @orderByClause = ' ORDER BY codigo DESC) AS GetAbsentismTemporalOne ORDER BY codigo DESC) AS GetAbsentismTemporalTwo ORDER BY V'
    
        END ELSE BEGIN
    
            IF @startPosition = 0
    
                SET @selectClause = 'SELECT TOP 100 PERCENT'
    
            ELSE
            
                SET @selectClause = 'SELECT TOP ' + RTRIM(LTRIM(STR(@elementsToRetrieve)))
    
            SET @selectClause = @selectClause + ' 
                                                 e.empresa,
                                                 substring(e.registro_patronal,1,3) + ''-'' + substring(e.registro_patronal,4,07) + ''-'' + substring(e.registro_patronal,11,1) as registro_patronal,
                                                 e.poblacion_empresa,
                                                 a.codigo,
                                                 a.nombre,
                                                 a.ap_paterno,
                                                 a.ap_materno,
                                                 a.afiliacion,
                                                 a.digvera,
                                                 a.sexo,
                                                 a.fchnac,
                                                 b.domicilio,
                                                 b.colonia,
                                                 b.municipio,
                                                 b.umf,
                                                 codpostal, ' + 
                                                 RTRIM(LTRIM(STR(@totalRecords))) + ' AS TotalRecords ,
                                                 b.numeroExterior,
                                                 b.numeroInterior,
                                                 b.poblacion
                                FROM empresas as e 
                                     INNER JOIN empleados as a ON e.empresa = a.empresa 
                                     INNER JOIN datosemps as b ON a.empresa = b.empresa 
                                                                  AND a.codigo = b.codigo '

            SET @orderByClause = ' ORDER BY a.empresa DESC '
        END

        IF @debugFlag = 1
            SELECT @selectClause + @whereClause + @orderByClause
        ELSE
            EXECUTE (@selectClause + @whereClause + @orderByClause)

    END TRY
    BEGIN CATCH

        DECLARE @ErrorSeverity udtInteger
        DECLARE @ErrorState udtInteger
        DECLARE @ErrorMessage udtStringSize2048

        SET @ErrorSeverity = ERROR_SEVERITY()
        SET @ErrorState = ERROR_STATE()
        SET @ErrorMessage = 'State: ' + LTRIM(RTRIM(STR(@ErrorState))) + CHAR(13) + CHAR(10) + 'Severity: ' + LTRIM(RTRIM(STR(@ErrorSeverity))) + CHAR(13) + CHAR(10) + 'Error number:  ' + LTRIM(RTRIM(STR(ERROR_NUMBER()))) + CHAR(13) + CHAR(10) + 'Message: ' + ERROR_MESSAGE() + CHAR(13) + CHAR(10) + 'Procedure: ' + ERROR_PROCEDURE() + CHAR(13) + CHAR(10) + 'Line: ' + LTRIM(RTRIM(STR(ERROR_LINE())))

        IF ( XACT_STATE() ) = -1 OR @@TRANCOUNT > 0
            ROLLBACK TRANSACTION

        RAISERROR ( @ErrorMessage, @ErrorSeverity, @ErrorState )

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION
GO

IF OBJECT_ID('dbo.GetTypePayrollByProfile') IS NOT NULL 
    DROP FUNCTION [dbo].[GetTypePayrollByProfile]
GO
CREATE FUNCTION [dbo].[GetTypePayrollByProfile]
    (
      @user udtName ,
      @typePayroll udtInteger ,
      @companyId udtInteger ,
      @system udtName
    )
RETURNS @typePayrollTable TABLE
    (
      typePayroll udtInteger
    )
    
AS 
    BEGIN
        DECLARE @string udtStringSize1024
        DECLARE @counter udtInteger
        DECLARE @block udtName
        DECLARE @uso udtName
        DECLARE @tipoNomina INT
                      
        SET @string = ( SELECT  p.nomina
                        FROM    [dbo].[perfiles] AS p
                                INNER JOIN [dbo].[perfil_usuarios] AS u ON p.idperfil = u.idperfil
                                --OUTER APPLY (SELECT TOP 1 1 AS existe
                                --             FROM dbo.perfil_centro AS pc
                                --             WHERE pc.idperfil = p.idperfil) AS pc
                        WHERE   u.usuario = @user
                                AND p.sistema = @system
                      )
              
        IF LTRIM(RTRIM(@string)) = '{}' 
            IF @typePayroll = 0 
                INSERT  INTO @typePayrollTable
                        ( typePayroll
                        )
                        SELECT  DISTINCT dbo.Nominas.tiponom
                        FROM    dbo.Nominas
                        WHERE   dbo.Nominas.empresa = @companyId
                                --AND dbo.Nominas.uso = 'S'
                        ORDER BY --dbo.Nominas.empresa ,
                                dbo.Nominas.tiponom
            ELSE 
                INSERT  INTO @typePayrollTable
                        ( typePayroll
                        )
                        SELECT  DISTINCT dbo.Nominas.tiponom
                        FROM    dbo.Nominas
                        WHERE   dbo.Nominas.empresa = @companyId
                                --AND dbo.Nominas.uso = 'S'
                                AND dbo.Nominas.tiponom = @typePayroll
                        ORDER BY --dbo.Nominas.empresa ,
                                dbo.Nominas.tiponom
                    
        ELSE 
            BEGIN 
                SET @string = SUBSTRING(@string, 2, LEN(@string) - 2)
            
                SET @counter = 1
                SET @block = ''
                
                WHILE @counter <= LEN(@string) 
                    BEGIN

                        IF SUBSTRING(@string, @counter, 1) <> ','
                            OR @counter = LEN(@string) 
                            SET @block = @block + SUBSTRING(@string, @counter,
                                                            1)
                 
                        IF SUBSTRING(@string, @counter, 1) = ','
                            OR @counter = LEN(@string) 
                            BEGIN
                                IF @typePayroll = 0
                                    OR @typePayroll = CONVERT(INT, @block) 
                                    BEGIN
                                    
                                        --SELECT  @uso = dbo.Nominas.uso
                                        --FROM    dbo.Nominas
                                        --WHERE   dbo.Nominas.empresa = @companyId
                                        --        AND dbo.Nominas.tiponom = CONVERT(INT, @block)
                                    
                                        --IF @uso = 'S' 
                                            SET @tipoNomina = CONVERT(INT, @block)
                                            
                                            IF EXISTS (SELECT dbo.Nominas.tiponom
                                                       FROM dbo.Nominas
                                                       WHERE dbo.Nominas.empresa = @companyId
                                                             AND dbo.Nominas.tiponom = @tiponomina)
                                               BEGIN
                                                 INSERT @typePayrollTable
                                                        ( typePayroll )
                                                 --VALUES  ( CONVERT(INT, @block) )
                                                        SELECT @tipoNomina AS typePayroll
                                                        WHERE NOT EXISTS (SELECT 1 FROM @typePayrollTable WHERE typePayroll = @tipoNomina)
                                               END
                                    END
                                SET @block = ''
                            END
                                                            
                        SET @counter = @counter + 1
                    END
            END  
            
        -- Agrega Centro General 
        IF NOT EXISTS ( SELECT  typePayrollTable.typePayroll
                        FROM    @typePayrollTable AS typePayrollTable
                        WHERE   typePayrollTable.typePayroll = 0 ) 
            BEGIN
                INSERT  @typePayrollTable
                        ( typePayroll )
                VALUES  ( 0 )
            END
        RETURN
    END
GO

IF OBJECT_ID('dbo.GrabaSeleccionSalarioMinimo') IS NOT NULL 
    DROP PROCEDURE dbo.GrabaSeleccionSalarioMinimo
GO
CREATE PROCEDURE dbo.GrabaSeleccionSalarioMinimo
    @empresa INT ,
    @seleccionSalario CHAR(1)
AS 
    UPDATE  dbo.empresas
    SET     dbo.empresas.usarSalarioMinimo = @seleccionSalario
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa
GO

IF OBJECT_ID('dbo.KardexImprimeRecibosDepura') IS NOT NULL 
    DROP PROCEDURE dbo.KardexImprimeRecibosDepura
GO
CREATE PROCEDURE dbo.KardexImprimeRecibosDepura
    @empresa INT ,
    @proceso VARCHAR(250) ,
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS 
    DELETE  kardexImprimeRecibos
    FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
    WHERE   RIGHT(10000 + YEAR(kardexImprimeRecibos.fechaProceso),4)
            + RIGHT(100 + MONTH(kardexImprimeRecibos.fechaProceso),2)
            + RIGHT(100 + DAY(kardexImprimeRecibos.fechaProceso),2)
            + kardexImprimeRecibos.horaProceso <= RIGHT(10000 + YEAR(@fechaProceso),4)
                                                  + RIGHT(100 + MONTH(@fechaProceso),2)
                                                  + RIGHT(100 + DAY(@fechaProceso),2)
                                                  + @horaProceso
            AND kardexImprimeRecibos.proceso = @proceso
            AND kardexImprimeRecibos.empresa = @empresa

    DELETE  KardexImprimeResumenISN
    FROM    dbo.KardexImprimeResumenISN AS KardexImprimeResumenISN
    WHERE   RIGHT(10000 + YEAR(KardexImprimeResumenISN.fechaProceso),4)
            + RIGHT(100 + MONTH(KardexImprimeResumenISN.fechaProceso),2)
            + RIGHT(100 + DAY(KardexImprimeResumenISN.fechaProceso),2)
            + KardexImprimeResumenISN.horaProceso <= RIGHT(10000 + YEAR(@fechaProceso),4)
                                                  + RIGHT(100 + MONTH(@fechaProceso),2)
                                                  + RIGHT(100 + DAY(@fechaProceso),2)
                                                  + @horaProceso
            AND KardexImprimeResumenISN.proceso = @proceso
            AND KardexImprimeResumenISN.empresa = @empresa
GO

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'LeeAuditoria' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[LeeAuditoria]
    END
GO


CREATE PROCEDURE [dbo].[LeeAuditoria] @nempresa NUMERIC(5, 0)
AS 
    SELECT  dbo.auditoria.empresa ,
            dbo.auditoria.codigo ,
            dbo.auditoria.ayos ,
            dbo.auditoria.sueldo ,
            dbo.auditoria.factor ,
            dbo.auditoria.importes_excedentes ,
            dbo.auditoria.sdi_fijo ,
            dbo.auditoria.parte_variable ,
            dbo.auditoria.sdi_reportado ,
            dbo.auditoria.sdi_ok ,
            dbo.auditoria.observacion ,
            dbo.auditoria.clase ,
            dbo.auditoria.nombre ,
            dbo.auditoria.fch_antigua ,
            dbo.auditoria.tipo_salario ,
            dbo.auditoria.mes ,
            dbo.auditoria.ayo ,
            dbo.auditoria.usuario ,
            dbo.auditoria.fecha_auto ,
            dbo.auditoria.marca ,
            dbo.auditoria.incapacitado ,
            dbo.auditoria.mov ,
            dbo.auditoria.fch_mov ,
            dbo.auditoria.obs_auto ,
            dbo.auditoria.fchalta ,
            dbo.auditoria.rpu ,
            dbo.auditoria.nombreClase ,
            dbo.auditoria.multiple ,
            dbo.auditoria.ocupacion ,
            dbo.auditoria.centro ,
            dbo.auditoria.jornada,
            convert(char(1), ' ') as observa,
            convert(char(1), 'N') as hay_error,
            incapacitado,
            convert(char(1), 'N') as error3_4,
            convert(char(1), 'N') as autoregularizacion,
            dbo.auditoria.tiponom
    FROM    dbo.auditoria
    WHERE   dbo.auditoria.empresa = @nempresa
    ORDER BY dbo.auditoria.clase ,
            dbo.auditoria.codigo
GO

IF OBJECT_ID('dbo.LeeAuditoria2')  IS NOT NULL
   DROP  PROCEDURE dbo.LeeAuditoria2
GO
CREATE PROCEDURE dbo.LeeAuditoria2 
@empresa NUMERIC(5, 0),
@usuario VARCHAR(30),
@ip VARCHAR(15),
@mac VARCHAR(17),
@nombreEquipo VARCHAR(50),
@origen VARCHAR(2)

AS 
    SELECT  dbo.auditoria.empresa ,
            dbo.auditoria.codigo ,
            dbo.auditoria.ayos ,
            dbo.auditoria.sueldo ,
            dbo.auditoria.factor ,
            dbo.auditoria.importes_excedentes ,
            dbo.auditoria.sdi_fijo ,
            dbo.auditoria.parte_variable ,
            dbo.auditoria.sdi_reportado ,
            dbo.auditoria.sdi_ok ,
            dbo.auditoria.observacion ,
            dbo.auditoria.clase ,
            dbo.auditoria.nombre ,
            dbo.auditoria.fch_antigua ,
            dbo.auditoria.tipo_salario ,
            dbo.auditoria.mes ,
            dbo.auditoria.ayo ,
            dbo.auditoria.usuario ,
            dbo.auditoria.fecha_auto ,
            dbo.auditoria.marca ,
            dbo.auditoria.incapacitado ,
            dbo.auditoria.mov ,
            dbo.auditoria.fch_mov ,
            dbo.auditoria.obs_auto ,
            dbo.auditoria.fchalta ,
            dbo.auditoria.rpu ,
            dbo.auditoria.nombreClase ,
            dbo.auditoria.multiple ,
            dbo.auditoria.ocupacion ,
            dbo.auditoria.centro ,
            dbo.auditoria.jornada,
            convert(char(1), ' ') as observa,
            convert(char(1), 'N') as hay_error,
            incapacitado,
            convert(char(1), 'N') as error3_4,
            convert(char(1), 'N') as autoregularizacion,
            dbo.auditoria.tiponom
    FROM    dbo.auditoria
  WHERE auditoria.empresa = @empresa 
        AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario)) 
        --AND LTRIM(RTRIM(auditoria.ip)) = LTRIM(RTRIM(@ip)) 
        AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac)) 
        AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreEquipo)) 
        AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
  ORDER BY auditoria.clase,
           auditoria.codigo
GO

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'LeePRT' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[LeePRT]
    END
GO


CREATE PROCEDURE [dbo].[LeePRT] @empresa INT, @ayo INT
AS 
    SELECT  dbo.resumen_rt.empresa ,
            dbo.resumen_rt.ayo_operacion ,
            dbo.resumen_rt.reg_pat ,
            dbo.resumen_rt.nom_pat ,
            dbo.resumen_rt.dom_pat ,
            dbo.resumen_rt.pob_pat ,
            dbo.resumen_rt.cod_pat ,
            dbo.resumen_rt.telefono ,
            dbo.resumen_rt.act_pat ,
            dbo.resumen_rt.clase ,
            dbo.resumen_rt.fraccion ,
            dbo.resumen_rt.prima_anterior ,
            FLOOR(dbo.resumen_rt.s) AS s ,
            CONVERT(NUMERIC(8, 2), dbo.resumen_rt.i) AS i ,
            FLOOR(dbo.resumen_rt.d) AS d ,
            CONVERT(VARCHAR(10), CONVERT(NUMERIC(8, 1), dbo.resumen_rt.n)) AS n ,
            dbo.resumen_rt.v ,
            dbo.resumen_rt.f ,
            CONVERT(VARCHAR(10), CONVERT(NUMERIC(10, 5), dbo.resumen_rt.m)) AS m ,
            dbo.resumen_rt.opera_1 ,
            dbo.resumen_rt.opera_2 ,
            dbo.resumen_rt.opera_3 ,
            dbo.resumen_rt.opera_4 ,
            dbo.resumen_rt.opera_5 ,
            dbo.resumen_rt.prima_nva ,
            dbo.resumen_rt.sistema ,
            dbo.resumen_rt.rep_pat ,
            dbo.resumen_rt.casos ,
            dbo.resumen_rt.rfc ,
            dbo.casos_rt_importado.nombre ,
            dbo.casos_rt_importado.afiliacion ,
            dbo.casos_rt_importado.digvera ,
            dbo.casos_rt_importado.curp ,
            dbo.casos_rt_importado.ayo_operacion ,
            dbo.casos_rt_importado.st1_accidente ,
            dbo.casos_rt_importado.st1_fecha ,
            dbo.casos_rt_importado.st2_accidente ,
            dbo.casos_rt_importado.st2_fecha ,
            dbo.casos_rt_importado.st3_accidente ,
            dbo.casos_rt_importado.st3_valuacion ,
            dbo.casos_rt_importado.dias_subs ,
            CONVERT(CHAR(4), YEAR(dbo.casos_rt_importado.st1_fecha)) AS ayoSt1 ,
            SUBSTRING(CONVERT(CHAR(3), 100
                      + MONTH(dbo.casos_rt_importado.st1_fecha)), 2, 2) AS mesSt1 ,
            SUBSTRING(CONVERT(CHAR(3), 100
                      + DAY(dbo.casos_rt_importado.st1_fecha)), 2, 2) AS diaSt1 ,
            CASE WHEN dbo.casos_rt_importado.st2_accidente = 1 THEN '1'
                 WHEN dbo.casos_rt_importado.st2_accidente = 2 THEN '3'
                 ELSE ' '
            END AS tipoRiesgo ,
            SUBSTRING(CONVERT(CHAR(4), 1000
                      + dbo.casos_rt_importado.st3_valuacion), 2, 3) AS st3Valuacion ,
            CASE WHEN dbo.casos_rt_importado.st3_accidente = 4 THEN 'D'
                 ELSE ' '
            END AS defuncion ,
            CONVERT(CHAR(4), YEAR(dbo.casos_rt_importado.st2_fecha)) AS ayoSt2 ,
            SUBSTRING(CONVERT(CHAR(3), 100
                      + MONTH(dbo.casos_rt_importado.st2_fecha)), 2, 2) AS mesSt2 ,
            SUBSTRING(CONVERT(CHAR(3), 100
                      + DAY(dbo.casos_rt_importado.st2_fecha)), 2, 2) AS diaSt2,
            CONVERT(VARCHAR(15), dbo.resumen_rt.prima_nva) AS primaNueva ,
            dbo.casos_rt_importado.apellidoPaterno ,
            dbo.casos_rt_importado.apellidoMaterno ,
            dbo.casos_rt_importado.nombreEmpleado ,
            dbo.resumen_rt.iCedula ,
            dbo.resumen_rt.sCedula ,
            dbo.resumen_rt.dCedula ,
            dbo.resumen_rt.nCedula ,
            dbo.resumen_rt.mCedula
    FROM    dbo.resumen_rt
            INNER JOIN dbo.casos_rt_importado ON dbo.resumen_rt.empresa = dbo.casos_rt_importado.empresa
                                                 AND dbo.resumen_rt.ayo_operacion = dbo.casos_rt_importado.ayo_operacion
    WHERE   resumen_rt.empresa = @empresa
            AND resumen_rt.ayo_operacion = @ayo
GO

IF OBJECT_ID('dbo.LlenaActualizacionFTP') IS NOT NULL 
   DROP PROCEDURE dbo.LlenaActualizacionFTP
GO
CREATE PROCEDURE dbo.LlenaActualizacionFTP
@archivo VARCHAR (255),
@tamano INTEGER,
@fecha DATETIME,
@hora CHAR(8)

AS 

  IF EXISTS (SELECT 1 FROM dbo.ActualizacionFTP AS af WHERE LTRIM(RTRIM(af.archivo)) = LTRIM(RTRIM(@archivo)))
     BEGIN
       UPDATE af
       SET af.tamano = @tamano,
           af.fecha = @fecha,
           af.hora = @hora,
           af.actualizado = 0
       FROM dbo.ActualizacionFTP AS af
       WHERE LTRIM(RTRIM(af.archivo)) = LTRIM(RTRIM(@archivo))
     END
  ELSE
     BEGIN
       INSERT dbo.ActualizacionFTP (archivo, tamano, fecha, hora, actualizado)  VALUES (@archivo, @tamano, @fecha, @hora, 0)
     END
GO

IF OBJECT_ID('dbo.LlenaImpresionNominaProcedure') IS NOT NULL
  DROP PROCEDURE dbo.LlenaImpresionNominaProcedure
GO

CREATE PROCEDURE [dbo].[LlenaImpresionNominaProcedure]
@empresa INT ,
@tiponomina INT ,
@nomina CHAR(3) ,
@incluirprovisiones CHAR(1) ,
@procesoname VARCHAR(100) ,
@ordenadopor INT ,
@desglosadopor INT ,
@porcentro INT ,
@esrecibo INT ,
@codigoseleccionado VARCHAR(500) ,
@ayoejercicio INT ,
@saltopagina CHAR(1) ,
@proceso VARCHAR(250) ,
@fechaproceso DATETIME ,
@horaproceso VARCHAR(8)
/*    
RETURNS @kardex TABLE
    (
      empresa INT ,
      codigoId VARCHAR(100) ,
      codigo INT ,
      nombre VARCHAR(100) ,
      fechaAlta DATETIME ,
      numeroSeguridadSocial VARCHAR(10) ,
      digitoVerificador CHAR(1) ,
      curp VARCHAR(18) ,
      centro VARCHAR(16) ,
      nombreCentro VARCHAR(50) ,
      cuentaBanco VARCHAR(30) ,
      nombreBanco VARCHAR(50) ,
      ocupacion INT ,
      categoria VARCHAR(50) ,
      tipoSalario INT ,
      renglon INT ,
      jornada INT ,
      sueldoDiario FLOAT ,
      salarioBaseCotizacion FLOAT ,
      clase VARCHAR(3) ,
      nombreClase VARCHAR(50) ,
      supervisor INT ,
      nombreSupervisor VARCHAR(50) ,
      marcaContraPercepcion CHAR(1) ,
      numeroConceptoPercepcion INT ,
      nombreConceptoPercepcion VARCHAR(50) ,
      importeConceptoPercepcion FLOAT ,
      gravablePercepcion FLOAT ,
      exentoPercepcion FLOAT ,
      saldoPercepcion FLOAT ,
      anexoConceptoPercepcion VARCHAR(150) ,
      marcaContraDeduccion CHAR(1) ,
      numeroConceptoDeduccion INT ,
      nombreConceptoDeduccion VARCHAR(50) ,
      importeConceptoDeduccion FLOAT ,
      gravableDeduccion FLOAT ,
      exentoDeduccion FLOAT ,
      saldoDeduccion FLOAT ,
      anexoConceptoDeduccion VARCHAR(150) ,
      numeroConceptoProvision INT ,
      nombreConceptoProvision VARCHAR(50) ,
      importeConceptoProvision FLOAT ,
      empleados INT ,
      provisionIMSS FLOAT ,
      provisionRCV FLOAT ,
      provisionINFONAVIT FLOAT ,
      retencionIMSS FLOAT ,
      retencionRCV FLOAT ,
      retencionINFONAVIT FLOAT ,
      empleadosConCuentaBancaria INT ,
      empleadosSinCuentaBancaria INT ,
      percepcionesConCuentaBancaria FLOAT ,
      deduccionesConCuentaBancaria FLOAT ,
      percepcionesSinCuentaBancaria FLOAT ,
      deduccionesSinCuentaBancaria FLOAT ,
      basePorcientoSobreNomina FLOAT ,
      porcientoSobreNomina FLOAT ,
      fondoAhorroAportacionEmpleado FLOAT ,
      fondoAhorroAportacionPatron FLOAT ,
      sueldoNetoGeneral FLOAT ,
      ejercicio INT ,
      diarioOficialDia INT ,
      diarioOficialMes INT ,
      diarioOficialAyo INT ,
      salarioMinimoDF FLOAT ,
      salarioMinimoRegion FLOAT ,
      eymArt25 FLOAT ,
      eymArt106ii FLOAT ,
      eymArt107 FLOAT ,
      ivArt147 FLOAT ,
      cvArt168ii FLOAT ,
      baseCalculo INT ,
      grupo VARCHAR(500) ,
      cuantosRecibos INT ,
      numeroRecibo INT ,
      recibo INT ,
      percepcionesEmpleado FLOAT ,
      deduccionesEmpleado FLOAT ,
      netoPagarEmpleado FLOAT ,
      grupoRecibo VARCHAR(500) ,
      rfcAlfa VARCHAR(4) ,
      rfcNum VARCHAR(6) ,
      rfcHomo VARCHAR(3) ,
      acumuladoPercepcion FLOAT ,
      acumuladoPercepcionGravable FLOAT ,
      acumuladoIsr FLOAT ,
      acumuladoInfonavit FLOAT ,
      acumuladoSar FLOAT ,
      acumuladoCv FLOAT ,
      email VARCHAR(60) ,
      fechaAntiguedad DATETIME ,
      procesoName VARCHAR(100) ,
      nomina CHAR(3) ,
      saltarPagina CHAR(1) ,
      firma CHAR(1) ,
      mov CHAR(2) ,
      foto VARCHAR(255),
      baseISN1      FLOAT,
      porcientoISN1 FLOAT,
      importeISN1   FLOAT,
      empleadosISN1 INT,
      baseISN2      FLOAT,
      porcientoISN2 FLOAT,
      importeISN2   FLOAT,
      empleadosISN2 INT ,
      imprimirResumen INT
    )
*/    
AS
SET NOCOUNT ON
    --BEGIN
-- Variables para Primas IMSS
        DECLARE @eymart25 FLOAT
        DECLARE @eympat25 FLOAT
        DECLARE @eymtra25 FLOAT
        DECLARE @eymart106i FLOAT
        DECLARE @eymart1062 FLOAT
        DECLARE @eympat1062 FLOAT
        DECLARE @eymtra1062 FLOAT
        DECLARE @eymart107 FLOAT
        DECLARE @eympat107 FLOAT
        DECLARE @eymtra107 FLOAT
        DECLARE @ivart147 FLOAT
        DECLARE @ivpat147 FLOAT
        DECLARE @ivtra147 FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvart168ii FLOAT
        DECLARE @cvpat168ii FLOAT
        DECLARE @cvtra168ii FLOAT
        DECLARE @patronpagaimss CHAR(1)
        DECLARE @mesempresa INT
        DECLARE @ayoempresa INT
        DECLARE @salarioregiona FLOAT
        DECLARE @salarioregionb FLOAT
        DECLARE @salarioregionc FLOAT
        DECLARE @salarioregion FLOAT
        DECLARE @salariodf FLOAT
        DECLARE @areageografica CHAR(1)
        DECLARE @topedf FLOAT
        DECLARE @toperegion FLOAT
        DECLARE @registropatronal VARCHAR(10)
        DECLARE @consulta VARCHAR(4000)
        DECLARE @orden VARCHAR(200)
        DECLARE @numeroconceptopercepcioniniciokardex INT
        DECLARE @numeroconceptopercepcionterminokardex INT
        DECLARE @numeroconceptocontrapercepcioniniciokardex INT
        DECLARE @numeroconceptocontrapercepcionterminokardex INT
        DECLARE @numeroconceptodeduccioniniciokardex INT
        DECLARE @numeroconceptodeduccionterminokardex INT
        DECLARE @numeroconceptocontradeduccioniniciokardex INT
        DECLARE @numeroconceptocontradeduccionterminokardex INT
        DECLARE @numeroconceptoprovisioniniciokardex INT
        DECLARE @numeroconceptoprovisionterminokardex INT
        DECLARE @ejercicio INT
        DECLARE @diariooficial DATETIME
        DECLARE @basecalculo VARCHAR(25)
        DECLARE @codigoanterior INT
        DECLARE @numerorecibo INT
        DECLARE @cuantosrecibos INT
        DECLARE @percepcionesempleado FLOAT
        DECLARE @deduccionesempleado FLOAT
        DECLARE @netopagarempleado FLOAT
        DECLARE @ayooperacion INT
        DECLARE @firma CHAR(1)
        DECLARE @regimen_seguridad_social CHAR(1)
        DECLARE @renglon TABLE
            (
              codigo INT ,
              nombre VARCHAR(100) ,
              centro VARCHAR(15) ,
              supervisor INT ,
              grupo VARCHAR(500) ,
              grupoRecibo VARCHAR(500) ,
              diferenciaRenglon INT ,
              ultimoRenglon INT ,
              renglon INT ,
              renglonesAgregar INT
            )
        DECLARE @agregarenglon TABLE ( renglon INT )

        DECLARE @pagonomina DATETIME
        DECLARE @uma FLOAT

        INSERT  @agregarenglon
                ( renglon )
        VALUES  ( 1 )
        INSERT  @agregarenglon
                ( renglon )
        VALUES  ( 2 )
        INSERT  @agregarenglon
                ( renglon )
        VALUES  ( 3 )

        SET @numeroconceptopercepcioniniciokardex = 1
        SET @numeroconceptopercepcionterminokardex = 99
        SET @numeroconceptocontrapercepcioniniciokardex = 1101
        SET @numeroconceptocontrapercepcionterminokardex = 1199
        SET @numeroconceptodeduccioniniciokardex = 101
        SET @numeroconceptodeduccionterminokardex = 199
        SET @numeroconceptocontradeduccioniniciokardex = 1001
        SET @numeroconceptocontradeduccionterminokardex = 1099
        SET @numeroconceptoprovisioniniciokardex = CASE WHEN @incluirprovisiones = 'S'
                                                        THEN 201
                                                        ELSE 0
                                                   END
        SET @numeroconceptoprovisionterminokardex = CASE WHEN @incluirprovisiones = 'S'
                                                         THEN 299
                                                         ELSE 0
                                                    END


-- Obtiene datos de empresas
        SELECT TOP 1
                @areageografica = dbo.empresas.zona_geografica ,
                @patronpagaimss = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoempresa = dbo.empresas.ayo_operacion ,
                @mesempresa = dbo.empresas.mes_operacion ,
                @registropatronal = SUBSTRING(dbo.empresas.registro_patronal,
                                              1, 10) ,
                @regimen_seguridad_social = ISNULL(dbo.empresas.Regimen_Seguridad_Social,'1')
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene primas IMSS en base al ao de operacion de la tabla empresas
        SELECT TOP 1
                @eymart25 = dbo.primas_imss.eymart25 ,
                @eympat25 = dbo.primas_imss.eympat25
                + CASE WHEN @patronpagaimss = 'S'
                       THEN dbo.primas_imss.eymtra25
                       ELSE 0
                  END ,
                @eymtra25 = CASE WHEN @patronpagaimss = 'S' THEN 0
                                 ELSE dbo.primas_imss.eymtra25
                            END ,
                @eymart106i = dbo.primas_imss.eymart106I ,
                @eymart1062 = dbo.primas_imss.eymart1062 ,
                @eympat1062 = dbo.primas_imss.eympat1062
                + CASE WHEN @patronpagaimss = 'S'
                       THEN dbo.primas_imss.eymtra1062
                       ELSE 0
                  END ,
                @eymtra1062 = CASE WHEN @patronpagaimss = 'S' THEN 0
                                   ELSE dbo.primas_imss.eymtra1062
                              END ,
                @eymart107 = dbo.primas_imss.eymart107 ,
                @eympat107 = dbo.primas_imss.eympat107
                + CASE WHEN @patronpagaimss = 'S'
                       THEN dbo.primas_imss.eymtra107
                       ELSE 0
                  END ,
                @eymtra107 = CASE WHEN @patronpagaimss = 'S' THEN 0
                                  ELSE dbo.primas_imss.eymtra107
                             END ,
                @ivart147 = dbo.primas_imss.ivart147 ,
                @ivpat147 = dbo.primas_imss.ivpat147
                + CASE WHEN @patronpagaimss = 'S'
                       THEN dbo.primas_imss.ivtra147
                       ELSE 0
                  END ,
                @ivtra147 = CASE WHEN @patronpagaimss = 'S' THEN 0
                                 ELSE dbo.primas_imss.ivtra147
                            END ,
                @retiro = dbo.primas_imss.retiro ,
                @cvart168ii = dbo.primas_imss.cvart168II ,
                @cvpat168ii = dbo.primas_imss.cvpat168II
                + CASE WHEN @patronpagaimss = 'S'
                       THEN dbo.primas_imss.cvtra168ii
                       ELSE 0
                  END ,
                @cvtra168ii = CASE WHEN @patronpagaimss = 'S' THEN 0
                                   ELSE dbo.primas_imss.cvtra168ii
                              END
        FROM    dbo.primas_imss
        WHERE   YEAR(dbo.primas_imss.periodo) = @ayoempresa



        SET @eymart25 = CASE WHEN @eymart25 IS NULL THEN 0
                             ELSE @eymart25
                        END
        SET @eympat25 = CASE WHEN @eympat25 IS NULL THEN 0
                             ELSE @eympat25
                        END
        SET @eymtra25 = CASE WHEN @eymtra25 IS NULL THEN 0
                             ELSE @eymtra25
                        END
        SET @eymart106i = CASE WHEN @eymart106i IS NULL THEN 0
                               ELSE @eymart106i
                          END
        SET @eymart1062 = CASE WHEN @eymart1062 IS NULL THEN 0
                               ELSE @eymart1062
                          END
        SET @eympat1062 = CASE WHEN @eympat1062 IS NULL THEN 0
                               ELSE @eympat1062
                          END
        SET @eymtra1062 = CASE WHEN @eymtra1062 IS NULL THEN 0
                               ELSE @eymtra1062
                          END
        SET @eymart107 = CASE WHEN @eymart107 IS NULL THEN 0
                              ELSE @eymart107
                         END
        SET @eympat107 = CASE WHEN @eympat107 IS NULL THEN 0
                              ELSE @eympat107
                         END
        SET @eymtra107 = CASE WHEN @eymtra107 IS NULL THEN 0
                              ELSE @eymtra107
                         END
        SET @ivart147 = CASE WHEN @ivart147 IS NULL THEN 0
                             ELSE @ivart147
                        END
        SET @ivpat147 = CASE WHEN @ivpat147 IS NULL THEN 0
                             ELSE @ivpat147
                        END
        SET @ivtra147 = CASE WHEN @ivtra147 IS NULL THEN 0
                             ELSE @ivtra147
                        END
        SET @retiro = CASE WHEN @retiro IS NULL THEN 0
                           ELSE @retiro
                      END
        SET @cvart168ii = CASE WHEN @cvart168ii IS NULL THEN 0
                               ELSE @cvart168ii
                          END
        SET @cvpat168ii = CASE WHEN @cvpat168ii IS NULL THEN 0
                               ELSE @cvpat168ii
                          END
        SET @cvtra168ii = CASE WHEN @cvtra168ii IS NULL THEN 0
                               ELSE @cvtra168ii
                          END
        SET @patronpagaimss = CASE WHEN @patronpagaimss IS NULL THEN 'N'
                                   ELSE @patronpagaimss
                              END


-- Obtiene Salario Minimo
        SELECT  @salarioregiona = ISNULL(zona_a, 0) ,
                @salarioregionb = ISNULL(zona_b, 0) ,
                @salarioregionc = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesempresa, @ayoempresa)

        SET @salariodf = @salarioregiona

        SET @salarioregion = CASE @areageografica
                               WHEN 'A' THEN @salarioregiona
                               WHEN 'B' THEN @salarioregionb
                               WHEN 'C' THEN @salarioregionc
                               ELSE 0
                             END

        SELECT  @ayooperacion = ISNULL(dbo.Periodos.ayo_operacion, 0),
                @pagonomina = dbo.Periodos.pago
        FROM    dbo.Periodos
        WHERE   dbo.Periodos.empresa = @empresa
                AND dbo.Periodos.tiponom = @tiponomina
                AND dbo.Periodos.estatus = 'A'

        SELECT TOP 1 @uma = UmaDiario
        FROM dbo.TblUMA
        WHERE dbo.TblUMA.Fecha <= @pagonomina
        ORDER BY dbo.TblUMA.Fecha DESC


        SET @topedf = ROUND(ISNULL(@uma,@salariodf) * 25, 2)
        SET @toperegion = @salarioregion


        SELECT  @firma = CASE WHEN dbo.Parametros_Nominas.Firma IS NULL
                              THEN 'N'
                              WHEN dbo.Parametros_Nominas.Firma <> 'T'
                              THEN 'N'
                              ELSE 'S'
                         END
        FROM    dbo.Parametros_Nominas
        WHERE   dbo.Parametros_Nominas.Empresa = @empresa
                AND dbo.Parametros_Nominas.TipoNom = @tiponomina
                
        IF @procesoname = 'NominaDetalle'
            BEGIN
-- Prepara tabla virtual
                INSERT  dbo.KardexImprimeRecibos
                        ( proceso ,
                          fechaProceso ,
                          horaProceso ,
                          empresa ,
                          codigoId ,
                          codigo ,
                          nombre ,
                          fechaAlta ,
                          numeroSeguridadSocial ,
                          digitoVerificador ,
                          curp ,
                          centro ,
                          nombreCentro ,
                          cuentaBanco ,
                          nombreBanco ,
                          ocupacion ,
                          categoria ,
                          tipoSalario ,
                          jornada ,
                          sueldoDiario ,
                          salarioBaseCotizacion ,
                          clase ,
                          nombreClase ,
                          supervisor ,
                          nombreSupervisor ,
                          renglon ,
                          grupo ,
                          rfcAlfa ,
                          rfcNum ,
                          rfcHomo ,
                          email ,
                          fechaAntiguedad ,
                          procesoName ,
                          nomina ,
                          firma ,
                          copia
                        )
                        SELECT DISTINCT
                                @proceso ,
                                @fechaproceso ,
                                @horaproceso ,
                                dbo.kardex.empresa ,
                                RIGHT(STR(100000000 + dbo.kardex.codigo), 8)
                                + RIGHT(STR(1000000000 + dbo.kardex.renglon),
                                        9) AS codigoId ,
                                dbo.kardex.codigo AS codigo ,
                                RTRIM(dbo.empleados.ap_paterno) + ' '
                                + RTRIM(dbo.empleados.ap_materno) + ' '
                                + RTRIM(dbo.empleados.nombre) AS nombre ,
                                dbo.empleados.fchalta ,
                                dbo.empleados.afiliacion ,
                                dbo.empleados.digvera ,
                                CASE WHEN LEN(dbo.empleados.curp) = 18
                                     THEN dbo.empleados.curp
                                     ELSE dbo.empleados.rfcalfa
                                          + dbo.empleados.rfcnum
                                          + dbo.empleados.rfchomo
                                END AS curp ,
                                dbo.Llaves.centro ,
                                dbo.centros.nomdepto ,
                                dbo.empleados.cta_bco_no ,
                                dbo.bancos.nombre AS nombreBanco ,
                                dbo.Llaves.ocupacion ,
                                LEFT(dbo.tabulador.actividad,50) AS actividad ,
                                dbo.empleados.tiposal ,
                                dbo.empleados.jornada ,
                                dbo.empleados.sueldo ,
                                CASE WHEN dbo.empleados.saldiaint > @topedf THEN @topedf ELSE dbo.empleados.saldiaint END AS saldiaint, --dbo.empleados.saldiaint ,
                                dbo.Llaves.clase ,
                                dbo.clases.nombre AS nombreClase ,
                                dbo.Llaves.supervisor ,
                                dbo.supervisores.nombre AS nombreSupervisor ,
                                dbo.kardex.renglon ,
                                CASE WHEN ( ( @ordenadopor & 4 > 0
                                              OR @ordenadopor & 8 > 0
                                            )
                                            OR ( ( @ordenadopor & 1 > 0
                                                   OR @ordenadopor & 2 > 0
                                                 )
                                                 AND @desglosadopor & 2 > 0
                                               )
                                          )
                                     THEN SUBSTRING(dbo.Llaves.centro, 1, 15)
                                     WHEN ( @ordenadopor & 16 > 0
                                            OR @ordenadopor & 32 > 0
                                          )
                                     THEN RTRIM(dbo.Llaves.centro)
                                          + RIGHT(STR(100000000
                                                      + dbo.Llaves.supervisor),
                                                  8)
                                     ELSE NULL
                                END ,
                                dbo.empleados.rfcalfa ,
                                dbo.empleados.rfcnum ,
                                dbo.empleados.rfchomo ,
                                dbo.datosemps.email ,
                                dbo.empleados.fchantigua ,
                                @procesoname ,
                                @nomina ,
                                @firma ,
                                1 AS copia 
                        FROM    dbo.kardex
                                INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                            AND dbo.kardex.codigo = dbo.empleados.codigo
                                INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                         AND dbo.empleados.codigo = dbo.Llaves.codigo
                                INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                          AND dbo.Llaves.empresa = dbo.centros.empresa
                                INNER JOIN dbo.tabulador ON dbo.centros.empresa = dbo.tabulador.empresa
                                                            AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
                                INNER JOIN dbo.bancos ON dbo.Llaves.banco = dbo.bancos.banco
                                INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa
                                                         AND dbo.Llaves.clase = dbo.clases.clase
                                INNER JOIN dbo.supervisores ON dbo.Llaves.empresa = dbo.supervisores.empresa
                                                              AND dbo.Llaves.supervisor = dbo.supervisores.supervisor
                                INNER JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                                            AND dbo.empleados.codigo = dbo.datosemps.codigo
                                INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN @porcentro = 1
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN @porcentro = 1
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN @porcentro = 1
                                                              THEN RTRIM(LTRIM(dbo.Llaves.centro))
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porcentro = 1
                                                              THEN dbo.SeleccionElementos.centro
                                                              ELSE '1'
                                                              END
                                                              AND CASE
                                                              WHEN @porcentro = 1
                                                              THEN dbo.SeleccionElementos.nomina
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN @porcentro = 1
                                                              THEN dbo.kardex.nomina
                                                              ELSE '1'
                                                              END
                        WHERE   ( ( ( dbo.kardex.num_conc >= @numeroconceptopercepcioniniciokardex
                                          AND dbo.kardex.num_conc <= @numeroconceptopercepcionterminokardex
                                        )
                                        OR ( dbo.kardex.num_conc >= @numeroconceptocontrapercepcioniniciokardex
                                             AND dbo.kardex.num_conc <= @numeroconceptocontrapercepcionterminokardex
                                           )
                                      )
                                      OR ( ( dbo.kardex.num_conc >= @numeroconceptodeduccioniniciokardex
                                             AND dbo.kardex.num_conc <= @numeroconceptodeduccionterminokardex
                                           )
                                           OR ( dbo.kardex.num_conc >= @numeroconceptocontradeduccioniniciokardex
                                                AND dbo.kardex.num_conc <= @numeroconceptocontradeduccionterminokardex
                                              )
                                         )
                                      OR ( dbo.kardex.num_conc >= @numeroconceptoprovisioniniciokardex
                                           AND dbo.kardex.num_conc <= @numeroconceptoprovisionterminokardex
                                         )
                                    )
                                AND dbo.kardex.nomina = @nomina
                                AND dbo.kardex.empresa = CASE WHEN @desglosadopor & 1 > 0
                                                               THEN @empresa
                                                               ELSE 0
                                                          END
                                --AND dbo.SeleccionElementos.nomina = @nomina
                                --AND dbo.SeleccionElementos.procesoName = @procesoname
                                --AND dbo.SeleccionElementos.empresa = @empresa
                                    

--SELECT 1,* FROM @kardex ORDER BY centro, codigo, renglon
        -- Agrega Centros de nivel superior
                IF @desglosadopor & 1 > 0
                   AND (@ordenadopor & 4 > 0 OR @ordenadopor & 8 > 0 OR @ordenadopor & 16 > 0 OR @ordenadopor & 32 > 0)
                    BEGIN
                        INSERT  dbo.KardexImprimeRecibos
                                ( proceso ,
                                  fechaProceso ,
                                  horaProceso ,
                                  empresa ,
                                  codigoId ,
                                  codigo ,
                                  nombre ,
                                  fechaAlta ,
                                  numeroSeguridadSocial ,
                                  digitoVerificador ,
                                  curp ,
                                  centro ,
                                  nombreCentro ,
                                  cuentaBanco ,
                                  nombreBanco ,
                                  ocupacion ,
                                  categoria ,
                                  tipoSalario ,
                                  jornada ,
                                  sueldoDiario ,
                                  salarioBaseCotizacion ,
                                  clase ,
                                  nombreClase ,
                                  supervisor ,
                                  nombreSupervisor ,
                                  renglon ,
                                  grupo ,
                                  procesoName ,
                                  nomina ,
                                  copia
                                )
                                SELECT DISTINCT
                                        @proceso ,
                                        @fechaproceso ,
                                        @horaproceso ,
                                        @empresa ,
                                        RIGHT(STR(100000000
                                                  + [dbo].[ResumenPorCentroNomina].codigo),
                                              8) + RIGHT(STR(1000000000
                                                             + [dbo].[ResumenPorCentroNomina].renglon),
                                                         9)
                                        + [dbo].[ResumenPorCentroNomina].centro AS codigoId ,
                                        [dbo].[ResumenPorCentroNomina].codigo ,
                                        CASE WHEN [dbo].[ResumenPorCentroNomina].codigo = 999999995
                                             THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZXXXX'
                                             ELSE 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ'
                                        END ,
                                        NULL AS fchalta ,
                                        NULL AS afiliacion ,
                                        NULL AS digvera ,
                                        NULL AS curp ,
                                        [dbo].[ResumenPorCentroNomina].centro ,
                                        CASE WHEN RTRIM(LTRIM(dbo.centros.centro)) = '99999999999997'
                                             THEN ' ' -- 'GENERAL'
                                             ELSE dbo.centros.nomdepto
                                        END ,
                                        NULL AS cta_bco_no ,
                                        NULL AS nombreBanco ,
                                        NULL AS ocupacion ,
                                        NULL AS actividad ,
                                        NULL AS tiposal ,
                                        NULL AS jornada ,
                                        NULL AS sueldo ,
                                        NULL AS saldiaint ,
                                        NULL AS clase ,
                                        NULL AS nombreClase ,
                                        CASE WHEN ( ( @ordenadopor & 16 > 0
                                                      OR @ordenadopor & 32 > 0
                                                    )
                                                    AND ( @desglosadopor & 1 > 0
                                                          OR @desglosadopor
                                                          & 2 > 0
                                                        )
                                                  )
                                             THEN [dbo].[ResumenPorCentroNomina].supervisor
                                             ELSE NULL
                                        END AS supervisor ,
                                        CASE WHEN ( ( @ordenadopor & 16 > 0
                                                      OR @ordenadopor & 32 > 0
                                                    )
                                                    AND ( @desglosadopor & 1 > 0
                                                          OR @desglosadopor
                                                          & 2 > 0
                                                        )
                                                  )
                                             THEN [dbo].[supervisores].nombre
                                             ELSE NULL
                                        END AS nombreSupervidor ,
                                        [dbo].[ResumenPorCentroNomina].renglon ,
                                        CASE WHEN ( ( @ordenadopor & 4 > 0
                                                      OR @ordenadopor & 8 > 0
                                                    )
                                                    OR ( ( @ordenadopor & 1 > 0
                                                           OR @ordenadopor & 2 > 0
                                                         )
                                                         AND @desglosadopor
                                                         & 2 > 0
                                                       )
                                                  )
                                             THEN SUBSTRING([dbo].[ResumenPorCentroNomina].centro,
                                                            1, 15)
                                             WHEN ( ( @ordenadopor & 16 > 0
                                                      OR @ordenadopor & 32 > 0
                                                    )
                                                    AND ( @desglosadopor & 1 > 0
                                                          OR @desglosadopor
                                                          & 2 > 0
                                                        )
                                                  )
                                             THEN RTRIM([dbo].[ResumenPorCentroNomina].centro)
                                                  + RIGHT(STR(100000000
                                                              + CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              THEN 999999995
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END), 8)
                                             ELSE CASE WHEN @desglosadopor & 4 > 0
                                                       THEN ''
                                                       ELSE NULL
                                                  END
                                        END ,
                                        @procesoname ,
                                        @nomina ,
                                        1 AS copia
                                FROM    [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'N', @tiponomina,
                                                              'G',
                                                              @ordenadopor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              2, --@desglosadopor,
                                                              @porcentro)
                                        INNER JOIN dbo.centros ON CASE
                                                              WHEN @porcentro = 1
                                                              AND [dbo].[ResumenPorCentroNomina].centro = '99999999999996'
                                                              THEN '99999999999997'
                                                              ELSE RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              END = RTRIM(LTRIM(dbo.centros.centro))
                                        INNER JOIN dbo.supervisores ON dbo.centros.empresa = dbo.supervisores.empresa
                                                              AND CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999995
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor IS NULL
                                                              THEN 0
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END = dbo.supervisores.supervisor
                                WHERE   dbo.centros.empresa = @empresa

--SELECT 2,* FROM @kardex ORDER BY centro, codigo, renglon
                    END
                ELSE
                   IF @esrecibo = 0
                      BEGIN
                            INSERT  dbo.KardexImprimeRecibos
                                    ( proceso ,
                                      fechaProceso , 
                                      horaProceso ,
                                      empresa ,
                                      codigoId ,
                                      codigo ,
                                      nombre ,
                                      fechaAlta ,
                                      numeroSeguridadSocial ,
                                      digitoVerificador ,
                                      curp ,
                                      centro ,
                                      nombreCentro ,
                                      cuentaBanco ,
                                      nombreBanco ,
                                      ocupacion ,
                                      categoria ,
                                      tipoSalario ,
                                      jornada ,
                                      sueldoDiario ,
                                      salarioBaseCotizacion ,
                                      clase ,
                                      nombreClase ,
                                      supervisor ,
                                      nombreSupervisor ,
                                      renglon ,
                                      grupo ,
                                      procesoName ,
                                      nomina ,
                                      copia 
                                    )
                                    SELECT DISTINCT
                                            @proceso ,
                                            @fechaproceso ,
                                            @horaproceso ,
                                            @empresa ,
                                            RIGHT(STR(100000000
                                                      + [dbo].[ResumenPorCentroNomina].codigo),
                                                  8) + RIGHT(STR(1000000000
                                                              + [dbo].[ResumenPorCentroNomina].renglon),
                                                             9)
                                            + [dbo].[ResumenPorCentroNomina].centro AS codigoId ,
                                            [dbo].[ResumenPorCentroNomina].codigo ,
                                            CASE WHEN [dbo].[ResumenPorCentroNomina].codigo = 999999995
                                                 THEN 'ZZZZZZZZZZZZZZZZZZZZZZZZZZXXXX'
                                                 ELSE 'ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ'
                                            END ,
                                            NULL AS fchalta ,
                                            NULL AS afiliacion ,
                                            NULL AS digvera ,
                                            NULL AS curp ,
                                            [dbo].[ResumenPorCentroNomina].centro ,
                                            CASE WHEN RTRIM(LTRIM(dbo.centros.centro)) = '99999999999997'
                                                 THEN ' ' -- 'GENERAL'
                                                 ELSE dbo.centros.nomdepto
                                            END ,
                                            NULL AS cta_bco_no ,
                                            NULL AS nombreBanco ,
                                            NULL AS ocupacion ,
                                            NULL AS actividad ,
                                            NULL AS tiposal ,
                                            NULL AS jornada ,
                                            NULL AS sueldo ,
                                            NULL AS saldiaint ,
                                            NULL AS clase ,
                                            NULL AS nombreClase ,
                                            CASE WHEN ( ( @ordenadopor & 16 > 0
                                                          OR @ordenadopor & 32 > 0
                                                        )
                                                        AND ( @desglosadopor
                                                              & 1 > 0
                                                              OR @desglosadopor
                                                              & 2 > 0
                                                            )
                                                      )
                                                 THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                 ELSE NULL
                                            END AS supervisor ,
                                            CASE WHEN ( ( @ordenadopor & 16 > 0
                                                          OR @ordenadopor & 32 > 0
                                                        )
                                                        AND ( @desglosadopor
                                                              & 1 > 0
                                                              OR @desglosadopor
                                                              & 2 > 0
                                                            )
                                                      )
                                                 THEN [dbo].[supervisores].nombre
                                                 ELSE NULL
                                            END AS nombreSupervidor ,
                                            [dbo].[ResumenPorCentroNomina].renglon ,
                                            CASE WHEN ( ( @ordenadopor & 4 > 0
                                                          OR @ordenadopor & 8 > 0
                                                        )
                                                        OR ( ( @ordenadopor
                                                              & 1 > 0
                                                              OR @ordenadopor
                                                              & 2 > 0
                                                             )
                                                             AND @desglosadopor
                                                             & 2 > 0
                                                           )
                                                      )
                                                 THEN SUBSTRING([dbo].[ResumenPorCentroNomina].centro,
                                                              1, 15)
                                                 WHEN ( ( @ordenadopor & 16 > 0
                                                          OR @ordenadopor & 32 > 0
                                                        )
                                                        AND ( @desglosadopor
                                                              & 1 > 0
                                                              OR @desglosadopor
                                                              & 2 > 0
                                                            )
                                                      )
                                                 THEN RTRIM([dbo].[ResumenPorCentroNomina].centro)
                                                      + RIGHT(STR(100000000
                                                              + CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              THEN 999999995
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END), 8)
                                                 ELSE CASE WHEN @desglosadopor
                                                              & 4 > 0 THEN ''
                                                           ELSE NULL
                                                      END
                                            END ,
                                            @procesoname ,
                                            @nomina ,
                                            1 AS copia
                                    FROM    [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'N', @tiponomina,
                                                              'G',
                                                              @ordenadopor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadopor,
                                                              @porcentro)
                                            INNER JOIN dbo.centros ON CASE
                                                              WHEN @porcentro = 1
                                                              AND [dbo].[ResumenPorCentroNomina].centro = '99999999999996'
                                                              THEN '99999999999997'
                                                              ELSE RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              END = RTRIM(LTRIM(dbo.centros.centro))
                                            INNER JOIN dbo.supervisores ON dbo.centros.empresa = dbo.supervisores.empresa
                                                              AND CASE
                                                              WHEN [dbo].[ResumenPorCentroNomina].supervisor = 999999995
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor = 999999996
                                                              OR [dbo].[ResumenPorCentroNomina].supervisor IS NULL
                                                              THEN 0
                                                              ELSE [dbo].[ResumenPorCentroNomina].supervisor
                                                              END = dbo.supervisores.supervisor
                                    WHERE   dbo.centros.empresa = @empresa


               --SELECT 3,* FROM @kardex ORDER BY centro, codigo, renglon
               --SELECT 2,* FROM @kardex ORDER BY codigo, renglon
                        END



                    --SELECT 3,* FROM @kardex ORDER BY centro, codigo, renglon



                -- solo cuando quiere imprimir el detalle de empleado
                IF @desglosadopor & 1 > 0
                    BEGIN
                        -- Carga Percepciones por empleado
                        UPDATE  kardexImprimeRecibos
                        SET     kardexImprimeRecibos.marcaContraPercepcion = CASE WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                             THEN 'C'
                                                             WHEN dbo.kardex.tipo_mov = 'FIN'
                                                             THEN 'F'
                                                             ELSE NULL
                                                        END ,
                                kardexImprimeRecibos.numeroConceptoPercepcion = dbo.kardex.num_conc ,
                                kardexImprimeRecibos.nombreConceptoPercepcion = dbo.kardex.concepto ,
                                kardexImprimeRecibos.importeConceptoPercepcion = dbo.kardex.importe ,
                                kardexImprimeRecibos.gravablePercepcion = dbo.kardex.igravable ,
                                kardexImprimeRecibos.exentoPercepcion = dbo.kardex.iexento ,
                                kardexImprimeRecibos.saldoPercepcion = CASE WHEN dbo.kardex.saldo > 0
                                                       THEN dbo.kardex.saldo
                                                       ELSE NULL
                                                  END ,
                                kardexImprimeRecibos.anexoConceptoPercepcion = CASE
                                      -- Detalle Sueldo
                                                              WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 8
                                                              THEN CONVERT(VARCHAR(15), dbo.AgregaComa(dbo.kardex.impor_base))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle Horas Extras
                                                              WHEN dbo.kardex.num_conc >= 10
                                                              AND dbo.kardex.num_conc <= 13
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.horas))
                                                              + ' Horas'

                                      -- Detalle Prima Vacacional
                                                              WHEN dbo.kardex.num_conc = 17
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle Vacaciones
                                                              WHEN dbo.kardex.num_conc = 30
                                                              THEN CONVERT(VARCHAR(15), dbo.AgregaComa(dbo.kardex.impor_base))
                                                              + ' * ' + '('
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + 'H' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + 'D' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + 'F' + ')'

                                      -- Detalle Subsidio para el Empleo
                                                              WHEN dbo.kardex.num_conc = 36
                                                              THEN CASE
                                                              WHEN dbo.kardex.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoempresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoempresa < 2014
                                                                        THEN 'Art. 8vo Trans$'                                                                         
                                                                        ELSE 'Art 10 Trans$'
                                                                    END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              ELSE ''
                                                              END
                                                              END

                                      -- Detalle Concepto 53 Por Registro Patronal
                                                              WHEN dbo.kardex.num_conc = 53
                                                              AND ( @registropatronal = 'R131234638'
                                                              OR @registropatronal = 'C166197810'
                                                              OR @registropatronal = 'C166939010'
                                                              OR @registropatronal = 'E647730310'
                                                              OR @registropatronal = 'E648122510'
                                                              OR @registropatronal = 'C534928610'
                                                              )
                                                              THEN SUBSTRING(dbo.kardex.referencia,
                                                              01, 06)
                                                              + RIGHT(RTRIM(dbo.kardex.referencia),
                                                              02) + ' (M'
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.unidades))
                                                              + ')'

                                      -- Detalle Sueldo Neto
                                                              WHEN dbo.kardex.num_conc = 99
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle de conceptos de Contras del 1107 al 1111
                                                              WHEN dbo.kardex.num_conc >= 1107
                                                              AND dbo.kardex.num_conc <= 1111
                                                              THEN CASE
                                                              WHEN dbo.kardex.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'
                                                              ELSE ''
                                                              END

                                      -- Detalle Conceptos con Valor Variable
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                              END
                                                          END ,
                                kardexImprimeRecibos.mov = CASE WHEN dbo.kardex.num_conc <= 6
                                           THEN RTRIM(dbo.kardex.referencia)
                                           ELSE NULL
                                      END
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                INNER JOIN dbo.kardex ON kardexImprimeRecibos.empresa = dbo.kardex.empresa
                                                         AND kardexImprimeRecibos.codigo = dbo.kardex.codigo
                                                         AND kardexImprimeRecibos.renglon = dbo.kardex.renglon
                                                         AND @nomina = dbo.kardex.nomina
                        WHERE   ( ( dbo.kardex.num_conc >= 1
                                        AND dbo.kardex.num_conc <= 99
                                      )
                                      OR ( dbo.kardex.num_conc >= 1101
                                           AND dbo.kardex.num_conc <= 1199
                                         )
                                    )
                                AND dbo.kardex.nomina = @nomina
                                AND dbo.kardex.empresa = @empresa
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa

                        -- Carga Deducciones
                        UPDATE  kardexImprimeRecibos
                        SET     kardexImprimeRecibos.marcaContraDeduccion = CASE WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                            THEN 'C'
                                                            WHEN dbo.kardex.tipo_mov = 'FIN'
                                                            THEN 'F'
                                                            ELSE NULL
                                                       END ,
                                kardexImprimeRecibos.numeroConceptoDeduccion = dbo.kardex.num_conc ,
                                kardexImprimeRecibos.nombreConceptoDeduccion = dbo.kardex.concepto ,
                                kardexImprimeRecibos.importeConceptoDeduccion = dbo.kardex.importe ,
                                kardexImprimeRecibos.gravableDeduccion = dbo.kardex.igravable ,
                                kardexImprimeRecibos.exentoDeduccion = dbo.kardex.iexento ,
                                kardexImprimeRecibos.saldoDeduccion = CASE WHEN dbo.kardex.saldo > 0
                                                      THEN --CASE WHEN dbo.kardex.num_conc = 126 THEN dbo.kardex.importe + dbo.kardex.saldo
                                                   --     WHEN dbo.kardex.num_conc = 127 THEN dbo.kardex.importe + dbo.kardex.saldo
                                                   --     ELSE dbo.kardex.saldo
                                                   --END
                                                           CASE
                                                              WHEN ( dbo.conceptos.marca2 = 'P'
                                                              OR ( dbo.kardex.num_conc >= 115
                                                              AND dbo.kardex.num_conc <= 117
                                                              )
                                                              )
                                                              THEN dbo.kardex.saldo
                                                              - dbo.kardex.importe
                                                              WHEN ( dbo.conceptos.marca2 = 'H'
                                                                   OR ( dbo.kardex.num_conc >= 125
                                                                   AND dbo.kardex.num_conc <= 127
                                                                   )
                                                                   OR dbo.kardex.num_conc = 112
                                                                   )
                                                              THEN dbo.kardex.saldo
                                                              + dbo.kardex.importe
                                                              ELSE NULL
                                                           END
                                                      ELSE NULL
                                                 END ,
                                kardexImprimeRecibos.anexoConceptoDeduccion = CASE
                                      -- Detalle Cuotas IMSS
                                                              WHEN (dbo.kardex.num_conc >= 101
                                                                    AND dbo.kardex.num_conc <= 105
                                                                    AND @regimen_seguridad_social = '1')
                                                                   THEN CONVERT(VARCHAR(15), CASE WHEN dbo.kardex.num_conc = 102
                                                                                                       THEN CASE WHEN dbo.kardex.saldiaint > ( ISNULL(@uma,@salariodf) * 3 )
                                                                                                                      THEN dbo.AgregaComa(dbo.kardex.saldiaint - ( ISNULL(@uma,@salariodf) * 3 ))
                                                                                                                      ELSE dbo.AgregaComa(dbo.kardex.saldiaint)
                                                                                                                 END
                                                                                                       ELSE dbo.AgregaComa(dbo.kardex.saldiaint)
                                                                                             END) + ' * ' + CASE WHEN dbo.kardex.num_conc = 101 THEN CONVERT(VARCHAR(15), @eymtra25)
                                                                                                                 WHEN dbo.kardex.num_conc = 102 THEN CONVERT(VARCHAR(15), @eymtra1062)
                                                                                                                 WHEN dbo.kardex.num_conc = 103 THEN CONVERT(VARCHAR(15), @eymtra107)
                                                                                                                 WHEN dbo.kardex.num_conc = 104 THEN CONVERT(VARCHAR(15), @ivtra147)
                                                                                                                 WHEN dbo.kardex.num_conc = 105 THEN CONVERT(VARCHAR(15), @cvtra168ii)
                                                                                                                 ELSE ''
                                                                                                            END + ' * ' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias_imss))

                                      -- Detalle Retencion IMSS por Faltas
                                                              WHEN (dbo.kardex.num_conc = 106 AND @regimen_seguridad_social = '1')
                                                                    OR dbo.kardex.num_conc = 107
                                                                    OR dbo.kardex.num_conc = 109
                                                                    OR dbo.kardex.num_conc = 110
                                                                    OR dbo.kardex.num_conc = 111
                                                                    OR dbo.kardex.num_conc = 130
                                                                   THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias)) + ' Da(s)'

                                      -- Detalle Faltas
                                                              WHEN dbo.kardex.num_conc = 108
                                                                   THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                        + ' Da(s)'
                                                                        + ' + '
                                                                        + CONVERT(VARCHAR(15), dbo.ChecaDecimales(ABS(dbo.kardex.descuento
                                                                        - 100))) + '%'

                                      -- Detalle Creditos INFONAVIT
                                                              WHEN dbo.kardex.num_conc = 112 AND dbo.kardex.saldo = 0 AND dbo.kardex.dias > 0
                                                                   THEN CASE WHEN dbo.kardex.descuento > 0
                                                                                  THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.saldiaint))
                                                                                       + ' * '
                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                                       + ' * '
                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.descuento))
                                                                                       + '%'
                                                                                  ELSE CONVERT(VARCHAR(15), CONVERT(NUMERIC(15,
                                                                                       2), dbo.ChecaDecimales(ROUND(dbo.kardex.importe
                                                                                       / dbo.kardex.dias,
                                                                                       2)))) + ' * '
                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                                       + 'DS'
                                                                        END

                                      -- Detalle Fondo de Ahorro
                                                              WHEN dbo.kardex.num_conc = 125
                                                                   OR dbo.kardex.num_conc = 126
                                                                   OR dbo.kardex.num_conc = 127
                                                                   OR (dbo.kardex.num_conc = 112 AND dbo.kardex.saldo > 0)
                                                                   THEN 'Saldo $ '
                                                                        + dbo.AgregaComa(dbo.kardex.saldo
                                                                        + dbo.kardex.importe)

                                      -- Detalle ISR
                                                              WHEN dbo.kardex.num_conc = 136
                                                                   THEN CASE WHEN dbo.kardex.variable1 = '1991'
                                                                             THEN '1991'
                                                                             ELSE CASE WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                                                            THEN CASE WHEN @ayoempresa < 2008
                                                                                                      THEN 'Art. 115 $'
                                                                                                      WHEN @ayoempresa < 2014
                                                                                                      THEN 'Art 8vo Trans$'
                                                                                                      ELSE 'Art 10 Trans$'
                                                                                                 END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                                                            ELSE ''
                                                                                  END
                                                                        END

                                      -- Contra Sueldo
                                                              WHEN dbo.kardex.num_conc >= 1001
                                                                   AND dbo.kardex.num_conc <= 1007
                                                                   THEN CASE WHEN dbo.kardex.dias > 0
                                                                             THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                                                  + ' Da(s)'
                                                                             ELSE ''
                                                                        END

                                      -- Detalle los demas conceptos
                                                              ELSE CASE WHEN dbo.kardex.saldo > 0
                                                                        THEN 'Saldo $ '
                                                                             + dbo.AgregaComa(dbo.kardex.saldo
                                                                             + CASE WHEN dbo.conceptos.marca2 = 'H'
                                                                                         OR --'A'
                                                                                         dbo.conceptos.num_conc IN (125, 126, 127 )
                                                                                    THEN 1
                                                                                    ELSE -1
                                                                               END
                                                                             * dbo.kardex.importe)
                                                -- Detalle de conceptos con valores variable
                                                                        ELSE CASE WHEN dbo.kardex.num_conc >= 101 AND dbo.kardex.num_conc <= 106 AND @regimen_seguridad_social = '2' THEN ''																		
																		          WHEN dbo.kardex.num_conc >= 101 AND dbo.kardex.num_conc <= 106 AND @regimen_seguridad_social = '3' 
																				       THEN CONVERT(varchar(15),dbo.ChecaDecimales(CASE WHEN dbo.kardex.impor_base < ( ISNULL(@uma,@salariodf) * 10 * kardex.dias_imss ) THEN dbo.kardex.impor_base ELSE ( ISNULL(@uma,@salariodf) * 10 * kardex.dias_imss ) END )) + '*' + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))  + ' %' 
                                                                                  ELSE CASE WHEN dbo.kardex.varia1 > 0
                                                                                            THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                                                                 + ': '
                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                                                                 + CASE WHEN dbo.kardex.varia2 > 0
                                                                                                        THEN ','
                                                                                                             + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                                                                             + ': '
                                                                                                             + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                                                                             + CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                    THEN ','
                                                                                                                         + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                         + ': '
                                                                                                                         + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                         + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                                THEN ','
                                                                                                                                     + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                     + ': '
                                                                                                                                     + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                                ELSE ''
                                                                                                                           END
                                                                                                                    ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                              THEN ','
                                                                                                                                   + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                   + ': '
                                                                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                              ELSE ''
                                                                                                                         END
                                                                                                               END
                                                                                                        ELSE CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                  THEN ','
                                                                                                                       + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                       + ': '
                                                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                       + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                              THEN ','
                                                                                                                                   + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                   + ': '
                                                                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                              ELSE ''
                                                                                                                         END
                                                                                                                  ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                            THEN ','
                                                                                                                                 + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                 + ': '
                                                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                            ELSE ''
                                                                                                                       END
                                                                                                             END
                                                                                                   END
                                                                                            ELSE CASE WHEN dbo.kardex.varia2 > 0
                                                                                                      THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                                                                           + ': '
                                                                                                           + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                                                                           + CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                  THEN ','
                                                                                                                       + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                       + ': '
                                                                                                                       + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                       + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                              THEN ','
                                                                                                                                   + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                   + ': '
                                                                                                                                   + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                              ELSE ''
                                                                                                                         END
                                                                                                                  ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                            THEN ','
                                                                                                                                 + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                 + ': '
                                                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                            ELSE ''
                                                                                                                       END
                                                                                                             END
                                                                                                      ELSE CASE WHEN dbo.kardex.varia3 > 0
                                                                                                                THEN ','
                                                                                                                     + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                                                                                     + ': '
                                                                                                                     + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                                                                                     + CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                            THEN ','
                                                                                                                                 + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                                 + ': '
                                                                                                                                 + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                            ELSE ''
                                                                                                                       END
                                                                                                                ELSE CASE WHEN dbo.kardex.varia4 > 0
                                                                                                                          THEN ','
                                                                                                                               + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                                                                                               + ': '
                                                                                                                               + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                                                                                          ELSE NULL -- Agregar mas condiciones

                                                                                                                     END
                                                                                                           END
                                                                                                 END
                                                                                       END
                                                                             END
                                                                   END
                                                         END

                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                INNER JOIN dbo.kardex ON kardexImprimeRecibos.empresa = dbo.kardex.empresa
                                                         AND kardexImprimeRecibos.codigo = dbo.kardex.codigo
                                                         AND kardexImprimeRecibos.renglon = dbo.kardex.renglon
                                                         AND @nomina = dbo.kardex.nomina
                                INNER JOIN dbo.conceptos ON dbo.kardex.empresa = dbo.conceptos.empresa
                                                            AND dbo.kardex.num_conc = dbo.conceptos.num_conc
                                                            AND dbo.kardex.clase = dbo.conceptos.clase
                                                            AND dbo.kardex.centro = dbo.conceptos.centro
                        WHERE   ( ( dbo.kardex.num_conc >= 101
                                        AND dbo.kardex.num_conc <= 199
                                      )
                                      OR ( dbo.kardex.num_conc >= 1001
                                           AND dbo.kardex.num_conc <= 1099
                                         )
                                    )
                                AND dbo.kardex.nomina = @nomina
                                AND dbo.kardex.empresa = @empresa
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa
--SELECT 4,* FROM @kardex ORDER BY centro, codigo, renglon
                    END



                -- Percepciones. Actualiza el subtotal y total de resumen de centro de costos
                UPDATE  kardexImprimeRecibos
                SET     kardexImprimeRecibos.numeroConceptoPercepcion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                        kardexImprimeRecibos.nombreConceptoPercepcion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                        kardexImprimeRecibos.importeConceptoPercepcion = [dbo].[ResumenPorCentroNomina].importe ,
                        kardexImprimeRecibos.gravablePercepcion = [dbo].[ResumenPorCentroNomina].gravable ,
                        kardexImprimeRecibos.exentoPercepcion = [dbo].[ResumenPorCentroNomina].exento ,
                        kardexImprimeRecibos.saldoPercepcion = [dbo].[ResumenPorCentroNomina].saldoPercepcion ,
                        kardexImprimeRecibos.anexoConceptoPercepcion = [dbo].[ResumenPorCentroNomina].anexoConceptoPercepcion
                FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'S', @tiponomina,
                                                              'P',
                                                              @ordenadopor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN kardexImprimeRecibos.supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND kardexImprimeRecibos.renglon = [dbo].[ResumenPorCentroNomina].renglon
                WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1
                            AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 99
                          )
                          OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1101
                               AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1199
                             )
                        )
                        AND kardexImprimeRecibos.horaProceso = @horaproceso
                        AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.nomina = @nomina
                        AND kardexImprimeRecibos.empresa = @empresa

                -- Deducciones. Actualiza el subtotal y total de resumen de centro de costos
                UPDATE  kardexImprimeRecibos
                SET     kardexImprimeRecibos.numeroConceptoDeduccion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                        kardexImprimeRecibos.nombreConceptoDeduccion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                        kardexImprimeRecibos.importeConceptoDeduccion = [dbo].[ResumenPorCentroNomina].importe ,
                        kardexImprimeRecibos.gravableDeduccion = [dbo].[ResumenPorCentroNomina].gravable ,
                        kardexImprimeRecibos.exentoDeduccion = [dbo].[ResumenPorCentroNomina].exento ,
                        kardexImprimeRecibos.anexoConceptoDeduccion = [dbo].[ResumenPorCentroNomina].anexoConceptoDeduccion
                FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'S', @tiponomina,
                                                              'D',
                                                              @ordenadopor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN kardexImprimeRecibos.supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND kardexImprimeRecibos.renglon = [dbo].[ResumenPorCentroNomina].renglon
                WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 101
                            AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 199
                          )
                          OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1001
                               AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1099
                             )
                        )
                        AND kardexImprimeRecibos.horaProceso = @horaproceso
                        AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.nomina = @nomina
                        AND kardexImprimeRecibos.empresa = @empresa
                        
--SELECT 5,* FROM @kardex ORDER BY centro, codigo, renglon

        -- Actualiza Centros de Nivel Superior
                IF @desglosadopor & 1 > 0
                   AND (@ordenadopor & 4 > 0 OR @ordenadopor & 8 > 0 OR @ordenadopor & 16 > 0 OR @ordenadopor & 32 > 0)
                    BEGIN
                -- Percepciones. Actualiza el subtotal y total de resumen de centro de costos
                        UPDATE  kardexImprimeRecibos
                        SET     --[@kardex].numeroConceptoPercepcion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                                --[@kardex].nombreConceptoPercepcion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                                kardexImprimeRecibos.importeConceptoPercepcion = [dbo].[ResumenPorCentroNomina].importe ,
                                kardexImprimeRecibos.gravablePercepcion = [dbo].[ResumenPorCentroNomina].gravable ,
                                kardexImprimeRecibos.exentoPercepcion = [dbo].[ResumenPorCentroNomina].exento ,
                                kardexImprimeRecibos.saldoPercepcion = [dbo].[ResumenPorCentroNomina].saldoPercepcion ,
                                kardexImprimeRecibos.anexoConceptoPercepcion = [dbo].[ResumenPorCentroNomina].anexoConceptoPercepcion
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'S', @tiponomina,
                                                              'P',
                                                              @ordenadopor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              2, --@desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN kardexImprimeRecibos.supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND kardexImprimeRecibos.renglon = [dbo].[ResumenPorCentroNomina].renglon
                                                              AND kardexImprimeRecibos.numeroConceptoPercepcion = [dbo].[ResumenPorCentroNomina].numeroConcepto
                                                              AND kardexImprimeRecibos.nombreConceptoPercepcion = [dbo].[ResumenPorCentroNomina].nombreConcepto
                        WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1
                                    AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 99
                                  )
                                  OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1101
                                       AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1199
                                     )
                                )
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa



                -- Deducciones. Actualiza el subtotal y total de resumen de centro de costos
                        UPDATE  kardexImprimeRecibos
                        SET     --[@kardex].numeroConceptoDeduccion = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                                --[@kardex].nombreConceptoDeduccion = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                                kardexImprimeRecibos.importeConceptoDeduccion = [dbo].[ResumenPorCentroNomina].importe ,
                                kardexImprimeRecibos.gravableDeduccion = [dbo].[ResumenPorCentroNomina].gravable ,
                                kardexImprimeRecibos.exentoDeduccion = [dbo].[ResumenPorCentroNomina].exento ,
                                kardexImprimeRecibos.anexoConceptoDeduccion = [dbo].[ResumenPorCentroNomina].anexoConceptoDeduccion
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'S', @tiponomina,
                                                              'D',
                                                              @ordenadopor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              2, --@desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN kardexImprimeRecibos.supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND kardexImprimeRecibos.renglon = [dbo].[ResumenPorCentroNomina].renglon
                                                              AND kardexImprimeRecibos.numeroConceptoDeduccion = [dbo].[ResumenPorCentroNomina].numeroConcepto
                                                              AND kardexImprimeRecibos.nombreConceptoDeduccion = [dbo].[ResumenPorCentroNomina].nombreConcepto
                        WHERE   ( ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 101
                                    AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 199
                                  )
                                  OR ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 1001
                                       AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 1099
                                     )
                                )
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa
                                
--SELECT 6,* FROM @kardex ORDER BY centro, codigo, renglon
                    END

-- Carga Provisiones
                IF @incluirprovisiones = 'S'
                    BEGIN
                        UPDATE  kardexImprimeRecibos
                        SET     kardexImprimeRecibos.numeroConceptoProvision = dbo.kardex.num_conc ,
                                kardexImprimeRecibos.nombreConceptoProvision = dbo.kardex.concepto ,
                                kardexImprimeRecibos.importeConceptoProvision = dbo.kardex.importe
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                INNER JOIN dbo.kardex ON kardexImprimeRecibos.empresa = dbo.kardex.empresa
                                                         AND kardexImprimeRecibos.codigo = dbo.kardex.codigo
                                                         AND kardexImprimeRecibos.renglon = dbo.kardex.renglon
                                                         AND @nomina = dbo.kardex.nomina
                        WHERE   ( dbo.kardex.num_conc >= 201
                                      AND dbo.kardex.num_conc <= 299
                                    )
                                AND dbo.kardex.nomina = @nomina
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa

                -- Provision. Actualiza el subtotal y total de resumen de centro de costos
                        UPDATE  kardexImprimeRecibos
                        SET     kardexImprimeRecibos.numeroConceptoProvision = [dbo].[ResumenPorCentroNomina].numeroConcepto ,
                                kardexImprimeRecibos.nombreConceptoProvision = [dbo].[ResumenPorCentroNomina].nombreConcepto ,
                                kardexImprimeRecibos.importeConceptoProvision = [dbo].[ResumenPorCentroNomina].importe
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'S', @tiponomina,
                                                              'I',
                                                              @ordenadopor, 0,
                                                              0, 0, 0, 0, 0, 0,
                                                              @desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN kardexImprimeRecibos.supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                                                              AND kardexImprimeRecibos.renglon = [dbo].[ResumenPorCentroNomina].renglon
                        WHERE   ( [dbo].[ResumenPorCentroNomina].numeroConcepto >= 201
                                  AND [dbo].[ResumenPorCentroNomina].numeroConcepto <= 299
                                )
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa
                    END

--SELECT 1,* FROM @kardex ORDER BY codigo, renglon
                -- Registro Totales
                UPDATE  kardexImprimeRecibos
                SET     kardexImprimeRecibos.empleados = [dbo].[ResumenPorCentroNomina].empleados ,
                        kardexImprimeRecibos.provisionIMSS = [dbo].[ResumenPorCentroNomina].provisionIMSS ,
                        kardexImprimeRecibos.provisionRCV = [dbo].[ResumenPorCentroNomina].provisionRCV ,
                        kardexImprimeRecibos.provisionINFONAVIT = [dbo].[ResumenPorCentroNomina].provisionINFONAVIT ,
                        kardexImprimeRecibos.retencionIMSS = [dbo].[ResumenPorCentroNomina].retencionIMSS ,
                        kardexImprimeRecibos.retencionRCV = [dbo].[ResumenPorCentroNomina].retencionRCV ,
                        kardexImprimeRecibos.retencionINFONAVIT = [dbo].[ResumenPorCentroNomina].retencionINFONAVIT ,
                        kardexImprimeRecibos.empleadosConCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosConCuentaBancaria ,
                        kardexImprimeRecibos.empleadosSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosSinCuentaBancaria ,
                        kardexImprimeRecibos.percepcionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesConCuentaBancaria ,
                        kardexImprimeRecibos.deduccionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesConCuentaBancaria ,
                        kardexImprimeRecibos.percepcionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesSinCuentaBancaria ,
                        kardexImprimeRecibos.deduccionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesSinCuentaBancaria ,
                        kardexImprimeRecibos.basePorcientoSobreNomina = [dbo].[ResumenPorCentroNomina].basePorcientoSobreNomina ,
                        kardexImprimeRecibos.porcientoSobreNomina = [dbo].[ResumenPorCentroNomina].porcientoSobreNomina ,
                        kardexImprimeRecibos.fondoAhorroAportacionEmpleado = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionEmpleado ,
                        kardexImprimeRecibos.fondoAhorroAportacionPatron = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionPatron ,
                        kardexImprimeRecibos.sueldoNetoGeneral = [dbo].[ResumenPorCentroNomina].sueldoNetoGeneral,

                        kardexImprimeRecibos.baseISN1 = [dbo].[ResumenPorCentroNomina].baseISN1,
                        kardexImprimeRecibos.porcientoISN1 = [dbo].[ResumenPorCentroNomina].porcientoISN1,
                        kardexImprimeRecibos.importeISN1 = [dbo].[ResumenPorCentroNomina].importeISN1,
                        kardexImprimeRecibos.empleadosISN1 = [dbo].[ResumenPorCentroNomina].empleadosISN1,
                        kardexImprimeRecibos.baseISN2 = [dbo].[ResumenPorCentroNomina].baseISN2,
                        kardexImprimeRecibos.porcientoISN2 = [dbo].[ResumenPorCentroNomina].porcientoISN2,
                        kardexImprimeRecibos.importeISN2 = [dbo].[ResumenPorCentroNomina].importeISN2,
                        kardexImprimeRecibos.empleadosISN2 = [dbo].[ResumenPorCentroNomina].empleadosISN2

                FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'T', @tiponomina,
                                                              '', @ordenadopor,
                                                              @salariodf,
                                                              @salarioregion,
                                                              @eymart25,
                                                              @eymart1062,
                                                              @eymart107,
                                                              @ivart147,
                                                              @cvart168ii,
                                                              @desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN kardexImprimeRecibos.supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                WHERE   [dbo].[ResumenPorCentroNomina].numeroConcepto = 9996
                        AND kardexImprimeRecibos.horaProceso = @horaproceso
                        AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.nomina = @nomina
                        AND kardexImprimeRecibos.empresa = @empresa
                        
--SELECT 7,* FROM @kardex ORDER BY centro, codigo, renglon
--SELECT 2,* FROM @kardex ORDER BY codigo, renglon

        -- Actualizadb Centros de Nivel Superior
                IF @desglosadopor & 1 > 0
                   AND (@ordenadopor & 4 > 0 OR @ordenadopor & 8 > 0 OR @ordenadopor & 16 > 0 OR @ordenadopor & 32 > 0)
                    BEGIN
                -- Registro Totales
                        UPDATE  kardexImprimeRecibos
                        SET     kardexImprimeRecibos.empleados = [dbo].[ResumenPorCentroNomina].empleados ,
                                kardexImprimeRecibos.provisionIMSS = [dbo].[ResumenPorCentroNomina].provisionIMSS ,
                                kardexImprimeRecibos.provisionRCV = [dbo].[ResumenPorCentroNomina].provisionRCV ,
                                kardexImprimeRecibos.provisionINFONAVIT = [dbo].[ResumenPorCentroNomina].provisionINFONAVIT ,
                                kardexImprimeRecibos.retencionIMSS = [dbo].[ResumenPorCentroNomina].retencionIMSS ,
                                kardexImprimeRecibos.retencionRCV = [dbo].[ResumenPorCentroNomina].retencionRCV ,
                                kardexImprimeRecibos.retencionINFONAVIT = [dbo].[ResumenPorCentroNomina].retencionINFONAVIT ,
                                kardexImprimeRecibos.empleadosConCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosConCuentaBancaria ,
                                kardexImprimeRecibos.empleadosSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].empleadosSinCuentaBancaria ,
                                kardexImprimeRecibos.percepcionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesConCuentaBancaria ,
                                kardexImprimeRecibos.deduccionesConCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesConCuentaBancaria ,
                                kardexImprimeRecibos.percepcionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].percepcionesSinCuentaBancaria ,
                                kardexImprimeRecibos.deduccionesSinCuentaBancaria = [dbo].[ResumenPorCentroNomina].deduccionesSinCuentaBancaria ,
                                kardexImprimeRecibos.basePorcientoSobreNomina = [dbo].[ResumenPorCentroNomina].basePorcientoSobreNomina ,
                                kardexImprimeRecibos.porcientoSobreNomina = [dbo].[ResumenPorCentroNomina].porcientoSobreNomina ,
                                kardexImprimeRecibos.fondoAhorroAportacionEmpleado = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionEmpleado ,
                                kardexImprimeRecibos.fondoAhorroAportacionPatron = [dbo].[ResumenPorCentroNomina].fondoAhorroAportacionPatron ,
                                kardexImprimeRecibos.sueldoNetoGeneral = [dbo].[ResumenPorCentroNomina].sueldoNetoGeneral,

                                kardexImprimeRecibos.baseISN1 = [dbo].[ResumenPorCentroNomina].baseISN1,
                                kardexImprimeRecibos.porcientoISN1 = [dbo].[ResumenPorCentroNomina].porcientoISN1,
                                kardexImprimeRecibos.importeISN1 = [dbo].[ResumenPorCentroNomina].importeISN1,
                                kardexImprimeRecibos.empleadosISN1 = [dbo].[ResumenPorCentroNomina].empleadosISN1,
                                kardexImprimeRecibos.baseISN2 = [dbo].[ResumenPorCentroNomina].baseISN2,
                                kardexImprimeRecibos.porcientoISN2 = [dbo].[ResumenPorCentroNomina].porcientoISN2,
                                kardexImprimeRecibos.importeISN2 = [dbo].[ResumenPorCentroNomina].importeISN2,
                                kardexImprimeRecibos.empleadosISN2 = [dbo].[ResumenPorCentroNomina].empleadosISN2

                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'T', @tiponomina,
                                                              '', @ordenadopor,
                                                              @salariodf,
                                                              @salarioregion,
                                                              @eymart25,
                                                              @eymart1062,
                                                              @eymart107,
                                                              @ivart147,
                                                              @cvart168ii, 2, --@desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                                                              AND CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN kardexImprimeRecibos.supervisor
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN ( ( @ordenadopor
                                                              & 16 > 0
                                                              OR @ordenadopor
                                                              & 32 > 0
                                                              )
                                                              AND @desglosadopor
                                                              & 4 = 0
                                                              )
                                                              THEN [dbo].[ResumenPorCentroNomina].supervisor
                                                              ELSE 1
                                                              END
                        WHERE   [dbo].[ResumenPorCentroNomina].numeroConcepto = 9996
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa
                        
--SELECT 8,* FROM @kardex ORDER BY centro, codigo, renglon
                    END

--SELECT 3,* FROM @kardex ORDER BY codigo, renglon

                UPDATE  kardexImprimeRecibos
                SET     kardexImprimeRecibos.ejercicio = [dbo].[ResumenPorCentroNomina].ejercicio ,
                        kardexImprimeRecibos.diarioOficialDia = [dbo].[ResumenPorCentroNomina].diarioOficialDia ,
                        kardexImprimeRecibos.diarioOficialMes = [dbo].[ResumenPorCentroNomina].diarioOficialMes ,
                        kardexImprimeRecibos.diarioOficialAyo = [dbo].[ResumenPorCentroNomina].diarioOficialAyo ,
                        kardexImprimeRecibos.salarioMinimoDF = [dbo].[ResumenPorCentroNomina].salarioMinimoDF ,
                        kardexImprimeRecibos.salarioMinimoRegion = [dbo].[ResumenPorCentroNomina].salarioMinimoRegion ,
                        kardexImprimeRecibos.eymArt25 = [dbo].[ResumenPorCentroNomina].eymArt25 ,
                        kardexImprimeRecibos.eymArt106ii = [dbo].[ResumenPorCentroNomina].eymArt106ii ,
                        kardexImprimeRecibos.eymArt107 = [dbo].[ResumenPorCentroNomina].eymArt107 ,
                        kardexImprimeRecibos.ivArt147 = [dbo].[ResumenPorCentroNomina].ivArt147 ,
                        kardexImprimeRecibos.cvArt168ii = [dbo].[ResumenPorCentroNomina].cvArt168ii ,
                        kardexImprimeRecibos.baseCalculo = [dbo].[ResumenPorCentroNomina].baseCalculo
                        /*
                        [@kardex].baseISN1 = [dbo].[ResumenPorCentroNomina].baseISN1,
                        [@kardex].porcientoISN1 = [dbo].[ResumenPorCentroNomina].porcientoISN1,
                        [@kardex].importeISN1 = [dbo].[ResumenPorCentroNomina].importeISN1,
                        [@kardex].empleadosISN1 = [dbo].[ResumenPorCentroNomina].empleadosISN1,
                        [@kardex].baseISN2 = [dbo].[ResumenPorCentroNomina].baseISN2,
                        [@kardex].porcientoISN2 = [dbo].[ResumenPorCentroNomina].porcientoISN2,
                        [@kardex].importeISN2 = [dbo].[ResumenPorCentroNomina].importeISN2,
                        [@kardex].empleadosISN2 = [dbo].[ResumenPorCentroNomina].empleadosISN2
                        */
                FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        INNER JOIN [dbo].[ResumenPorCentroNomina](@empresa,
                                                              @nomina,
                                                              @incluirprovisiones,
                                                              'T', @tiponomina,
                                                              '', @ordenadopor,
                                                              @salariodf,
                                                              @salarioregion,
                                                              @eymart25,
                                                              @eymart1062,
                                                              @eymart107,
                                                              @ivart147,
                                                              @cvart168ii,
                                                              @desglosadopor,
                                                              @porcentro) ON kardexImprimeRecibos.codigo = [dbo].[ResumenPorCentroNomina].codigo
                                                              AND RTRIM(LTRIM(kardexImprimeRecibos.centro)) = RTRIM(LTRIM([dbo].[ResumenPorCentroNomina].centro))
                WHERE   [dbo].[ResumenPorCentroNomina].numeroConcepto = 9996
                        AND kardexImprimeRecibos.codigo = 999999996
                        AND kardexImprimeRecibos.centro = '99999999999997'
                        AND kardexImprimeRecibos.horaProceso = @horaproceso
                        AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.nomina = @nomina
                        AND kardexImprimeRecibos.empresa = @empresa
                        
--SELECT 9,* FROM @kardex ORDER BY centro, codigo, renglon
--SELECT 4,* FROM @kardex ORDER BY codigo, renglon
            END

        IF @esrecibo = 0
            BEGIN 
                DELETE  kardexImprimeRecibos
                FROM dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                WHERE   kardexImprimeRecibos.empresa = @empresa
                        AND kardexImprimeRecibos.codigo = 999999995
                        AND kardexImprimeRecibos.numeroConceptoPercepcion IS NULL
                        AND kardexImprimeRecibos.numeroConceptoDeduccion IS NULL
                        AND kardexImprimeRecibos.numeroConceptoProvision IS NULL
                        AND kardexImprimeRecibos.horaProceso = @horaproceso
                        AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.nomina = @nomina
                        AND kardexImprimeRecibos.empresa = @empresa
            END
--SELECT 10,* FROM @kardex ORDER BY centro, codigo, renglon

        IF @firma = 'S'
            AND @desglosadopor & 1 > 0
            BEGIN
                INSERT  @renglon
                        ( codigo ,
                          nombre ,
                          centro ,
                          supervisor ,
                          grupo ,
                          grupoRecibo ,
                          diferenciaRenglon ,
                          ultimoRenglon
                        )
                        SELECT  kardexImprimeRecibos.codigo ,
                                kardexImprimeRecibos.nombre ,
                                kardexImprimeRecibos.centro ,
                                kardexImprimeRecibos.supervisor ,
                                kardexImprimeRecibos.grupo ,
                                kardexImprimeRecibos.grupoRecibo ,
                                SUM(CASE WHEN ISNULL(kardexImprimeRecibos.numeroConceptoPercepcion,
                                                     0) > 0 THEN 1
                                         ELSE 0
                                    END
                                    - CASE WHEN ISNULL(kardexImprimeRecibos.numeroConceptoDeduccion,
                                                       0) > 0 THEN 1
                                           ELSE 0
                                      END) ,
                                MAX(kardexImprimeRecibos.renglon)
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        WHERE   kardexImprimeRecibos.codigo <= 99999999
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa
                        GROUP BY kardexImprimeRecibos.codigo ,
                                kardexImprimeRecibos.nombre ,
                                kardexImprimeRecibos.centro ,
                                kardexImprimeRecibos.supervisor ,
                                kardexImprimeRecibos.grupo ,
                                kardexImprimeRecibos.grupoRecibo
                        ORDER BY kardexImprimeRecibos.codigo

                INSERT  @renglon
                        ( codigo ,
                          nombre ,
                          centro ,
                          supervisor ,
                          grupo ,
                          grupoRecibo ,
                          diferenciaRenglon ,
                          ultimoRenglon ,
                          renglon ,
                          renglonesAgregar
                        )
                        SELECT  codigo ,
                                nombre ,
                                centro ,
                                supervisor ,
                                grupo ,
                                grupoRecibo ,
                                diferenciaRenglon ,
                                ultimoRenglon ,
                                agregaRenglon.renglon ,
                                ultimoRenglon + agregaRenglon.renglon
                        FROM    @renglon ,
                                @agregarenglon AS agregaRenglon
                        WHERE   diferenciaRenglon > -3

                DELETE  renglon
                FROM    @renglon AS renglon
                WHERE   renglonesAgregar IS NULL
                        OR codigo = 999999996

                INSERT  dbo.KardexImprimeRecibos
                        ( proceso ,
                          fechaProceso ,
                          horaProceso ,
                          empresa ,
                          codigo ,
                          nombre ,
                          centro ,
                          supervisor ,
                          grupo ,
                          grupoRecibo ,
                          renglon ,
                          procesoName ,
                          firma ,
                          copia
                        )
                        SELECT  @proceso ,
                                @fechaproceso ,
                                @horaproceso ,
                                @empresa ,
                                renglon.codigo ,
                                renglon.nombre ,
                                renglon.centro ,
                                renglon.supervisor ,
                                renglon.grupo ,
                                renglon.grupoRecibo ,
                                renglon.renglonesAgregar ,
                                @procesoname ,
                                @firma ,
                                1 AS copia
                        FROM    @renglon AS renglon
                        WHERE   renglon <= ABS(-3 - diferenciaRenglon)
                        ORDER BY codigo ,
                                renglonesAgregar
            END

        IF @saltopagina = 'S'
            AND ( @ordenadopor & 4 > 0
                  OR @ordenadopor & 8 > 0
                  OR @ordenadopor & 16 > 0
                  OR @ordenadopor & 32 > 0
                )
            AND ( @desglosadopor & 1 > 0
                  OR @desglosadopor & 2 > 0
                )
            BEGIN
                DECLARE @tablaordenada TABLE
                    (
                      serial INT IDENTITY ,
                      grupo VARCHAR(500) ,
                      codigo INT ,
                      campo VARCHAR(500) ,
                      renglon INT ,
                      saltarPagina VARCHAR(1)
                    )

                DECLARE @grupoanterior VARCHAR(500)
                DECLARE @saltarpagina VARCHAR(1)

                INSERT  @tablaordenada
                        (
                          grupo ,
                          codigo ,
                          campo ,
                          renglon
                        )
                        SELECT  DISTINCT
                                kardexImprimeRecibos.grupo ,
                                kardexImprimeRecibos.codigo,
                                CASE WHEN @ordenadopor & 4 > 0
                                     THEN kardexImprimeRecibos.centro + kardexImprimeRecibos.nombre
                                     WHEN @ordenadopor & 8 > 0
                                     THEN kardexImprimeRecibos.centro + STR(kardexImprimeRecibos.codigo)
                                     WHEN @ordenadopor & 16 > 0
                                     THEN kardexImprimeRecibos.centro + STR(kardexImprimeRecibos.supervisor) + kardexImprimeRecibos.nombre
                                     WHEN @ordenadopor & 32 > 0
                                     THEN kardexImprimeRecibos.centro + STR(kardexImprimeRecibos.supervisor)
                                          + STR(kardexImprimeRecibos.codigo)
                                END ,
                                1
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        WHERE   kardexImprimeRecibos.centro <> '99999999999997' 
                                AND kardexImprimeRecibos.codigo <> 999999996 
                                AND kardexImprimeRecibos.renglon = 1
                                AND kardexImprimeRecibos.horaProceso = @horaproceso
                                AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                                AND kardexImprimeRecibos.proceso = @proceso
                                AND kardexImprimeRecibos.nomina = @nomina
                                AND kardexImprimeRecibos.empresa = @empresa
                        ORDER BY kardexImprimeRecibos.grupo ,
                                CASE WHEN @ordenadopor & 4 > 0
                                     THEN kardexImprimeRecibos.centro + kardexImprimeRecibos.nombre
                                     WHEN @ordenadopor & 8 > 0
                                     THEN kardexImprimeRecibos.centro + STR(kardexImprimeRecibos.codigo)
                                     WHEN @ordenadopor & 16 > 0
                                     THEN kardexImprimeRecibos.centro + STR(kardexImprimeRecibos.supervisor) + kardexImprimeRecibos.nombre
                                     WHEN @ordenadopor & 32 > 0
                                     THEN kardexImprimeRecibos.centro + STR(kardexImprimeRecibos.supervisor)
                                          + STR(kardexImprimeRecibos.codigo)
                                END

                SELECT TOP 1
                        @grupoanterior = grupo
                FROM    @tablaordenada

                UPDATE  @tablaordenada
                SET     @saltarpagina = CASE WHEN (@grupoanterior <> grupo OR codigo = 999999995) AND serial <> 1
                                             THEN 'S'
                                             ELSE NULL
                                        END ,
                        saltarPagina = @saltarpagina ,
                        @grupoanterior = grupo


                UPDATE  kardexImprimeRecibos
                SET     kardexImprimeRecibos.saltarPagina = tablaOrdenada.saltarPagina
                FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        INNER JOIN @tablaordenada AS tablaOrdenada ON kardexImprimeRecibos.grupo = tablaOrdenada.grupo
                                                              AND kardexImprimeRecibos.renglon = tablaOrdenada.renglon
                                                              AND CASE
                                                              WHEN @ordenadopor
                                                              & 4 > 0
                                                              THEN kardexImprimeRecibos.centro
                                                              + kardexImprimeRecibos.nombre
                                                              WHEN @ordenadopor
                                                              & 8 > 0
                                                              THEN kardexImprimeRecibos.centro
                                                              + STR(kardexImprimeRecibos.codigo)
                                                              WHEN @ordenadopor
                                                              & 16 > 0
                                                              THEN kardexImprimeRecibos.centro
                                                              + STR(kardexImprimeRecibos.supervisor)
                                                              + kardexImprimeRecibos.nombre
                                                              WHEN @ordenadopor
                                                              & 32 > 0
                                                              THEN kardexImprimeRecibos.centro
                                                              + STR(kardexImprimeRecibos.supervisor)
                                                              + STR(kardexImprimeRecibos.codigo)
                                                              END = tablaOrdenada.campo
                WHERE   kardexImprimeRecibos.horaProceso = @horaproceso
                        AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.nomina = @nomina
                        AND kardexImprimeRecibos.empresa = @empresa

                --UPDATE  tablaKardex
                --SET     tablaKardex.grupo = RTRIM(LTRIM(tablaKardex.grupo)) + '.' + '999999995' ,
                --        tablaKardex.imprimirResumen = CASE WHEN tablaKardex.codigo = 999999996 THEN 1 ELSE NULL END
                --FROM    @kardex AS tablaKardex
                --WHERE tablaKardex.codigo = 999999995 OR tablaKardex.codigo = 999999996
            END

        UPDATE  kardexImprimeRecibos
        SET     kardexImprimeRecibos.grupo = CASE WHEN RTRIM(LTRIM(kardexImprimeRecibos.centro)) = '99999999999997' THEN RTRIM(LTRIM(kardexImprimeRecibos.grupo)) + '.' + '999999995' ELSE kardexImprimeRecibos.grupo END , --RTRIM(LTRIM(tablaKardex.grupo)) + '.' + '999999995' ,
                kardexImprimeRecibos.imprimirResumen = CASE WHEN kardexImprimeRecibos.codigo = 999999996 THEN 1 ELSE NULL END
        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
        WHERE (kardexImprimeRecibos.codigo = 999999995 OR kardexImprimeRecibos.codigo = 999999996)
              AND kardexImprimeRecibos.fechaProceso = @fechaproceso
              AND kardexImprimeRecibos.proceso = @proceso
              AND kardexImprimeRecibos.nomina = @nomina
              AND kardexImprimeRecibos.empresa = @empresa


        IF @procesoname = 'NominaDetalle'
            BEGIN
                DECLARE @fechacierrenomina DATETIME
                DECLARE @tfechaaltaempleado TABLE
                    (
                      codigo INT ,
                      fechaAltaEmpleado DATETIME
                    )

                SELECT  @fechacierrenomina = dbo.Periodos.cierre
                FROM    dbo.Periodos
                WHERE   dbo.Periodos.empresa = @empresa
                        AND dbo.Periodos.tiponom = @tiponomina
                        AND dbo.Periodos.estatus = 'A'

                INSERT  @tfechaaltaempleado
                        ( codigo ,
                          fechaAltaEmpleado
                        )
                        SELECT  dbo.empleados.codigo ,
                                ISNULL(( SELECT TOP 1
                                                dbo.avisos_imss.fch_mov
                                         FROM   dbo.avisos_imss
                                         WHERE  dbo.avisos_imss.empresa = dbo.empleados.empresa
                                                AND dbo.avisos_imss.codigo = dbo.empleados.codigo
                                                AND ( dbo.avisos_imss.mov = 'A'
                                                      OR dbo.avisos_imss.mov = 'RI'
                                                    )
                                                AND dbo.avisos_imss.fch_mov <= @fechacierrenomina
                                         ORDER BY dbo.avisos_imss.fch_mov DESC
                                       ), dbo.empleados.fchalta) AS fechaAlta
                        FROM    dbo.empleados
                                INNER JOIN dbo.KardexImprimeRecibos AS kardexImprimeRecibos ON dbo.empleados.empresa = kardexImprimeRecibos.empresa
                                                                                               AND dbo.empleados.codigo = kardexImprimeRecibos.codigo
                        WHERE dbo.empleados.empresa = @empresa
                              AND kardexImprimeRecibos.fechaProceso = @fechaproceso
                              AND kardexImprimeRecibos.proceso = @proceso
                              AND kardexImprimeRecibos.nomina = @nomina
                              AND kardexImprimeRecibos.empresa = @empresa

                UPDATE  kardexImprimeRecibos
                SET     kardexImprimeRecibos.fechaAlta = tFechaAltaEmpleado.fechaAltaEmpleado
                FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                        INNER JOIN @tfechaaltaempleado AS tFechaAltaEmpleado ON tFechaAltaEmpleado.codigo = kardexImprimeRecibos.codigo
                WHERE   kardexImprimeRecibos.fechaProceso = @fechaproceso
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.nomina = @nomina
                        AND kardexImprimeRecibos.empresa = @empresa
            END

        /*
        IF @ordenadopor IN (4,8,16,32) AND @desglosadopor = 1 AND @saltopagina = 'S' AND @esrecibo = 0
          BEGIN

            DECLARE @tmpkardex TABLE
            (
              empresa INT ,
              codigoId VARCHAR(100) ,
              codigo INT ,
              nombre VARCHAR(100) ,
              fechaAlta DATETIME ,
              numeroSeguridadSocial VARCHAR(10) ,
              digitoVerificador CHAR(1) ,
              curp VARCHAR(18) ,
              centro VARCHAR(16) ,
              nombreCentro VARCHAR(50) ,
              cuentaBanco VARCHAR(30) ,
              nombreBanco VARCHAR(50) ,
              ocupacion INT ,
              categoria VARCHAR(50) ,
              tipoSalario INT ,
              renglon INT ,
              jornada INT ,
              sueldoDiario FLOAT ,
              salarioBaseCotizacion FLOAT ,
              clase VARCHAR(3) ,
              nombreClase VARCHAR(50) ,
              supervisor INT ,
              nombreSupervisor VARCHAR(50) ,
              marcaContraPercepcion CHAR(1) ,
              numeroConceptoPercepcion INT ,
              nombreConceptoPercepcion VARCHAR(50) ,
              importeConceptoPercepcion FLOAT ,
              gravablePercepcion FLOAT ,
              exentoPercepcion FLOAT ,
              saldoPercepcion FLOAT ,
              anexoConceptoPercepcion VARCHAR(150) ,
              marcaContraDeduccion CHAR(1) ,
              numeroConceptoDeduccion INT ,
              nombreConceptoDeduccion VARCHAR(50) ,
              importeConceptoDeduccion FLOAT ,
              gravableDeduccion FLOAT ,
              exentoDeduccion FLOAT ,
              saldoDeduccion FLOAT ,
              anexoConceptoDeduccion VARCHAR(150) ,
              numeroConceptoProvision INT ,
              nombreConceptoProvision VARCHAR(50) ,
              importeConceptoProvision FLOAT ,
              empleados INT ,
              provisionIMSS FLOAT ,
              provisionRCV FLOAT ,
              provisionINFONAVIT FLOAT ,
              retencionIMSS FLOAT ,
              retencionRCV FLOAT ,
              retencionINFONAVIT FLOAT ,
              empleadosConCuentaBancaria INT ,
              empleadosSinCuentaBancaria INT ,
              percepcionesConCuentaBancaria FLOAT ,
              deduccionesConCuentaBancaria FLOAT ,
              percepcionesSinCuentaBancaria FLOAT ,
              deduccionesSinCuentaBancaria FLOAT ,
              basePorcientoSobreNomina FLOAT ,
              porcientoSobreNomina FLOAT ,
              fondoAhorroAportacionEmpleado FLOAT ,
              fondoAhorroAportacionPatron FLOAT ,
              sueldoNetoGeneral FLOAT ,
              ejercicio INT ,
              diarioOficialDia INT ,
              diarioOficialMes INT ,
              diarioOficialAyo INT ,
              salarioMinimoDF FLOAT ,
              salarioMinimoRegion FLOAT ,
              eymArt25 FLOAT ,
              eymArt106ii FLOAT ,
              eymArt107 FLOAT ,
              ivArt147 FLOAT ,
              cvArt168ii FLOAT ,
              baseCalculo INT ,
              grupo VARCHAR(500) ,
              cuantosRecibos INT ,
              numeroRecibo INT ,
              recibo INT ,
              percepcionesEmpleado FLOAT ,
              deduccionesEmpleado FLOAT ,
              netoPagarEmpleado FLOAT ,
              grupoRecibo VARCHAR(500) ,
              rfcAlfa VARCHAR(4) ,
              rfcNum VARCHAR(6) ,
              rfcHomo VARCHAR(3) ,
              acumuladoPercepcion FLOAT ,
              acumuladoPercepcionGravable FLOAT ,
              acumuladoIsr FLOAT ,
              acumuladoInfonavit FLOAT ,
              acumuladoSar FLOAT ,
              acumuladoCv FLOAT ,
              email VARCHAR(60) ,
              fechaAntiguedad DATETIME ,
              procesoName VARCHAR(100) ,
              nomina CHAR(3) ,
              saltarPagina CHAR(1) ,
              firma CHAR(1) ,
              mov CHAR(2) ,
              foto VARCHAR(255),
              baseISN1      FLOAT,
              porcientoISN1 FLOAT,
              importeISN1   FLOAT,
              empleadosISN1 INT,
              baseISN2      FLOAT,
              porcientoISN2 FLOAT,
              importeISN2   FLOAT,
              empleadosISN2 INT ,
              imprimirResumen INT
            )

            INSERT INTO @tmpkardex
            SELECT *
            FROM @kardex
            ORDER BY centro, codigo, codigoId

            DECLARE @codigo INT
            DECLARE @centro VARCHAR(16)
            DECLARE @salta  CHAR(1)

            SET @codigo = 0
            SET @centro = ''
            SET @salta  = 'N'

            UPDATE @tmpkardex
            SET saltarPagina = @salta,
                @salta       = CASE WHEN @centro <> centro AND @codigo > 0 AND centro <> '99999999999997'
                                    THEN 'S'
                                    ELSE 'N'
                               END,
                @codigo = codigo,
                @centro = centro


            DELETE @kardex


            INSERT INTO @kardex
            SELECT *
            FROM @tmpkardex

          END
        */

    --    RETURN
    --END

GO

IF OBJECT_ID('dbo.LlenaImpresionReciboNominaNoOrdinaria') IS NOT NULL
    DROP PROCEDURE dbo.LlenaImpresionReciboNominaNoOrdinaria
GO
CREATE PROCEDURE dbo.LlenaImpresionReciboNominaNoOrdinaria
    @empresa INT ,
    @tiponomina INT ,
    @nomina CHAR(3) ,
    @incluirprovisiones CHAR(1) ,
    @procesoname VARCHAR(100) ,
    @ordenadopor INT ,
    @desglosadopor INT ,
    @porcentro INT ,
    @esrecibo INT ,
    @codigoseleccionado VARCHAR(500) ,
    @ayoejercicio INT ,
    @proceso VARCHAR(250) ,
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)

AS

SET NOCOUNT ON

/*
DECLARE @empresa INT
DECLARE @tiponomina INT
DECLARE @nomina CHAR(3)
DECLARE @incluirprovisiones CHAR(1)
DECLARE @procesoname VARCHAR(100)
DECLARE @ordenadopor INT
DECLARE @desglosadopor INT
DECLARE @porcentro INT
DECLARE @esrecibo INT
DECLARE @codigoseleccionado VARCHAR(500)
DECLARE @ayoejercicio INT
DECLARE @proceso VARCHAR(250)
DECLARE @fechaProceso DATETIME
DECLARE @horaProceso VARCHAR(8)

SET @empresa = 1
SET @tiponomina = 0
SET @nomina = 'AGI'
SET @incluirprovisiones = 'N'
SET @procesoname = 'NominaNoOrdinaria'
SET @ordenadopor = 1
SET @desglosadopor = 1
SET @porcentro = ''
SET @esrecibo = 2
SET @codigoseleccionado = ''
SET @ayoejercicio = 2013
SET @proceso = 'KardexImprimeRecibos_' + @nomina
SET @fechaProceso = GETDATE()
SET @horaProceso = CONVERT(VARCHAR(8), GETDATE(), 108)
*/

    DECLARE @eymtra25 FLOAT
    DECLARE @eymtra1062 FLOAT
    DECLARE @eymtra107 FLOAT
    DECLARE @ivtra147 FLOAT
    DECLARE @cvtra168ii FLOAT
    DECLARE @patronpagaimss CHAR(1)
    DECLARE @mesempresa INT
    DECLARE @ayoempresa INT
    DECLARE @salarioregiona FLOAT
    DECLARE @salariodf FLOAT
    DECLARE @registropatronal VARCHAR(10)
    DECLARE @consulta VARCHAR(4000)
    DECLARE @numeroconceptopercepcioniniciokardex INT
    DECLARE @numeroconceptopercepcionterminokardex INT
    DECLARE @numeroconceptocontrapercepcioniniciokardex INT
    DECLARE @numeroconceptocontrapercepcionterminokardex INT
    DECLARE @numeroconceptodeduccioniniciokardex INT
    DECLARE @numeroconceptodeduccionterminokardex INT
    DECLARE @numeroconceptocontradeduccioniniciokardex INT
    DECLARE @numeroconceptocontradeduccionterminokardex INT
    DECLARE @numeroconceptoprovisioniniciokardex INT
    DECLARE @numeroconceptoprovisionterminokardex INT
    DECLARE @codigoanterior INT
    DECLARE @numerorecibo INT
    DECLARE @cuantosrecibos INT
    DECLARE @ayooperacion INT
    DECLARE @nombreanterior VARCHAR(100)
    DECLARE @copiasRecibo INT
    DECLARE @cuentaCopia INT
    DECLARE @cuentaRenglon INT
    DECLARE @tablaNumeroRecibo TABLE
        (
          codigo INT ,
          renglon INT ,
          cuantosRecibos INT ,
          numeroRecibo INT ,
          recibo INT ,
          centro VARCHAR(16) ,
          supervisor INT ,
          nombre VARCHAR(100)
        )

    DECLARE @tablabaserenglon TABLE ( renglon INT )

    SET @cuentaRenglon = 1

    WHILE @cuentaRenglon <= 40
        BEGIN
            INSERT  @tablabaserenglon
                    ( renglon )
            VALUES  ( @cuentaRenglon )
            SET @cuentaRenglon = @cuentaRenglon + 1
        END


    SET @cuentaCopia = 1
    SET @copiasRecibo = 0
    SET @numeroconceptopercepcioniniciokardex = 1
    SET @numeroconceptopercepcionterminokardex = 99
    SET @numeroconceptocontrapercepcioniniciokardex = 1101
    SET @numeroconceptocontrapercepcionterminokardex = 1199
    SET @numeroconceptodeduccioniniciokardex = 101
    SET @numeroconceptodeduccionterminokardex = 199
    SET @numeroconceptocontradeduccioniniciokardex = 1001
    SET @numeroconceptocontradeduccionterminokardex = 1099
    SET @numeroconceptoprovisioniniciokardex = CASE WHEN @incluirprovisiones = 'S'
                                                    THEN 201
                                                    ELSE 0
                                               END
    SET @numeroconceptoprovisionterminokardex = CASE WHEN @incluirprovisiones = 'S'
                                                     THEN 299
                                                     ELSE 0
                                                END

-- Obtiene datos de empresas
    SELECT TOP 1
            @patronpagaimss = dbo.empresas.patron_paga_cuotas_imss ,
            @ayoempresa = dbo.empresas.ayo_operacion ,
            @mesempresa = dbo.empresas.mes_operacion ,
            @registropatronal = SUBSTRING(dbo.empresas.registro_patronal, 1,
                                          10)
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa


-- Obtiene primas IMSS en base al ao de operacion de la tabla empresas
    SELECT TOP 1
            @eymtra25 = CASE WHEN @patronpagaimss = 'S' THEN 0
                             ELSE dbo.primas_imss.eymtra25
                        END ,
            @eymtra1062 = CASE WHEN @patronpagaimss = 'S' THEN 0
                               ELSE dbo.primas_imss.eymtra1062
                          END ,
            @eymtra107 = CASE WHEN @patronpagaimss = 'S' THEN 0
                              ELSE dbo.primas_imss.eymtra107
                         END ,
            @ivtra147 = CASE WHEN @patronpagaimss = 'S' THEN 0
                             ELSE dbo.primas_imss.ivtra147
                        END ,
            @cvtra168ii = CASE WHEN @patronpagaimss = 'S' THEN 0
                               ELSE dbo.primas_imss.cvtra168ii
                          END
    FROM    dbo.primas_imss
    WHERE   YEAR(dbo.primas_imss.periodo) = @ayoempresa

    SET @eymtra25 = CASE WHEN @eymtra25 IS NULL THEN 0
                         ELSE @eymtra25
                    END
    SET @cvtra168ii = CASE WHEN @cvtra168ii IS NULL THEN 0
                           ELSE @cvtra168ii
                      END

-- Obtiene Salario Minimo
    SELECT  @salarioregiona = ISNULL(zona_a, 0)
    FROM    [dbo].[GetMinimumWage](@mesempresa, @ayoempresa)

    SET @salariodf = @salarioregiona
    SET @ayooperacion = @ayoejercicio

        --- Para cuando se va a imprimir mas de una copia de recibo
    SELECT  @copiasRecibo = ISNULL(dbo.Parametros_Empresas.Copias_Recibo, 0)
    FROM    dbo.Parametros_Empresas
    WHERE   dbo.Parametros_Empresas.Empresa = @empresa

    WHILE @cuentaCopia <= @copiasRecibo
        BEGIN
            DELETE  @tablaNumeroRecibo

            IF @procesoname = 'NominaNoOrdinaria'
                BEGIN
                    INSERT  dbo.KardexImprimeRecibos
                            ( proceso ,
                              fechaProceso ,
                              horaProceso ,
                              empresa ,
                              codigoId ,
                              codigo ,
                              nombre ,
                              fechaAlta ,
                              numeroSeguridadSocial ,
                              digitoVerificador ,
                              curp ,
                              centro ,
                              nombreCentro ,
                              cuentaBanco ,
                              nombreBanco ,
                              ocupacion ,
                              categoria ,
                              tipoSalario ,
                              jornada ,
                              sueldoDiario ,
                              salarioBaseCotizacion ,
                              clase ,
                              nombreClase ,
                              supervisor ,
                              nombreSupervisor ,
                              renglon ,
                              grupo ,
                              rfcAlfa ,
                              rfcNum ,
                              rfcHomo ,
                              email ,
                              fechaAntiguedad ,
                              procesoName ,
                              nomina ,
                              copia
                            )
                            SELECT DISTINCT
                                    @proceso ,
                                    @fechaProceso ,
                                    @horaProceso ,
                                    dbo.kardex.empresa ,
                                    RIGHT(STR(100000000 + dbo.kardex.codigo),
                                          8) + RIGHT(STR(1000000000
                                                         + dbo.kardex.renglon),
                                                     9) AS codigoId ,
                                    dbo.kardex.codigo AS codigo ,
                                    RTRIM(dbo.empleados.ap_paterno) + ' '
                                    + RTRIM(dbo.empleados.ap_materno) + ' '
                                    + RTRIM(dbo.empleados.nombre) AS nombre ,
                                    dbo.empleados.fchalta ,
                                    dbo.empleados.afiliacion ,
                                    dbo.empleados.digvera ,
                                    CASE WHEN LEN(dbo.empleados.curp) = 18
                                         THEN dbo.empleados.curp
                                         ELSE dbo.empleados.rfcalfa
                                              + dbo.empleados.rfcnum
                                              + dbo.empleados.rfchomo
                                    END AS curp ,
                                    dbo.Llaves.centro ,
                                    dbo.centros.nomdepto ,
                                    dbo.empleados.cta_bco_no ,
                                    dbo.bancos.nombre AS nombreBanco ,
                                    dbo.Llaves.ocupacion ,
                                    dbo.tabulador.actividad ,
                                    dbo.empleados.tiposal ,
                                    dbo.empleados.jornada ,
                                    dbo.empleados.sueldo ,
                                    dbo.empleados.saldiaint ,
                                    dbo.Llaves.clase ,
                                    dbo.clases.nombre AS nombreClase ,
                                    dbo.Llaves.supervisor ,
                                    dbo.supervisores.nombre AS nombreSupervisor ,
                                    dbo.kardex.renglon ,
                                    CASE WHEN ( ( @ordenadopor & 4 > 0
                                                  OR @ordenadopor & 8 > 0
                                                )
                                                OR ( ( @ordenadopor & 1 > 0
                                                       OR @ordenadopor & 2 > 0
                                                     )
                                                     AND @desglosadopor & 2 > 0
                                                   )
                                              )
                                         THEN SUBSTRING(dbo.Llaves.centro, 1,
                                                        15)
                                         WHEN ( @ordenadopor & 16 > 0
                                                OR @ordenadopor & 32 > 0
                                              )
                                         THEN RTRIM(dbo.Llaves.centro)
                                              + RIGHT(STR(100000000
                                                          + dbo.Llaves.supervisor),
                                                      8)
                                         ELSE NULL
                                    END AS grupo ,
                                    dbo.empleados.rfcalfa ,
                                    dbo.empleados.rfcnum ,
                                    dbo.empleados.rfchomo ,
                                    dbo.datosemps.email ,
                                    dbo.empleados.fchantigua ,
                                    @procesoname AS procesoName ,
                                    @nomina AS nomina ,
                                    @cuentaCopia AS copia
                            FROM    dbo.SeleccionElementos
                                    INNER JOIN dbo.kardex ON dbo.SeleccionElementos.empresa = dbo.kardex.empresa
                                                             AND dbo.SeleccionElementos.codigo = dbo.kardex.codigo
                                    INNER JOIN dbo.empleados ON dbo.kardex.empresa = dbo.empleados.empresa
                                                              AND dbo.kardex.codigo = dbo.empleados.codigo
                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                             AND dbo.empleados.codigo = dbo.Llaves.codigo
                                    INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                              AND dbo.Llaves.empresa = dbo.centros.empresa
                                    INNER JOIN dbo.tabulador ON dbo.centros.empresa = dbo.tabulador.empresa
                                                              AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
                                    INNER JOIN dbo.bancos ON dbo.Llaves.banco = dbo.bancos.banco
                                    INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa
                                                             AND dbo.Llaves.clase = dbo.clases.clase
                                    INNER JOIN dbo.supervisores ON dbo.Llaves.empresa = dbo.supervisores.empresa
                                                              AND dbo.Llaves.supervisor = dbo.supervisores.supervisor
                                    INNER JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                                              AND dbo.empleados.codigo = dbo.datosemps.codigo
                            WHERE   ( ( ( dbo.kardex.num_conc >= @numeroconceptopercepcioniniciokardex
                                              AND dbo.kardex.num_conc <= @numeroconceptopercepcionterminokardex
                                            )
                                            OR ( dbo.kardex.num_conc >= @numeroconceptocontrapercepcioniniciokardex
                                                 AND dbo.kardex.num_conc <= @numeroconceptocontrapercepcionterminokardex
                                               )
                                          )
                                          OR ( ( dbo.kardex.num_conc >= @numeroconceptodeduccioniniciokardex
                                                 AND dbo.kardex.num_conc <= @numeroconceptodeduccionterminokardex
                                               )
                                               OR ( dbo.kardex.num_conc >= @numeroconceptocontradeduccioniniciokardex
                                                    AND dbo.kardex.num_conc <= @numeroconceptocontradeduccionterminokardex
                                                  )
                                             )
                                          OR ( dbo.kardex.num_conc >= @numeroconceptoprovisioniniciokardex
                                               AND dbo.kardex.num_conc <= @numeroconceptoprovisionterminokardex
                                             )
                                        )
                                    AND dbo.kardex.empresa = CASE WHEN @desglosadopor & 1 > 0
                                                                  THEN @empresa
                                                                  ELSE 0
                                                             END
                                    AND dbo.kardex.nomina = @nomina
                                    AND dbo.SeleccionElementos.nomina = @nomina
                                    AND dbo.SeleccionElementos.procesoName = @procesoname
                                    AND dbo.SeleccionElementos.empresa = @empresa

-- Carga Percepciones
                    UPDATE  kardexImprimeRecibos
                    SET     kardexImprimeRecibos.marcaContraPercepcion = CASE
                                                              WHEN dbo.kardex.num_conc >= 1101
                                                              AND dbo.kardex.num_conc <= 1199
                                                              THEN 'C'
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.numeroConceptoPercepcion = dbo.kardex.num_conc ,
                            kardexImprimeRecibos.nombreConceptoPercepcion = dbo.kardex.concepto ,
                            kardexImprimeRecibos.importeConceptoPercepcion = dbo.kardex.importe ,
                            kardexImprimeRecibos.gravablePercepcion = dbo.kardex.igravable ,
                            kardexImprimeRecibos.exentoPercepcion = dbo.kardex.iexento ,
                            kardexImprimeRecibos.saldoPercepcion = CASE
                                                              WHEN dbo.kardex.saldo > 0
                                                              THEN dbo.kardex.saldo
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.anexoConceptoPercepcion = CASE
                                      -- Detalle Sueldo
                                                              WHEN dbo.kardex.num_conc >= 1
                                                              AND dbo.kardex.num_conc <= 8
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.impor_base))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle Horas Extras
                                                              WHEN dbo.kardex.num_conc >= 10
                                                              AND dbo.kardex.num_conc <= 13
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.horas))
                                                              + ' Horas'

                                      -- Detalle Aguinaldo
                                                              WHEN dbo.kardex.num_conc = 16
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.impor_base))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle Prima Vacacional
                                                              WHEN dbo.kardex.num_conc = 17
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle Vacaciones
                                                              WHEN dbo.kardex.num_conc = 30
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.impor_base))
                                                              + ' * ' + '('
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + 'H' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + 'D' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + 'F' + ')'

                                      -- Detalle Subsidio para el Empleo
                                                              WHEN dbo.kardex.num_conc = 36
                                                              THEN CASE
                                                              WHEN dbo.kardex.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoempresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoEmpresa < 2014
                                                                        THEN 'Art 8vo Trans$'
                                                                        ELSE 'Art 10 Trans$'
                                                                   END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              ELSE ''
                                                              END
                                                              END

                                      -- Detalle Concepto 53 Por Registro Patronal
                                                              WHEN dbo.kardex.num_conc = 53
                                                              AND ( @registropatronal = 'R131234638'
                                                              OR @registropatronal = 'C166197810'
                                                              OR @registropatronal = 'C166939010'
                                                              OR @registropatronal = 'E647730310'
                                                              OR @registroPatronal = 'E648122510'
                                                              )
                                                              THEN SUBSTRING(dbo.kardex.referencia,
                                                              01, 06)
                                                              + RIGHT(RTRIM(dbo.kardex.referencia),
                                                              02) + ' (M'
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.unidades))
                                                              + ')'

                                      -- Detalle Sueldo Neto
                                                              WHEN dbo.kardex.num_conc = 99
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'

                                      -- Detalle de conceptos de Contras del 1107 al 1111
                                                              WHEN dbo.kardex.num_conc >= 1107
                                                              AND dbo.kardex.num_conc <= 1111
                                                              THEN CASE
                                                              WHEN dbo.kardex.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Das'
                                                              ELSE ''
                                                              END

                                      -- Detalle Conceptos con Valor Variable
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                              END
                                                              END ,
                            kardexImprimeRecibos.mov = CASE WHEN dbo.kardex.num_conc <= 6
                                                            THEN RTRIM(dbo.kardex.referencia)
                                                            ELSE NULL
                                                       END
                    FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                            INNER JOIN dbo.kardex ON kardexImprimeRecibos.empresa = dbo.kardex.empresa
                                                     AND kardexImprimeRecibos.codigo = dbo.kardex.codigo
                                                     AND kardexImprimeRecibos.renglon = dbo.kardex.renglon
                                                     AND @nomina = dbo.kardex.nomina
                    WHERE   ( ( dbo.kardex.num_conc >= 1
                                AND dbo.kardex.num_conc <= 99
                              )
                              OR ( dbo.kardex.num_conc >= 1101
                                   AND dbo.kardex.num_conc <= 1199
                                 )
                            )
                            AND dbo.kardex.nomina = @nomina
                            AND kardexImprimeRecibos.copia = @cuentaCopia
                            AND kardexImprimeRecibos.proceso = @proceso
                            AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                            AND kardexImprimeRecibos.horaProceso = @horaProceso
                            AND kardexImprimeRecibos.empresa = @empresa

-- Carga Deducciones
                    UPDATE  kardexImprimeRecibos
                    SET     kardexImprimeRecibos.marcaContraDeduccion = CASE
                                                              WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1099
                                                              THEN 'C'
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.numeroConceptoDeduccion = dbo.kardex.num_conc ,
                            kardexImprimeRecibos.nombreConceptoDeduccion = dbo.kardex.concepto ,
                            kardexImprimeRecibos.importeConceptoDeduccion = dbo.kardex.importe ,
                            kardexImprimeRecibos.gravableDeduccion = dbo.kardex.igravable ,
                            kardexImprimeRecibos.exentoDeduccion = dbo.kardex.iexento ,
                            kardexImprimeRecibos.saldoDeduccion = CASE
                                                              WHEN dbo.kardex.saldo > 0
                                                              THEN CASE
                                                              WHEN dbo.kardex.num_conc = 126
                                                              THEN dbo.kardex.importe
                                                              + dbo.kardex.saldo
                                                              WHEN dbo.kardex.num_conc = 127
                                                              THEN dbo.kardex.importe
                                                              + dbo.kardex.saldo
                                                              ELSE dbo.kardex.saldo
                                                              END
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.anexoConceptoDeduccion = CASE
                                      -- Detalle Cuotas IMSS
                                                              WHEN dbo.kardex.num_conc >= 101
                                                              AND dbo.kardex.num_conc <= 105
                                                              THEN CONVERT(VARCHAR(15), CASE
                                                              WHEN dbo.kardex.num_conc = 102
                                                              THEN CASE
                                                              WHEN dbo.kardex.saldiaint > ( @salariodf
                                                              * 3 )
                                                              THEN dbo.ChecaDecimales(dbo.kardex.saldiaint
                                                              - ( @salariodf
                                                              * 3 ))
                                                              ELSE dbo.ChecaDecimales(dbo.kardex.saldiaint)
                                                              END
                                                              ELSE dbo.ChecaDecimales(dbo.kardex.saldiaint)
                                                              END) + ' * '
                                                              + CASE
                                                              WHEN dbo.kardex.num_conc = 101
                                                              THEN CONVERT(VARCHAR(15), @eymtra25)
                                                              WHEN dbo.kardex.num_conc = 102
                                                              THEN CONVERT(VARCHAR(15), @eymtra1062)
                                                              WHEN dbo.kardex.num_conc = 103
                                                              THEN CONVERT(VARCHAR(15), @eymtra107)
                                                              WHEN dbo.kardex.num_conc = 104
                                                              THEN CONVERT(VARCHAR(15), @ivtra147)
                                                              WHEN dbo.kardex.num_conc = 105
                                                              THEN CONVERT(VARCHAR(15), @cvtra168ii)
                                                              ELSE ''
                                                              END + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias_imss))

                                      -- Detalle Retencion IMSS por Faltas
                                                              WHEN dbo.kardex.num_conc = 106
                                                              OR dbo.kardex.num_conc = 107
                                                              OR dbo.kardex.num_conc = 109
                                                              OR dbo.kardex.num_conc = 110
                                                              OR dbo.kardex.num_conc = 111
                                                              OR dbo.kardex.num_conc = 130
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Da(s)'

                                      -- Detalle Faltas
                                                              WHEN dbo.kardex.num_conc = 108
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Da(s)'
                                                              + ' + '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(ABS(dbo.kardex.descuento
                                                              - 100))) + '%'

                                      -- Detalle Creditos INFONAVIT
                                                              WHEN dbo.kardex.num_conc = 112
                                                              AND dbo.kardex.dias > 0
                                                              THEN CASE
                                                              WHEN dbo.kardex.descuento > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.saldiaint))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.descuento))
                                                              + '%'
                                                              ELSE CONVERT(VARCHAR(15), CONVERT(NUMERIC(15,
                                                              2), dbo.ChecaDecimales(ROUND(dbo.kardex.importe
                                                              / dbo.kardex.dias,
                                                              2)))) + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + 'DS'
                                                              END

                                      -- Detalle Fondo de Ahorro
                                                              WHEN dbo.kardex.num_conc = 126
                                                              OR dbo.kardex.num_conc = 127
                                                              THEN 'Saldo $ '
                                                              + CONVERT(VARCHAR(15), dbo.kardex.saldo
                                                              + dbo.kardex.importe)

                                      -- Detalle ISR
                                                              WHEN dbo.kardex.num_conc = 136
                                                              THEN CASE
                                                              WHEN dbo.kardex.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.kardex.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoempresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoempresa < 2014
                                                                        THEN 'Art 8vo Trans$'
                                                                        ELSE 'Art 10 Trans$'
                                                                    END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              ELSE ''
                                                              END
                                                              END

                                      -- Contra Sueldo
                                                              WHEN dbo.kardex.num_conc >= 1001
                                                              AND dbo.kardex.num_conc <= 1007
                                                              THEN CASE
                                                              WHEN dbo.kardex.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.dias))
                                                              + ' Da(s)'
                                                              ELSE ''
                                                              END

                                      -- Detalle los demas conceptos
                                                              ELSE CASE
                                                              WHEN dbo.kardex.saldo > 0
                                                              THEN 'Saldo $ '
                                                              + CONVERT(VARCHAR(15), dbo.kardex.saldo
                                                              + CASE
                                                              WHEN dbo.conceptos.marca2 = 'H'
                                                              OR --'A'
                                                              dbo.conceptos.num_conc IN (
                                                              125, 126, 127 )
                                                              THEN 1
                                                              ELSE -1
                                                              END
                                                              * dbo.kardex.descuento)
                                                -- Detalle de conceptos con valores variable
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia1))
                                                              + CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.kardex.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia2))
                                                              + CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia3))
                                                              + CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.kardex.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.kardex.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.kardex.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                              END
                                                              END
                                                              END
                    FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                            INNER JOIN dbo.kardex ON kardexImprimeRecibos.empresa = dbo.kardex.empresa
                                                     AND kardexImprimeRecibos.codigo = dbo.kardex.codigo
                                                     AND kardexImprimeRecibos.renglon = dbo.kardex.renglon
                                                     AND @nomina = dbo.kardex.nomina
                            INNER JOIN dbo.conceptos ON dbo.kardex.empresa = dbo.conceptos.empresa
                                                        AND dbo.kardex.num_conc = dbo.conceptos.num_conc
                                                        AND dbo.kardex.clase = dbo.conceptos.clase
                                                        AND dbo.kardex.centro = dbo.conceptos.centro
                    WHERE   ( ( dbo.kardex.num_conc >= 101
                                AND dbo.kardex.num_conc <= 199
                              )
                              OR ( dbo.kardex.num_conc >= 1001
                                   AND dbo.kardex.num_conc <= 1099
                                 )
                            )
                            AND dbo.kardex.nomina = @nomina
                            AND kardexImprimeRecibos.copia = @cuentaCopia
                            AND kardexImprimeRecibos.proceso = @proceso
                            AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                            AND kardexImprimeRecibos.horaProceso = @horaProceso
                            AND kardexImprimeRecibos.empresa = @empresa
                END

            SET @codigoanterior = 0
            SET @numerorecibo = 0
            SET @nombreanterior = ''

                -- Ordenado por Cdigo
            IF @ordenadopor & 1 > 0
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    CASE WHEN [@tablabaserenglon].renglon <= 20
                                         THEN 1
                                         ELSE 2
                                    END AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numerorecibo = @numerorecibo
                            + CASE WHEN [@tablaNumeroRecibo].codigo <> @codigoanterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numerorecibo ,
                            @codigoanterior = [@tablaNumeroRecibo].codigo
                END


                -- Ordenado por Nombre
            IF @ordenadopor & 2 > 0
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    CASE WHEN [@tablabaserenglon].renglon <= 20
                                         THEN 1
                                         ELSE 2
                                    END AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.nombre ,
                                    [@tablabaserenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numerorecibo = @numerorecibo
                            + CASE WHEN [@tablaNumeroRecibo].nombre <> @nombreanterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numerorecibo ,
                            @nombreanterior = [@tablaNumeroRecibo].nombre
                END

                -- Ordenado por Centro y Nombre
            IF @ordenadopor & 4 > 0
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    CASE WHEN [@tablabaserenglon].renglon <= 20
                                         THEN 1
                                         ELSE 2
                                    END AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.nombre ,
                                    [@tablabaserenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numerorecibo = @numerorecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + [@tablaNumeroRecibo].nombre <> @nombreanterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numerorecibo ,
                            @nombreanterior = [@tablaNumeroRecibo].centro
                            + ' ' + [@tablaNumeroRecibo].nombre
                END

                -- Ordenado por Centro y Cdigo
            IF @ordenadopor & 8 > 0
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    CASE WHEN [@tablabaserenglon].renglon <= 20
                                         THEN 1
                                         ELSE 2
                                    END AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numerorecibo = @numerorecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + STR([@tablaNumeroRecibo].codigo) <> @nombreanterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numerorecibo ,
                            @nombreanterior = [@tablaNumeroRecibo].centro
                            + ' ' + STR([@tablaNumeroRecibo].codigo)
                END

                -- Ordenado por Centro, Supervisor y Nombre
            IF @ordenadopor & 16 > 0
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    CASE WHEN [@tablabaserenglon].renglon <= 20
                                         THEN 1
                                         ELSE 2
                                    END AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre ,
                                    [@tablabaserenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numerorecibo = @numerorecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + STR([@tablaNumeroRecibo].supervisor)
                                        + ' ' + [@tablaNumeroRecibo].nombre <> @nombreanterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numerorecibo ,
                            @nombreanterior = [@tablaNumeroRecibo].centro
                            + ' ' + STR([@tablaNumeroRecibo].supervisor) + ' '
                            + [@tablaNumeroRecibo].nombre
                END

                -- Ordenado por Centro, Supervisor y Cdigo
            IF @ordenadopor & 32 > 0
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    CASE WHEN [@tablabaserenglon].renglon <= 20
                                         THEN 1
                                         ELSE 2
                                    END AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 20
                                                              THEN 40
                                                              ELSE 20
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numerorecibo = @numerorecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + STR([@tablaNumeroRecibo].supervisor)
                                        + ' '
                                        + STR([@tablaNumeroRecibo].codigo) <> @nombreanterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numerorecibo ,
                            @nombreanterior = [@tablaNumeroRecibo].centro
                            + ' ' + STR([@tablaNumeroRecibo].supervisor) + ' '
                            + STR([@tablaNumeroRecibo].codigo)
                END


            UPDATE  kardexImprimeRecibos
            SET     kardexImprimeRecibos.cuantosRecibos = tablaNumeroRecibo2.cuantosRecibos ,
                    kardexImprimeRecibos.recibo = CASE WHEN kardexImprimeRecibos.renglon <= 20
                                                       THEN 1
                                                       ELSE 2
                                                  END ,
                    kardexImprimeRecibos.numeroRecibo = tablaNumeroRecibo2.numeroRecibo ,
                    kardexImprimeRecibos.grupoRecibo = RIGHT(STR(100000000
                                                              + kardexImprimeRecibos.codigo),
                                                             8)
                    + RIGHT(STR(100 + @cuentaCopia), 2) + RIGHT(STR(100
                                                              + CASE
                                                              WHEN kardexImprimeRecibos.renglon <= 20
                                                              THEN 1
                                                              ELSE 2
                                                              END), 2)
            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                    INNER JOIN ( SELECT DISTINCT
                                        tablaNumeroRecibo.codigo ,
                                        MAX(tablaNumeroRecibo.renglon) AS renglon ,
                                        MAX(tablaNumeroRecibo.numeroRecibo) AS numeroRecibo ,
                                        MAX(tablaNumeroRecibo.cuantosRecibos) AS cuantosRecibos
                                 FROM   @tablaNumeroRecibo AS tablaNumeroRecibo
                                 GROUP BY tablaNumeroRecibo.codigo
                               ) AS tablaNumeroRecibo2 ON kardexImprimeRecibos.codigo = tablaNumeroRecibo2.codigo
            WHERE   kardexImprimeRecibos.copia = @cuentaCopia
                    AND kardexImprimeRecibos.proceso = @proceso
                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                    AND kardexImprimeRecibos.empresa = @empresa

        -- Optimizacion
            INSERT  dbo.KardexImprimeRecibos
                    ( proceso ,
                      fechaProceso ,
                      horaProceso ,
                      empresa ,
                      codigo ,
                      renglon ,
                      codigoId ,
                      nombre ,
                      centro ,
                      supervisor ,
                      procesoName ,
                      nomina ,
                      cuantosRecibos ,
                      recibo ,
                      numeroRecibo ,
                      grupoRecibo ,
                      copia
                    )
                    SELECT  @proceso AS proceso ,
                            @fechaProceso AS fechaProceso ,
                            @horaProceso AS horaProceso ,
                            @empresa AS empresa ,
                            tablaNumeroRecibo.codigo ,
                            tablaNumeroRecibo.renglon ,
                            RIGHT(STR(100000000 + tablaNumeroRecibo.codigo), 8)
                            + RIGHT(STR(1000000000 + tablaNumeroRecibo.renglon),
                                    9) AS codigoId ,
                            tablaNumeroRecibo.nombre ,
                            tablaNumeroRecibo.centro ,
                            tablaNumeroRecibo.supervisor ,
                            @procesoname ,
                            @nomina ,
                            tablaNumeroRecibo.cuantosRecibos ,
                            CASE WHEN tablaNumeroRecibo.renglon <= 20 THEN 1
                                 ELSE 2
                            END AS recibo ,
                            tablaNumeroRecibo.numeroRecibo ,
                            RIGHT(STR(100000000 + tablaNumeroRecibo.codigo), 8)
                            + RIGHT(STR(100 + @cuentaCopia), 2)
                            + RIGHT(STR(100
                                        + CASE WHEN tablaNumeroRecibo.renglon <= 20
                                               THEN 1
                                               ELSE 2
                                          END), 2) AS grupoRecibo ,
                            @cuentaCopia AS copia
                    FROM    @tablaNumeroRecibo AS tablaNumeroRecibo
                    WHERE   NOT EXISTS ( SELECT TOP 1
                                                kardexImprimeRecibos.renglon
                                         FROM   dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                         WHERE  tablaNumeroRecibo.renglon = kardexImprimeRecibos.renglon
                                                AND tablaNumeroRecibo.codigo = kardexImprimeRecibos.codigo
                                                AND kardexImprimeRecibos.copia = @cuentaCopia
                                                AND kardexImprimeRecibos.proceso = @proceso
                                                AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                                AND kardexImprimeRecibos.horaProceso = @horaProceso
                                                AND kardexImprimeRecibos.empresa = @empresa )


            IF @nomina = 'AGI'
                BEGIN
                    UPDATE  kardexImprimeRecibos
                    SET     kardexImprimeRecibos.percepcionesEmpleado = ISNULL(dbo.aguinaldos.tpercepcion,
                                                              0) ,
                            kardexImprimeRecibos.deduccionesEmpleado = ISNULL(dbo.aguinaldos.tdeduccion,
                                                              0) ,
                            kardexImprimeRecibos.netoPagarEmpleado = ISNULL(dbo.aguinaldos.neto,
                                                              0) ,
                            kardexImprimeRecibos.acumuladoPercepcion = ISNULL(dbo.acum_emps.acu_percep,
                                                              0) ,
                            kardexImprimeRecibos.acumuladoPercepcionGravable = ISNULL(dbo.acum_emps.gravable,
                                                              0) ,
                            kardexImprimeRecibos.acumuladoIsr = ISNULL(dbo.acum_emps.ispt,
                                                              0) ,
                            kardexImprimeRecibos.acumuladoInfonavit = ISNULL(dbo.acum_emps.acu_info,
                                                              0) ,
                            kardexImprimeRecibos.acumuladoSar = ISNULL(dbo.acum_emps.acu_sar,
                                                              0) ,
                            kardexImprimeRecibos.acumuladoCv = ISNULL(dbo.acum_emps.acu_cv,
                                                              0)
                    FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                            INNER JOIN dbo.aguinaldos ON kardexImprimeRecibos.empresa = dbo.aguinaldos.empresa
                                                         AND kardexImprimeRecibos.codigo = dbo.aguinaldos.codigo
                            LEFT JOIN dbo.acum_emps ON kardexImprimeRecibos.empresa = dbo.acum_emps.empresa
                                                       AND kardexImprimeRecibos.codigo = dbo.acum_emps.codigo
                                                       AND @ayooperacion = dbo.acum_emps.ejercicio
                    WHERE   ( ( kardexImprimeRecibos.cuantosRecibos = 1
                                AND kardexImprimeRecibos.renglon = 20
                              )
                              OR ( kardexImprimeRecibos.cuantosRecibos = 2
                                   AND kardexImprimeRecibos.renglon = 40
                                 )
                            )
                            AND kardexImprimeRecibos.copia = @cuentaCopia
                            AND kardexImprimeRecibos.proceso = @proceso
                            AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                            AND kardexImprimeRecibos.horaProceso = @horaProceso
                            AND kardexImprimeRecibos.empresa = @empresa
                END
            ELSE
                BEGIN
                    IF @nomina = 'PTU'
                        OR @nomina = 'DES'
                        OR @nomina = 'VAC'
                        BEGIN
                            UPDATE  kardexImprimeRecibos
                            SET     kardexImprimeRecibos.percepcionesEmpleado = ISNULL(kardexTotal.importePercepcion,
                                                              0) ,
                                    kardexImprimeRecibos.deduccionesEmpleado = ISNULL(kardexTotal.importeDeduccion,
                                                              0) ,
                                    kardexImprimeRecibos.netoPagarEmpleado = ISNULL(kardexTotal.netoPagar,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoPercepcion = ISNULL(dbo.acum_emps.acu_percep,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoPercepcionGravable = ISNULL(dbo.acum_emps.gravable,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoIsr = ISNULL(dbo.acum_emps.ispt,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoInfonavit = ISNULL(dbo.acum_emps.acu_info,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoSar = ISNULL(dbo.acum_emps.acu_sar,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoCv = ISNULL(dbo.acum_emps.acu_cv,
                                                              0)
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                    LEFT JOIN dbo.acum_emps ON kardexImprimeRecibos.empresa = dbo.acum_emps.empresa
                                                              AND kardexImprimeRecibos.codigo = dbo.acum_emps.codigo
                                                              AND @ayooperacion = dbo.acum_emps.ejercicio
                                    INNER JOIN ( SELECT kardexImprimeRecibos1.empresa ,
                                                        kardexImprimeRecibos1.codigo ,
                                                        SUM(ISNULL(kardexImprimeRecibos1.importeConceptoPercepcion,
                                                              0)
                                                            - ISNULL(kardexImprimeRecibos1.importeConceptoDeduccion,
                                                              0)) AS netoPagar ,
                                                        SUM(ISNULL(kardexImprimeRecibos1.importeConceptoPercepcion,
                                                              0)) AS importePercepcion ,
                                                        SUM(ISNULL(kardexImprimeRecibos1.importeConceptoDeduccion,
                                                              0)) AS importeDeduccion
                                                 FROM   dbo.KardexImprimeRecibos
                                                        AS kardexImprimeRecibos1
                                                 WHERE  kardexImprimeRecibos1.copia = @cuentaCopia
                                                        AND kardexImprimeRecibos1.proceso = @proceso
                                                        AND kardexImprimeRecibos1.fechaProceso = @fechaProceso
                                                        AND kardexImprimeRecibos1.horaProceso = @horaProceso
                                                        AND kardexImprimeRecibos1.empresa = @empresa
                                                 GROUP BY kardexImprimeRecibos1.empresa ,
                                                        kardexImprimeRecibos1.codigo
                                               ) AS kardexTotal ON kardexImprimeRecibos.codigo = kardexTotal.codigo
                                                              AND kardexImprimeRecibos.proceso = @proceso
                                                              AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                                              AND kardexImprimeRecibos.horaProceso = @horaProceso
                                                              AND kardexImprimeRecibos.empresa = @empresa
                            WHERE   ( ( kardexImprimeRecibos.cuantosRecibos = 1
                                        AND kardexImprimeRecibos.renglon = 20
                                      )
                                      OR ( kardexImprimeRecibos.cuantosRecibos = 2
                                           AND kardexImprimeRecibos.renglon = 40
                                         )
                                    )
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                        END
                    ELSE
                        BEGIN
                            UPDATE  kardexImprimeRecibos
                            SET     kardexImprimeRecibos.percepcionesEmpleado = ISNULL(dbo.otranomina.percepcion,
                                                              0) ,
                                    kardexImprimeRecibos.deduccionesEmpleado = ISNULL(dbo.otranomina.deduccion,
                                                              0) ,
                                    kardexImprimeRecibos.netoPagarEmpleado = ISNULL(dbo.otranomina.neto,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoPercepcion = ISNULL(dbo.acum_emps.acu_percep,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoPercepcionGravable = ISNULL(dbo.acum_emps.gravable,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoIsr = ISNULL(dbo.acum_emps.ispt,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoInfonavit = ISNULL(dbo.acum_emps.acu_info,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoSar = ISNULL(dbo.acum_emps.acu_sar,
                                                              0) ,
                                    kardexImprimeRecibos.acumuladoCv = ISNULL(dbo.acum_emps.acu_cv,
                                                              0)
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                    INNER JOIN dbo.otranomina ON kardexImprimeRecibos.empresa = dbo.otranomina.empresa
                                                              AND kardexImprimeRecibos.codigo = dbo.otranomina.codigo
                                    LEFT JOIN dbo.acum_emps ON kardexImprimeRecibos.empresa = dbo.acum_emps.empresa
                                                              AND kardexImprimeRecibos.codigo = dbo.acum_emps.codigo
                                                              AND @ayooperacion = dbo.acum_emps.ejercicio
                            WHERE   ( ( kardexImprimeRecibos.cuantosRecibos = 1
                                        AND kardexImprimeRecibos.renglon = 20
                                      )
                                      OR ( kardexImprimeRecibos.cuantosRecibos = 2
                                           AND kardexImprimeRecibos.renglon = 40
                                         )
                                    )
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                        END
                END
            SET @cuentaCopia = @cuentaCopia + 1
        END

    IF @procesoname = 'NominaNoOrdinaria'
        BEGIN
            DECLARE @tfechaaltaempleado TABLE
                (
                  codigo INT ,
                  fechaAltaEmpleado DATETIME
                )

            INSERT  @tfechaaltaempleado
                    ( codigo ,
                      fechaAltaEmpleado

                    )
                    SELECT  dbo.empleados.codigo ,
                            ISNULL(( SELECT TOP 1
                                            dbo.avisos_imss.fch_mov
                                     FROM   dbo.avisos_imss
                                     WHERE  dbo.avisos_imss.empresa = dbo.empleados.empresa
                                            AND dbo.avisos_imss.codigo = dbo.empleados.codigo
                                            AND ( dbo.avisos_imss.mov = 'A'
                                                  OR dbo.avisos_imss.mov = 'RI'
                                                )
                                            AND dbo.avisos_imss.fch_mov <= dbo.Periodos.cierre
                                     ORDER BY dbo.avisos_imss.fch_mov DESC
                                   ), dbo.empleados.fchalta) AS fechaAlta
                    FROM    dbo.empleados
                            INNER JOIN dbo.KardexImprimeRecibos AS kardexImprimeRecibos ON dbo.empleados.empresa = kardexImprimeRecibos.empresa
                                                              AND dbo.empleados.codigo = kardexImprimeRecibos.codigo
                            INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                     AND dbo.empleados.codigo = dbo.Llaves.codigo
                            LEFT JOIN dbo.Periodos ON dbo.Llaves.empresa = dbo.Periodos.empresa
                                                      AND dbo.Llaves.tiponom = dbo.Periodos.tiponom
                                                      AND dbo.Periodos.estatus = 'A'
                    WHERE   dbo.empleados.empresa = @empresa
                            AND kardexImprimeRecibos.proceso = @proceso
                            AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                            AND kardexImprimeRecibos.horaProceso = @horaProceso
                            AND kardexImprimeRecibos.empresa = @empresa

            UPDATE  kardexImprimeRecibos
            SET     kardexImprimeRecibos.fechaAlta = tFechaAltaEmpleado.fechaAltaEmpleado
            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                    INNER JOIN @tfechaaltaempleado AS tFechaAltaEmpleado ON tFechaAltaEmpleado.codigo = kardexImprimeRecibos.codigo
            WHERE   kardexImprimeRecibos.copia = @cuentaCopia
                    AND kardexImprimeRecibos.proceso = @proceso
                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                    AND kardexImprimeRecibos.empresa = @empresa
        END
GO

IF OBJECT_ID('dbo.LlenaImpresionReciboNominaOrdinaria') IS NOT NULL 
    DROP  PROCEDURE [dbo].[LlenaImpresionReciboNominaOrdinaria]
GO
CREATE PROCEDURE [dbo].[LlenaImpresionReciboNominaOrdinaria]
    (
      @empresa INT ,
      @tipoNomina INT ,
      @nomina CHAR(3) ,
      @incluirProvisiones CHAR(1) ,
      @procesoName VARCHAR(100) ,
      @ordenadoPor INT ,
      @desglosadoPor INT ,
      @porCentro INT ,
      @esRecibo INT ,
      @codigoSeleccionado VARCHAR(500) ,
      @ayoEjercicio INT ,
      @proceso VARCHAR(250) ,
      @fechaProceso DATETIME ,
      @horaProceso VARCHAR(8)
    )
AS 
    SET NOCOUNT ON

    DECLARE @renglonTope INT
    DECLARE @reciboSeleccionado VARCHAR(6)

    SELECT  @reciboSeleccionado = SUBSTRING(dbo.Parametros_Nominas.Recibo, 1,
                                            6)
    FROM    dbo.Parametros_Nominas
    WHERE   dbo.Parametros_Nominas.Empresa = @empresa
            AND dbo.Parametros_Nominas.TipoNom = @tipoNomina

    IF @reciboSeleccionado = 'Apsi 3' 
        SET @renglonTope = 17
    ELSE 
        SET @renglonTope = 20


-- Variables para Primas IMSS
    DECLARE @eymArt25 FLOAT
    DECLARE @eymPat25 FLOAT
    DECLARE @eymTra25 FLOAT
    DECLARE @eymArt106I FLOAT
    DECLARE @eymArt1062 FLOAT
    DECLARE @eymPat1062 FLOAT
    DECLARE @eymTra1062 FLOAT
    DECLARE @eymArt107 FLOAT
    DECLARE @eymPat107 FLOAT
    DECLARE @eymTra107 FLOAT
    DECLARE @ivArt147 FLOAT
    DECLARE @ivPat147 FLOAT
    DECLARE @ivTra147 FLOAT
    DECLARE @retiro FLOAT
    DECLARE @cvArt168II FLOAT
    DECLARE @cvPat168II FLOAT
    DECLARE @cvTra168II FLOAT
    DECLARE @patronPagaIMSS CHAR(1)
    DECLARE @mesEmpresa INT
    DECLARE @ayoEmpresa INT
    DECLARE @salarioRegionA FLOAT
    DECLARE @salarioRegionB FLOAT
    DECLARE @salarioRegionC FLOAT
    DECLARE @salarioRegion FLOAT
    DECLARE @salarioDF FLOAT
        --DECLARE @areaGeografica CHAR(1)
    DECLARE @topeDF FLOAT
    DECLARE @topeRegion FLOAT
    DECLARE @registroPatronal VARCHAR(10)
    DECLARE @consulta VARCHAR(4000)
    DECLARE @orden VARCHAR(200)
    DECLARE @numeroConceptoPercepcionInicioKardex INT
    DECLARE @numeroConceptoPercepcionTerminoKardex INT
    DECLARE @numeroConceptoContraPercepcionInicioKardex INT
    DECLARE @numeroConceptoContraPercepcionTerminoKardex INT
    DECLARE @numeroConceptoDeduccionInicioKardex INT
    DECLARE @numeroConceptoDeduccionTerminoKardex INT
    DECLARE @numeroConceptoContraDeduccionInicioKardex INT
    DECLARE @numeroConceptoContraDeduccionTerminoKardex INT
    DECLARE @numeroConceptoProvisionInicioKardex INT
    DECLARE @numeroConceptoProvisionTerminoKardex INT
    DECLARE @ejercicio INT
    DECLARE @diarioOficial DATETIME
    DECLARE @baseCalculo VARCHAR(25)
    DECLARE @codigoAnterior INT
    DECLARE @numeroRecibo INT
    DECLARE @cuantosRecibos INT
    DECLARE @percepcionesEmpleado FLOAT
    DECLARE @deduccionesEmpleado FLOAT
    DECLARE @netoPagarEmpleado FLOAT
    DECLARE @ayoOperacion INT
    DECLARE @nombreAnterior VARCHAR(100)
    DECLARE @copiasRecibo INT
    DECLARE @cuentaCopia INT
    DECLARE @cuentaRenglon INT

        --DECLARE @codigoBase TABLE
        --    (
        --      codigo INT ,
        --      renglon INT ,
        --      cuantosRecibos INT ,
        --      numeroRecibo INT ,
        --      recibo INT ,
        --      centro VARCHAR(16) ,
        --      supervisor INT ,
        --      nombre VARCHAR(100)
        --    )

    DECLARE @tablaNumeroRecibo TABLE
        (
          codigo INT ,
          renglon INT ,
          cuantosRecibos INT ,
          numeroRecibo INT ,
          recibo INT ,
          centro VARCHAR(16) ,
          supervisor INT ,
          nombre VARCHAR(100)
        )

    DECLARE @tablaBaseRenglon TABLE ( renglon INT )

    SET @cuentaRenglon = 1
    --IF @renglonTope = 20 
        WHILE @cuentaRenglon <= CASE WHEN @renglonTope = 20 THEN 100
                                     ELSE 85
                                END 
            BEGIN
                INSERT  @tablabaserenglon
                        ( renglon )
                VALUES  ( @cuentaRenglon )
                SET @cuentaRenglon = @cuentaRenglon + 1
            END  

    SET @cuentaCopia = 1
    SET @copiasRecibo = 0
    SET @numeroConceptoPercepcionInicioKardex = 1
    SET @numeroConceptoPercepcionTerminoKardex = 99
    SET @numeroConceptoContraPercepcionInicioKardex = 1101
    SET @numeroConceptoContraPercepcionTerminoKardex = 1199
    SET @numeroConceptoDeduccionInicioKardex = 101
    SET @numeroConceptoDeduccionTerminoKardex = 199
    SET @numeroConceptoContraDeduccionInicioKardex = 1001
    SET @numeroConceptoContraDeduccionTerminoKardex = 1099
    SET @numeroConceptoProvisionInicioKardex = CASE WHEN @incluirProvisiones = 'S'
                                                    THEN 201
                                                    ELSE 0
                                               END
    SET @numeroConceptoProvisionTerminoKardex = CASE WHEN @incluirProvisiones = 'S'
                                                     THEN 299
                                                     ELSE 0
                                                END



-- Obtiene datos de empresas
    SELECT TOP 1
                --@areaGeografica = dbo.empresas.zona_geografica ,
            @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
            @ayoEmpresa = dbo.empresas.ayo_operacion ,
            @mesEmpresa = dbo.empresas.mes_operacion ,
            @registroPatronal = SUBSTRING(dbo.empresas.registro_patronal, 1,
                                          10)
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa


-- Obtiene primas IMSS en base al ao de operacion de la tabla empresas
    SELECT TOP 1
            @eymArt25 = dbo.primas_imss.eymart25 ,
            @eymPat25 = dbo.primas_imss.eympat25
            + CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.eymtra25
                   ELSE 0
              END ,
            @eymTra25 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                             ELSE dbo.primas_imss.eymtra25
                        END ,
            @eymArt106I = dbo.primas_imss.eymart106I ,
            @eymArt1062 = dbo.primas_imss.eymart1062 ,
            @eymPat1062 = dbo.primas_imss.eympat1062
            + CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.eymtra1062
                   ELSE 0
              END ,
            @eymTra1062 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                               ELSE dbo.primas_imss.eymtra1062
                          END ,
            @eymArt107 = dbo.primas_imss.eymart107 ,
            @eymPat107 = dbo.primas_imss.eympat107
            + CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.eymtra107
                   ELSE 0
              END ,
            @eymTra107 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                              ELSE dbo.primas_imss.eymtra107
                         END ,
            @ivArt147 = dbo.primas_imss.ivart147 ,
            @ivPat147 = dbo.primas_imss.ivpat147
            + CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.ivtra147
                   ELSE 0
              END ,
            @ivTra147 = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                             ELSE dbo.primas_imss.ivtra147
                        END ,
            @retiro = dbo.primas_imss.retiro ,
            @cvArt168II = dbo.primas_imss.cvart168II ,
            @cvPat168II = dbo.primas_imss.cvpat168II
            + CASE WHEN @patronPagaIMSS = 'S' THEN dbo.primas_imss.cvtra168ii
                   ELSE 0
              END ,
            @cvTra168II = CASE WHEN @patronPagaIMSS = 'S' THEN 0
                               ELSE dbo.primas_imss.cvtra168ii
                          END
    FROM    dbo.primas_imss
    WHERE   YEAR(dbo.primas_imss.periodo) = @ayoEmpresa



    SET @eymArt25 = CASE WHEN @eymArt25 IS NULL THEN 0
                         ELSE @eymArt25
                    END
    SET @eymPat25 = CASE WHEN @eymPat25 IS NULL THEN 0
                         ELSE @eymPat25
                    END
    SET @eymTra25 = CASE WHEN @eymTra25 IS NULL THEN 0
                         ELSE @eymTra25
                    END
    SET @eymArt106I = CASE WHEN @eymArt106I IS NULL THEN 0
                           ELSE @eymArt106I
                      END
    SET @eymArt1062 = CASE WHEN @eymArt1062 IS NULL THEN 0
                           ELSE @eymArt1062
                      END
    SET @eymPat1062 = CASE WHEN @eymPat1062 IS NULL THEN 0
                           ELSE @eymPat1062
                      END
    SET @eymTra1062 = CASE WHEN @eymTra1062 IS NULL THEN 0
                           ELSE @eymTra1062
                      END
    SET @eymArt107 = CASE WHEN @eymArt107 IS NULL THEN 0
                          ELSE @eymArt107
                     END
    SET @eymPat107 = CASE WHEN @eymPat107 IS NULL THEN 0
                          ELSE @eymPat107
                     END
    SET @eymTra107 = CASE WHEN @eymTra107 IS NULL THEN 0
                          ELSE @eymTra107
                     END
    SET @ivArt147 = CASE WHEN @ivArt147 IS NULL THEN 0
                         ELSE @ivArt147
                    END
    SET @ivPat147 = CASE WHEN @ivPat147 IS NULL THEN 0
                         ELSE @ivPat147
                    END
    SET @ivTra147 = CASE WHEN @ivTra147 IS NULL THEN 0
                         ELSE @ivTra147
                    END
    SET @retiro = CASE WHEN @retiro IS NULL THEN 0
                       ELSE @retiro
                  END
    SET @cvArt168II = CASE WHEN @cvArt168II IS NULL THEN 0
                           ELSE @cvArt168II
                      END
    SET @cvPat168II = CASE WHEN @cvPat168II IS NULL THEN 0
                           ELSE @cvPat168II
                      END
    SET @cvTra168II = CASE WHEN @cvTra168II IS NULL THEN 0
                           ELSE @cvTra168II
                      END
    SET @patronPagaIMSS = CASE WHEN @patronPagaIMSS IS NULL THEN 'N'
                               ELSE @patronPagaIMSS
                          END


-- Obtiene Salario Minimo
    SELECT  @salarioRegionA = ISNULL(zona_a, 0) 
                --@salarioRegionB = ISNULL(zona_b, 0) ,
                --@salarioRegionC = ISNULL(zona_c, 0)
    FROM    [dbo].[GetMinimumWage](@mesEmpresa, @ayoEmpresa)

    SET @salarioDF = @salarioRegionA

        --SET @salarioRegion = CASE @areaGeografica
        --                       WHEN 'A' THEN @salarioRegionA
        --                       WHEN 'B' THEN @salarioRegionB
        --                       WHEN 'C' THEN @salarioRegionC
        --                       ELSE 0
        --                     END

    SET @topeDF = ROUND(@salarioDF * 25, 2)
    SET @topeRegion = @salarioRegion

        SELECT  @ayoOperacion = ISNULL(dbo.Periodos.ayo_operacion, 0)
        FROM    dbo.Periodos
        WHERE   dbo.Periodos.empresa = @empresa
                AND dbo.Periodos.tiponom = @tipoNomina
                AND dbo.Periodos.estatus = 'A'
    --SET @ayooperacion = @ayoejercicio

        --- Para cuando se va a imprimir mas de una copia de recibo
    SELECT  @copiasRecibo = ISNULL(dbo.Parametros_Empresas.Copias_Recibo, 0)
    FROM    dbo.Parametros_Empresas
    WHERE   dbo.Parametros_Empresas.Empresa = @empresa
        
    WHILE @cuentaCopia <= @copiasRecibo 
        BEGIN
            DELETE  @tablaNumeroRecibo


            IF @procesoName = 'NominaDetalle' 
                BEGIN
                
-- Prepara tabla virtual
                    INSERT  dbo.KardexImprimeRecibos
                            ( proceso ,
                              fechaProceso ,
                              horaProceso ,
                              empresa ,
                              codigoId ,
                              codigo ,
                              nombre ,
                              fechaAlta ,
                              numeroSeguridadSocial ,
                              digitoVerificador ,
                              curp ,
                              centro ,
                              nombreCentro ,
                              cuentaBanco ,
                              nombreBanco ,
                              ocupacion ,
                              categoria ,
                              tipoSalario ,
                              jornada ,
                              sueldoDiario ,
                              salarioBaseCotizacion ,
                              clase ,
                              nombreClase ,
                              supervisor ,
                              nombreSupervisor ,
                              renglon ,
                              grupo ,
                              rfcAlfa ,
                              rfcNum ,
                              rfcHomo ,
                              email ,
                              fechaAntiguedad ,
                              procesoName ,
                              nomina ,
                              foto ,
                              copia
                            )
                            SELECT DISTINCT
                                    @proceso ,
                                    @fechaProceso ,
                                    @horaProceso ,
                                    dbo.recibos.empresa ,
                                    RIGHT(STR(100000000 + dbo.recibos.codigo),
                                          8) + RIGHT(STR(1000000000
                                                         + dbo.recibos.renglon),
                                                     9) AS codigoId ,
                                    dbo.recibos.codigo AS codigo ,
                                    RTRIM(dbo.empleados.ap_paterno) + ' '
                                    + RTRIM(dbo.empleados.ap_materno) + ' '
                                    + RTRIM(dbo.empleados.nombre) AS nombre ,
                                    dbo.empleados.fchalta ,
                                    dbo.empleados.afiliacion ,
                                    dbo.empleados.digvera ,
                                    CASE WHEN LEN(dbo.empleados.curp) = 18
                                         THEN dbo.empleados.curp
                                         ELSE dbo.empleados.rfcalfa
                                              + dbo.empleados.rfcnum
                                              + dbo.empleados.rfchomo
                                    END AS curp ,
                                    dbo.Llaves.centro ,
                                    dbo.centros.nomdepto ,
                                    dbo.empleados.cta_bco_no ,
                                    dbo.bancos.nombre AS nombreBanco ,
                                    dbo.Llaves.ocupacion ,
                                    dbo.tabulador.actividad ,
                                    dbo.empleados.tiposal ,
                                    dbo.empleados.jornada ,
                                    ISNULL(salarios.sueldo,
                                           dbo.empleados.sueldo) AS sueldo ,
                                    ISNULL(salarios.saldiaint,
                                           dbo.empleados.saldiaint) AS saldiaint ,
                                    dbo.Llaves.clase ,
                                    dbo.clases.nombre AS nombreClase ,
                                    dbo.Llaves.supervisor ,
                                    dbo.supervisores.nombre AS nombreSupervisor ,
                                    dbo.recibos.renglon ,
                                    CASE WHEN ( ( @ordenadoPor & 4 > 0
                                                  OR @ordenadoPor & 8 > 0
                                                )
                                                OR ( ( @ordenadoPor & 1 > 0
                                                       OR @ordenadoPor & 2 > 0
                                                     )
                                                     AND @desglosadoPor & 2 > 0
                                                   )
                                              )
                                         THEN SUBSTRING(dbo.Llaves.centro, 1,
                                                        15)
                                         WHEN ( @ordenadoPor & 16 > 0
                                                OR @ordenadopor & 32 > 0
                                              )
                                         THEN RTRIM(dbo.Llaves.centro)
                                              + RIGHT(STR(100000000
                                                          + dbo.Llaves.supervisor),
                                                      8)
                                         ELSE NULL
                                    END ,
                                    dbo.empleados.rfcalfa ,
                                    dbo.empleados.rfcnum ,
                                    dbo.empleados.rfchomo ,
                                    dbo.datosemps.email ,
                                    dbo.empleados.fchantigua ,
                                    @procesoName ,
                                    @nomina ,
                                    dbo.datosemps.foto ,
                                    @cuentaCopia
                            FROM    dbo.SeleccionElementos
                                    INNER JOIN dbo.recibos ON dbo.SeleccionElementos.empresa = dbo.recibos.empresa
                                                              AND dbo.SeleccionElementos.codigo = dbo.recibos.codigo
                                    INNER JOIN dbo.empleados ON dbo.recibos.empresa = dbo.empleados.empresa
                                                              AND dbo.recibos.codigo = dbo.empleados.codigo
                                    INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                             AND dbo.empleados.codigo = dbo.Llaves.codigo
                                    INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                                              AND dbo.Llaves.empresa = dbo.centros.empresa
                                    INNER JOIN dbo.tabulador ON dbo.centros.empresa = dbo.tabulador.empresa
                                                              AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
                                    INNER JOIN dbo.bancos ON dbo.Llaves.banco = dbo.bancos.banco
                                    INNER JOIN dbo.clases ON dbo.Llaves.empresa = dbo.clases.empresa
                                                             AND dbo.Llaves.clase = dbo.clases.clase
                                    INNER JOIN dbo.supervisores ON dbo.Llaves.empresa = dbo.supervisores.empresa
                                                              AND dbo.Llaves.supervisor = dbo.supervisores.supervisor
                                    INNER JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                                              AND dbo.empleados.codigo = dbo.datosemps.codigo

                                -- Buscar el ultimo sueldo e integrado antes del cierre, cuando existen movimientos
                                -- posteriores estaba imprimiendo unos valores que no correspondian con los calculos
                                -- de los conceptos de sueldo ni las retenciones IMSS e INFONAVIT
                                    INNER JOIN ( SELECT emps.codigo ,
                                                        ( SELECT TOP 1
                                                              avisos_imss.sueldo
                                                          FROM
                                                              avisos_imss
                                                          WHERE
                                                              avisos_imss.codigo = emps.codigo
                                                              AND avisos_imss.fch_mov <= periodos.cierre
                                                              AND avisos_imss.mov <> 'B'
                                                              AND avisos_imss.empresa = @empresa
                                                          ORDER BY avisos_imss.fch_mov DESC ,
                                                              avisos_imss.serial DESC
                                                        ) AS sueldo ,
                                                        ( SELECT TOP 1
                                                              avisos_imss.saldiaint
                                                          FROM
                                                              avisos_imss
                                                          WHERE
                                                              avisos_imss.codigo = emps.codigo
                                                              AND avisos_imss.fch_mov <= periodos.cierre
                                                              AND avisos_imss.mov <> 'B'
                                                              AND avisos_imss.empresa = @empresa
                                                          ORDER BY avisos_imss.fch_mov DESC ,
                                                              avisos_imss.serial DESC
                                                        ) AS saldiaint
                                                 FROM   empleados AS emps
                                                        INNER JOIN llaves ON llaves.codigo = emps.codigo
                                                              AND llaves.empresa = emps.empresa
                                                        INNER JOIN periodos ON periodos.tiponom = llaves.tiponom
                                                              AND periodos.estatus = 'A'
                                                              AND periodos.empresa = emps.empresa
                                                 WHERE  emps.activo = 'S'
                                                        AND emps.borrado <> 'S'
                                                        AND emps.empresa = @empresa
                                               ) AS salarios ON salarios.codigo = empleados.codigo
                                -- 25 de Julio 2012
                                /*
                                INNER JOIN dbo.SeleccionElementos ON CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.Llaves.empresa
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.empresa
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.Llaves.codigo
                                                              ELSE 1
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.codigo
                                                              ELSE 1
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.procesoName
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN @procesoName
                                                              ELSE '1'
                                                              END
                                                              AND CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.SeleccionElementos.nomina
                                                              ELSE '1'
                                                              END = CASE
                                                              WHEN LEN(@codigoSeleccionado) > 0
                                                              THEN dbo.recibos.nomina
                                                              ELSE '1'
                                                              END
                                */
                            WHERE   ( ( ( dbo.recibos.num_conc >= @numeroConceptoPercepcionInicioKardex
                                          AND dbo.recibos.num_conc <= @numeroConceptoPercepcionTerminoKardex
                                        )
                                        OR ( dbo.recibos.num_conc >= @numeroConceptoContraPercepcionInicioKardex
                                             AND dbo.recibos.num_conc <= @numeroConceptoContraPercepcionTerminoKardex
                                           )
                                      )
                                      OR ( ( dbo.recibos.num_conc >= @numeroConceptoDeduccionInicioKardex
                                             AND dbo.recibos.num_conc <= @numeroConceptoDeduccionTerminoKardex
                                           )
                                           OR ( dbo.recibos.num_conc >= @numeroConceptoContraDeduccionInicioKardex
                                                AND dbo.recibos.num_conc <= @numeroConceptoContraDeduccionTerminoKardex
                                              )
                                         )
                                      OR ( dbo.recibos.num_conc >= @numeroConceptoProvisionInicioKardex
                                           AND dbo.recibos.num_conc <= @numeroConceptoProvisionTerminoKardex
                                         )
                                    )
                                    AND dbo.recibos.nomina = @nomina
                                    AND dbo.recibos.empresa = CASE
                                                              WHEN @desglosadoPor
                                                              & 1 > 0
                                                              THEN @empresa
                                                              ELSE 0
                                                              END
                                    AND dbo.SeleccionElementos.nomina = @nomina
                                    AND dbo.SeleccionElementos.procesoName = @procesoname
                                    AND dbo.SeleccionElementos.empresa = @empresa

-- Carga Percepciones
                    UPDATE  kardexImprimeRecibos
                    SET     kardexImprimeRecibos.marcaContraPercepcion = CASE
                                                              WHEN dbo.recibos.num_conc >= 1101
                                                              AND dbo.recibos.num_conc <= 1199
                                                              THEN 'C'
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.numeroConceptoPercepcion = dbo.recibos.num_conc ,
                            kardexImprimeRecibos.nombreConceptoPercepcion = dbo.recibos.concepto ,
                            kardexImprimeRecibos.importeConceptoPercepcion = dbo.recibos.importe ,
                            kardexImprimeRecibos.gravablePercepcion = dbo.recibos.igravable ,
                            kardexImprimeRecibos.exentoPercepcion = dbo.recibos.iexento ,
                            kardexImprimeRecibos.saldoPercepcion = CASE
                                                              WHEN dbo.recibos.saldo > 0
                                                              THEN dbo.recibos.saldo
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.anexoConceptoPercepcion = CASE
                                      -- Detalle Sueldo
                                                              WHEN dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 8
                                                              AND @registroPatronal <> 'A341223110'
                                                              THEN CASE WHEN dbo.recibos.impor_base > 0
                                                                        THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.impor_base))
                                                                             + ' * '
                                                                        ELSE ''
                                                                   END
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Das'

                                     -- Detalle sueldo para Leticia
                                                              WHEN dbo.recibos.num_conc >= 1
                                                              AND dbo.recibos.num_conc <= 8
                                                              AND @registroPatronal = 'A341223110'
                                                              THEN ''

                                      -- Detalle Laboras en Dia de Descanso
                                                              WHEN dbo.recibos.num_conc = 10
                                                              AND @registroPatronal <> 'A341223110'
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.horas))
                                                              + ' Horas'

                                      -- Detella Horas Extras
                                                              WHEN dbo.recibos.num_conc >= 11
                                                              AND dbo.recibos.num_conc <= 13
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.horas))
                                                              + ' Horas'

                                      -- Detalle Prima Vacacional
                                                              WHEN dbo.recibos.num_conc = 17
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Das'

                                      -- Detalle Vacaciones
                                                              WHEN dbo.recibos.num_conc = 30
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.impor_base))
                                                              + ' * ' + '('
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                              + 'H' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                              + 'D' + ' '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + 'F' + ')'

                                      -- Detalle Subsidio para el Empleo
                                                              WHEN dbo.recibos.num_conc = 36
                                                              THEN CASE
                                                              WHEN dbo.recibos.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.recibos.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoEmpresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoEmpresa < 2014
                                                                        THEN 'Art 8vo Trans$'
                                                                        ELSE 'Art 10 Trans$'
                                                                   END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                              ELSE ''
                                                              END
                                                              END

                                      -- Detalle Concepto 53 Por Registro Patronal
                                                              WHEN dbo.recibos.num_conc = 53
                                                              AND ( @registroPatronal = 'R131234638'
                                                              OR @registroPatronal = 'C166197810'
                                                              OR @registroPatronal = 'C166939010'
                                                              OR @registroPatronal = 'E647730310'
                                                              OR @registroPatronal = 'E648122510'
                                                              )
                                                              THEN SUBSTRING(dbo.recibos.referencia,
                                                              01, 06)
                                                              + RIGHT(RTRIM(dbo.recibos.referencia),
                                                              02) + ' (M'
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.unidades))
                                                              + ')'

                                      -- Detalle Sueldo Neto
                                                              WHEN dbo.recibos.num_conc = 99
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Das'

                                      -- Detalle de conceptos de Contras del 1107 al 1111
                                                              WHEN dbo.recibos.num_conc >= 1107
                                                              AND dbo.recibos.num_conc <= 1111
                                                              THEN CASE
                                                              WHEN dbo.recibos.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Das'
                                                              ELSE ''
                                                              END

                                      -- Detalle Conceptos con Valor Variable
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                              + CASE
                                                              WHEN dbo.recibos.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                              + CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                              + CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                              END
                                                              END
                    FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                            INNER JOIN dbo.recibos ON kardexImprimeRecibos.empresa = dbo.recibos.empresa
                                                      AND kardexImprimeRecibos.codigo = dbo.recibos.codigo
                                                      AND kardexImprimeRecibos.renglon = dbo.recibos.renglon
                                                      AND @nomina = dbo.recibos.nomina
                    WHERE   ( ( dbo.recibos.num_conc >= 1
                                AND dbo.recibos.num_conc <= 99
                              )
                              OR ( dbo.recibos.num_conc >= 1101
                                   AND dbo.recibos.num_conc <= 1199
                                 )
                            )
                            AND dbo.recibos.nomina = @nomina
                            AND kardexImprimeRecibos.copia = @cuentaCopia
                            AND kardexImprimeRecibos.proceso = @proceso
                            AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                            AND kardexImprimeRecibos.horaProceso = @horaProceso
                            AND kardexImprimeRecibos.empresa = @empresa

-- Carga Deducciones
                    UPDATE  kardexImprimeRecibos
                    SET     kardexImprimeRecibos.marcaContraDeduccion = CASE
                                                              WHEN dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1099
                                                              THEN 'C'
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.numeroConceptoDeduccion = dbo.recibos.num_conc ,
                            kardexImprimeRecibos.nombreConceptoDeduccion = dbo.recibos.concepto ,
                            kardexImprimeRecibos.importeConceptoDeduccion = dbo.recibos.importe ,
                            kardexImprimeRecibos.gravableDeduccion = dbo.recibos.igravable ,
                            kardexImprimeRecibos.exentoDeduccion = dbo.recibos.iexento ,
                            kardexImprimeRecibos.saldoDeduccion = CASE
                                                              WHEN dbo.recibos.saldo > 0
                                                              THEN --CASE WHEN dbo.recibos.num_conc = 126 THEN dbo.recibos.importe + dbo.recibos.saldo
                                                   --     WHEN dbo.recibos.num_conc = 127 THEN dbo.recibos.importe + dbo.recibos.saldo
                                                   --     ELSE dbo.recibos.saldo
                                                   --END
                                                              CASE
                                                              WHEN ( dbo.conceptos.marca2 = 'P'
                                                              OR ( dbo.recibos.num_conc >= 115
                                                              AND dbo.recibos.num_conc <= 117
                                                              )
                                                              )
                                                              THEN dbo.recibos.saldo
                                                              - dbo.recibos.importe
                                                              WHEN ( dbo.conceptos.marca2 = 'H'
                                                              OR ( dbo.recibos.num_conc >= 125
                                                              AND dbo.recibos.num_conc <= 127
                                                              )
                                                              )
                                                              THEN dbo.recibos.saldo
                                                              + dbo.recibos.importe
                                                              ELSE NULL
                                                              END
                                                              ELSE NULL
                                                              END ,
                            kardexImprimeRecibos.anexoConceptoDeduccion = CASE
                                      -- Detalle Cuotas IMSS
                                                              WHEN dbo.recibos.num_conc >= 101
                                                              AND dbo.recibos.num_conc <= 105
                                                              THEN CONVERT(VARCHAR(15), CASE
                                                              WHEN dbo.recibos.num_conc = 102
                                                              THEN CASE
                                                              WHEN dbo.recibos.saldiaint > ( @salarioDF
                                                              * 3 )
                                                              THEN dbo.ChecaDecimales(dbo.recibos.saldiaint
                                                              - ( @salarioDF
                                                              * 3 ))
                                                              ELSE dbo.ChecaDecimales(dbo.recibos.saldiaint)
                                                              END
                                                              ELSE dbo.ChecaDecimales(dbo.recibos.saldiaint)
                                                              END) + ' * '
                                                              + CASE
                                                              WHEN dbo.recibos.num_conc = 101
                                                              THEN CONVERT(VARCHAR(15), @eymTra25)
                                                              WHEN dbo.recibos.num_conc = 102
                                                              THEN CONVERT(VARCHAR(15), @eymTra1062)
                                                              WHEN dbo.recibos.num_conc = 103
                                                              THEN CONVERT(VARCHAR(15), @eymTra107)
                                                              WHEN dbo.recibos.num_conc = 104
                                                              THEN CONVERT(VARCHAR(15), @ivTra147)
                                                              WHEN dbo.recibos.num_conc = 105
                                                              THEN CONVERT(VARCHAR(15), @cvTra168II)
                                                              ELSE ''
                                                              END + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias_imss))

                                      -- Detalle Retencion IMSS por Faltas
                                                              WHEN dbo.recibos.num_conc = 106
                                                              OR dbo.recibos.num_conc = 107
                                                              OR dbo.recibos.num_conc = 109
                                                              OR dbo.recibos.num_conc = 110
                                                              OR dbo.recibos.num_conc = 111
                                                              OR dbo.recibos.num_conc = 130
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Da(s)'

                                      -- Detalle Faltas
                                                              WHEN dbo.recibos.num_conc = 108
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Da(s)'
                                                              + ' + '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(ABS(dbo.recibos.descuento
                                                              - 100))) + '%'

                                      -- Detalle Creditos INFONAVIT
                                                              WHEN dbo.recibos.num_conc = 112
                                                              THEN CASE
                                                              WHEN dbo.recibos.descuento > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.saldiaint))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.descuento))
                                                              + '%'
                                                              ELSE CONVERT(VARCHAR(15), CONVERT(NUMERIC(15,
                                                              2), dbo.ChecaDecimales(ROUND(dbo.recibos.importe
                                                              / dbo.recibos.dias,
                                                              2)))) + ' * '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + 'DS'
                                                              END

                                      -- Detalle Fondo de Ahorro
                                                              WHEN ( dbo.recibos.num_conc = 126
                                                              OR dbo.recibos.num_conc = 127
                                                              )
                                                              AND ( @reciboSeleccionado <> 'Apsi 4'
                                                              AND @reciboSeleccionado <> 'Apsi 5'
                                                              AND @reciboSeleccionado <> 'Apsi 6'
                                                              AND @reciboSeleccionado <> 'Apsi 7'
                                                              )
                                                              THEN 'Saldo $ '
                                                              + CONVERT(VARCHAR(15), dbo.recibos.saldo
                                                              + dbo.recibos.importe)

                                      -- Detalle ISR
                                                              WHEN dbo.recibos.num_conc = 136
                                                              THEN CASE
                                                              WHEN dbo.recibos.variable1 = '1991'
                                                              THEN '1991'
                                                              ELSE CASE
                                                              WHEN dbo.recibos.variable2 = 'MUESTRA'
                                                              THEN CASE WHEN @ayoEmpresa < 2008
                                                                        THEN 'Art. 115 $'
                                                                        WHEN @ayoEmpresa < 2014
                                                                        THEN 'Art 8vo Trans$'
                                                                        ELSE 'Art 10 Trans$'
                                                                   END + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                              ELSE ''
                                                              END
                                                              END

                                      -- Contra Sueldo
                                                              WHEN dbo.recibos.num_conc >= 1001
                                                              AND dbo.recibos.num_conc <= 1007
                                                              THEN CASE
                                                              WHEN dbo.recibos.dias > 0
                                                              THEN CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.dias))
                                                              + ' Da(s)'
                                                              ELSE ''
                                                              END

                                      -- Detalle los demas conceptos
                                                              ELSE CASE
                                                              WHEN dbo.recibos.saldo > 0
                                                              AND ( @reciboSeleccionado <> 'Apsi 4'
                                                              AND @reciboSeleccionado <> 'Apsi 5'
                                                              AND @reciboSeleccionado <> 'Apsi 6'
                                                              AND @reciboSeleccionado <> 'Apsi 7'
                                                              )
                                                              THEN 'Saldo $ '
                                                              + CONVERT(VARCHAR(15), dbo.recibos.saldo
                                                              + CASE
                                                              WHEN dbo.conceptos.marca2 = 'H'
                                                              OR --A'
                                                              dbo.conceptos.num_conc IN (
                                                              125, 126, 127 )
                                                              THEN 1
                                                              ELSE -1
                                                              END
                                                              * dbo.recibos.descuento)
                                                -- Detalle de conceptos con valores variable
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia1 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable1)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia1))
                                                              + CASE
                                                              WHEN dbo.recibos.varia2 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                              + CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia2 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable2)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia2))
                                                              + CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia3 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable3)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia3))
                                                              + CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN ','
                                                              + RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE ''
                                                              END
                                                              ELSE CASE
                                                              WHEN dbo.recibos.varia4 > 0
                                                              THEN RTRIM(LTRIM(UPPER(dbo.recibos.variable4)))
                                                              + ': '
                                                              + CONVERT(VARCHAR(15), dbo.ChecaDecimales(dbo.recibos.varia4))
                                                              ELSE NULL -- Agregar mas condiciones
                                                              END
                                                              END
                                                              END
                                                              END
                                                              END
                                                              END
                    FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                            INNER JOIN dbo.recibos ON kardexImprimeRecibos.empresa = dbo.recibos.empresa
                                                      AND kardexImprimeRecibos.codigo = dbo.recibos.codigo
                                                      AND kardexImprimeRecibos.renglon = dbo.recibos.renglon
                                                      AND @nomina = dbo.recibos.nomina
                            INNER JOIN dbo.conceptos ON dbo.recibos.empresa = dbo.conceptos.empresa
                                                        AND dbo.recibos.num_conc = dbo.conceptos.num_conc
                                                        AND dbo.recibos.clase = dbo.conceptos.clase
                                                        AND dbo.recibos.centro = dbo.conceptos.centro
                    WHERE   ( ( dbo.recibos.num_conc >= 101
                                AND dbo.recibos.num_conc <= 199
                              )
                              OR ( dbo.recibos.num_conc >= 1001
                                   AND dbo.recibos.num_conc <= 1099
                                 )
                            )
                            AND dbo.recibos.nomina = @nomina
                            AND kardexImprimeRecibos.copia = @cuentaCopia
                            AND kardexImprimeRecibos.proceso = @proceso
                            AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                            AND kardexImprimeRecibos.horaProceso = @horaProceso
                            AND kardexImprimeRecibos.empresa = @empresa
                END

        /*
        IF @esRecibo = 0
            BEGIN
                DELETE  kardexImprimeRecibos
                FROM dbo.KardexImprimeRecibos
                WHERE   kardexImprimeRecibos.numeroConceptoPercepcion IS NULL
                        AND kardexImprimeRecibos.numeroConceptoDeduccion IS NULL
                        AND kardexImprimeRecibos.numeroConceptoProvision IS NULL
                        AND kardexImprimeRecibos.copia = @cuentaCopia
                        AND kardexImprimeRecibos.proceso = @proceso
                        AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                        AND kardexImprimeRecibos.horaProceso = @horaProceso
                        AND kardexImprimeRecibos.codigo = 999999995
                        AND kardexImprimeRecibos.empresa = @empresa
            END
        ELSE
            --BEGIN
                INSERT  @codigoBase
                        ( codigo ,
                          renglon ,
                          centro ,
                          supervisor ,
                          nombre
                        )
                        SELECT DISTINCT
                                kardexImprimeRecibos.codigo ,
                                [@tablaBaseRenglon].renglon ,
                                kardexImprimeRecibos.centro ,
                                kardexImprimeRecibos.supervisor ,
                                kardexImprimeRecibos.nombre
                        FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos,
                                @tablaBaseRenglon
                        WHERE [@tablaBaseRenglon].renglon <= CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN @renglonTope
                                                                  WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                  WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                  WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                  ELSE @renglonTope * 5
                                                             END
        */
                        
            SET @codigoAnterior = 0
            SET @numeroRecibo = 0
            SET @nombreAnterior = ''
                -- Ordenado por Cdigo
            IF @ordenadoPor & 1 > 0 
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    
                                    --CASE WHEN [@tablabaserenglon].renglon >= 01 AND [@tablabaserenglon].renglon <= 020 THEN 1
                                    --     WHEN [@tablabaserenglon].renglon >= 21 AND [@tablabaserenglon].renglon <= 040 THEN 2
                                    --     WHEN [@tablabaserenglon].renglon >= 41 AND [@tablabaserenglon].renglon <= 060 THEN 3
                                    --     WHEN [@tablabaserenglon].renglon >= 61 AND [@tablabaserenglon].renglon <= 080 THEN 4
                                    --     ELSE 5
                                    --END AS cuantosRecibos ,
                                    
                                    CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                         ELSE 5
                                    END  AS cuantosRecibos ,
                                    
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN @renglonTope
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                              ELSE @renglonTope * 5
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numerorecibo = @numerorecibo
                            + CASE WHEN [@tablaNumeroRecibo].codigo <> @codigoanterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numerorecibo ,
                            @codigoanterior = [@tablaNumeroRecibo].codigo  
                END

                -- Ordenado por Nombre
            IF @ordenadoPor & 2 > 0 
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    --CASE WHEN [@tablabaserenglon].renglon >= 01 AND [@tablabaserenglon].renglon <= 020 THEN 1
                                    --     WHEN [@tablabaserenglon].renglon >= 21 AND [@tablabaserenglon].renglon <= 040 THEN 2
                                    --     WHEN [@tablabaserenglon].renglon >= 41 AND [@tablabaserenglon].renglon <= 060 THEN 3
                                    --     WHEN [@tablabaserenglon].renglon >= 61 AND [@tablabaserenglon].renglon <= 080 THEN 4
                                    --     ELSE 5
                                    --END AS cuantosRecibos ,
                                    CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                         ELSE 5
                                    END  AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN @renglonTope
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                              ELSE @renglonTope * 5
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.nombre ,
                                    [@tablaBaseRenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numeroRecibo = @numeroRecibo
                            + CASE WHEN [@tablaNumeroRecibo].nombre <> @nombreAnterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                            @nombreAnterior = [@tablaNumeroRecibo].nombre
                END

                -- Ordenado por Centro y Nombre
            IF @ordenadoPor & 4 > 0 
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                                
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    --CASE WHEN [@tablabaserenglon].renglon >= 01 AND [@tablabaserenglon].renglon <= 020 THEN 1
                                    --     WHEN [@tablabaserenglon].renglon >= 21 AND [@tablabaserenglon].renglon <= 040 THEN 2
                                    --     WHEN [@tablabaserenglon].renglon >= 41 AND [@tablabaserenglon].renglon <= 060 THEN 3
                                    --     WHEN [@tablabaserenglon].renglon >= 61 AND [@tablabaserenglon].renglon <= 080 THEN 4
                                    --     ELSE 5
                                    --END AS cuantosRecibos ,
                                    CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                         ELSE 5
                                    END  AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE
                                                              WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN @renglonTope
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                              ELSE @renglonTope * 5
                                                              END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.nombre ,
                                    [@tablaBaseRenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numeroRecibo = @numeroRecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + [@tablaNumeroRecibo].nombre <> @nombreAnterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                            @nombreAnterior = [@tablaNumeroRecibo].centro
                            + ' ' + [@tablaNumeroRecibo].nombre
                END

                -- Ordenado por Centro y Cdigo
            IF @ordenadoPor & 8 > 0 
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                                
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    --CASE WHEN [@tablabaserenglon].renglon >= 01 AND [@tablabaserenglon].renglon <= 020 THEN 1
                                    --     WHEN [@tablabaserenglon].renglon >= 21 AND [@tablabaserenglon].renglon <= 040 THEN 2
                                    --     WHEN [@tablabaserenglon].renglon >= 41 AND [@tablabaserenglon].renglon <= 060 THEN 3
                                    --     WHEN [@tablabaserenglon].renglon >= 61 AND [@tablabaserenglon].renglon <= 080 THEN 4
                                    --     ELSE 5
                                    --END AS cuantosRecibos ,
                                    CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                         ELSE 5
                                    END  AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN @renglonTope
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                        ELSE @renglonTope * 5
                                                                   END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.codigo ,
                                    [@tablaBaseRenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numeroRecibo = @numeroRecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + STR([@tablaNumeroRecibo].codigo) <> @nombreAnterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                            @nombreAnterior = [@tablaNumeroRecibo].centro
                            + ' ' + STR([@tablaNumeroRecibo].codigo)
                END

                -- Ordenado por Centro, Supervisor y Nombre
            IF @ordenadoPor & 16 > 0 
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                                
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    --CASE WHEN [@tablabaserenglon].renglon >= 01 AND [@tablabaserenglon].renglon <= 020 THEN 1
                                    --     WHEN [@tablabaserenglon].renglon >= 21 AND [@tablabaserenglon].renglon <= 040 THEN 2
                                    --     WHEN [@tablabaserenglon].renglon >= 41 AND [@tablabaserenglon].renglon <= 060 THEN 3
                                    --     WHEN [@tablabaserenglon].renglon >= 61 AND [@tablabaserenglon].renglon <= 080 THEN 4
                                    --     ELSE 5
                                    --END AS cuantosRecibos ,
                                    CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                         ELSE 5
                                    END  AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN @renglonTope 
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                        ELSE @renglonTope * 5
                                                                   END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre ,
                                    [@tablaBaseRenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numeroRecibo = @numeroRecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + STR([@tablaNumeroRecibo].supervisor)
                                        + ' ' + [@tablaNumeroRecibo].nombre <> @nombreAnterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                            @nombreAnterior = [@tablaNumeroRecibo].centro
                            + ' ' + STR([@tablaNumeroRecibo].supervisor) + ' '
                            + [@tablaNumeroRecibo].nombre
                END

                -- Ordenado por Centro, Supervisor y Cdigo
            IF @ordenadoPor & 32 > 0 
                BEGIN
                    INSERT  @tablaNumeroRecibo
                            ( codigo ,
                              renglon ,
                              cuantosRecibos ,
                              centro ,
                              supervisor ,
                              nombre
                                
                            )
                            SELECT DISTINCT
                                    kardexImprimeRecibos.codigo ,
                                    [@tablabaserenglon].renglon ,
                                    --CASE WHEN [@tablabaserenglon].renglon >= 01 AND [@tablabaserenglon].renglon <= 020 THEN 1
                                    --     WHEN [@tablabaserenglon].renglon >= 21 AND [@tablabaserenglon].renglon <= 040 THEN 2
                                    --     WHEN [@tablabaserenglon].renglon >= 41 AND [@tablabaserenglon].renglon <= 060 THEN 3
                                    --     WHEN [@tablabaserenglon].renglon >= 61 AND [@tablabaserenglon].renglon <= 080 THEN 4
                                    --     ELSE 5
                                    --END AS cuantosRecibos ,
                                    CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                         WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                         ELSE 5
                                    END  AS cuantosRecibos ,
                                    kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.nombre
                            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos ,
                                    @tablabaserenglon
                            WHERE   [@tablabaserenglon].renglon <= CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN @renglonTope
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN @renglonTope * 2
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN @renglonTope * 3
                                                                        WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN @renglonTope * 4
                                                                        ELSE @renglonTope * 5
                                                                   END
                                    AND kardexImprimeRecibos.copia = @cuentaCopia
                                    AND kardexImprimeRecibos.proceso = @proceso
                                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                                    AND kardexImprimeRecibos.empresa = @empresa
                            ORDER BY kardexImprimeRecibos.centro ,
                                    kardexImprimeRecibos.supervisor ,
                                    kardexImprimeRecibos.codigo ,
                                    [@tablaBaseRenglon].renglon

                    UPDATE  @tablaNumeroRecibo
                    SET     @numeroRecibo = @numeroRecibo
                            + CASE WHEN [@tablaNumeroRecibo].centro + ' '
                                        + STR([@tablaNumeroRecibo].supervisor)
                                        + ' '
                                        + STR([@tablaNumeroRecibo].codigo) <> @nombreAnterior
                                   THEN 1
                                   ELSE 0
                              END ,
                            [@tablaNumeroRecibo].numeroRecibo = @numeroRecibo ,
                            @nombreAnterior = [@tablaNumeroRecibo].centro
                            + ' ' + STR([@tablaNumeroRecibo].supervisor) + ' '
                            + STR([@tablaNumeroRecibo].codigo)
                END

                /*
                SET @cuantosRecibos = 0
                SET @codigoAnterior = 0
                SET @numeroRecibo = 0
                
                UPDATE  @codigoBase
                SET     @cuantosRecibos = CASE WHEN codigoBase.renglon > 0 AND codigoBase.renglon <= @renglonTope THEN 1
                                               WHEN codigoBase.renglon >= @renglonTope + 1 AND codigoBase.renglon <= @renglonTope * 2 THEN 2
                                               WHEN codigoBase.renglon >= @renglonTope * 2 + 1 AND codigoBase.renglon <= @renglonTope * 3 THEN 3
                                               WHEN codigoBase.renglon >= @renglonTope * 3 + 1 AND codigoBase.renglon <= @renglonTope * 4 THEN 4
                                               ELSE 5
                                          END ,                                          
                        [@codigoBase].cuantosRecibos = @cuantosRecibos ,
                        [@codigoBase].recibo = CASE WHEN [@codigoBase].renglon > 0 AND [@codigoBase].renglon <= @renglonTope THEN 1
                                                    WHEN [@codigoBase].renglon >= @renglonTope + 1 AND [@codigoBase].renglon <= @renglonTope * 2 THEN 2
                                                    WHEN [@codigoBase].renglon >= @renglonTope * 2 + 1 AND [@codigoBase].renglon <= @renglonTope * 3 THEN 3
                                                    WHEN [@codigoBase].renglon >= @renglonTope * 3 + 1 AND [@codigoBase].renglon <= @renglonTope * 4 THEN 4
                                                    ELSE 5
                                               END ,
                        @numeroRecibo = @numeroRecibo + CASE WHEN [@codigoBase].codigo <> @codigoAnterior THEN 1 ELSE 0 END ,
                        @codigoAnterior = [@codigoBase].codigo ,
                        [@codigoBase].numeroRecibo = [@tablaNumeroRecibo].numeroRecibo
                FROM    @codigoBase
                        INNER JOIN ( SELECT [@codigoBase].codigo ,
                                            MAX([@codigoBase].renglon) AS renglon
                                     FROM   @codigoBase
                                     GROUP BY [@codigoBase].codigo
                                   ) AS codigoBase ON [@codigoBase].codigo = codigoBase.codigo
                        INNER JOIN @tablaNumeroRecibo ON [@codigoBase].codigo = [@tablaNumeroRecibo].codigo
                                                         AND [@codigoBase].renglon = [@tablaNumeroRecibo].renglon
                                                         
                INSERT  @kardex
                        ( empresa ,
                          codigo ,
                          renglon ,
                          codigoId ,
                          nombre ,
                          centro ,
                          supervisor ,
                          procesoName ,
                          nomina
                        )
                        SELECT  @empresa ,
                                [@codigoBase].codigo ,
                                [@codigoBase].renglon ,
                                RIGHT(STR(100000000 + [@codigoBase].codigo), 8)
                                + RIGHT(STR(1000000000 + [@codigoBase].renglon),
                                        9) ,
                                [@codigoBase].nombre ,
                                [@codigoBase].centro ,
                                [@codigoBase].supervisor ,
                                @procesoName ,
                                @nomina
                        FROM    @kardex
                                RIGHT JOIN @codigoBase ON [@kardex].codigo = [@codigoBase].codigo
                                                          AND [@kardex].renglon = [@codigoBase].renglon
                        WHERE   [@kardex].renglon IS NULL


                UPDATE  @kardex
                SET     [@kardex].cuantosRecibos = [@codigoBase].cuantosRecibos ,
                        [@kardex].recibo = [@codigoBase].recibo ,
                        [@kardex].numeroRecibo = [@codigoBase].numeroRecibo ,
                        [@kardex].grupoRecibo = RIGHT(STR(100000000
                                                          + [@codigoBase].codigo),
                                                      8) + '01'
                        + RIGHT(STR(100 + [@codigoBase].recibo), 2)
                FROM    @kardex
                        INNER JOIN @codigoBase ON [@kardex].codigo = [@codigoBase].codigo
                                                  AND [@kardex].renglon = [@codigoBase].renglon
                */

            UPDATE  kardexImprimeRecibos
            SET     kardexImprimeRecibos.cuantosRecibos = tablaNumeroRecibo2.cuantosRecibos ,
                    --kardexImprimeRecibos.recibo = CASE WHEN kardexImprimeRecibos.renglon >= 01 AND kardexImprimeRecibos.renglon <= 20 THEN 1
                    --                                   WHEN kardexImprimeRecibos.renglon >= 21 AND kardexImprimeRecibos.renglon <= 40 THEN 2
                    --                                   WHEN kardexImprimeRecibos.renglon >= 41 AND kardexImprimeRecibos.renglon <= 60 THEN 3
                    --                                   WHEN kardexImprimeRecibos.renglon >= 61 AND kardexImprimeRecibos.renglon <= 80 THEN 4
                    --                                   ELSE 5
                    --                              END ,
                    kardexImprimeRecibos.recibo = CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                                       WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                                       WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                                       WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                                       ELSE 5
                                                  END ,
                    kardexImprimeRecibos.numeroRecibo = tablaNumeroRecibo2.numeroRecibo ,
                    kardexImprimeRecibos.grupoRecibo = RIGHT(STR(100000000 + kardexImprimeRecibos.codigo), 8) 
                                                       + RIGHT(STR(100 + @cuentaCopia), 2) 
                                                       + RIGHT(STR(100 + CASE WHEN kardexImprimeRecibos.renglon > 0 AND kardexImprimeRecibos.renglon <= @renglonTope THEN 1
                                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 2 THEN 2
                                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 2 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 3 THEN 3
                                                                              WHEN kardexImprimeRecibos.renglon >= @renglonTope * 3 + 1 AND kardexImprimeRecibos.renglon <= @renglonTope * 4 THEN 4
                                                                              ELSE 5
                                                                         END), 2)
                                                       --+ RIGHT(STR(100 + CASE WHEN kardexImprimeRecibos.renglon >= 01 AND kardexImprimeRecibos.renglon <= 20 THEN 1
                                                       --       WHEN kardexImprimeRecibos.renglon >= 21 AND kardexImprimeRecibos.renglon <= 40 THEN 2
                                                       --       WHEN kardexImprimeRecibos.renglon >= 41 AND kardexImprimeRecibos.renglon <= 60 THEN 3
                                                       --       WHEN kardexImprimeRecibos.renglon >= 61 AND kardexImprimeRecibos.renglon <= 80 THEN 4
                                                       --       ELSE 5
                                                       --       END), 2)
                                                              
            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                    INNER JOIN ( SELECT DISTINCT
                                        tablaNumeroRecibo.codigo ,
                                        MAX(tablaNumeroRecibo.renglon) AS renglon ,
                                        MAX(tablaNumeroRecibo.numeroRecibo) AS numeroRecibo ,
                                        MAX(tablaNumeroRecibo.cuantosRecibos) AS cuantosRecibos
                                 FROM   @tablaNumeroRecibo AS tablaNumeroRecibo
                                 GROUP BY tablaNumeroRecibo.codigo
                               ) AS tablaNumeroRecibo2 ON kardexImprimeRecibos.codigo = tablaNumeroRecibo2.codigo
            WHERE   kardexImprimeRecibos.copia = @cuentaCopia
                    AND kardexImprimeRecibos.proceso = @proceso
                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                    AND kardexImprimeRecibos.empresa = @empresa

        -- Optimizacion
            INSERT  dbo.KardexImprimeRecibos
                    ( proceso ,
                      fechaProceso ,
                      horaProceso ,
                      empresa ,
                      codigo ,
                      renglon ,
                      codigoId ,
                      nombre ,
                      centro ,
                      supervisor ,
                      procesoName ,
                      nomina ,
                      cuantosRecibos ,
                      recibo ,
                      numeroRecibo ,
                      grupoRecibo ,
                      copia
                    )
                    SELECT  @proceso AS proceso ,
                            @fechaProceso AS fechaProceso ,
                            @horaProceso AS horaProceso ,
                            @empresa AS empresa ,
                            tablaNumeroRecibo.codigo ,
                            tablaNumeroRecibo.renglon ,
                            RIGHT(STR(100000000 + tablaNumeroRecibo.codigo), 8) + RIGHT(STR(1000000000 + tablaNumeroRecibo.renglon),9) AS codigoId ,
                            tablaNumeroRecibo.nombre ,
                            tablaNumeroRecibo.centro ,
                            tablaNumeroRecibo.supervisor ,
                            @procesoname ,
                            @nomina ,
                            tablaNumeroRecibo.cuantosRecibos ,
                            
                            --CASE WHEN tablaNumeroRecibo.renglon >= 01 AND tablaNumeroRecibo.renglon <= 20 THEN 1
                            --     WHEN tablaNumeroRecibo.renglon >= 21 AND tablaNumeroRecibo.renglon <= 40 THEN 2
                            --     WHEN tablaNumeroRecibo.renglon >= 41 AND tablaNumeroRecibo.renglon <= 60 THEN 3
                            --     WHEN tablaNumeroRecibo.renglon >= 61 AND tablaNumeroRecibo.renglon <= 80 THEN 4
                            --     ELSE 5
                            --END AS recibo ,
                            CASE WHEN tablaNumeroRecibo.renglon > 0 AND tablaNumeroRecibo.renglon <= @renglonTope THEN 1
                                 WHEN tablaNumeroRecibo.renglon >= @renglonTope + 1 AND tablaNumeroRecibo.renglon <= @renglonTope * 2 THEN 2
                                 WHEN tablaNumeroRecibo.renglon >= @renglonTope * 2 + 1 AND tablaNumeroRecibo.renglon <= @renglonTope * 3 THEN 3
                                 WHEN tablaNumeroRecibo.renglon >= @renglonTope * 3 + 1 AND tablaNumeroRecibo.renglon <= @renglonTope * 4 THEN 4
                                 ELSE 5
                            END AS recibo, 
                            
                            tablaNumeroRecibo.numeroRecibo ,
                            RIGHT(STR(100000000 + tablaNumeroRecibo.codigo), 8)
                            + RIGHT(STR(100 + @cuentaCopia), 2)
                            + RIGHT(STR(100 + CASE WHEN tablaNumeroRecibo.renglon > 0 AND tablaNumeroRecibo.renglon <= @renglonTope THEN 1
                                                   WHEN tablaNumeroRecibo.renglon >= @renglonTope + 1 AND tablaNumeroRecibo.renglon <= @renglonTope * 2 THEN 2
                                                   WHEN tablaNumeroRecibo.renglon >= @renglonTope * 2 + 1 AND tablaNumeroRecibo.renglon <= @renglonTope * 3 THEN 3
                                                   WHEN tablaNumeroRecibo.renglon >= @renglonTope * 3 + 1 AND tablaNumeroRecibo.renglon <= @renglonTope * 4 THEN 4
                                                   ELSE 5
                                              END), 2) AS grupoRecibo ,

                            --+ RIGHT(STR(100 + CASE WHEN tablaNumeroRecibo.renglon >= 01 AND tablaNumeroRecibo.renglon <= 20 THEN 1
                            --                       WHEN tablaNumeroRecibo.renglon >= 21 AND tablaNumeroRecibo.renglon <= 40 THEN 2
                            --                       WHEN tablaNumeroRecibo.renglon >= 41 AND tablaNumeroRecibo.renglon <= 60 THEN 3
                            --                       WHEN tablaNumeroRecibo.renglon >= 61 AND tablaNumeroRecibo.renglon <= 80 THEN 4
                            --                       ELSE 5
                            --                  END), 2) AS grupoRecibo ,

                            @cuentaCopia AS copia
                    FROM    @tablaNumeroRecibo AS tablaNumeroRecibo
                    WHERE   NOT EXISTS ( SELECT TOP 1
                                                kardexImprimeRecibos.renglon
                                         FROM   dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                                         WHERE  tablaNumeroRecibo.renglon = kardexImprimeRecibos.renglon
                                                AND tablaNumeroRecibo.codigo = kardexImprimeRecibos.codigo
                                                AND kardexImprimeRecibos.copia = @cuentaCopia
                                                AND kardexImprimeRecibos.proceso = @proceso
                                                AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                                                AND kardexImprimeRecibos.horaProceso = @horaProceso
                                                AND kardexImprimeRecibos.empresa = @empresa )

            UPDATE  kardexImprimeRecibos
            SET     kardexImprimeRecibos.percepcionesEmpleado = dbo.nomina_tot.tot_percep ,
                    kardexImprimeRecibos.deduccionesEmpleado = dbo.nomina_tot.tot_deducc ,
                    kardexImprimeRecibos.netoPagarEmpleado = dbo.nomina_tot.tot_percep - dbo.nomina_tot.tot_deducc ,
                    kardexImprimeRecibos.acumuladoPercepcion = dbo.acum_emps.acu_percep ,
                    kardexImprimeRecibos.acumuladoPercepcionGravable = dbo.acum_emps.gravable ,
                    kardexImprimeRecibos.acumuladoIsr = dbo.acum_emps.ispt ,
                    kardexImprimeRecibos.acumuladoInfonavit = dbo.acum_emps.acu_info ,
                    kardexImprimeRecibos.acumuladoSar = dbo.acum_emps.acu_sar ,
                    kardexImprimeRecibos.acumuladoCv = dbo.acum_emps.acu_cv ,
                    kardexImprimeRecibos.subsTotal = dbo.nomina_tot.subsidio
            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                    INNER JOIN dbo.nomina_tot ON kardexImprimeRecibos.empresa = dbo.nomina_tot.empresa
                                                 AND kardexImprimeRecibos.codigo = dbo.nomina_tot.codigo
                    LEFT JOIN dbo.acum_emps ON dbo.nomina_tot.empresa = dbo.acum_emps.empresa
                                               AND dbo.nomina_tot.codigo = dbo.acum_emps.codigo
                                               AND @ayoOperacion = dbo.acum_emps.ejercicio
            WHERE   ( ( kardexImprimeRecibos.cuantosRecibos = 1 AND kardexImprimeRecibos.renglon = @renglonTope )
                      OR ( kardexImprimeRecibos.cuantosRecibos = 2 AND kardexImprimeRecibos.renglon = @renglonTope * 2 )
                      OR ( kardexImprimeRecibos.cuantosRecibos = 3 AND kardexImprimeRecibos.renglon = @renglonTope * 3 )
                      OR ( kardexImprimeRecibos.cuantosRecibos = 4 AND kardexImprimeRecibos.renglon = @renglonTope * 4 )
                      OR ( kardexImprimeRecibos.cuantosRecibos = 5 AND kardexImprimeRecibos.renglon = @renglonTope * 5 )
                    )
                    AND dbo.nomina_tot.tiponom = @tipoNomina
                    AND kardexImprimeRecibos.copia = @cuentaCopia
                    AND kardexImprimeRecibos.proceso = @proceso
                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                    AND kardexImprimeRecibos.empresa = @empresa
                    
            SET @cuentaCopia = @cuentaCopia + 1
                        
        END

    IF @procesoname = 'NominaDetalle' 
        BEGIN
            DECLARE @tfechaaltaempleado TABLE
                (
                  codigo INT ,
                  fechaAltaEmpleado DATETIME
                )

            INSERT  @tfechaaltaempleado
                    ( codigo ,
                      fechaAltaEmpleado
                        
                    )
                    SELECT  dbo.empleados.codigo ,
                            ISNULL(( SELECT TOP 1
                                            dbo.avisos_imss.fch_mov
                                     FROM   dbo.avisos_imss
                                     WHERE  dbo.avisos_imss.empresa = dbo.empleados.empresa
                                            AND dbo.avisos_imss.codigo = dbo.empleados.codigo
                                            AND ( dbo.avisos_imss.mov = 'A'
                                                  OR dbo.avisos_imss.mov = 'RI'
                                                )
                                            AND dbo.avisos_imss.fch_mov <= dbo.Periodos.cierre
                                     ORDER BY dbo.avisos_imss.fch_mov DESC
                                   ), dbo.empleados.fchalta) AS fechaAlta
                    FROM    dbo.empleados
                            INNER JOIN dbo.KardexImprimeRecibos AS kardexImprimeRecibos ON dbo.empleados.empresa = kardexImprimeRecibos.empresa
                                                              AND dbo.empleados.codigo = kardexImprimeRecibos.codigo
                            INNER JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                                     AND dbo.empleados.codigo = dbo.Llaves.codigo
                            LEFT JOIN dbo.Periodos ON dbo.Llaves.empresa = dbo.Periodos.empresa
                                                      AND dbo.Llaves.tiponom = dbo.Periodos.tiponom
                                                      AND dbo.Periodos.estatus = 'A'
                    WHERE   dbo.empleados.empresa = @empresa
                            AND kardexImprimeRecibos.proceso = @proceso
                            AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                            AND kardexImprimeRecibos.horaProceso = @horaProceso
                            AND kardexImprimeRecibos.empresa = @empresa
                            
            UPDATE  kardexImprimeRecibos
            SET     kardexImprimeRecibos.fechaAlta = tFechaAltaEmpleado.fechaAltaEmpleado
            FROM    dbo.KardexImprimeRecibos AS kardexImprimeRecibos
                    INNER JOIN @tfechaaltaempleado AS tFechaAltaEmpleado ON tFechaAltaEmpleado.codigo = kardexImprimeRecibos.codigo
            WHERE   --kardexImprimeRecibos.copia = @cuentaCopia
                    --AND 
                    kardexImprimeRecibos.proceso = @proceso
                    AND kardexImprimeRecibos.fechaProceso = @fechaProceso
                    AND kardexImprimeRecibos.horaProceso = @horaProceso
                    AND kardexImprimeRecibos.empresa = @empresa
        END

GO

/**************************************************************************************************
 * Name          : LlenaResumenISN
 * Project       : APSI Nomina
 * Description   : llena tabla resumen ISN
 * Table name    : kardex, llaves, centros
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Agosto 16, 2016
 **************************************************************************************************/
IF OBJECT_ID('dbo.LlenaResumenISN') IS NOT NULL
    DROP  PROCEDURE [dbo].[LlenaResumenISN]
GO
CREATE PROCEDURE [dbo].[LlenaResumenISN]
@empresa INT ,
@tipoNomina INT ,
@nomina CHAR(3) ,
@incluirProvisiones CHAR(1) ,
@procesoName VARCHAR(100) ,
@ordenadoPor INT ,
@desglosadoPor INT ,
@porCentro INT ,
@esRecibo INT ,
@codigoSeleccionado VARCHAR(500) ,
@ayoEjercicio INT ,
@saltoPagina CHAR(1) ,
@proceso VARCHAR(250) ,
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8)

AS

  SET NOCOUNT ON
  
  IF @procesoName = 'NominaDetalle'
     BEGIN
       INSERT  dbo.KardexImprimeResumenISN
             ( proceso ,
               fechaProceso ,
               horaProceso ,
               empresa ,
               centro ,
               nombreCentro ,
               procesoName ,
               numeroConceptoProvision ,
               nombreConceptoProvision ,
               importeConceptoProvision ,
               porcientoSobreNomina ,
               basePorcientoSobreNomina ,
               empleados
             )
             SELECT DISTINCT
                    @proceso ,
                    @fechaProceso ,
                    @horaProceso ,
                    estatal.empresa ,
                    estatal.centro ,
                    dbo.centros.nomdepto ,
                    @procesoName ,
                    216 ,
                    'IMPUESTO SOBRE NOMINA' ,
                    estatal.importe ,
                    estatal.porciento ,
                    estatal.base ,
                    estatal.registros
             FROM dbo.estatal AS estatal
                  INNER JOIN (SELECT DISTINCT 
                                     ll.centro
                              FROM dbo.llaves AS ll
                                   INNER JOIN dbo.kardex AS k ON k.num_conc = 216
                                                                 AND ll.codigo = k.codigo
                                                                 AND ll.empresa = k.empresa
                              WHERE ll.tiponom = @tipoNomina
                                    AND ll.empresa = @empresa) AS ll ON LTRIM(RTRIM(estatal.centro)) = LTRIM(RTRIM(ll.centro))
                  INNER JOIN dbo.centros ON LTRIM(RTRIM(estatal.centro)) = LTRIM(RTRIM(dbo.centros.centro))
                                            AND estatal.empresa = dbo.centros.empresa
                  INNER JOIN dbo.SeleccionElementos ON CASE WHEN @porCentro = 1
                                                            THEN estatal.empresa
                                                            ELSE 1
                                                       END = CASE WHEN @porCentro = 1
                                                                  THEN dbo.SeleccionElementos.empresa
                                                                  ELSE 1
                                                             END
                                                       AND CASE WHEN @porCentro = 1
                                                                THEN LTRIM(RTRIM(estatal.centro))
                                                                ELSE '1'
                                                           END = CASE WHEN @porCentro = 1
                                                                      THEN LTRIM(RTRIM(dbo.SeleccionElementos.centro))
                                                                      ELSE '1'
                                                                 END
                                                       AND CASE WHEN @porCentro = 1
                                                                THEN dbo.SeleccionElementos.tipoNomina
                                                                ELSE '1'
                                                           END = CASE WHEN @porCentro = 1
                                                                      THEN estatal.tiponom
                                                                      ELSE '1'
                                                                 END
             WHERE estatal.tiponom = @tipoNomina
                   AND LTRIM(RTRIM(estatal.centro)) <> '99999999999997'
                   AND estatal.empresa = @empresa --CASE WHEN @desglosadoPor & 1 > 0
                                         --     THEN @empresa
                                         --     ELSE 0
                                         --END
/*       
       INSERT  dbo.KardexImprimeResumenISN
             ( proceso ,
               fechaProceso ,
               horaProceso ,
               empresa ,
               centro ,
               nombreCentro ,
               procesoName ,
               numeroConceptoProvision ,
               nombreConceptoProvision ,
               importeConceptoProvision ,
               porcientoSobreNomina ,
               basePorcientoSobreNomina ,
               empleados
             )
             SELECT 
                    @proceso ,
                    @fechaProceso ,
                    @horaProceso ,
                    @empresa,
                    'X',
                    '',
                    @procesoName ,
                    0,
                    '',
                    0,
                    0,
                    0,
                    0
             WHERE (SELECT COUNT(*)
                    FROM dbo.KardexImprimeResumenISN
                    WHERE proceso = @proceso
                          AND fechaProceso = @fechaProceso
                          AND horaProceso = @horaProceso
                          AND procesoName = @procesoName
                          AND empresa = @empresa) = 0
*/
     END
GO

IF OBJECT_ID('dbo.LlenaTablaAvisosImssTemporalCalculo') IS NOT NULL 
    DROP PROCEDURE dbo.LlenaTablaAvisosImssTemporalCalculo
GO
CREATE PROCEDURE dbo.LlenaTablaAvisosImssTemporalCalculo
@empresa INT ,
@proceso VARCHAR(500) ,
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8) ,
@periodoInicio VARCHAR(6) ,
@periodoTermino VARCHAR(6) ,
@cedula VARCHAR(8)

AS 

  SET NOCOUNT ON
 
  DECLARE @mes_non CHAR(2)
  DECLARE @mes_par CHAR(2)
  DECLARE @mes2 CHAR(2)
  DECLARE @dfch_fin_mes2 DATETIME
  DECLARE @fechaInicio DATETIME
  DECLARE @fechaTermino DATETIME
  DECLARE @EsRpuEspecial INT
  DECLARE @EsRpu CHAR(1)
  DECLARE @Rpu CHAR(3)

  SET @EsRpuEspecial = dbo.EsRpuEspecial(@empresa)
  SET @fechaInicio = CONVERT(DATETIME, @periodoInicio + '01')
  SET @fechaTermino = CONVERT(DATETIME, @periodoTermino + '01')
  SET @fechaInicio = (SELECT fechaInicio FROM [dbo].[ObtieneRangoFecha](@fechaInicio, 7))
  SET @fechaTermino = (SELECT fechaFin FROM [dbo].[ObtieneRangoFecha](@fechaTermino, 7))

  SET @mes_non = RIGHT(@periodoInicio,2)
  SET @mes_par = RIGHT(@periodoTermino,2)

  DECLARE @posicion INT
  SET @posicion = CHARINDEX('"', @proceso)
  IF @posicion > 0
     SET @posicion = @posicion - 1
  ELSE
     SET @posicion = LEN(@proceso)

  SELECT @EsRpu = ISNULL(dbo.empresas.Rpu, 'N'),
		 @Rpu = LEFT(dbo.empresas.registro_patronal,3)
  FROM dbo.empresas
  WHERE dbo.empresas.empresa = @empresa


--SELECT '1', * FROM dbo.AvisosImssTemporalCalculo AS aItc

  DELETE aItc
  FROM dbo.AvisosImssTemporalCalculo AS aItc
       INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = aItc.empresa
  WHERE LTRIM(RTRIM(SUBSTRING(aItc.proceso,1,@posicion))) = LTRIM(RTRIM(SUBSTRING(@proceso,1,@posicion)))

--SELECT '2', * FROM dbo.AvisosImssTemporalCalculo AS aItc

  INSERT dbo.AvisosImssTemporalCalculo
         (proceso ,
          fechaProceso ,
          horaProceso ,
          empresa ,
          codigo ,
          serial ,
          mes_operacion ,
          ayo_operacion ,
          fch_mov ,
          mov ,
          saldiaint ,
          diastr ,
          incap ,
          ausen ,
          rpu ,
		  umaDiario,
		  aplicaIMSS,
		  umaFD,
		  registro)

         SELECT @proceso,
                @fechaProceso ,
                @horaProceso ,
                empresa, 
                codigo, 
                ROW_NUMBER() OVER (PARTITION BY empresa, codigo, CASE WHEN @EsRpuEspecial = 1 
				                                             THEN rpu 
															 ELSE ''
                                                        END ORDER BY empresa, codigo, fch_mov, serial) AS serial, 
                mes_operacion, 
                ayo_operacion, 
                fch_mov, 
                mov, 
                saldiaint, 
                0 AS diastr, 
                0 AS incap, 
                0 AS ausen, 
                rpu, 
                umaDiario, 
                aplicaIMSS, 
                UmiFD,
				registro

         FROM (SELECT avisosImss.empresa AS empresa,
                      avisosImss.codigo AS codigo,
                      avisosImss.serial AS serial,
                      MONTH(avisosImss.fch_mov) AS mes_operacion,
                      YEAR(avisosImss.fch_mov) AS ayo_operacion,
                      avisosImss.fch_mov AS fch_mov,
                      avisosImss.mov AS mov,
                      avisosImss.saldiaint AS saldiaint,
                      avisosImss.diastr AS diastr,
                      avisosImss.incap AS incap,
                      avisosImss.ausen AS ausen,
                      ISNULL(avisosImss.rpu, @Rpu) AS rpu,
                      uma.umaDiario AS umaDiario,
                      uma.aplicaIMSS AS aplicaIMSS,
                      UmiFD.UmiFD AS umiFD,
					  0 AS registro
               FROM dbo.avisos_imss AS avisosImss 
					INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = avisosImss.empresa
                    OUTER APPLY (SELECT TOP 1 
			                            uma.umaDiario,
							            uma.aplicaIMSS
                                 FROM dbo.TblUMA AS uma
                                 WHERE @periodoInicio >= '201701'
						               AND uma.fecha <= avisosImss.fch_mov
                                 ORDER BY uma.fecha DESC) AS uma

                    OUTER APPLY (SELECT TOP 1 
			                            UmiFD.umaDiario AS UmiFD
                                 FROM dbo.TblUMAFD AS UmiFD
                                 WHERE UmiFD.fecha <= avisosImss.fch_mov
                                 ORDER BY UmiFD.fecha DESC) AS UmiFD

               WHERE avisosImss.fch_mov >= @fechaInicio
					 AND avisosImss.fch_mov <= @fechaTermino

               UNION

               SELECT avisosImss.empresa AS empresa, 
                      avisosImss.codigo AS codigo, 
                      0 AS serial, 
                      MONTH(RegistroUma.fecha) AS mes_operacion, 
                      YEAR(RegistroUma.fecha) AS ayo_operacion, 
                      RegistroUma.fecha AS fch_mov, 
                      'UM' AS mov, 
                      avisosImss.saldiaint AS saldiaint, 
                      avisosImss.diastr AS diastr, 
                      avisosImss.incap AS incap, 
                      avisosImss.ausen AS ausen, 
					  ISNULL(avisosImss.rpu, @Rpu) AS rpu,
                      RegistroUma.umaDiario AS umaDiario, 
                      RegistroUma.aplicaIMSS AS aplicaIMSS, 
                      UmiFD.UmiFD AS UmiFD,
					  0 AS registro

               FROM dbo.avisos_imss AS avisosImss
					INNER JOIN dbo.NOM_FUN_FiltraEmpresa(@empresa, @proceso) AS filtraEmpresa ON filtraEmpresa.empresa = avisosImss.empresa
                    INNER JOIN dbo.TblUMA AS RegistroUma ON RegistroUma.fecha > avisosImss.fch_mov AND RegistroUma.fecha <= avisosImss.fch_mov + avisosImss.diastr - 1
                    OUTER APPLY (SELECT TOP 1 
			                            UmiFd.umaDiario AS UmiFD
                                 FROM dbo.TblUMAFD AS UmiFd
                                 WHERE UmiFD.fecha <= avisosImss.fch_mov
                                 ORDER BY UmiFD.fecha DESC) AS UmiFD

               WHERE avisosImss.fch_mov >= @fechaInicio
					 AND avisosImss.fch_mov <= @fechaTermino
			         AND avisosImss.mov <> 'B') AS avisosImss

         ORDER BY empresa
		          , codigo
                  , fch_mov ASC
                  , serial ASC

  -- Rutina para integrar UMA
  IF @periodoInicio >= '201701'
     BEGIN
       DECLARE @nayo CHAR(4)
       DECLARE @mes CHAR(2)
       DECLARE @dfch_fin_mes DATETIME
          
       SET @nayo = LEFT(@periodoInicio,4)
       SET @mes = RIGHT(@periodoInicio,2)
       SET @dfch_fin_mes = dbo.fin_mes(@mes, @nayo)
       
       IF @cedula = 'MENSUAL' OR @mes_non = @mes_par
          BEGIN
            EXECUTE dbo.asp_ds_UMA @empresa,0,@nayo,@mes,@dfch_fin_mes, @proceso, @fechaProceso, @horaProceso
            EXECUTE dbo.asp_ds_aus_UMA @empresa, 0, @nayo, @mes, 7, @proceso, @fechaProceso, @horaProceso
            EXECUTE dbo.asp_ds_inc_UMA @empresa, 0, @nayo, @mes, @proceso, @fechaProceso, @horaProceso
          END

       IF @cedula = 'BIMESTRE' AND @mes_non < @mes_par
          BEGIN
            SET @mes2 = RIGHT(@periodoTermino,2)
            SET @dfch_fin_mes2 = dbo.fin_mes(@mes2, @nayo)
                             
            EXECUTE dbo.asp_bim_ds_UMA @empresa,@nayo,@mes_non,@mes_par,0,@dfch_fin_mes2, @proceso, @fechaProceso, @horaProceso
            EXECUTE dbo.asp_bim_aus_UMA @empresa,@nayo,@mes_non,@mes_par,0,7, @proceso, @fechaProceso, @horaProceso
            EXECUTE dbo.asp_bim_inc_UMA @empresa,@nayo,@mes_non,@mes_par,0, @proceso, @fechaProceso, @horaProceso
          END
     END
GO

IF OBJECT_ID('dbo.MarcaAvisoEnvio') IS NOT NULL 
    DROP PROCEDURE dbo.MarcaAvisoEnvio
GO
CREATE PROCEDURE dbo.MarcaAvisoEnvio
    @empresa INT ,
    @codigo INT ,
    @serial INT ,
    @fechaAviso DATETIME ,
    @fecha DATETIME ,
    @tipoAviso VARCHAR(2)
AS 
    IF @tipoAviso = 'A'
        OR @tipoAviso = 'B'
        OR @tipoAviso = 'C' 
        UPDATE  dbo.avisos_imss
        SET     dbo.avisos_imss.fechaEnvio = @fecha ,
                dbo.avisos_imss.estatus = 'Enviado'
        WHERE   dbo.avisos_imss.empresa = @empresa
                AND dbo.avisos_imss.codigo = @codigo
                AND dbo.avisos_imss.serial = @serial
                AND dbo.avisos_imss.fch_mov = @fechaAviso
    ELSE 
        IF @tipoAviso = 'AR'
            OR @tipoAviso = 'BR' 
            UPDATE  dbo.rpu_trabajador
            SET     dbo.rpu_trabajador.fechaEnvio = @fecha ,
                    dbo.rpu_trabajador.estatus = 'Enviado'
            WHERE   dbo.rpu_trabajador.empresa = @empresa
                    AND dbo.rpu_trabajador.codigo = @codigo
                    AND dbo.rpu_trabajador.folio = @serial
                    AND dbo.rpu_trabajador.fch_mov = @fechaAviso
GO

IF OBJECT_ID('dbo.NOM_PRO_BorraEmpleadoApsiRelojAnalisisHistoricoP_Nom') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_BorraEmpleadoApsiRelojAnalisisHistoricoP_Nom
GO
CREATE PROCEDURE dbo.NOM_PRO_BorraEmpleadoApsiRelojAnalisisHistoricoP_Nom
@Empresa INT, 
@Codigo INT,
@Fecha DATETIME

AS 

  SET NOCOUNT ON

   DELETE Apsi_Reloj_Analisis_HistoricoP_Nom
   WHERE EmpresaApsi = @Empresa
         AND codigo = @Codigo
	     AND fecha = @Fecha
	     AND noconcepto = 0
	     AND SUBSTRING(incidencia,1,10)='Cambio CC:'
GO

IF OBJECT_ID('dbo.NOM_PRO_CambiaCentroDeCostosEmpleado') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_CambiaCentroDeCostosEmpleado
GO
CREATE PROCEDURE dbo.NOM_PRO_CambiaCentroDeCostosEmpleado
@Empresa INT,
@Codigo INT,
@Centro VARCHAR(15)

AS 
  
  SET NOCOUNT ON

  UPDATE ll
  SET ll.centro = LTRIM(RTRIM(@centro))
  FROM dbo.Llaves AS ll
  WHERE ll.empresa = @Empresa
        AND ll.codigo = @Codigo
GO

IF OBJECT_ID('dbo.NOM_PRO_ObtieneCentroDeCostosEmpleado') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ObtieneCentroDeCostosEmpleado
GO
CREATE PROCEDURE dbo.NOM_PRO_ObtieneCentroDeCostosEmpleado
@Empresa INT,
@Codigo INT

AS 
  
  SET NOCOUNT ON

  SELECT ll.centro,
         c.nomdepto
  FROM dbo.Llaves AS ll
       INNER JOIN dbo.centros AS c ON ll.empresa = c.empresa AND LTRIM(RTRIM(ll.centro)) = LTRIM(RTRIM(c.centro))
  WHERE ll.empresa = @Empresa
        AND ll.codigo = @Codigo
GO

IF OBJECT_ID('dbo.NOM_PRO_ValidaCentroEnCatalogo') IS NOT NULL
   DROP PROCEDURE dbo.NOM_PRO_ValidaCentroEnCatalogo
GO
CREATE PROCEDURE dbo.NOM_PRO_ValidaCentroEnCatalogo
@Empresa INT,
@Centro VARCHAR(15)

AS 
  
  SET NOCOUNT ON

  DECLARE @ExisteCentro INT

  IF EXISTS (SELECT 1
             FROM dbo.centros AS c
			 WHERE c.empresa = @Empresa
                   AND LTRIM(RTRIM(c.centro)) = LTRIM(RTRIM(@Centro)))
     SET @ExisteCentro = 1
  ELSE
     SET @ExisteCentro = 0

  SELECT @ExisteCentro AS ExisteCentro
GO

IF OBJECT_ID('dbo.ObtieneAusentismo') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneAusentismo
GO
CREATE PROCEDURE dbo.ObtieneAusentismo
    @empresa INT ,
    @codigo INT ,
    @ayo INT ,
    @mes INT
AS 
    SET NOCOUNT ON

    DECLARE @fi DATETIME
    DECLARE @ff DATETIME
    DECLARE @dias INT
    DECLARE @ausentismo TABLE
        (
          empresa INT ,
          codigo INT ,
          num_conc INT ,
          fchinicio DATETIME ,
          dias DECIMAL(5, 2) ,
          numeroinc VARCHAR(12)
        )

    IF @mes = 0 
        BEGIN
            IF @ayo = 0 
                BEGIN
                    SET @fi = CONVERT(DATETIME, '19000101')
                    SET @ff = dbo.fin_mes(12, 2999)
                END
            ELSE 
                BEGIN
                    SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
                        + '0101')
                    SET @ff = dbo.fin_mes(12, @ayo)
                END
        END
    ELSE 
        BEGIN
            SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
                + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
            SET @ff = dbo.fin_mes(@mes, @ayo)
        END
    
    SET @dias = DATEDIFF(dd,@fi,@ff) + 1
    

    INSERT  @ausentismo
            ( empresa ,
              codigo ,
              num_conc ,
              fchinicio ,
              dias ,
              numeroinc
            )
            SELECT  dbo.deducciones.empresa ,
                    dbo.deducciones.codigo ,
                    dbo.deducciones.num_conc ,
                    MIN(dbo.deducciones.fchinicio) AS fchinicio ,
                    SUM(dbo.deducciones.dias) AS dias ,
                    dbo.deducciones.numeroinc
            FROM    dbo.deducciones
            WHERE   dbo.deducciones.empresa >= CASE WHEN @empresa = 0 THEN 1
                                                    ELSE @empresa
                                               END
                    AND dbo.deducciones.empresa <= CASE WHEN @empresa = 0
                                                        THEN 99999
                                                        ELSE @empresa
                                                   END
                    AND dbo.deducciones.codigo >= CASE WHEN @codigo = 0 THEN 1
                                                       ELSE @codigo
                                                  END
                    AND dbo.deducciones.codigo <= CASE WHEN @codigo = 0
                                                       THEN 99999999
                                                       ELSE @codigo
                                                  END
                    AND dbo.deducciones.num_conc >= 109
                    AND dbo.deducciones.num_conc <= 111
            GROUP BY dbo.deducciones.empresa ,
                    dbo.deducciones.codigo ,
                    dbo.deducciones.num_conc ,
                    dbo.deducciones.numeroinc
            HAVING  MIN(dbo.deducciones.fchinicio) BETWEEN @fi AND @ff
            ORDER BY dbo.deducciones.empresa ,
                    dbo.deducciones.codigo ,
                    MIN(dbo.deducciones.fchinicio)        

    INSERT  @ausentismo
            ( empresa ,
              codigo ,
              num_conc ,
              fchinicio ,
              dias ,
              numeroinc
            )
            SELECT  dbo.deducciones.empresa ,
                    dbo.deducciones.codigo ,
                    dbo.deducciones.num_conc ,
                    dbo.deducciones.fchinicio,
                    --dbo.deducciones.dias ,
                    CASE WHEN dbo.deducciones.fchinicio < @fi AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 > @fi
                              AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                         THEN DATEDIFF(dd,@fi,dbo.deducciones.fchinicio + dbo.deducciones.dias)
                         ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                        AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 <= @ff
                                   THEN dbo.deducciones.dias
                                   ELSE CASE WHEN dbo.deducciones.fchinicio >= @fi
                                                  AND dbo.deducciones.fchinicio <= @ff
                                                  AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 >= @ff
                                             THEN datediff(dd,dbo.deducciones.fchinicio,@ff) + 1
                                             ELSE CASE WHEN dbo.deducciones.fchinicio < @fi
                                                            AND dbo.deducciones.fchinicio + dbo.deducciones.dias - 1 > @ff
                                                       THEN @dias
                                                       ELSE 0
                                                  END
                                        END
                              END
                    END AS dias,
                    dbo.deducciones.numeroinc
            FROM    dbo.deducciones
            WHERE   dbo.deducciones.empresa >= CASE WHEN @empresa = 0 THEN 1
                                                    ELSE @empresa
                                               END
                    AND dbo.deducciones.empresa <= CASE WHEN @empresa = 0
                                                        THEN 99999
                                                        ELSE @empresa
                                                   END
                    AND dbo.deducciones.codigo >= CASE WHEN @codigo = 0 THEN 1
                                                       ELSE @codigo
                                                  END
                    AND dbo.deducciones.codigo <= CASE WHEN @codigo = 0
                                                       THEN 99999999
                                                       ELSE @codigo
                                                  END
                    AND dbo.deducciones.num_conc = 108
                    AND ( ( dbo.deducciones.fchinicio <= @fi
                            AND dbo.deducciones.fchtermino >= @fi
                            AND dbo.deducciones.fchinicio <= @ff
                          )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchtermino <= @ff
                             )
                          OR ( dbo.deducciones.fchinicio >= @fi
                               AND dbo.deducciones.fchinicio <= @ff
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                          OR ( dbo.deducciones.fchinicio <= @fi
                               AND dbo.deducciones.fchtermino >= @ff
                             )
                        )
                    --AND dbo.deducciones.fchinicio >= @fi
                    --AND dbo.deducciones.fchinicio <= @ff
            ORDER BY dbo.deducciones.empresa ,
                    dbo.deducciones.codigo ,
                    --dbo.deducciones.fchinicio
                    CASE WHEN dbo.deducciones.fchinicio < @fi THEN @fi ELSE dbo.deducciones.fchinicio END
        
    SELECT  ausentismo.empresa ,
            ausentismo.codigo ,
            ausentismo.num_conc ,
            ausentismo.dias ,
            --ausentismo.fchinicio ,
            CASE WHEN ausentismo.num_conc = 108 AND ausentismo.fchinicio < @fi THEN @fi ELSE ausentismo.fchinicio END AS fchinicio,
            ausentismo.numeroinc ,
            dbo.deducciones.inicsubs ,
            dbo.deducciones.varia1 ,
            dbo.deducciones.varia2 ,
            dbo.deducciones.folio ,
            dbo.conceptos.concepto
    FROM    @ausentismo AS ausentismo
            INNER JOIN dbo.deducciones ON ausentismo.empresa = dbo.deducciones.empresa
                                          AND ausentismo.codigo = dbo.deducciones.codigo
                                          AND ausentismo.num_conc = dbo.deducciones.num_conc
                                          AND ausentismo.fchinicio = dbo.deducciones.fchinicio
            INNER JOIN dbo.conceptos ON dbo.conceptos.empresa = dbo.deducciones.empresa
                                        AND dbo.conceptos.num_conc = dbo.deducciones.num_conc
                                        AND dbo.conceptos.clase = ' '
                                        AND dbo.conceptos.centro = ' '
    ORDER BY ausentismo.empresa ,
            ausentismo.codigo ,
            --ausentismo.fchinicio
            CASE WHEN ausentismo.num_conc = 108 AND ausentismo.fchinicio < @fi THEN @fi ELSE ausentismo.fchinicio END
GO

IF OBJECT_ID('dbo.ObtieneAusentismoMes') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneAusentismoMes
GO

CREATE PROCEDURE [dbo].[ObtieneAusentismoMes]
    @empresa INT = 0 ,
    @codigo INT = 0 ,
    @ayo INT = 0 ,
    @mes INT = 0
AS 
    SET NOCOUNT ON

    DECLARE @fi DATETIME
    DECLARE @ff DATETIME

    SET @fi = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
        + SUBSTRING(CONVERT(CHAR(3), 100 + @mes), 2, 2) + '01')
    SET @ff = dbo.fin_mes(@mes, @ayo)


    SELECT  dbo.deducciones.empresa ,
            dbo.deducciones.codigo ,
            dbo.deducciones.num_conc ,
            dbo.deducciones.dias ,
            dbo.deducciones.fchinicio ,
            dbo.deducciones.numeroinc ,
            dbo.deducciones.inicsubs ,
            dbo.deducciones.varia1 ,
            dbo.deducciones.varia2 ,
            dbo.deducciones.folio ,
            dbo.conceptos.concepto
    FROM    dbo.deducciones
            INNER JOIN dbo.conceptos ON dbo.conceptos.empresa = dbo.deducciones.empresa
                                        AND dbo.conceptos.num_conc = dbo.deducciones.num_conc
                                        AND dbo.conceptos.clase = ' '
                                        AND dbo.conceptos.centro = ' '
    WHERE   dbo.deducciones.empresa >= CASE WHEN @empresa = 0 THEN 1
                                            ELSE @empresa
                                       END
            AND dbo.deducciones.empresa <= CASE WHEN @empresa = 0 THEN 99999
                                                ELSE @empresa
                                           END
            AND dbo.deducciones.codigo >= CASE WHEN @codigo = 0 THEN 1
                                               ELSE @codigo
                                          END
            AND dbo.deducciones.codigo <= CASE WHEN @codigo = 0 THEN 99999999
                                               ELSE @codigo
                                          END
            AND dbo.deducciones.num_conc >= 108
            AND dbo.deducciones.num_conc <= 111
            AND ( ( dbo.deducciones.fchinicio <= @fi
                    AND dbo.deducciones.fchtermino >= @fi
                    AND dbo.deducciones.fchinicio <= @ff
                  )
                  OR ( dbo.deducciones.fchinicio >= @fi
                       AND dbo.deducciones.fchtermino <= @ff
                     )
                  OR ( dbo.deducciones.fchinicio >= @fi
                       AND dbo.deducciones.fchinicio <= @ff
                       AND dbo.deducciones.fchtermino >= @ff
                     )
                  OR ( dbo.deducciones.fchinicio <= @fi
                       AND dbo.deducciones.fchtermino >= @ff
                     )
                )
    ORDER BY dbo.deducciones.codigo ,
            dbo.deducciones.fchinicio
GO

IF OBJECT_ID('dbo.ObtieneAvisoImss') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneAvisoImss
GO
CREATE PROCEDURE dbo.ObtieneAvisoImss
    @empresa INT ,
    @ayo INT ,
    @mes INT ,
    @nomina VARCHAR(50)
AS 
    SET NOCOUNT ON

    DECLARE @tblNomina TABLE ( tiponom INT )
    DECLARE @ciclo INT
    DECLARE @zonaGeografica CHAR(1)
    DECLARE @fechaAplicaUMA DATETIME
    SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
    
    SELECT  @zonaGeografica = dbo.empresas.zona_geografica
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa

    SET @ciclo = 2

    IF @nomina = '()' 
        BEGIN
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 1 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 2 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 3 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 4 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 5 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 6 )
        END
    ELSE 
        BEGIN
            WHILE @ciclo < LEN(@nomina) 
                BEGIN
                    INSERT  @tblNomina
                            ( tiponom )
                    VALUES  ( SUBSTRING(@nomina, @ciclo, 1)  -- tiponom - int
                              )
                    SET @ciclo = @ciclo + 2
                END
        END


    SELECT  avisos_imss.codigo ,
            avisos_imss.serial ,
            avisos_imss.fch_mov ,
            avisos_imss.mov ,
            avisos_imss.fch_real ,
            CASE WHEN dbo.avisos_imss.fch_mov >= @fechaAplicaUMA 
                 THEN CASE WHEN dbo.avisos_imss.saldiaint > ROUND(ISNULL((SELECT TOP 1
                                                                                 uma.umaDiario
                                                                          FROM dbo.TblUMA AS uma
                                                                          WHERE uma.fecha <= dbo.avisos_imss.fch_mov
                                                                          ORDER BY uma.fecha DESC),0) * 25,2)
                           THEN ROUND(ISNULL((SELECT TOP 1
                                                     uma.umaDiario
                                              FROM dbo.TblUMA AS uma
                                              WHERE uma.fecha <= dbo.avisos_imss.fch_mov
                                              ORDER BY uma.fecha DESC),0) * 25,2)
                           ELSE ISNULL(dbo.avisos_imss.saldiaint,0)
                      END
                 ELSE ISNULL(avisos_imss.saldiaint, 0)
            END AS saldiaint ,
            avisos_imss.sueldo ,
            empleados.nombre ,
            empleados.ap_paterno ,
            empleados.ap_materno ,
            empleados.afiliacion ,
            empleados.digvera ,
            empleados.curp ,
            empleados.fchalta ,
            --empleados.sueldo ,
            --empleados.saldiaint ,
            empleados.tiposal ,
            llaves.centro ,
            llaves.tiponom ,
            tabulador.actividad ,
            ISNULL(avisos_imss.mot_baja, ' ') AS motivoBaja ,
            centros.nomdepto ,
            empleados.tipo_emp ,
            empleados.jornada ,
            empleados.rfcalfa ,
            empleados.rfcnum ,
            empleados.rfchomo ,
            datosemps.umf ,
            empleados.edonac ,
            empleados.fchnac ,
            empleados.sexo ,
            ISNULL(avisos_imss.clave_baja, 2) AS claveBaja ,
            ' ' AS filler1 ,
            datosemps.domicilio ,
            datosemps.colonia ,
            datosemps.poblacion ,
            avisos_imss.rpu ,
            ' ' AS enviado ,
            ' ' AS filler2 ,
            ISNULL(avisos_imss.sueldoant, avisos_imss.sueldo) AS sueldoAnt ,
            ISNULL(avisos_imss.saldiaintant, avisos_imss.saldiaint) AS saldiaintant ,
            llaves.clase ,
            CASE WHEN dbo.avisos_imss.fechaEnvio IS NULL THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.avisos_imss.fechaEnvio), 4)
                      + RIGHT(100 + MONTH(dbo.avisos_imss.fechaEnvio), 2)
                      + RIGHT(100 + DAY(dbo.avisos_imss.fechaEnvio), 2) + ' '
                      + RIGHT(100 + DATEPART(HH, dbo.avisos_imss.fechaEnvio),
                              2) + ':' + RIGHT(100 + DATEPART(MI,
                                                              dbo.avisos_imss.fechaEnvio),
                                               2) + ':' + RIGHT(100
                                                              + DATEPART(SS,
                                                              dbo.avisos_imss.fechaEnvio),
                                                              2)
            END AS fechaEnvio ,
            dbo.avisos_imss.estatus ,
            dbo.avisos_imss.lote ,
            CASE WHEN dbo.avisos_imss.fechaConfirmacion IS NULL
                 THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.avisos_imss.fechaConfirmacion), 4)
                      + RIGHT(100 + MONTH(dbo.avisos_imss.fechaConfirmacion),
                              2) + RIGHT(100
                                         + DAY(dbo.avisos_imss.fechaConfirmacion),
                                         2) + ' ' + RIGHT(100 + DATEPART(HH,
                                                              dbo.avisos_imss.fechaConfirmacion),
                                                          2) + ':' + RIGHT(100
                                                              + DATEPART(MI,
                                                              dbo.avisos_imss.fechaConfirmacion),
                                                              2) + ':'
                      + RIGHT(100 + DATEPART(SS,
                                             dbo.avisos_imss.fechaConfirmacion),
                              2)
            END AS fechaConfirmacion ,
            dbo.deducciones.dias AS diasIncapacidad ,
            dbo.avisos_imss.origen ,
            ISNULL(( SELECT TOP 1
                            dbo.salarios_minimos.zona_a
                     FROM   dbo.salarios_minimos
                     WHERE  dbo.salarios_minimos.fecha_ini <= dbo.avisos_imss.fch_mov
                            AND dbo.salarios_minimos.fecha_fin >= dbo.avisos_imss.fch_mov
                   ), 0) AS salarioMinimoDF ,
            ISNULL(( SELECT TOP 1
                            CASE @zonaGeografica
                              WHEN 'A' THEN dbo.salarios_minimos.zona_a
                              WHEN 'B' THEN dbo.salarios_minimos.zona_b
                              ELSE dbo.salarios_minimos.zona_c
                            END
                     FROM   dbo.salarios_minimos
                     WHERE  dbo.salarios_minimos.fecha_ini <= dbo.avisos_imss.fch_mov
                            AND dbo.salarios_minimos.fecha_fin >= dbo.avisos_imss.fch_mov
                   ), 0) AS salarioMinimoRegion,
            dbo.datosemps.email,
            ISNULL((SELECT TOP 1
                           uma.umaDiario
                    FROM dbo.TblUMA AS uma
                    WHERE uma.fecha <= dbo.avisos_imss.fch_mov
                    ORDER BY uma.fecha DESC),0) AS umaDiario,
            ISNULL(dbo.supervisores.nombre, '') AS nombreSupervisor
    FROM    dbo.avisos_imss
            LEFT JOIN dbo.empleados ON ( dbo.avisos_imss.Empresa = dbo.empleados.Empresa )
                                       AND ( dbo.avisos_imss.Codigo = dbo.empleados.Codigo )
            LEFT JOIN dbo.llaves ON ( dbo.avisos_imss.Empresa = dbo.llaves.Empresa )
                                    AND ( dbo.avisos_imss.Codigo = dbo.llaves.Codigo )
            LEFT JOIN dbo.centros ON ( dbo.avisos_imss.Empresa = dbo.centros.Empresa )
                                     AND ( dbo.llaves.Centro = dbo.centros.centro )
            LEFT JOIN dbo.tabulador ON ( dbo.avisos_imss.Empresa = dbo.tabulador.Empresa )
                                       AND ( dbo.llaves.Ocupacion = dbo.tabulador.Ocupacion )
            LEFT JOIN dbo.datosemps ON ( dbo.avisos_imss.Empresa = dbo.datosemps.Empresa )
                                       AND ( dbo.avisos_imss.codigo = dbo.datosemps.Codigo )
            LEFT JOIN dbo.deducciones ON ( dbo.avisos_imss.empresa = dbo.deducciones.empresa
                                           AND dbo.avisos_imss.codigo = dbo.deducciones.codigo
                                           AND dbo.avisos_imss.fch_mov >= dbo.deducciones.fchinicio
                                           AND dbo.avisos_imss.fch_mov <= dbo.deducciones.fchtermino
                                           AND dbo.deducciones.num_conc >= 109
                                           AND dbo.deducciones.num_conc <= 111
                                         )
            INNER JOIN ( SELECT avisosImss.empresa ,
                                avisosImss.codigo ,
                                avisosImss.mov ,
                                avisosImss.fch_mov ,
                                MAX(avisosImss.serial) AS serial
                         FROM   dbo.avisos_imss AS avisosImss
                         WHERE  avisosImss.mov <> 'IM'
                                --AND MONTH(avisosImss.fch_mov) = 3
                                AND CASE WHEN @mes = 13 
                                         THEN 1
                                         ELSE MONTH(avisosImss.fch_mov) --dbo.avisos_imss.mes_operacion
                                    END = CASE WHEN @mes = 13 
                                               THEN 1
                                               ELSE @mes
                                          END
                                AND YEAR(avisosImss.fch_mov) = @ayo
                                AND empresa = @empresa
                         GROUP BY avisosImss.empresa ,
                                avisosImss.codigo ,
                                avisosImss.mov ,
                                avisosImss.fch_mov
                       ) AS avisosImss ON dbo.avisos_imss.serial = avisosImss.serial
                                          AND dbo.avisos_imss.mov = avisosImss.mov
                                          AND dbo.avisos_imss.fch_mov = avisosImss.fch_mov
                                          AND dbo.avisos_imss.codigo = avisosImss.codigo
                                          AND dbo.avisos_imss.empresa = avisosImss.empresa
            LEFT JOIN dbo.supervisores ON dbo.llaves.Empresa = dbo.supervisores.empresa
                                          AND dbo.llaves.supervisor = dbo.supervisores.supervisor
    WHERE   --dbo.avisos_imss.empresa = @empresa
            --AND dbo.avisos_imss.mov <> 'IM'
            --AND dbo.avisos_imss.ayo_operacion = @ayo
            --AND CASE WHEN @mes = 13 THEN 1
            --         ELSE dbo.avisos_imss.mes_operacion
            --    END = CASE WHEN @mes = 13 THEN 1
            --               ELSE @mes
            --          END
            --AND 
            dbo.Llaves.tiponom IN ( SELECT  tiponom
                                        FROM    @tblNomina )
            AND dbo.empleados.cotiza_imss = 'S'
            --AND ISNULL(dbo.avisos_imss.fechaEnvio, CONVERT(DATETIME, '19000101')) = @fechaEnvio
    ORDER BY CASE WHEN @mes = 13
                  THEN CONVERT(INT, RIGHT(YEAR(dbo.avisos_imss.fch_mov), 4)
                       + RIGHT(100 + MONTH(dbo.avisos_imss.fch_mov), 2)
                       + RIGHT(100 + DAY(dbo.avisos_imss.fch_mov), 2))
                  ELSE dbo.avisos_imss.codigo
             END ,
            CASE WHEN @mes = 13 THEN dbo.avisos_imss.codigo
                 ELSE CONVERT(INT, RIGHT(YEAR(dbo.avisos_imss.fch_mov), 4)
                      + RIGHT(100 + MONTH(dbo.avisos_imss.fch_mov), 2)
                      + RIGHT(100 + DAY(dbo.avisos_imss.fch_mov), 2))
            END
GO

IF OBJECT_ID('dbo.ObtieneAvisoImssReporte') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneAvisoImssReporte
GO
CREATE PROCEDURE dbo.ObtieneAvisoImssReporte
    @empresa INT ,
    @ayo INT ,
    @mes INT ,
    @nomina VARCHAR(50) ,
    @tipoAviso VARCHAR(1) ,
    @ordenadoPor INT
AS 
    SET NOCOUNT ON

    DECLARE @tblNomina TABLE ( tiponom INT )
    DECLARE @ciclo INT
    DECLARE @fechaAplicaUMA DATETIME
    SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')

    SET @ciclo = 2

    IF @nomina = '()' 
        BEGIN
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 1 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 2 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 3 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 4 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 5 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 6 )
        END
    ELSE 
        BEGIN
            WHILE @ciclo < LEN(@nomina) 
                BEGIN
                    INSERT  @tblNomina
                            ( tiponom )
                    VALUES  ( SUBSTRING(@nomina, @ciclo, 1)  -- tiponom - int
                              )
                    SET @ciclo = @ciclo + 2
                END
        END


    SELECT  avisos_imss.codigo ,
            avisos_imss.serial ,
            avisos_imss.fch_mov ,
            CASE WHEN avisos_imss.mov = 'RI' THEN 'A'
                 ELSE dbo.avisos_imss.mov
            END AS 'mov' ,
            avisos_imss.fch_real ,
            CASE WHEN dbo.avisos_imss.fch_mov >= @fechaAplicaUMA 
                 THEN CASE WHEN dbo.avisos_imss.saldiaint > ROUND(ISNULL((SELECT TOP 1
                                                                                 uma.umaDiario
                                                                          FROM dbo.TblUMA AS uma
                                                                          WHERE uma.fecha <= dbo.avisos_imss.fch_mov
                                                                          ORDER BY uma.fecha DESC),0) * 25,2)
                           THEN ROUND(ISNULL((SELECT TOP 1
                                                     uma.umaDiario
                                              FROM dbo.TblUMA AS uma
                                              WHERE uma.fecha <= dbo.avisos_imss.fch_mov
                                              ORDER BY uma.fecha DESC),0) * 25,2)
                           ELSE ISNULL(dbo.avisos_imss.saldiaint,0)
                      END
                 ELSE ISNULL(avisos_imss.saldiaint, 0)
            END AS saldiaint ,
            avisos_imss.sueldo ,
            empleados.nombre ,
            empleados.ap_paterno ,
            empleados.ap_materno ,
            empleados.afiliacion ,
            empleados.digvera ,
            empleados.curp ,
            empleados.fchalta ,
            empleados.tiposal ,
            llaves.centro ,
            llaves.tiponom ,
            tabulador.actividad ,
            ISNULL(avisos_imss.mot_baja, ' ') AS motivoBaja ,
            centros.nomdepto ,
            empleados.tipo_emp ,
            empleados.jornada ,
            empleados.rfcalfa ,
            empleados.rfcnum ,
            empleados.rfchomo ,
            datosemps.umf ,
            empleados.edonac ,
            empleados.fchnac ,
            empleados.sexo ,
            ISNULL(avisos_imss.clave_baja, 2) AS claveBaja ,
            ' ' AS filler1 ,
            datosemps.domicilio ,
            datosemps.colonia ,
            datosemps.poblacion ,
            avisos_imss.rpu ,
            ' ' AS enviado ,
            ' ' AS filler2 ,
            ISNULL(avisos_imss.sueldoant, avisos_imss.sueldo) AS sueldoAnt ,
            ISNULL(avisos_imss.saldiaintant, avisos_imss.saldiaint) AS saldiaintant ,
            llaves.clase ,
            CASE WHEN dbo.avisos_imss.fechaEnvio IS NULL THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.avisos_imss.fechaEnvio), 4)
                      + RIGHT(100 + MONTH(dbo.avisos_imss.fechaEnvio), 2)
                      + RIGHT(100 + DAY(dbo.avisos_imss.fechaEnvio), 2) + ' '
                      + RIGHT(100 + DATEPART(HH, dbo.avisos_imss.fechaEnvio),
                              2) + ':' + RIGHT(100 + DATEPART(MI,
                                                              dbo.avisos_imss.fechaEnvio),
                                               2) + ':' + RIGHT(100
                                                              + DATEPART(SS,
                                                              dbo.avisos_imss.fechaEnvio),
                                                              2)
            END AS fechaEnvio ,
            dbo.avisos_imss.estatus ,
            dbo.avisos_imss.lote ,
            CASE WHEN dbo.avisos_imss.fechaConfirmacion IS NULL
                 THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.avisos_imss.fechaConfirmacion), 4)
                      + RIGHT(100 + MONTH(dbo.avisos_imss.fechaConfirmacion),
                              2) + RIGHT(100
                                         + DAY(dbo.avisos_imss.fechaConfirmacion),
                                         2) + ' ' + RIGHT(100 + DATEPART(HH,
                                                              dbo.avisos_imss.fechaConfirmacion),
                                                          2) + ':' + RIGHT(100
                                                              + DATEPART(MI,
                                                              dbo.avisos_imss.fechaConfirmacion),
                                                              2) + ':'
                      + RIGHT(100 + DATEPART(SS,
                                             dbo.avisos_imss.fechaConfirmacion),
                              2)
            END AS fechaConfirmacion ,
            dbo.deducciones.dias AS diasIncapacidad
    FROM    dbo.avisos_imss
            LEFT JOIN dbo.empleados ON ( dbo.avisos_imss.Empresa = dbo.empleados.Empresa )
                                       AND ( dbo.avisos_imss.Codigo = dbo.empleados.Codigo )
            LEFT JOIN dbo.llaves ON ( dbo.avisos_imss.Empresa = dbo.llaves.Empresa )
                                    AND ( dbo.avisos_imss.Codigo = dbo.llaves.Codigo )
            LEFT JOIN dbo.centros ON ( dbo.avisos_imss.Empresa = dbo.centros.Empresa )
                                     AND ( dbo.llaves.Centro = dbo.centros.centro )
            LEFT JOIN dbo.tabulador ON ( dbo.avisos_imss.Empresa = dbo.tabulador.Empresa )
                                       AND ( dbo.llaves.Ocupacion = dbo.tabulador.Ocupacion )
            LEFT JOIN dbo.datosemps ON ( dbo.avisos_imss.Empresa = dbo.datosemps.Empresa )
                                       AND ( dbo.avisos_imss.codigo = dbo.datosemps.Codigo )
            LEFT JOIN dbo.deducciones ON ( dbo.avisos_imss.empresa = dbo.deducciones.empresa
                                           AND dbo.avisos_imss.codigo = dbo.deducciones.codigo
                                           AND dbo.avisos_imss.fch_mov >= dbo.deducciones.fchinicio
                                           AND dbo.avisos_imss.fch_mov <= dbo.deducciones.fchtermino
                                           AND dbo.deducciones.num_conc >= 109
                                           AND dbo.deducciones.num_conc <= 111
                                         )
    WHERE   dbo.avisos_imss.empresa = @empresa
            AND CASE WHEN avisos_imss.mov = 'RI' THEN 'A'
                     WHEN dbo.avisos_imss.mov = 'MS' THEN 'C'
                     ELSE dbo.avisos_imss.mov
                END = @tipoAviso
            AND dbo.avisos_imss.ayo_operacion = @ayo
            AND CASE WHEN @mes = 13 THEN 1
                     ELSE dbo.avisos_imss.mes_operacion
                END = CASE WHEN @mes = 13 THEN 1
                           ELSE @mes
                      END
            AND dbo.Llaves.tiponom IN ( SELECT  tiponom
                                        FROM    @tblNomina )
            AND dbo.empleados.cotiza_imss = 'S'
    ORDER BY CASE WHEN dbo.avisos_imss.fechaEnvio IS NULL THEN '29991231'
                  ELSE RIGHT(10000 + YEAR(dbo.avisos_imss.fechaEnvio), 4)
                       + RIGHT(100 + MONTH(dbo.avisos_imss.fechaEnvio), 2)
                       + RIGHT(100 + DAY(dbo.avisos_imss.fechaEnvio), 2) + ' '
                       + RIGHT(100 + DATEPART(HH, dbo.avisos_imss.fechaEnvio),
                               2) + ':' + RIGHT(100 + DATEPART(MI,
                                                              dbo.avisos_imss.fechaEnvio),
                                                2) + ':' + RIGHT(100
                                                              + DATEPART(SS,
                                                              dbo.avisos_imss.fechaEnvio),
                                                              2)
             END DESC ,
            CASE @ordenadoPor
              WHEN 1
              THEN STR(dbo.avisos_imss.codigo) + RIGHT(10000
                                                       + YEAR(dbo.avisos_imss.fch_mov),
                                                       4) + RIGHT(100
                                                              + MONTH(dbo.avisos_imss.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.avisos_imss.fch_mov),
                                                              2)
              WHEN 2
              THEN dbo.empleados.ap_paterno + dbo.empleados.ap_materno
                   + dbo.empleados.nombre + RIGHT(10000
                                                  + YEAR(dbo.avisos_imss.fch_mov),
                                                  4) + RIGHT(100
                                                             + MONTH(dbo.avisos_imss.fch_mov),
                                                             2) + RIGHT(100
                                                              + DAY(dbo.avisos_imss.fch_mov),
                                                              2)
              WHEN 3
              THEN RIGHT(10000 + YEAR(dbo.avisos_imss.fch_mov), 4) + RIGHT(100
                                                              + MONTH(dbo.avisos_imss.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.avisos_imss.fch_mov),
                                                              2)
                   + STR(dbo.avisos_imss.codigo)
              WHEN 4
              THEN RIGHT(10000 + YEAR(dbo.avisos_imss.fch_mov), 4) + RIGHT(100
                                                              + MONTH(dbo.avisos_imss.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.avisos_imss.fch_mov),
                                                              2)
                   + STR(dbo.avisos_imss.codigo)
              WHEN 5
              THEN dbo.Llaves.centro + STR(dbo.avisos_imss.codigo)
                   + RIGHT(10000 + YEAR(dbo.avisos_imss.fch_mov), 4)
                   + RIGHT(100 + MONTH(dbo.avisos_imss.fch_mov), 2)
                   + RIGHT(100 + DAY(dbo.avisos_imss.fch_mov), 2)             --ELSE dbo.avisos_imss.codigo
              WHEN 6
              THEN dbo.Llaves.centro + dbo.empleados.ap_paterno
                   + dbo.empleados.ap_materno + dbo.empleados.nombre
                   + RIGHT(10000 + YEAR(dbo.avisos_imss.fch_mov), 4)
                   + RIGHT(100 + MONTH(dbo.avisos_imss.fch_mov), 2)
                   + RIGHT(100 + DAY(dbo.avisos_imss.fch_mov), 2)
              ELSE STR(dbo.avisos_imss.codigo) + RIGHT(10000
                                                       + YEAR(dbo.avisos_imss.fch_mov),
                                                       4) + RIGHT(100
                                                              + MONTH(dbo.avisos_imss.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.avisos_imss.fch_mov),
                                                              2)
            END ,
            CASE WHEN @mes = 13
                 THEN CONVERT(INT, RIGHT(YEAR(dbo.avisos_imss.fch_mov), 4)
                      + RIGHT(100 + MONTH(dbo.avisos_imss.fch_mov), 2)
                      + RIGHT(100 + DAY(dbo.avisos_imss.fch_mov), 2))
                 ELSE dbo.avisos_imss.codigo
            END ,
            CASE WHEN @mes = 13 THEN dbo.avisos_imss.codigo
                 ELSE CONVERT(INT, RIGHT(YEAR(dbo.avisos_imss.fch_mov), 4)
                      + RIGHT(100 + MONTH(dbo.avisos_imss.fch_mov), 2)
                      + RIGHT(100 + DAY(dbo.avisos_imss.fch_mov), 2))
            END
GO

IF OBJECT_ID('dbo.ObtieneAvisoImssRpu') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneAvisoImssRpu
GO
CREATE PROCEDURE dbo.ObtieneAvisoImssRpu
    @empresa INT ,
    @ayo INT ,
    @mes INT
AS 
    SET NOCOUNT ON

    DECLARE @zonaGeografica CHAR(1)
    DECLARE @fechaAplicaUMA DATETIME
    SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
    
    SELECT @zonaGeografica = dbo.empresas.zona_geografica
    FROM dbo.empresas
    WHERE dbo.empresas.empresa = @empresa

    SELECT  rpu_trabajador.codigo ,
            rpu_trabajador.folio ,
            rpu_trabajador.fch_mov ,
            rpu_trabajador.mov ,
            '' AS fch_real ,
            CASE WHEN dbo.rpu_trabajador.fch_mov >= @fechaAplicaUMA 
                 THEN CASE WHEN dbo.empleados.saldiaint > ROUND(ISNULL((SELECT TOP 1
                                                                                 uma.umaDiario
                                                                        FROM dbo.TblUMA AS uma
                                                                        WHERE uma.fecha <= dbo.rpu_trabajador.fch_mov
                                                                        ORDER BY uma.fecha DESC),0) * 25,2)
                           THEN ROUND(ISNULL((SELECT TOP 1
                                                     uma.umaDiario
                                              FROM dbo.TblUMA AS uma
                                              WHERE uma.fecha <= dbo.rpu_trabajador.fch_mov
                                              ORDER BY uma.fecha DESC),0) * 25,2)
                           ELSE ISNULL(dbo.empleados.saldiaint,0)
                      END
                 ELSE ISNULL(dbo.empleados.saldiaint, 0)
            END AS saldiaint ,
            empleados.sueldo ,
            empleados.nombre ,
            empleados.ap_paterno ,
            empleados.ap_materno ,
            empleados.afiliacion ,
            empleados.digvera ,
            empleados.curp ,
            empleados.fchalta ,
            --empleados.sueldo ,
            --empleados.saldiaint ,
            empleados.tiposal ,
            llaves.centro ,
            llaves.tiponom ,
            tabulador.actividad ,
            'CAMBIO DE MUNICIPIO' AS motivoBaja ,
            centros.nomdepto ,
            empleados.tipo_emp ,
            empleados.jornada ,
            empleados.rfcalfa ,
            empleados.rfcnum ,
            empleados.rfchomo ,
            datosemps.umf ,
            empleados.edonac ,
            empleados.fchnac ,
            empleados.sexo ,
            ' ' AS claveBaja ,
            ' ' AS filler1 ,
            datosemps.domicilio ,
            datosemps.colonia ,
            datosemps.poblacion ,
            rpu_trabajador.rpu ,
            rpu_trabajador.enviado ,
            ' ' AS filler2 ,
            0 AS sueldoant ,
            0 AS saldiaintant ,
            llaves.clase ,
            CASE WHEN dbo.rpu_trabajador.fechaEnvio IS NULL THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.rpu_trabajador.fechaEnvio), 4)
                      + RIGHT(100 + MONTH(dbo.rpu_trabajador.fechaEnvio), 2)
                      + RIGHT(100 + DAY(dbo.rpu_trabajador.fechaEnvio), 2) + ' '
                      + RIGHT(100 + DATEPART(HH, dbo.rpu_trabajador.fechaEnvio),
                              2) + ':' + RIGHT(100 + DATEPART(MI,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                               2) + ':' + RIGHT(100
                                                              + DATEPART(SS,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                                              2)
            END AS fechaEnvio ,
            dbo.rpu_trabajador.estatus ,
            dbo.rpu_trabajador.lote ,
            CASE WHEN dbo.rpu_trabajador.fechaConfirmacion IS NULL
                 THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.rpu_trabajador.fechaConfirmacion), 4)
                      + RIGHT(100 + MONTH(dbo.rpu_trabajador.fechaConfirmacion),
                              2) + RIGHT(100
                                         + DAY(dbo.rpu_trabajador.fechaConfirmacion),
                                         2) + ' ' + RIGHT(100 + DATEPART(HH,
                                                              dbo.rpu_trabajador.fechaConfirmacion),
                                                          2) + ':' + RIGHT(100
                                                              + DATEPART(MI,
                                                              dbo.rpu_trabajador.fechaConfirmacion),
                                                              2) + ':'
                      + RIGHT(100 + DATEPART(SS,
                                             dbo.rpu_trabajador.fechaConfirmacion),
                              2)
            END AS fechaConfirmacion ,
            dbo.deducciones.dias AS diasIncapacidad ,
            'R' AS origen,
            ISNULL((SELECT TOP 1 dbo.salarios_minimos.zona_a
                    FROM dbo.salarios_minimos
                    WHERE dbo.salarios_minimos.fecha_ini <= dbo.rpu_trabajador.fch_mov
                          AND dbo.salarios_minimos.fecha_fin >= dbo.rpu_trabajador.fch_mov), 0) AS salarioMinimoDF,
            ISNULL((SELECT TOP 1 CASE @zonaGeografica WHEN 'A' THEN dbo.salarios_minimos.zona_a
                                                      WHEN 'B' THEN dbo.salarios_minimos.zona_b
                                                      ELSE dbo.salarios_minimos.zona_c
                                 END
                    FROM dbo.salarios_minimos
                    WHERE dbo.salarios_minimos.fecha_ini <= dbo.rpu_trabajador.fch_mov
                          AND dbo.salarios_minimos.fecha_fin >= dbo.rpu_trabajador.fch_mov), 0) AS salarioMinimoRegion,
            dbo.datosemps.email,
            ISNULL((SELECT TOP 1
                           uma.umaDiario
                    FROM dbo.TblUMA AS uma
                    WHERE uma.fecha <= dbo.rpu_trabajador.fch_mov
                    ORDER BY uma.fecha DESC),0) AS umaDiario,
            ISNULL(dbo.supervisores.nombre, '') AS nombreSupervisor
    FROM    dbo.rpu_trabajador
            LEFT JOIN empleados ON ( rpu_trabajador.empresa = empleados.empresa )
                                   AND ( rpu_trabajador.Codigo = empleados.Codigo )
            LEFT JOIN llaves ON ( rpu_trabajador.empresa = llaves.empresa )
                                AND ( rpu_trabajador.Codigo = llaves.Codigo )
            LEFT JOIN centros ON ( rpu_trabajador.Empresa = centros.empresa )
                                 AND ( llaves.Centro = centros.centro )
            LEFT JOIN tabulador ON ( rpu_trabajador.empresa = tabulador.empresa )
                                   AND ( llaves.Ocupacion = tabulador.Ocupacion )
            LEFT JOIN datosemps ON ( rpu_trabajador.empresa = datosemps.empresa )
                                   AND ( rpu_trabajador.codigo = datosemps.Codigo )
            LEFT JOIN dbo.deducciones ON ( dbo.rpu_trabajador.empresa = dbo.deducciones.empresa
                                           AND dbo.rpu_trabajador.codigo = dbo.deducciones.codigo
                                           AND dbo.rpu_trabajador.fch_mov >= dbo.deducciones.fchinicio
                                           AND dbo.rpu_trabajador.fch_mov <= dbo.deducciones.fchtermino
                                           AND dbo.deducciones.num_conc >= 109
                                           AND dbo.deducciones.num_conc <= 111
                                         )
            LEFT JOIN dbo.supervisores ON dbo.llaves.Empresa = dbo.supervisores.empresa
                                          AND dbo.llaves.supervisor = dbo.supervisores.supervisor
    WHERE   dbo.rpu_trabajador.empresa = @empresa
            AND YEAR(dbo.rpu_trabajador.fch_mov) = @ayo
            AND CASE WHEN @mes = 13 THEN 1
                     ELSE MONTH(dbo.rpu_trabajador.fch_mov)
                END = CASE WHEN @mes = 13 THEN 1
                           ELSE @mes
                      END
    ORDER BY CASE WHEN @mes = 13
                  THEN CONVERT(INT, RIGHT(YEAR(dbo.rpu_trabajador.fch_mov), 4)
                       + RIGHT(100 + MONTH(dbo.rpu_trabajador.fch_mov), 2)
                       + RIGHT(100 + DAY(dbo.rpu_trabajador.fch_mov), 2))
                  ELSE dbo.rpu_trabajador.codigo
             END ,
            CASE WHEN @mes = 13 THEN dbo.rpu_trabajador.codigo
                 ELSE CONVERT(INT, RIGHT(YEAR(dbo.rpu_trabajador.fch_mov), 4)
                      + RIGHT(100 + MONTH(dbo.rpu_trabajador.fch_mov), 2)
                      + RIGHT(100 + DAY(dbo.rpu_trabajador.fch_mov), 2))
            END
GO

IF OBJECT_ID('dbo.ObtieneAvisoImssRpuReporte') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneAvisoImssRpuReporte
GO
CREATE PROCEDURE dbo.ObtieneAvisoImssRpuReporte
    @empresa INT ,
    @ayo INT ,
    @mes INT ,
    @nomina VARCHAR(50) ,
    @tipoAviso VARCHAR(1),
    @ordenadoPor INT
AS 
    SET NOCOUNT ON

    DECLARE @tblNomina TABLE ( tiponom INT )
    DECLARE @ciclo INT
    DECLARE @fechaAplicaUMA DATETIME
    SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')

    SET @ciclo = 2

    IF @nomina = '()' 
        BEGIN
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 1 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 2 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 3 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 4 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 5 )
            INSERT  @tblNomina
                    ( tiponom )
            VALUES  ( 6 )
        END
    ELSE 
        BEGIN
            WHILE @ciclo < LEN(@nomina) 
                BEGIN
                    INSERT  @tblNomina
                            ( tiponom )
                    VALUES  ( SUBSTRING(@nomina, @ciclo, 1)  -- tiponom - int
                              )
                    SET @ciclo = @ciclo + 2
                END
        END

    SELECT  rpu_trabajador.codigo ,
            rpu_trabajador.folio ,
            rpu_trabajador.fch_mov ,
            rpu_trabajador.mov ,
            '' AS fch_real ,
            CASE WHEN dbo.rpu_trabajador.fch_mov >= @fechaAplicaUMA 
                 THEN CASE WHEN dbo.empleados.saldiaint > ROUND(ISNULL((SELECT TOP 1
                                                                                uma.umaDiario
                                                                         FROM dbo.TblUMA AS uma
                                                                         WHERE uma.fecha <= dbo.rpu_trabajador.fch_mov
                                                                         ORDER BY uma.fecha DESC),0) * 25,2)
                           THEN ROUND(ISNULL((SELECT TOP 1
                                                     uma.umaDiario
                                              FROM dbo.TblUMA AS uma
                                              WHERE uma.fecha <= dbo.rpu_trabajador.fch_mov
                                              ORDER BY uma.fecha DESC),0) * 25,2)
                           ELSE ISNULL(dbo.empleados.saldiaint,0)
                      END
                 ELSE ISNULL(dbo.empleados.saldiaint, 0)
            END AS saldiaint ,
            empleados.sueldo ,
            empleados.nombre ,
            empleados.ap_paterno ,
            empleados.ap_materno ,
            empleados.afiliacion ,
            empleados.digvera ,
            empleados.curp ,
            empleados.fchalta ,
            empleados.tiposal ,
            llaves.centro ,
            llaves.tiponom ,
            tabulador.actividad ,
            'CAMBIO DE MUNICIPIO' AS motivoBaja ,
            centros.nomdepto ,
            empleados.tipo_emp ,
            empleados.jornada ,
            empleados.rfcalfa ,
            empleados.rfcnum ,
            empleados.rfchomo ,
            datosemps.umf ,
            empleados.edonac ,
            empleados.fchnac ,
            empleados.sexo ,
            ' ' AS claveBaja ,
            ' ' AS filler1 ,
            datosemps.domicilio ,
            datosemps.colonia ,
            datosemps.poblacion ,
            rpu_trabajador.rpu ,
            rpu_trabajador.enviado ,
            ' ' AS filler2 ,
            0 AS sueldoant ,
            0 AS saldiaintant ,
            llaves.clase ,
            CASE WHEN dbo.rpu_trabajador.fechaEnvio IS NULL THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.rpu_trabajador.fechaEnvio), 4)
                      + RIGHT(100 + MONTH(dbo.rpu_trabajador.fechaEnvio), 2)
                      + RIGHT(100 + DAY(dbo.rpu_trabajador.fechaEnvio), 2)
                      + ' ' + RIGHT(100 + DATEPART(HH,
                                                   dbo.rpu_trabajador.fechaEnvio),
                                    2) + ':' + RIGHT(100 + DATEPART(MI,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                                     2) + ':' + RIGHT(100
                                                              + DATEPART(SS,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                                              2)
            END AS fechaEnvio ,
            dbo.rpu_trabajador.estatus ,
            dbo.rpu_trabajador.lote ,
            CASE WHEN dbo.rpu_trabajador.fechaConfirmacion IS NULL
                 THEN '29991231'
                 ELSE RIGHT(10000 + YEAR(dbo.rpu_trabajador.fechaConfirmacion),
                            4) + RIGHT(100
                                       + MONTH(dbo.rpu_trabajador.fechaConfirmacion),
                                       2) + RIGHT(100
                                                  + DAY(dbo.rpu_trabajador.fechaConfirmacion),
                                                  2) + ' ' + RIGHT(100
                                                              + DATEPART(HH,
                                                              dbo.rpu_trabajador.fechaConfirmacion),
                                                              2) + ':'
                      + RIGHT(100 + DATEPART(MI,
                                             dbo.rpu_trabajador.fechaConfirmacion),
                              2) + ':' + RIGHT(100 + DATEPART(SS,
                                                              dbo.rpu_trabajador.fechaConfirmacion),
                                               2)
            END AS fechaConfirmacion ,
            dbo.deducciones.dias AS diasIncapacidad
    FROM    rpu_trabajador
            LEFT JOIN empleados ON ( rpu_trabajador.empresa = empleados.empresa )
                                   AND ( rpu_trabajador.Codigo = empleados.Codigo )
            LEFT JOIN llaves ON ( rpu_trabajador.empresa = llaves.empresa )
                                AND ( rpu_trabajador.Codigo = llaves.Codigo )
            LEFT JOIN centros ON ( rpu_trabajador.Empresa = centros.empresa )
                                 AND ( llaves.Centro = centros.centro )
            LEFT JOIN tabulador ON ( rpu_trabajador.empresa = tabulador.empresa )
                                   AND ( llaves.Ocupacion = tabulador.Ocupacion )
            LEFT JOIN datosemps ON ( rpu_trabajador.empresa = datosemps.empresa )
                                   AND ( rpu_trabajador.codigo = datosemps.Codigo )
            LEFT JOIN dbo.deducciones ON ( dbo.rpu_trabajador.empresa = dbo.deducciones.empresa
                                           AND dbo.rpu_trabajador.codigo = dbo.deducciones.codigo
                                           AND dbo.rpu_trabajador.fch_mov >= dbo.deducciones.fchinicio
                                           AND dbo.rpu_trabajador.fch_mov <= dbo.deducciones.fchtermino
                                           AND dbo.deducciones.num_conc >= 109
                                           AND dbo.deducciones.num_conc <= 111
                                         )
    WHERE   dbo.rpu_trabajador.empresa = @empresa
            AND dbo.rpu_trabajador.mov = @tipoAviso
            AND YEAR(dbo.rpu_trabajador.fch_mov) = @ayo
            AND CASE WHEN @mes = 13 THEN 1
                     ELSE MONTH(dbo.rpu_trabajador.fch_mov)
                END = CASE WHEN @mes = 13 THEN 1
                           ELSE @mes
                      END
            AND dbo.Llaves.tiponom IN ( SELECT  tiponom
                                        FROM    @tblNomina )
            AND dbo.empleados.cotiza_imss = 'S'
    ORDER BY CASE WHEN dbo.rpu_trabajador.fechaEnvio IS NULL THEN '29991231'
                  ELSE RIGHT(10000 + YEAR(dbo.rpu_trabajador.fechaEnvio), 4)
                       + RIGHT(100 + MONTH(dbo.rpu_trabajador.fechaEnvio), 2)
                       + RIGHT(100 + DAY(dbo.rpu_trabajador.fechaEnvio), 2)
                       + ' ' + RIGHT(100 + DATEPART(HH,
                                                    dbo.rpu_trabajador.fechaEnvio),
                                     2) + ':' + RIGHT(100 + DATEPART(MI,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                                      2) + ':' + RIGHT(100
                                                              + DATEPART(SS,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                                              2)
             END DESC ,
            CASE @ordenadoPor
              WHEN 1
              THEN STR(dbo.rpu_trabajador.codigo) + RIGHT(10000
                                                       + YEAR(dbo.rpu_trabajador.fch_mov),
                                                       4) + RIGHT(100
                                                              + MONTH(dbo.rpu_trabajador.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.rpu_trabajador.fch_mov),
                                                              2)
              WHEN 2
              THEN dbo.empleados.ap_paterno + dbo.empleados.ap_materno
                   + dbo.empleados.nombre + RIGHT(10000
                                                  + YEAR(dbo.rpu_trabajador.fch_mov),
                                                  4) + RIGHT(100
                                                             + MONTH(dbo.rpu_trabajador.fch_mov),
                                                             2) + RIGHT(100
                                                              + DAY(dbo.rpu_trabajador.fch_mov),
                                                              2)
              WHEN 3
              THEN RIGHT(10000 + YEAR(dbo.rpu_trabajador.fch_mov), 4) + RIGHT(100
                                                              + MONTH(dbo.rpu_trabajador.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.rpu_trabajador.fch_mov),
                                                              2)
                   + STR(dbo.rpu_trabajador.codigo)
              WHEN 4
              THEN RIGHT(10000 + YEAR(dbo.rpu_trabajador.fch_mov), 4) + RIGHT(100
                                                              + MONTH(dbo.rpu_trabajador.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.rpu_trabajador.fch_mov),
                                                              2)
                   + STR(dbo.rpu_trabajador.codigo)
              WHEN 5
              THEN dbo.Llaves.centro + STR(dbo.rpu_trabajador.codigo)
                   + RIGHT(10000 + YEAR(dbo.rpu_trabajador.fch_mov), 4)
                   + RIGHT(100 + MONTH(dbo.rpu_trabajador.fch_mov), 2)
                   + RIGHT(100 + DAY(dbo.rpu_trabajador.fch_mov), 2)             
              WHEN 6
              THEN dbo.Llaves.centro + dbo.empleados.ap_paterno
                   + dbo.empleados.ap_materno + dbo.empleados.nombre
                   + RIGHT(10000 + YEAR(dbo.rpu_trabajador.fch_mov), 4)
                   + RIGHT(100 + MONTH(dbo.rpu_trabajador.fch_mov), 2)
                   + RIGHT(100 + DAY(dbo.rpu_trabajador.fch_mov), 2)
              ELSE STR(dbo.rpu_trabajador.codigo) + RIGHT(10000
                                                       + YEAR(dbo.rpu_trabajador.fch_mov),
                                                       4) + RIGHT(100
                                                              + MONTH(dbo.rpu_trabajador.fch_mov),
                                                              2) + RIGHT(100
                                                              + DAY(dbo.rpu_trabajador.fch_mov),
                                                              2)
            END ,
            CASE WHEN @mes = 13
                 THEN CONVERT(INT, RIGHT(YEAR(dbo.rpu_trabajador.fch_mov), 4)
                      + RIGHT(100 + MONTH(dbo.rpu_trabajador.fch_mov), 2)
                      + RIGHT(100 + DAY(dbo.rpu_trabajador.fch_mov), 2))
                 ELSE dbo.rpu_trabajador.codigo
            END ,
            CASE WHEN @mes = 13 THEN dbo.rpu_trabajador.codigo
                 ELSE CONVERT(INT, RIGHT(YEAR(dbo.rpu_trabajador.fch_mov), 4)
                      + RIGHT(100 + MONTH(dbo.rpu_trabajador.fch_mov), 2)
                      + RIGHT(100 + DAY(dbo.rpu_trabajador.fch_mov), 2))
            END
GO

IF OBJECT_ID('dbo.ObtieneAyoAviso') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneAyoAviso
GO

CREATE PROCEDURE dbo.ObtieneAyoAviso
@empresa INT,
@codigo INT

AS 

  SET NOCOUNT ON
  
  SELECT DISTINCT(YEAR(avisos.fch_mov)) AS ayo 
  FROM dbo.avisos_imss AS avisos
  WHERE avisos.codigo = @codigo
        AND avisos.empresa = @empresa
  ORDER BY YEAR(avisos.fch_mov) DESC
GO

IF OBJECT_ID('dbo.ObtieneBitacora') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneBitacora
GO
CREATE PROCEDURE dbo.ObtieneBitacora
@empresa INT,
@codigo INT,
@funcion1 VARCHAR(20),
@funcion2 VARCHAR(20),
@funcion3 VARCHAR(20),
@funcion4 VARCHAR(20),
@funcion5 VARCHAR(20),
@usuario VARCHAR(20),
@sistema CHAR(2),
@fecha DATETIME,
@hora CHAR(10),
@periodo INT

AS
  
  DECLARE @fechaInicio DATETIME
  DECLARE @fechaFin DATETIME
  
  SELECT @fechaInicio = fechaInicio,
         @fechaFin = fechaFin
  FROM [dbo].[ObtieneRangoFecha](@fecha, @periodo)
  
  SELECT b.empresa,
         b.fecha,
         b.hora,
         b.consecutivo,
         b.funcion,
         b.codigo,
         b.opcion,
         b.opcion2,
         b.opcion3,
         b.usuario,
         b.clave,
         b.regpat,
         b.sistema,
         CASE b.funcion WHEN 'B' THEN 'Variable'
                        WHEN 'C' THEN 'Auditoria'
                        WHEN 'D' THEN 'Captura Individual'
                        WHEN 'M' THEN 'Aumento Masivo'
                        WHEN 'N' THEN 'Enlace Nmina'
                        ELSE 'No Identificado'
         END AS origen,
         @fechaInicio AS fechaInicio,
         @fechaFin AS fechaFin
  FROM dbo.bitacora AS b
  WHERE CASE WHEN @empresa = 0 THEN 0 ELSE b.empresa END = @empresa
        -- @codigo = -1 Saca todos los registros
        -- @codigo = 0 Saca todos los registros con codigo mayor a 0
        -- @codigo = a un codigo Saca todos los registros de ese codigo
        AND b.codigo >= CASE WHEN @codigo = -1 THEN 0
                 WHEN @codigo = 0 THEN 1
                 ELSE @codigo END 
        AND b.codigo <= CASE WHEN @codigo = -1 THEN 99999999
                             WHEN @codigo = 0 THEN 99999999
                             ELSE @codigo END
                 
        AND (CASE WHEN @funcion1 = '' THEN '@' ELSE LTRIM(RTRIM(b.funcion)) END = LTRIM(RTRIM(@funcion1))
             OR CASE WHEN @funcion2 = '' THEN '@' ELSE LTRIM(RTRIM(b.funcion)) END = LTRIM(RTRIM(@funcion2))
             OR CASE WHEN @funcion3 = '' THEN '@' ELSE LTRIM(RTRIM(b.funcion)) END = LTRIM(RTRIM(@funcion3))
             OR CASE WHEN @funcion4 = '' THEN '@' ELSE LTRIM(RTRIM(b.funcion)) END = LTRIM(RTRIM(@funcion4))
             OR CASE WHEN @funcion5 = '' THEN '@' ELSE LTRIM(RTRIM(b.funcion)) END = LTRIM(RTRIM(@funcion5)))
        
        AND CASE WHEN @usuario = '' THEN @usuario ELSE LTRIM(RTRIM(b.usuario)) END = LTRIM(RTRIM(@usuario))
        AND CASE WHEN @sistema = '' THEN @sistema ELSE b.sistema END = @sistema
        AND CASE WHEN @hora = '' THEN @hora ELSE b.hora END = @hora
        AND b.fecha >= @fechaInicio
		AND b.fecha <= @fechaFin
  ORDER BY b.fecha DESC,
           b.hora DESC
GO

IF OBJECT_ID('dbo.ObtieneCalendarioDiasEmpleado') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneCalendarioDiasEmpleado
GO
CREATE PROCEDURE dbo.ObtieneCalendarioDiasEmpleado
@empresa INT,
@codigo INT,
@ayo INT

AS 

  SET NOCOUNT ON

  DECLARE @mesAyo INT
  DECLARE @mesNombre VARCHAR(10)
  DECLARE @calendarioIdentity INT
  DECLARE @diaMes INT
  DECLARE @diaNombre VARCHAR(9)
  DECLARE @diaSemana INT
  DECLARE @fechaMes DATETIME
  DECLARE @diasDelMes INT
  DECLARE @fecha DATETIME
  DECLARE @fechaInicio DATETIME
  DECLARE @fechaFin DATETIME
  DECLARE @mesEmpresa INT
  DECLARE @ayoEmpresa INT 
  DECLARE @fechaEmpresa DATETIME
  DECLARE @ff DATETIME

  SELECT @mesEmpresa = e.mes_operacion,
         @ayoEmpresa = e.ayo_operacion
  FROM dbo.empresas AS e
  WHERE e.empresa = @empresa

  SET @fechaEmpresa = CONVERT(DATETIME, LTRIM(STR(@ayoEmpresa)) + RIGHT(100 + @mesEmpresa,2) + '01')
  SELECT @ff = empresa.fechaFin FROM [dbo].[ObtieneRangoFecha](@fechaEmpresa, 7) AS empresa

  SET @fecha = CONVERT(DATETIME, LTRIM(STR(@ayo)) + '0101')
  SELECT @fechaInicio = fechaInicio, @fechaFin = fechaFin FROM [dbo].[ObtieneRangoFecha](@fecha, 11)

  SET @mesAyo = 1

  DECLARE @calendario TABLE (idCalendario INT IDENTITY, ayo INT, mes INT, mesNombre VARCHAR(10))
  DECLARE @calendarioDetalle TABLE (idCalendario INT, 
                                    fecha DATETIME, 
									dia INT, 
									diaNombre VARCHAR(9), 
									diaSemana INT, 
									laborado INT, 
									vacaciones INT, 
									tipoVacaciones VARCHAR(50), 
									observacionVacaciones VARCHAR(100), 
									falta INT, 
									tipoFalta VARCHAR(50), 
									observacionFalta VARCHAR(100), 
									incapacidad INT, 
									tipoIncapacidad VARCHAR(25), 
									numeroIncapacidad VARCHAR(12), 
									observacionIncapacidad VARCHAR(100), 
									avisoImss VARCHAR(2),
									serial INT, 
									--fechaAvisoImss DATETIME,
									--tipoAvisoImss VARCHAR(50), 
									--sueldo NUMERIC(12,2),
									--saldiaint NUMERIC(12,2),
									--origenAvisoImss VARCHAR(50), 
									alta INT,
									sueldoAlta NUMERIC(12,2),
									saldiaintAlta NUMERIC(12,2),
									origenAlta VARCHAR(50),
									serialAlta INT,
									baja INT,
									claveBaja INT,
									motivoBaja VARCHAR(30),
									origenBaja VARCHAR(50), 
									serialBaja INT,
									ms INT,
									sueldoMs NUMERIC(12,2),
									saldiaintMs NUMERIC(12,2),
									origenMs VARCHAR(50),
									serialMs INT,
									diaSiguiente INT,
									ultimoMov VARCHAR(2),
									ultimaFecha DATETIME
									--observacionAvisoImss VARCHAR(100), 
									--observacion VARCHAR(100), 
									--usuario VARCHAR(50)
									)

  WHILE @mesAyo <= 12
    BEGIN
	  SET @mesNombre = CASE @mesAyo WHEN 01 THEN 'Enero'
	                                WHEN 02 THEN 'Febrero'
		                            WHEN 03 THEN 'Marzo'
 								    WHEN 04 THEN 'Abril'
								    WHEN 05 THEN 'Mayo'
								    WHEN 06 THEN 'Junio'
								    WHEN 07 THEN 'Julio'
								    WHEN 08 THEN 'Agosto'
								    WHEN 09 THEN 'Septiembre'
								    WHEN 10 THEN 'Octubre'
								    WHEN 11 THEN 'Noviembre'
								    WHEN 12 THEN 'Diciembre'
							ELSE ''
					   END

	  SET @diasDelMes = CASE @mesAyo WHEN 01 THEN 31
 	                                 WHEN 02 THEN CASE WHEN @ayo % 4 = 0 THEN 29 ELSE 28 END
		  		                     WHEN 03 THEN 31
			  					     WHEN 04 THEN 30
								     WHEN 05 THEN 31
								     WHEN 06 THEN 30
								     WHEN 07 THEN 31
								     WHEN 08 THEN 31
								     WHEN 09 THEN 30
								     WHEN 10 THEN 31
								     WHEN 11 THEN 30
								     WHEN 12 THEN 31
								     ELSE 0
					    END

	  INSERT @calendario (ayo, mes, mesNombre) VALUES (@ayo, @mesAyo, @mesNombre)
	  SELECT @calendarioIdentity = @@IDENTITY

	  SET @diaMes = 1

	  WHILE @diaMes <= @diasDelMes
	    BEGIN
	      SET @fechaMes = CONVERT(DATETIME, RIGHT(@ayo,4) + RIGHT(100 + @mesAyo,2) + RIGHT(100 + @diaMes,2))
          SET @diaSemana = DATEPART(WeekDay,@fechaMes)

          SET @diaNombre = CASE @diaSemana WHEN 1 THEN 'Domingo'
		                                   WHEN 2 THEN 'Lunes'
                                           WHEN 3 THEN 'Martes'
                                           WHEN 4 THEN 'Mircoles'
                                           WHEN 5 THEN 'Jueves'
                                           WHEN 6 THEN 'Viernes'
                                           WHEN 7 THEN 'Sbado'
										   ELSE ''
						   END

	      INSERT @calendarioDetalle (idCalendario, fecha, dia, diaNombre, diaSemana) VALUES (@calendarioIdentity, @fechaMes, @diaMes, @diaNombre, @diaSemana)
	      SET @diaMes = @diaMes + 1
	    END

      SET @mesAyo = @mesAyo + 1
    END

  UPDATE cd
  SET -- Vacaciones
      cd.vacaciones = ISNULL(CASE WHEN v.fecha IS NOT NULL THEN 1 ELSE hv.veces END,0),
	  cd.tipoVacaciones = ISNULL(CASE hv.tipoVacaciones WHEN '' THEN 'Pago en nmina' WHEN 'F' THEN 'Pago finiquito' ELSE hv.tipoVacaciones END,''), 
      cd.observacionVacaciones = CASE WHEN hv.veces > 1 THEN 'Repetida' ELSE '' END,

	  -- Faltas
	  cd.falta = ISNULL(f.veces,0),
	  cd.tipoFalta = ISNULL(f.tipoIncidencia,''),
	  cd.observacionFalta = CASE WHEN d.veces > 1 THEN 'Repetida' ELSE '' END,

	  -- Incapacidades
	  cd.incapacidad = ISNULL(d.veces,0),
	  cd.tipoIncapacidad = ISNULL(d.tipoIncidencia,''),
	  cd.numeroIncapacidad = ISNULL(d.numeroinc,''),
	  cd.observacionIncapacidad = CASE WHEN d.veces > 1 THEN 'Repetida' ELSE '' END,

	  -- Ultimo Aviso IMSS
      cd.avisoImss = ISNULL(av.mov,''),
	  cd.serial = ISNULL(av.serial,0),
	  cd.ultimoMov = ISNULL(u.mov,''),
	  cd.ultimaFecha = ISNULL(CASE WHEN u.fch_mov > i.fchtermino THEN u.fch_mov ELSE i.fchtermino END, @ff),
	  --cd.tipoAvisoImss = ISNULL(CASE a.mov WHEN 'A' THEN 'Alta' WHEN 'RI' THEN 'Reingreso' WHEN 'B' THEN 'Baja' WHEN 'MS' THEN 'Modificacin salario' ELSE a.mov END,''),
	  --cd.sueldo = ISNULL(a.sueldo,0),
	  --cd.saldiaint = ISNULL(a.saldiaint,0),
	  --cd.origenAvisoImss = ISNULL(a.origen,''),
	  --cd.observacionAvisoImss = '',

	  -- Alta
      cd.alta = ISNULL(a.alta,0),
	  cd.sueldoAlta = ISNULL(a.sueldo,0),
	  cd.saldiaintAlta = ISNULL(a.saldiaint,0),
	  cd.origenAlta = ISNULL(a.origen,''),
	  cd.serialAlta = ISNULL(a.serial,0),
	  --cd.observacionAvisoImss = '',

	  -- Baja
	  baja = ISNULL(b.baja,0),
	  claveBaja = ISNULL(b.clave_baja,0),
	  motivoBaja  = ISNULL(b.mot_baja,''),
	  origenBaja  = ISNULL(b.origen,''), 
	  cd.serialBaja = ISNULL(b.serial,0),

	  -- MS
      cd.ms = ISNULL(ms.ms,0),
	  cd.sueldoMs = ISNULL(ms.sueldo,0),
	  cd.saldiaintMs = ISNULL(ms.saldiaint,0),
	  cd.origenMs = ISNULL(ms.origen,''),
	  cd.serialMs = ISNULL(ms.serial,0),

	  --cd.observacion = '',
	  --cd.usuario = '',
	  cd.laborado = 0

  FROM @calendarioDetalle AS cd
       LEFT JOIN (SELECT cd1.fecha,
	                     hv1.marca AS tipoVacaciones,
                         COUNT(*) AS veces
                  FROM dbo.hist_vac AS hv1
	                   INNER JOIN @calendarioDetalle AS cd1 ON cd1.fecha >= hv1.disfrute AND cd1.fecha <= (hv1.disfrute + ISNULL(hv1.dias_disfr,0) + ISNULL(hv1.disf_ant,0) + ISNULL(hv1.descansos,0) + ISNULL(hv1.festivos,0) - 1)
                  WHERE hv1.empresa = @empresa
                        AND hv1.codigo = @codigo
					    AND hv1.marca <> 'A'
                  GROUP BY cd1.fecha,
				           hv1.marca) AS hv ON hv.fecha = cd.fecha

       LEFT JOIN (SELECT cd1.fecha
                  FROM dbo.vacaciones AS v
	                   INNER JOIN @calendarioDetalle AS cd1 ON cd1.fecha >= v.disfrute AND cd1.fecha <= v.fin_disfru
                  WHERE v.empresa = @empresa
                        AND v.codigo = @codigo
						AND v.dias_disfr + v.disf_ant + v.descansos + v.festivos > 0
                  ) AS v ON v.fecha = cd.fecha

       LEFT JOIN (SELECT CASE f.justificar WHEN 'F' THEN 'Falta'
		  			                       WHEN 'P' THEN 'Permiso Sin Goce de Sueldo'
						                   WHEN 'S' THEN 'Suspensin Disciplinaria'
						                   WHEN 'T' THEN 'Paro Tcnico'
						                  ELSE ''
					     END AS tipoIncidencia,
                         cd1.fecha,
                         COUNT(*) AS veces
                  FROM dbo.deducciones AS f
	                   INNER JOIN @calendarioDetalle AS cd1 ON cd1.fecha >= f.fchinicio AND cd1.fecha <= (f.fchinicio + f.dias - 1)
                  WHERE f.empresa = @empresa
                        AND f.codigo = @codigo
					    AND f.num_conc = 108
                  GROUP BY CASE f.justificar WHEN 'F' THEN 'Falta'
		  			                         WHEN 'P' THEN 'Permiso Sin Goce de Sueldo'
						                     WHEN 'S' THEN 'Suspensin Disciplinaria'
						                     WHEN 'T' THEN 'Paro Tcnico'
						                    ELSE ''
					       END,
                           cd1.fecha) AS f ON f.fecha = cd.fecha

       LEFT JOIN (SELECT d.num_conc,
	                     CASE d.num_conc WHEN 109 THEN 'Enfermedad General'
						                  WHEN 110 THEN 'Maternidad'
						                  WHEN 111 THEN 'Riesgo de Trabajo'
										  ELSE ''
					     END AS tipoIncidencia,
					     d.numeroinc, 
                         cd1.fecha,
                         COUNT(*) AS veces
                  FROM dbo.deducciones AS d
	                   INNER JOIN @calendarioDetalle AS cd1 ON cd1.fecha >= d.fchinicio AND cd1.fecha <= (d.fchinicio + d.dias - 1)
                  WHERE d.empresa = @empresa
                        AND d.codigo = @codigo
					    AND d.num_conc >= 109
					    AND d.num_conc <= 111
                  GROUP BY d.num_conc,
	                       CASE d.num_conc WHEN 109 THEN 'Enfermedad General'
							                WHEN 110 THEN 'Maternidad'
							                WHEN 111 THEN 'Riesgo de Trabajo'
							                ELSE ''
						   END,
					       d.numeroinc, 
                           cd1.fecha) AS d ON d.fecha = cd.fecha

	   OUTER APPLY (SELECT TOP 1
	                       av.mov,
						   av.serial
	   --	                 a.sueldo,
	   --                    a.saldiaint,
	   --                    o.descripcion AS origen
	                FROM dbo.avisos_imss AS av
	                     LEFT JOIN dbo.OrigenAvisoImss AS o ON o.origen = av.origen
	                WHERE av.empresa = @empresa
	                      AND av.codigo = @codigo
	                      AND (av.mov = 'A'
	                           OR av.mov = 'RI'
	                           OR av.mov = 'B'
	                           OR av.mov = 'MS'
	                           OR av.mov = 'IM')
	                      AND av.fch_mov = cd.fecha
	                ORDER BY av.serial DESC) AS av

	   OUTER APPLY (SELECT TOP 1
	                       u.mov,
						   u.fch_mov
	                FROM dbo.avisos_imss AS u
	                     LEFT JOIN dbo.OrigenAvisoImss AS o ON o.origen = u.origen
	                WHERE u.empresa = @empresa
	                      AND u.codigo = @codigo
				   ORDER BY u.fch_mov DESC,
				            u.serial DESC) AS u

	   OUTER APPLY (SELECT TOP 1
	                       CASE WHEN i.fchinicio <= @fechaFin AND i.fchtermino >= @fechaFin 
								THEN @fechaFin 
								ELSE i.fchtermino 
						   END AS fchtermino
				    FROM dbo.deducciones AS i
					WHERE i.empresa = @empresa
					      AND i.codigo = @codigo
						  AND i.num_conc >= 108
						  AND i.num_conc <= 111
						  AND CASE WHEN i.fchinicio <= @fechaFin AND i.fchtermino >= @fechaFin 
								   THEN @fechaFin 
								   ELSE i.fchtermino 
						      END <= @fechaFin
				   ORDER BY CASE WHEN i.fchinicio <= @fechaFin AND i.fchtermino >= @fechaFin 
								 THEN @fechaFin 
								 ELSE i.fchtermino 
						    END DESC) AS i

	   OUTER APPLY (SELECT TOP 1
	                       1 AS alta,
	   	                   a.sueldo,
	                       a.saldiaint,
	                       o.descripcion AS origen,
						   a.serial
	                FROM dbo.avisos_imss AS a
	                     LEFT JOIN dbo.OrigenAvisoImss AS o ON o.origen = a.origen
	                WHERE a.empresa = @empresa
	                      AND a.codigo = @codigo
	                      AND (a.mov = 'A' OR a.mov = 'RI')
	                      AND a.fch_mov = cd.fecha
	                ORDER BY a.serial DESC) AS a

	   OUTER APPLY (SELECT TOP 1
	                       1 AS baja,
	   	                   b.clave_baja,
	                       b.mot_baja,
	                       o.descripcion AS origen,
						   b.serial
	                FROM dbo.avisos_imss AS b
	                     LEFT JOIN dbo.OrigenAvisoImss AS o ON o.origen = b.origen
	                WHERE b.empresa = @empresa
	                      AND b.codigo = @codigo
	                      AND b.mov = 'B'
	                      AND b.fch_mov = cd.fecha
	                ORDER BY b.serial DESC) AS b

	   OUTER APPLY (SELECT TOP 1
	                       1 AS ms,
	   	                   ms.sueldo,
	                       ms.saldiaint,
	                       o.descripcion AS origen,
						   ms.serial
	                FROM dbo.avisos_imss AS ms
	                     LEFT JOIN dbo.OrigenAvisoImss AS o ON o.origen = ms.origen
	                WHERE ms.empresa = @empresa
	                      AND ms.codigo = @codigo
	                      AND ms.mov = 'MS'
	                      AND ms.fch_mov = cd.fecha
	                ORDER BY ms.serial DESC) AS ms

  DECLARE @avisoImssAnterior VARCHAR(2)
  DECLARE @laborado INT
  --DECLARE @diaSiguiente INT
  --DECLARE @fechaFF DATETIME

  SET @avisoImssAnterior = ''
  SET @laborado = 0
  --SET @diaSiguiente = 0

  UPDATE cd
  SET @avisoImssAnterior = CASE WHEN cd.avisoImss = '' THEN @avisoImssAnterior ELSE cd.avisoImss END,
      @laborado = CASE WHEN @avisoImssAnterior = '' OR (@avisoImssAnterior = 'B' AND cd.avisoImss = '') THEN 0 ELSE  1 END,
	  @laborado = CASE WHEN cd.vacaciones > 0 AND cd.tipoVacaciones = 'Pago en nmina' THEN 0 ELSE @laborado END,
	  @laborado = CASE WHEN cd.falta > 0 THEN 0 ELSE @laborado END,
	  @laborado = CASE WHEN cd.incapacidad > 0 THEN 0 ELSE @laborado END,
	  diaSiguiente = 
	  
	  CASE WHEN cd.fecha > CASE WHEN @ff > cd.ultimaFecha THEN @ff ELSE cd.ultimaFecha END THEN CASE WHEN cd.ultimomov <> 'B' THEN 1 ELSE 0 END ELSE 0 END,

	  @laborado = CASE WHEN cd.fecha > CASE WHEN @ff > cd.ultimaFecha THEN @ff ELSE cd.ultimaFecha END THEN 0 ELSE @laborado END,
	  cd.laborado = @laborado
	  --cd.tipoAvisoImss = CASE WHEN cd.avisoImss = 'IM' THEN '' ELSE cd.tipoAvisoImss END,
	  --cd.sueldo = CASE WHEN cd.avisoImss = 'IM' THEN 0 ELSE cd.sueldo END,
	  --cd.saldiaint = CASE WHEN cd.avisoImss = 'IM' THEN 0 ELSE cd.saldiaint END,
	  --cd.avisoImss = CASE WHEN cd.avisoImss = 'IM' THEN '' ELSE cd.avisoImss END
  FROM @calendarioDetalle AS cd

  SELECT cd.idCalendario,
         cd.fecha,
		 c.mes,
		 c.mesNombre,
	     cd.dia,
	     cd.diaNombre,
	     cd.diaSemana,
	     cd.laborado,
	     cd.vacaciones,
	     cd.tipoVacaciones,
	     cd.observacionVacaciones,
	     cd.falta,
	     cd.tipoFalta,
	     cd.observacionFalta,
	     cd.incapacidad,
	     cd.tipoIncapacidad,
	     cd.numeroIncapacidad,
	     cd.observacionIncapacidad,
         cd.alta,
	     cd.sueldoAlta,
	     cd.saldiaintAlta,
	     cd.origenAlta,
		 cd.serialAlta,
	     cd.baja,
	     cd.claveBaja,
	     cd.motivoBaja,
	     cd.origenBaja, 
		 cd.serialBaja,
         cd.ms,
	     cd.sueldoMs,
	     cd.saldiaintMs,
	     cd.origenMs,
		 cd.serialMs,
	     cd.avisoImss,
		 cd.serial,
		 cd.ultimoMov,
		 cd.ultimaFecha,
		 cd.diaSiguiente,
	     --cd.tipoAvisoImss,
	     --cd.sueldo,
	     --cd.saldiaint,
	     --cd.origenAvisoImss,
	     --cd.observacionAvisoImss,
	     --cd.observacion,
	     --cd.usuario,
         @fechaInicio AS fechaInicio,
         @fechaFin AS fechaFin
  FROM @calendarioDetalle AS cd
       INNER JOIN @calendario AS c ON c.idCalendario = cd.idCalendario
GO

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneCasosRT' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneCasosRT]
    END
GO


CREATE PROCEDURE [dbo].[ObtieneCasosRT] @empresa INT, @ayo INT
AS 
    SELECT  codigo ,
            tipo ,
            folio ,
            nombre ,
            ap_paterno ,
            ap_materno ,
            caso ,
            ayo_operacion ,
            st1_accidente ,
            st1_trayecto ,
            st1_fecha ,
            st2_accidente ,
            st2_fecha ,
            st3_accidente ,
            st3_valuacion ,
            fechaIncapaciad ,
            diasIncapacidad ,
            numeroIncapacidad ,
            sec_conIncapacidad ,
            ctr_incIncapacidad ,
            tipo_rtIncapacidad,
            cuentaEmpleado,
            cuentaCaso
    FROM    [dbo].[LlenaCasosRT](@empresa, @ayo)
    ORDER BY codigo ,
            caso ,
            tipo
GO

IF OBJECT_ID('dbo.ObtieneCatalogoALSC') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoALSC
GO
CREATE PROCEDURE dbo.ObtieneCatalogoALSC
AS 
    SELECT  catalogo.id ,
            catalogo.clave ,
            catalogo.descripcion
    FROM    dbo.CatalogoALSC AS catalogo
    ORDER BY FLOOR(catalogo.clave)
GO 

IF OBJECT_ID('dbo.ObtieneCatalogoCentroCostos') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoCentroCostos
GO
CREATE PROCEDURE dbo.ObtieneCatalogoCentroCostos
    @companyId INT,
    @costCenter VARCHAR(15),
    @user VARCHAR(50),
    @system VARCHAR(15)
    
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    SET XACT_ABORT ON
    BEGIN TRY

        SELECT centro.centro ,
               centro.nomdepto ,
               LTRIM(RTRIM(centro.centro)) + '.- ' + centro.nomdepto AS centroIntegrado,
               ISNULL(centroPerfil.permiso,0) AS permiso
        FROM dbo.centros AS centro
             LEFT JOIN (SELECT 1 AS permiso, costCenter
                        FROM [dbo].[GetCostCenterByProfile](@user, @costCenter, @companyId, @system)) AS centroPerfil ON LTRIM(RTRIM(centro.centro)) = LTRIM(RTRIM(centroPerfil.costCenter))
        WHERE centro.empresa = @companyId
              AND CASE WHEN @costCenter = '' THEN @costCenter ELSE centro.centro END = @costCenter
        ORDER BY centro.centro

    END TRY
    
    BEGIN CATCH

        DECLARE @ErrorSeverity udtInteger
        DECLARE @ErrorState udtInteger
        DECLARE @ErrorMessage udtStringSize2048

        SET @ErrorSeverity = ERROR_SEVERITY()
        SET @ErrorState = ERROR_STATE()
        SET @ErrorMessage = 'State: ' + LTRIM(RTRIM(STR(@ErrorState)))
            + CHAR(13) + CHAR(10) + 'Severity: '
            + LTRIM(RTRIM(STR(@ErrorSeverity))) + CHAR(13) + CHAR(10)
            + 'Error number:  ' + LTRIM(RTRIM(STR(ERROR_NUMBER()))) + CHAR(13)
            + CHAR(10) + 'Message: ' + ERROR_MESSAGE() + CHAR(13) + CHAR(10)
            + 'Procedure: ' + ERROR_PROCEDURE() + CHAR(13) + CHAR(10)
            + 'Line: ' + LTRIM(RTRIM(STR(ERROR_LINE())))

        RAISERROR ( @ErrorMessage, @ErrorSeverity, @ErrorState )

    END CATCH                    
GO

IF OBJECT_ID('dbo.ObtieneCatalogoClaveEstados') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneCatalogoClaveEstados
GO
CREATE PROCEDURE dbo.ObtieneCatalogoClaveEstados
AS
  
  SET NOCOUNT ON
  
  SELECT idClaveEstado,
         claveEstado,
         pais,
         nombreEstado
  FROM dbo.CatalogoEstadosCFDI
  ORDER BY CASE WHEN pais = 'MEX' THEN '' ELSE pais END, claveEstado
GO

IF OBJECT_ID('dbo.ObtieneCatalogoEmpleado') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoEmpleado
GO
CREATE PROCEDURE [dbo].[ObtieneCatalogoEmpleado]
    @empresa NUMERIC(5, 0) ,
    @string VARCHAR(50) ,
    @estatusEmpleado VARCHAR(50) ,
    @user VARCHAR(50)
AS 
    DECLARE @costCenterEmployee VARCHAR(50)
    DECLARE @system VARCHAR(50)
    DECLARE @typePayrollEmployee INT

    SET @costCenterEmployee = ''
    SET @system = 'NO'
    SET @typePayrollEmployee = 0

    SELECT  dbo.empleados.codigo ,
            RTRIM(dbo.empleados.ap_paterno) + ' '
            + RTRIM(dbo.empleados.ap_materno) + ' '
            + RTRIM(dbo.empleados.nombre) AS nombre ,
            dbo.empleados.borrado ,
            dbo.empleados.activo ,
            dbo.Llaves.tiponom
    FROM    dbo.empleados
            INNER JOIN dbo.llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                     AND dbo.empleados.codigo = dbo.Llaves.codigo
    WHERE   dbo.empleados.empresa = @empresa
            AND ( RTRIM(dbo.empleados.ap_paterno) + ' '
                  + RTRIM(dbo.empleados.ap_materno) + ' '
                  + RTRIM(dbo.empleados.nombre) LIKE @string + '%'
                  OR RTRIM(dbo.empleados.ap_paterno)
                  + RTRIM(dbo.empleados.ap_materno)
                  + RTRIM(dbo.empleados.nombre) LIKE '%' + @string + '%'
                )
            --AND RTRIM(dbo.empleados.ap_paterno) + ' '
            --+ RTRIM(dbo.empleados.ap_materno) + ' '
            --+ RTRIM(dbo.empleados.nombre) LIKE @string + '%'
            AND CASE WHEN @estatusEmpleado = '' THEN '1'
                     ELSE dbo.empleados.activo
                END = CASE WHEN @estatusEmpleado = '' THEN '1'
                           ELSE @estatusEmpleado
                      END
            AND dbo.Llaves.centro IN (
            SELECT  costCenter
            FROM    [dbo].[GetCostCenterByProfile](@user, @costCenterEmployee,
                                                   @empresa, @system) )
            AND dbo.Llaves.tiponom IN (
            SELECT  typePayroll
            FROM    [dbo].[GetTypePayrollByProfile](@user,
                                                    @typePayrollEmployee,
                                                    @empresa, @system) )
    ORDER BY dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre
GO

IF OBJECT_ID('dbo.ObtieneCatalogoEntidad') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoEntidad
GO
CREATE PROCEDURE dbo.ObtieneCatalogoEntidad
AS 
    SELECT  dbo.capa_entidad.entidad ,
            dbo.capa_poblacion.poblacion
    FROM    dbo.capa_entidad
            INNER JOIN dbo.capa_poblacion ON dbo.capa_entidad.idEntidad = dbo.capa_poblacion.idEntidad
    ORDER BY dbo.capa_entidad.entidad ,
            dbo.capa_poblacion.poblacion
GO

IF OBJECT_ID('dbo.ObtieneCatalogoOrigen') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoOrigen
GO
CREATE PROCEDURE dbo.ObtieneCatalogoOrigen
AS 
    SELECT  catalogo.id ,
            catalogo.clave ,
            catalogo.descripcion
    FROM    dbo.CatalogoOrigen AS catalogo
    ORDER BY FLOOR(catalogo.clave)
GO 

IF OBJECT_ID('dbo.ObtieneCatalogoOrigenAvisoImss') IS NOT NULL 
    DROP PROCEDURE [dbo].[ObtieneCatalogoOrigenAvisoImss]
GO
CREATE PROCEDURE dbo.ObtieneCatalogoOrigenAvisoImss
AS 
    SELECT  dbo.OrigenAvisoImss.origen ,
            dbo.OrigenAvisoImss.descripcion ,
            dbo.OrigenAvisoImss.funcion ,
            dbo.OrigenAvisoImss.serial ,
            dbo.OrigenAvisoImss.aviso
    FROM    dbo.OrigenAvisoImss
    ORDER BY dbo.OrigenAvisoImss.origen
GO

IF OBJECT_ID('dbo.ObtieneCatalogoRegimenFiscal') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoRegimenFiscal
GO
CREATE PROCEDURE dbo.ObtieneCatalogoRegimenFiscal
AS 
    SELECT  catalogo.idClave ,
            catalogo.descripcion
    FROM    dbo.CatalogoRegimenFiscalEmpleado AS catalogo
    ORDER BY catalogo.idClave
GO

IF OBJECT_ID('dbo.ObtieneCatalogoSalarioMinimo') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneCatalogoSalarioMinimo
GO
CREATE PROCEDURE dbo.ObtieneCatalogoSalarioMinimo
AS
  SET NOCOUNT ON
  
  SELECT sm.fecha_ini,
         sm.zona_a,
         sm.zona_b,
         sm.zona_c,
         sm.fecha_fin
  FROM dbo.salarios_minimos AS sm
  ORDER BY sm.fecha_ini DESC
GO

IF OBJECT_ID('dbo.ObtieneCatalogoTipoContrato') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoTipoContrato
GO
CREATE PROCEDURE dbo.ObtieneCatalogoTipoContrato
AS 
    SELECT  catalogo.idClave ,
            catalogo.descripcion
    FROM    dbo.CatalogoTipoContrato AS catalogo
    ORDER BY catalogo.idClave
GO

IF OBJECT_ID('dbo.ObtieneCatalogoTipoRegimen') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCatalogoTipoRegimen
GO
CREATE PROCEDURE dbo.ObtieneCatalogoTipoRegimen
AS 
    SELECT  catalogo.idClave ,
            catalogo.descripcion
    FROM    dbo.CatalogoRegimenContratacionTrabajador AS catalogo
    ORDER BY catalogo.idClave
GO

IF OBJECT_ID('dbo.ObtieneCentroPorPerfil') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCentroPorPerfil
GO
CREATE PROCEDURE dbo.ObtieneCentroPorPerfil
    @usuario VARCHAR(50) ,
    @sistema VARCHAR(50)
AS 
    SET NOCOUNT ON

    --DECLARE @nomina TABLE
    --    (
    --      empresa INT ,
    --      tipoNomina INT ,
    --      descripcion VARCHAR(70)
    --    )
        
    DECLARE @empresaPerfil TABLE ( empresa INT )    
    DECLARE @centroPerfil TABLE
        (
          empresa INT ,
          centro VARCHAR(15)
        )    
    --DECLARE @centroTemporal TABLE
    --    (
    --      empresa INT ,
    --      centro VARCHAR(15)
    --    )
    DECLARE @stringEmpresa VARCHAR(50)
    DECLARE @counter INT
    DECLARE @block VARCHAR(50)

    SELECT  @stringEmpresa = dbo.perfiles.empresas
    FROM    dbo.perfiles
            INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
    WHERE   dbo.perfil_usuarios.usuario = @usuario
            AND dbo.perfiles.sistema = @sistema

    IF @stringEmpresa = '{}' 
        BEGIN
            INSERT  @empresaPerfil
                    ( empresa 
                    )
                    SELECT  dbo.empresas.empresa
                    FROM    dbo.empresas
                    ORDER BY dbo.empresas.empresa
        END
    ELSE 
        BEGIN
            SET @stringEmpresa = SUBSTRING(@stringEmpresa, 2,
                                           LEN(@stringEmpresa) - 2)
            
            SET @counter = 1
            SET @block = ''
                
            WHILE @counter <= LEN(@stringEmpresa) 
                BEGIN

                    IF SUBSTRING(@stringEmpresa, @counter, 1) <> ','
                        OR @counter = LEN(@stringEmpresa) 
                        SET @block = @block + SUBSTRING(@stringEmpresa,
                                                        @counter, 1)
                 
                    IF SUBSTRING(@stringEmpresa, @counter, 1) = ','
                        OR @counter = LEN(@stringEmpresa) 
                        BEGIN
                            INSERT  @empresaPerfil
                                    ( empresa )
                            VALUES  ( CONVERT(INT, @block) )
                            SET @block = ''
                        END
                                                            
                    SET @counter = @counter + 1
                END
        END

      
    IF NOT EXISTS ( SELECT  dbo.perfiles.idperfil
                    FROM    dbo.perfiles
                            INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
                            INNER JOIN dbo.perfil_centro ON dbo.perfil_usuarios.idperfil = dbo.perfil_centro.idperfil
                    WHERE   dbo.perfil_usuarios.usuario = @usuario
                            AND dbo.perfiles.sistema = @sistema ) 
        BEGIN               
            INSERT  INTO @centroPerfil
                    ( empresa ,
                      centro 
                    )
                    SELECT  dbo.centros.empresa ,
                            dbo.centros.centro
                    FROM    [dbo].[centros]
                            INNER JOIN @empresaPerfil AS empresaPerfil ON dbo.centros.empresa = empresaPerfil.empresa
                    WHERE   RTRIM(LTRIM(dbo.centros.centro)) <> '99999999999997'
                    ORDER BY dbo.centros.empresa ,
                            dbo.centros.centro
        END
    ELSE 
        BEGIN
            INSERT  INTO @centroPerfil
                    ( empresa ,
                      centro 
                    )
                    SELECT  DISTINCT
                            dbo.centros.empresa ,
                            dbo.perfil_centro.centro
                    FROM    dbo.perfiles
                            INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
                            INNER JOIN dbo.perfil_centro ON dbo.perfil_usuarios.idperfil = dbo.perfil_centro.idperfil
                            INNER JOIN dbo.centros ON dbo.perfil_centro.centro = dbo.centros.centro
                    WHERE   dbo.perfil_usuarios.usuario = @usuario
                            AND dbo.perfiles.sistema = @sistema
                            AND RTRIM(LTRIM(dbo.perfil_centro.centro)) <> '99999999999997'
        END
        
    -- Agrega Centro General 
    INSERT  @centroPerfil
            ( empresa ,
              centro 
            )
            SELECT  DISTINCT
                    centroPerfil.empresa ,
                    '               ' -- General
            FROM    @centroPerfil AS centroPerfil
            WHERE   NOT EXISTS ( SELECT DISTINCT
                                        centroPerfil.empresa
                                 FROM   @centroPerfil AS centroPerfil
                                 WHERE  centroPerfil.centro = '               ' )
        

    SELECT  centroPerfil.empresa ,
            dbo.empresas.nombre_empresa ,
            centroPerfil.centro ,
            dbo.centros.nomdepto
    FROM    @centroPerfil AS centroPerfil
            INNER JOIN dbo.empresas ON centroPerfil.empresa = dbo.empresas.empresa
            INNER JOIN dbo.centros ON centroPerfil.empresa = dbo.centros.empresa
                                      AND centroPerfil.centro = dbo.centros.centro
    ORDER BY centroPerfil.empresa ,
            centroPerfil.centro
            
GO

IF OBJECT_ID('dbo.ObtieneCuotaDiariaMarcaFiniquito') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneCuotaDiariaMarcaFiniquito
GO
CREATE PROCEDURE [dbo].[ObtieneCuotaDiariaMarcaFiniquito]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @nmes_ini INTEGER = 0 ,
    @nmes_fin INTEGER = 0 ,
    @nayo_ini INTEGER = 0 ,
    @nayo_fin INTEGER = 0
AS 
    SET NOCOUNT ON

    SELECT  --a.serial ,
            a.mov ,
            --a.fch_mov ,
            --a.fch_real ,
            a.sueldo ,
            --a.saldiaint ,
            --a.clave_baja ,
            --a.mot_baja ,
            --a.sueldoant ,
            --a.saldiaintant ,
            --a.origen ,
            --CASE WHEN @tieneRpu = 'S' THEN a.rpu ELSE NULL END AS rpu ,
            --a.lote ,
            CASE WHEN fa.ayo_operacion IS NOT NULL AND fa.periodo IS NOT NULL THEN STR(fa.ayo_operacion, 4) + '/' + RIGHT(STR(100 + fa.periodo), 2) ELSE CASE WHEN f.codigo IS NOT NULL THEN STR(p.ayo_operacion, 4) + '/' + RIGHT(STR(100 + p.periodo), 2) ELSE '' END END AS periodoFiniquito
            --a.saldiaiv,
            --a.campo_07,
            --a.fechaEnvio,
            --a.estatus,
            --a.fechaConfirmacion,
            --oai.descripcion,
            --p.periodo AS periodoNomina,
            --ll.tiponom AS tipoNomina,
            --Enviar,
            --Enviado,
            --'FIN' AS FIN -- Este campo simpre se debe dejar al ultimo en caso de agregar mas campos jorge Mtz 27/04/2016
    FROM    dbo.avisos_imss AS a
            LEFT JOIN dbo.finiquitos_anual AS fa ON a.mov = 'B'
                                                    AND fa.empresa = a.empresa
                                                    AND fa.codigo = a.codigo
                                                    AND fa.fchbaja = a.fch_mov
            LEFT JOIN dbo.finiquitos AS f ON a.mov = 'B'
                                             AND f.empresa = a.empresa
                                             AND f.codigo = a.codigo
                                             AND f.fchbaja = a.fch_mov
            --LEFT JOIN dbo.OrigenAvisoImss AS oai ON oai.origen = a.origen

			INNER JOIN dbo.Llaves AS ll ON ll.empresa = a.empresa
			                               AND ll.codigo = a.codigo
            LEFT JOIN dbo.Periodos AS p ON p.estatus = 'A'
			                               AND p.empresa = ll.empresa
			                               AND p.tiponom = ll.tiponom
    WHERE   a.empresa = @nempresa
            AND a.codigo = @ncodigo
            AND ( ( a.ayo_operacion = @nayo_ini
                    AND a.mes_operacion = @nmes_ini
                  )
                  OR ( a.ayo_operacion = @nayo_fin
                       AND a.mes_operacion = @nmes_fin
                     )
                )
    ORDER BY a.ayo_operacion ,
            a.mes_operacion ,
            a.serial
GO

IF OBJECT_ID('dbo.ObtieneDatosConstruccion') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneDatosConstruccion
GO
CREATE PROCEDURE dbo.ObtieneDatosConstruccion
@empresa INT,
@fecha DATETIME

AS
  
  SET NOCOUNT ON
  
  DECLARE @fechaInicio1 DATETIME
  DECLARE @fechaFin1 DATETIME
  
  SET @fechaInicio1 = DATEADD(dd,-(DAY(@fecha)-1),@fecha)
  SET @fechaFin1 = DATEADD(dd,-(DAY(DATEADD(mm,1,@fecha))),DATEADD(mm,1,@fecha))
  
  SELECT oe.Obra,
         oo.nombre AS nombreObra,
         oe.codigo,
         e.ap_paterno,
         e.ap_materno,
         e.nombre,
         e.afiliacion,
         e.digvera,
         oe.fecha_i,
         oe.fecha_f
  FROM dbo.Obras_emps AS oe
       INNER JOIN dbo.Obras AS oo ON  oe.Obra = oo.Obra
       LEFT JOIN dbo.empleados AS e ON oe.codigo = e.codigo
                                       AND oe.empresa = e.empresa
  WHERE oe.fecha_i >= @fechaInicio1
        AND oe.fecha_i <= @fechaFin1
  ORDER BY oe.Obra,
           e.ap_paterno,
           e.ap_materno,
           e.nombre
GO

IF OBJECT_ID('dbo.ObtieneDatosEmpleadoRFC') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneDatosEmpleadoRFC
GO
CREATE PROCEDURE dbo.ObtieneDatosEmpleadoRFC
    @empresa INT ,
    @rfc VARCHAR(13)
AS 
    SELECT  empleado.codigo ,
            empleado.afiliacion ,
            empleado.digvera ,
            empleado.ap_paterno ,
            empleado.ap_materno ,
            empleado.nombre
    FROM    dbo.empleados AS empleado
    WHERE   empleado.rfcalfa + empleado.rfcnum + empleado.rfchomo = @rfc
            AND empleado.empresa = @empresa
GO

IF OBJECT_ID('dbo.ObtieneDatosParaRelojChecador') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneDatosParaRelojChecador
GO
CREATE PROCEDURE dbo.ObtieneDatosParaRelojChecador
@empresa INT
, @codigo INT

AS 

  SET NOCOUNT ON

  SELECT pagar_nomina
         , nombre
         , ap_paterno
         , ap_materno
         , sexo
         , ISNULL(pension.tienePension,'N') AS pensiones 
  FROM dbo.empleados 
       LEFT JOIN (SELECT TOP 1 
                         'S' AS tienePension 
                  FROM dbo.pensionalimenticia 
                  WHERE codigo = @codigo
                        AND uso = 'S' 
                        AND empresa = @empresa
                 ) AS pension ON pension.tienePension = 'S'
WHERE empleados.empresa = @empresa
      AND empleados.codigo = @codigo
GO

IF OBJECT_ID('dbo.ObtieneDetalleHorario1') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneDetalleHorario1
GO
CREATE PROCEDURE dbo.ObtieneDetalleHorario1
@empresa INT,
@horario INT

AS 
  
  SET NOCOUNT ON
  
  SELECT dh.dia_Semana,
         dh.nombre_dia,
         dh.entra1,
         dh.entra2,
         dh.sale1,
         dh.sale2,
         dh.minutos,
         dh.pausa,
         dh.descanso,
         dh.factor,
         dh.factor_aus,
         dh.sdoxhor,
         CASE WHEN dh.dia_Semana = 1 THEN dht.totalMinutos ELSE NULL END AS totalMinutos,
         CASE WHEN dh.dia_Semana = 1 THEN dht.totalPausa ELSE NULL END AS totalPausa,
         CASE WHEN dh.dia_Semana = 1 THEN dht.totalMinutos - dht.totalPausa ELSE NULL END AS totalMinutosMenosPausa,
         CASE WHEN dh.dia_Semana = 1 THEN dht.totalMinutos / 60 ELSE NULL END AS horasLaboradas,
         CASE WHEN dh.dia_Semana = 1 THEN dht.totalPausa / 60 ELSE NULL END AS horasPausa,
         CASE WHEN dh.dia_Semana = 1 THEN (dht.totalMinutos - dht.totalPausa) / 60 ELSE NULL END AS totalHorasMenosPausa,
         CASE WHEN dh.dia_Semana = 1 THEN dht.diasLaborados ELSE NULL END AS diasLaborados,
         CASE WHEN dh.dia_Semana = 1 THEN CONVERT(NUMERIC(12,2), ROUND(dht.totalSdoXHor / dht.diasLaborados,2)) ELSE NULL END AS horasPromedio,
         hc.JornadaSAT,
         js.Descripcion,
         hc.jornada,
         hc.semana_red
  FROM dbo.detalle_horarios AS dh
       LEFT JOIN (
                    SELECT SUM(dh.minutos) AS totalMinutos,
                           SUM(dh.pausa) AS totalPausa,
                           SUM(CASE WHEN dh.descanso = 'F' THEN 1 ELSE 0 END) AS diasLaborados,
                           SUM(dh.sdoxhor) AS totalSdoXHor
                    FROM dbo.detalle_horarios AS dh
                    WHERE dh.horario = @horario
                          AND dh.empresa = @empresa
                  ) AS dht ON dh.dia_Semana = 1
       LEFT JOIN dbo.horarios_catalogo AS hc ON dh.horario = hc.horario
                                                 AND dh.empresa = hc.empresa
                                                 AND dh.dia_Semana = 1
       LEFT JOIN dbo.Jornadas_SAT AS js ON hc.JornadaSAT = js.JornadaSAT
                                           AND dh.dia_Semana = 1
  WHERE dh.horario = @horario
        AND dh.empresa = @empresa
GO

/**************************************************************************************************
 * Name          : ObtieneDetalleNominaActivaProcedure
 * Project       : APSI Nomina
 * Description   : Obtiene detalle de impresion de nmina activa
 * Table name    : Funcion LlenaImpresionNomina
 * Return        : tabla con la nomina 
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Viernes, Julio 02, 2010
 **************************************************************************************************/
IF OBJECT_ID('dbo.ObtieneDetalleNominaActivaProcedure') IS NOT NULL
   DROP  PROCEDURE [dbo].[ObtieneDetalleNominaActivaProcedure]
GO
CREATE PROCEDURE [dbo].[ObtieneDetalleNominaActivaProcedure]
    @empresa INT ,
    @tipoNomina INT ,
    @nomina CHAR(3) ,
    @ordenadoPor INT ,
    @procesoId INT ,
    @procesoName VARCHAR(100) ,
    @incluirProvisiones CHAR(1) ,
    @desglosadoPor INT ,
    @esRecibo INT ,
    @ayoEjercicio INT ,
    @saltoPagina CHAR(1) ,
    @proceso VARCHAR(250) ,
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS
    SET NOCOUNT ON

    DECLARE @orden VARCHAR(1000)
    DECLARE @apostrofe CHAR(1)
    DECLARE @centroSeleccionado VARCHAR(500)
    DECLARE @codigoSeleccionado VARCHAR(500)
    DECLARE @whereSinProvisiones VARCHAR(500)
    DECLARE @grupo VARCHAR(500)
    DECLARE @textoGrupo VARCHAR(500)
    DECLARE @porCentro INT
    DECLARE @queFuncion VARCHAR(50)
    DECLARE @saltaPagina VARCHAR(50)
    DECLARE @campoSaltaPagina VARCHAR(50)
    DECLARE @regPatronal CHAR(10)
    --DECLARE @cEmpleadosIsn VARCHAR(1000)
    DECLARE @subsTotal VARCHAR(50)
    
    SET @apostrofe = CHAR(39)
    SET @subsTotal = CASE WHEN @esRecibo = 1 AND
                               EXISTS (SELECT Num_Conc FROM Conceptos WHERE Num_Conc = 36 AND Variable2 = 'MUESTRA' AND Empresa = @empresa)
                          THEN 'ISNULL(ImprimeDetalle.subsTotal,0) as subsTotal,'
                          ELSE '0 as subsTotal,'
                     END
    SET @regPatronal = (SELECT Registro_Patronal FROM Empresas WHERE Empresa = @empresa)
    SET @orden = CASE
                      -- Ordenado por Cdigo
                      WHEN @ordenadoPor & 1 > 0
                      THEN CASE
                                -- Desglosedo detalle = 1
                                WHEN @desglosadoPor & 1 > 0
                                THEN CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                          THEN 'ImprimeDetalle.grupoRecibo'
                                          ELSE 'ImprimeDetalle.codigo'
                                     END + ', ImprimeDetalle.renglon'
                                --THEN 'ImprimeDetalle.codigo, ImprimeDetalle.renglon' + CASE WHEN @esRecibo = 1 THEN ', ImprimeDetalle.grupoRecibo' ELSE '' END
                                -- Deglosado por centro = 2 o Desglosado General = 4
                                WHEN @desglosadoPor & 2 > 0
                                     OR @desglosadoPor & 4 > 0
                                THEN 'ImprimeDetalle.centro, '
                                     + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                            THEN 'ImprimeDetalle.grupoRecibo'
                                            ELSE 'ImprimeDetalle.codigo'
                                       END + ', ImprimeDetalle.renglon'
                                --THEN 'ImprimeDetalle.centro, ImprimeDetalle.codigo, ImprimeDetalle.renglon' + CASE WHEN @esRecibo = 1 THEN ', ImprimeDetalle.grupoRecibo' ELSE '' END
                                ELSE CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                          THEN 'ImprimeDetalle.grupoRecibo'
                                          ELSE 'ImprimeDetalle.codigo'
                                     END + ', ImprimeDetalle.renglon'
                           END

                      -- Ordenado por Nombre
                      WHEN @ordenadoPor & 2 > 0
                      THEN CASE
                                -- Desglosado detalle = 1
                                WHEN @desglosadoPor & 1 > 0
                                THEN 'ImprimeDetalle.nombre, '
                                     + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                            THEN 'ImprimeDetalle.grupoRecibo'
                                            ELSE 'ImprimeDetalle.codigo'
                                       END + ', ImprimeDetalle.renglon'
                                -- Desglosado por centro = 2 o Desglosado General = 4
                                WHEN @desglosadoPor & 2 > 0
                                     OR @desglosadoPor & 4 > 0
                                THEN 'ImprimeDetalle.centro, '
                                     + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                            THEN 'ImprimeDetalle.grupoRecibo'
                                            ELSE 'ImprimeDetalle.codigo'
                                       END + ', ImprimeDetalle.renglon'
                                ELSE 'ImprimeDetalle.codigo, '
                                     + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                            THEN 'ImprimeDetalle.grupoRecibo'
                                            ELSE 'ImprimeDetalle.codigo'
                                       END + ', ImprimeDetalle.renglon'
                           END

                      -- Ordenado por Centro y Nombre
                      WHEN @ordenadoPor & 4 > 0
                      THEN 'ImprimeDetalle.centro, ImprimeDetalle.nombre, '
                           + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                  THEN 'ImprimeDetalle.grupoRecibo'
                                  ELSE 'ImprimeDetalle.codigo'
                             END + ', ImprimeDetalle.renglon'

                      -- Ordenado por Centro y Cdigo
                      WHEN @ordenadoPor & 8 > 0
                      THEN 'ImprimeDetalle.centro, '
                           + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                  THEN 'ImprimeDetalle.grupoRecibo'
                                  ELSE 'ImprimeDetalle.codigo'
                             END + ', ImprimeDetalle.renglon'

                      -- Ordenado por Centro, Supervisor y Nombre
                      WHEN @ordenadoPor & 16 > 0
                      THEN CASE WHEN @regPatronal = 'A341147010' OR @regPatronal = 'A341157810'
                                THEN 'ImprimeDetalle.supervisor, ImprimeDetalle.centro, ImprimeDetalle.nombre, '
                                ELSE 'ImprimeDetalle.centro, ImprimeDetalle.supervisor, ImprimeDetalle.nombre, '
                           END + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                      THEN 'ImprimeDetalle.grupoRecibo'
                                      ELSE 'ImprimeDetalle.codigo'
                                 END + ', ImprimeDetalle.renglon'

                      -- Ordenado por Centro, Supervisor y Cdigo
                      WHEN @ordenadoPor & 32 > 0
                      THEN CASE WHEN @regPatronal = 'A341147010' OR @regPatronal = 'A341157810'
                                THEN 'ImprimeDetalle.supervisor, ImprimeDetalle.centro, '
                                ELSE 'ImprimeDetalle.centro, ImprimeDetalle.supervisor, '
                           END + CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                      THEN 'ImprimeDetalle.grupoRecibo'
                                      ELSE 'ImprimeDetalle.codigo'
                                 END + ', ImprimeDetalle.renglon'

                      --WHEN @ordenadoPor & 64 > 0
                      --THEN 'ImprimeDetalle.detalle, ImprimeDetalle.clase, ImprimeDetalle.codigo, ImprimeDetalle.renglon'
                      --WHEN @ordenadoPor & 128 > 0
                      --THEN 'ImprimeDetalle.detalle, ImprimeDetalle.clase, ImprimeDetalle.nombre, ImprimeDetalle.renglon'
                      ELSE CASE WHEN @esRecibo = 1 OR @esRecibo = 2
                                THEN 'ImprimeDetalle.grupoRecibo'
                                ELSE 'ImprimeDetalle.codigo'
                           END + ', ImprimeDetalle.renglon'
                 END


    SET @textoGrupo = CASE
                      -- Ordenado por Centro y Nombre, Centro y Cdigo
                           WHEN @ordenadoPor & 4 > 0
                                OR @ordenadoPor & 8 > 0
                           THEN 'CASE WHEN RTRIM(ImprimeDetalle.centro) = '
                                + @apostrofe + '99999999999997' + @apostrofe
                                + ' THEN ' + @apostrofe + '' + @apostrofe
                                + ' WHEN RTRIM(ImprimeDetalle.centro) = '
                                + @apostrofe + '99999999999996' + @apostrofe
                                + ' THEN ' + @apostrofe
                                + 'SUMA DEPARTAMENTO(S) SELECCIONADO(S)'
                                + @apostrofe
                                + ' ELSE RTRIM(ImprimeDetalle.centro) + '
                                + @apostrofe + '.- ' + @apostrofe
                                + ' END + CASE WHEN RTRIM(ImprimeDetalle.centro) = '
                                + @apostrofe + '99999999999996' + @apostrofe
                                + ' THEN ' + @apostrofe + '' + @apostrofe
                                + ' ELSE RTRIM(ImprimeDetalle.nombreCentro) END'

                      -- Ordenado por Centro, Supervisor y Nombre, Centro, Supervisor y Cdigo
                           WHEN @ordenadoPor & 16 > 0
                                OR @ordenadoPor & 32 > 0
                           THEN 'CASE WHEN RTRIM(ImprimeDetalle.centro) = '
                                + @apostrofe + '99999999999997' + @apostrofe
                                + ' THEN ' + @apostrofe + '' + @apostrofe
                                + ' ELSE RTRIM(ImprimeDetalle.centro) + '
                                + @apostrofe + '.- ' + @apostrofe
                                + ' END + RTRIM(ImprimeDetalle.nombreCentro) + '
                                + @apostrofe + SPACE(5) + ' SUPERVISOR'
                                + @apostrofe
                                + ' + CASE WHEN LTRIM(STR(ImprimeDetalle.supervisor)) = '
                                + @apostrofe + '999999995' + @apostrofe
                                + ' OR LTRIM(STR(ImprimeDetalle.supervisor)) = '
                                + @apostrofe + '999999996' + @apostrofe
                                + ' THEN ' + @apostrofe + ' TOTAL'
                                + @apostrofe + ' ELSE ' + @apostrofe + ': '
                                + @apostrofe
                                + ' + LTRIM(STR(ImprimeDetalle.supervisor)) + '
                                + @apostrofe + '.- ' + @apostrofe
                                + ' + ImprimeDetalle.nombreSupervisor END'
                           ELSE @apostrofe + '' + @apostrofe
                      END

    SET @textoGrupo = CASE WHEN @desglosadoPor & 2 > 0
                                OR @desglosadoPor & 4 > 0
                           THEN @apostrofe + '' + @apostrofe
                           ELSE @textoGrupo
                      END


    IF @procesoName = 'NominaDetalle'
        OR @procesoName = 'NominaNoOrdinaria'
        OR @procesoName = 'ReciboFondoAhorro'
        BEGIN
         -- Checa los centro de costos seleccionados
            IF ( ( @ordenadoPor & 4 > 0
                   OR @ordenadoPor & 8 > 0
                   OR @ordenadoPor & 16 > 0
                   OR @ordenadoPor & 32 > 0
                 )
                 OR ( ( @ordenadoPor & 1 > 0
                        OR @ordenadoPor & 2 > 0
                      )
                      AND @desglosadoPor = 2
                    )
               )
                BEGIN
                    IF EXISTS ( SELECT  dbo.SeleccionElementos.centro
                                FROM    dbo.SeleccionElementos
                                WHERE   dbo.SeleccionElementos.empresa = @empresa
                                        AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                        AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                        AND dbo.SeleccionElementos.nomina = @nomina
                                        AND dbo.SeleccionElementos.centro > '' )
                        AND @esRecibo = 0
                        BEGIN
                            SET @centroSeleccionado = 'INNER JOIN dbo.SeleccionElementos AS porCentro ON ImprimeDetalle.empresa = porCentro.empresa AND LTRIM(RTRIM(ImprimeDetalle.centro)) = LTRIM(RTRIM(porCentro.centro)) AND ImprimeDetalle.procesoName = porCentro.procesoName AND ImprimeDetalle.nomina = porCentro.nomina '
                            SET @porCentro = 1
                        END
                    ELSE
                        BEGIN
                            SET @centroSeleccionado = ''
                            SET @porCentro = 0
                        END
                END
            ELSE
                BEGIN
                    SET @porCentro = 0
                END


         -- Checa los codigos seleccionados
            IF EXISTS ( SELECT  codigo
                        FROM    dbo.SeleccionElementos
                        WHERE   empresa = @empresa
                                AND procesoName = @procesoName
                                AND codigo > 0
                                AND ( @esRecibo = 1
                                      OR @esRecibo = 2
                                      --OR @esRecibo = 3
                                    ) )
                SET @codigoSeleccionado = 'INNER JOIN dbo.SeleccionElementos AS porCodigo ON ImprimeDetalle.empresa = porCodigo.empresa AND ImprimeDetalle.codigo = porCodigo.codigo AND ImprimeDetalle.procesoName = porCodigo.procesoName AND ImprimeDetalle.nomina = porCodigo.nomina '
            ELSE
                SET @codigoSeleccionado = ''

        END

    SET @campoSaltaPagina = ', ImprimeDetalle.saltarPagina '
    SET @saltaPagina = ''

    IF @esRecibo = 0
        BEGIN
            SET @queFuncion = 'dbo.LlenaImpresionNomina'
            IF @saltoPagina = 'S'
               SET @saltaPagina = ',' + @apostrofe + @saltoPagina + @apostrofe
            ELSE
               SET @saltaPagina = ',' + @apostrofe + 'N' + @apostrofe
        END
    ELSE
        IF @esRecibo = 1
            SET @queFuncion = 'dbo.LlenaImpresionRecibo'
        ELSE
            IF @esRecibo = 2
                SET @queFuncion = 'dbo.LlenaImpresionReciboNoOrdinaria'
            --ELSE
            --    IF @esRecibo = 3 -- Recibo completo (se imprime todos los conceptos)
            --        SET @queFuncion = 'dbo.LlenaImpresionReciboFondoAhorro'

    IF @procesoName = 'NominaDetalle'
        OR @procesoName = 'NominaNoOrdinaria'
        OR @procesoName = 'ReciboFondoAhorro'
        BEGIN

          /*
          DECLARE @camposVacaciones VARCHAR(200)
          DECLARE @joinVacaciones VARCHAR(500)

          SET @camposVacaciones = CASE WHEN @nomina = 'VAC'
                                       THEN ', Vacaciones.Disfrute, Vacaciones.Fin_Disfru, Vacaciones.Fch_Pago, vacaciones.neto '
                                       ELSE ', NULL AS Disfrute, NULL AS Fin_Disfru, NULL AS Fch_Pago, 0 AS neto'
                                  END

          SET @joinVacaciones = CASE WHEN @nomina = 'VAC'
                                     THEN 'LEFT JOIN Vacaciones ON Vacaciones.Codigo = ImprimeDetalle.Codigo AND Vacaciones.Empresa = ImprimeDetalle.Empresa '
                                     ELSE ''
                                END
          */
          
          DECLARE @join VARCHAR(500)
          DECLARE @campoNeto VARCHAR(500)

          SET @join = CASE WHEN (@nomina = 'SEM'
                                OR @nomina = 'DEC'
                                OR @nomina = 'CAT'
                                OR @nomina = 'QNA'
                                OR @nomina = 'MES'
                                OR @nomina = 'ESP') THEN 'LEFT JOIN dbo.nomina_tot AS nominaTot ON       nominaTot.codigo  = ImprimeDetalle.codigo AND        nominaTot.empresa = ImprimeDetalle.Empresa '
                               WHEN @nomina = 'VAC' THEN 'LEFT JOIN dbo.vacaciones              ON       vacaciones.codigo = ImprimeDetalle.codigo AND       vacaciones.empresa = ImprimeDetalle.empresa '
                               WHEN @nomina = 'AGI' THEN 'LEFT JOIN dbo.aguinaldos              ON       aguinaldos.codigo = ImprimeDetalle.codigo AND       aguinaldos.empresa = ImprimeDetalle.empresa '
                               WHEN @nomina = 'PTU' THEN 'LEFT JOIN dbo.ptu                     ON              ptu.codigo = ImprimeDetalle.codigo AND              ptu.empresa = ImprimeDetalle.empresa '
                               WHEN @nomina = 'OTR' THEN 'LEFT JOIN dbo.otranomina              ON       otranomina.codigo = ImprimeDetalle.codigo AND       otranomina.empresa = ImprimeDetalle.empresa '
                               WHEN @nomina = 'FAH' THEN 'LEFT JOIN dbo.fondo_de_ahorros        ON fondo_de_ahorros.codigo = ImprimeDetalle.codigo AND fondo_de_ahorros.empresa = ImprimeDetalle.empresa '
                               WHEN @nomina = 'CAH' THEN 'LEFT JOIN dbo.caja_de_ahorros         ON  caja_de_ahorros.codigo = ImprimeDetalle.codigo AND  caja_de_ahorros.empresa = ImprimeDetalle.empresa '
                               WHEN @nomina = 'VAL' THEN 'LEFT JOIN dbo.despensas               ON        despensas.codigo = ImprimeDetalle.codigo AND        despensas.empresa = ImprimeDetalle.empresa '
                           ELSE ''
                      END
                      
          SET @campoNeto = CASE WHEN (@nomina = 'SEM'
                                     OR @nomina = 'DEC'
                                     OR @nomina = 'CAT'
                                     OR @nomina = 'QNA'
                                     OR @nomina = 'MES'
                                     OR @nomina = 'ESP') THEN ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN        nominaTot.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN        dbo.ImporteEnLetraNomina(nominaTot.neto) ELSE '''' END AS netoEnLetra '
                                WHEN @nomina = 'VAC'     THEN ', Vacaciones.Disfrute, Vacaciones.Fin_Disfru, Vacaciones.Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN       vacaciones.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN       dbo.ImporteEnLetraNomina(vacaciones.neto) ELSE '''' END AS netoEnLetra '
                                WHEN @nomina = 'AGI'     THEN ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN       aguinaldos.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN       dbo.ImporteEnLetraNomina(aguinaldos.neto) ELSE '''' END AS netoEnLetra '
                                WHEN @nomina = 'PTU'     THEN ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN              ptu.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN              dbo.ImporteEnLetraNomina(ptu.neto) ELSE '''' END AS netoEnLetra '
                                WHEN @nomina = 'OTR'     THEN ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN       otranomina.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN       dbo.ImporteEnLetraNomina(otranomina.neto) ELSE '''' END AS netoEnLetra '
                                WHEN @nomina = 'FAH'     THEN ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN fondo_de_ahorros.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN dbo.ImporteEnLetraNomina(fondo_de_ahorros.neto) ELSE '''' END AS netoEnLetra '
                                WHEN @nomina = 'CAH'     THEN ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN  caja_de_ahorros.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN  dbo.ImporteEnLetraNomina(caja_de_ahorros.neto) ELSE '''' END AS netoEnLetra '
                                WHEN @nomina = 'VAL'     THEN ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN        despensas.neto ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN        dbo.ImporteEnLetraNomina(despensas.neto) ELSE '''' END AS netoEnLetra '
                                ELSE                          ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, 0 AS neto, '' AS netoEnLetra '
                           END

            DECLARE @joinDomicilio VARCHAR(500)
            DECLARE @camposDomicilio VARCHAR(900)

            SET @joinDomicilio = 'LEFT JOIN dbo.Parametros_Empresas AS parametroEmpresa ON parametroEmpresa.empresa = ImprimeDetalle.empresa ' 
            SET @camposDomicilio = ', CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.CalleFiscal      ELSE '''' END AS CalleFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.NoExteriorFiscal ELSE '''' END AS NoExteriorFiscal, ' + 
                                   '   CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.NoInteriorFiscal ELSE '''' END AS NoInteriorFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.ColoniaFiscal    ELSE '''' END AS ColoniaFiscal, ' +
                                   '   CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.EstadoFiscal     ELSE '''' END AS EstadoFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.LocalidadFiscal  ELSE '''' END AS LocalidadFiscal, ' +
                                   '   CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.MunicipioFiscal  ELSE '''' END AS MunicipioFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.CPFiscal         ELSE '''' END AS CPFiscal '

            DECLARE @joinEmpleadoAdicional VARCHAR(500)
            DECLARE @camposEmpleadoAdicional VARCHAR(900)
            
            SET @joinEmpleadoAdicional = 'LEFT JOIN dbo.EmpleadoAdicional AS empleadoAdicional ON ImprimeDetalle.Empresa = empleadoAdicional.empresa AND ImprimeDetalle.codigo = empleadoAdicional.codigo ' +
                                         'LEFT JOIN dbo.CatalogoTipoContrato AS catalogoTipoContrato ON empleadoAdicional.tipoContrato = catalogoTipoContrato.idClave ' +
                                         'LEFT JOIN dbo.CatalogoRegimenContratacionTrabajador AS catalogoRegimen ON empleadoAdicional.tipoRegimen = catalogoRegimen.idClave '
            SET @camposEmpleadoAdicional = ', CASE WHEN ImprimeDetalle.renglon = 1 THEN empleadoAdicional.tipoContrato ELSE '''' END AS claveTipoContrato, ' +
                                           '  CASE WHEN ImprimeDetalle.renglon = 1 THEN catalogoTipoContrato.descripcion ELSE '''' END AS descripcionTipoContrato, ' +
                                           '  CASE WHEN ImprimeDetalle.renglon = 1 THEN empleadoAdicional.tipoRegimen ELSE '''' END AS claveTipoRegimen, ' +
                                           '  CASE WHEN ImprimeDetalle.renglon = 1 THEN catalogoRegimen.descripcion ELSE '''' END AS descripcionTipoRegimen ' 

            -- 5 Ago 2021
            -- Para SEAPAL de Jaime, imprimir el campo libre1
            DECLARE @joinclasificacion VARCHAR(500)
            DECLARE @camposclasificacion VARCHAR(100)

            SET @joinclasificacion = 'LEFT JOIN dbo.Clasificacion_Empleados ON Clasificacion_Empleados.Codigo = ImprimeDetalle.Codigo AND Clasificacion_Empleados.Empresa = ImprimeDetalle.Empresa '
            SET @camposclasificacion = ' , Clasificacion_Empleados.Campo_02 '
            --
                                           
            EXECUTE('SELECT ImprimeDetalle.empresa ,
            CASE WHEN ImprimeDetalle.codigo = 999999996 THEN 999999995 ELSE ImprimeDetalle.codigo END AS codigo,
            ImprimeDetalle.codigoId,
            CASE WHEN ImprimeDetalle.codigo = 999999995 THEN ' + @apostrofe + 'ZZX' + @apostrofe + ' + SUBSTRING(CASE WHEN ImprimeDetalle.centro = ' + @apostrofe + '99999999999997 ' + @apostrofe + ' THEN ' + @apostrofe + 'GENERAL' + @apostrofe + ' ELSE ImprimeDetalle.nombreCentro END,1,30)
            WHEN ImprimeDetalle.codigo = 999999996 THEN ' + @apostrofe + 'ZZZ' + @apostrofe + ' + SUBSTRING(CASE WHEN ImprimeDetalle.centro = ' + @apostrofe + '99999999999997 ' + @apostrofe + ' THEN ' + @apostrofe + 'GENERAL' + @apostrofe + ' ELSE ImprimeDetalle.nombreCentro END,1,30)
            ELSE ImprimeDetalle.nombre
            END AS nombre,
            ImprimeDetalle.fechaAlta ,
            ImprimeDetalle.numeroSeguridadSocial ,
            ImprimeDetalle.digitoVerificador ,
            ImprimeDetalle.curp ,
            RTRIM(LTRIM(ImprimeDetalle.centro)) AS centro,
            ImprimeDetalle.nombreCentro ,
            ImprimeDetalle.cuentaBanco ,
            ImprimeDetalle.nombreBanco ,
            ImprimeDetalle.ocupacion ,
            ImprimeDetalle.categoria ,
            ImprimeDetalle.tipoSalario ,
            CASE WHEN ImprimeDetalle.codigo = 999999996 THEN 999 ELSE ImprimeDetalle.renglon END AS renglon,
            ImprimeDetalle.jornada ,
            ImprimeDetalle.sueldoDiario ,
            ImprimeDetalle.salarioBaseCotizacion ,
            ImprimeDetalle.clase ,
            ImprimeDetalle.nombreClase ,
            CASE WHEN ImprimeDetalle.supervisor IS NULL THEN -1 ELSE ImprimeDetalle.supervisor END AS supervisor ,
            ImprimeDetalle.nombreSupervisor ,
            ImprimeDetalle.marcaContraPercepcion ,
            ImprimeDetalle.numeroConceptoPercepcion ,
            ImprimeDetalle.nombreConceptoPercepcion ,
            ImprimeDetalle.importeConceptoPercepcion ,
            ImprimeDetalle.gravablePercepcion ,
            ImprimeDetalle.exentoPercepcion ,
            ImprimeDetalle.saldoPercepcion ,
            ImprimeDetalle.anexoConceptoPercepcion ,
            ImprimeDetalle.marcaContraDeduccion ,
            ImprimeDetalle.numeroConceptoDeduccion ,
            ImprimeDetalle.nombreConceptoDeduccion ,
            ImprimeDetalle.importeConceptoDeduccion ,
            ImprimeDetalle.gravableDeduccion ,
            ImprimeDetalle.exentoDeduccion ,
            ImprimeDetalle.saldoDeduccion ,
            ImprimeDetalle.anexoConceptoDeduccion ,
            ImprimeDetalle.numeroConceptoProvision ,
            ImprimeDetalle.nombreConceptoProvision ,
            ImprimeDetalle.importeConceptoProvision , ' +
            @apostrofe + '' + @apostrofe + ' AS detelle ,
            ImprimeDetalle.empleados ,
            ImprimeDetalle.provisionIMSS ,
            ImprimeDetalle.provisionRCV ,
            ImprimeDetalle.provisionINFONAVIT ,
            ImprimeDetalle.retencionIMSS ,
            ImprimeDetalle.retencionRCV ,
            ImprimeDetalle.retencionINFONAVIT ,
            ImprimeDetalle.empleadosConCuentaBancaria ,
            ImprimeDetalle.empleadosSinCuentaBancaria ,
            ImprimeDetalle.percepcionesConCuentaBancaria ,
            ImprimeDetalle.deduccionesConCuentaBancaria ,
            ImprimeDetalle.percepcionesSinCuentaBancaria ,
            ImprimeDetalle.deduccionesSinCuentaBancaria ,
            ImprimeDetalle.basePorcientoSobreNomina ,
            ImprimeDetalle.porcientoSobreNomina ,
            ROUND(ImprimeDetalle.basePorcientoSobreNomina * ( ImprimeDetalle.porcientoSobreNomina / 100 ), 2) AS impuestoSobreNomina ,
            ImprimeDetalle.fondoAhorroAportacionEmpleado ,
            ImprimeDetalle.fondoAhorroAportacionPatron ,
            ImprimeDetalle.sueldoNetoGeneral ,
            ImprimeDetalle.ejercicio ,
            ImprimeDetalle.diarioOficialDia ,
            ImprimeDetalle.diarioOficialMes ,
            ImprimeDetalle.diarioOficialAyo ,
            ImprimeDetalle.salarioMinimoDF ,
            ImprimeDetalle.salarioMinimoRegion ,
            ImprimeDetalle.eymArt25 ,
            ImprimeDetalle.eymArt106ii ,
            ImprimeDetalle.eymArt107 ,
            ImprimeDetalle.ivArt147 ,
            ImprimeDetalle.cvArt168ii ,
            ImprimeDetalle.baseCalculo ,
            LTRIM(RTRIM(ImprimeDetalle.grupo)) AS grupo , ' +
            @textoGrupo + ' AS textoGrupo ,
            ImprimeDetalle.cuantosRecibos ,
            ImprimeDetalle.numeroRecibo ,
            ImprimeDetalle.recibo ,
            ImprimeDetalle.percepcionesEmpleado ,
            ImprimeDetalle.deduccionesEmpleado ,
            ImprimeDetalle.netoPagarEmpleado ,
            ImprimeDetalle.grupoRecibo ,
            ImprimeDetalle.rfcAlfa ,
            ImprimeDetalle.rfcNum ,
            ImprimeDetalle.rfcHomo ,
            ImprimeDetalle.acumuladoPercepcion ,
            ImprimeDetalle.acumuladoPercepcionGravable ,
            ImprimeDetalle.acumuladoIsr ,
            ImprimeDetalle.acumuladoInfonavit ,
            ImprimeDetalle.acumuladoSar ,
            ImprimeDetalle.acumuladoCv ,
            ImprimeDetalle.email ,
            ImprimeDetalle.fechaAntiguedad ,
            CASE WHEN ImprimeDetalle.centro = ' + @apostrofe + '99999999999997' + @apostrofe + ' AND ImprimeDetalle.renglon = 1 AND ' + @desglosadoPor + ' <> 4 THEN 1
            WHEN ImprimeDetalle.centro = ' + @apostrofe + '99999999999997' + @apostrofe + ' AND ImprimeDetalle.renglon = 1 AND ' + @desglosadoPor + ' = 4 THEN 0
            ELSE NULL
            END AS esTotal ,
            ImprimeDetalle.saltarPagina ,
            CASE WHEN ImprimeDetalle.firma = ''S'' AND ImprimeDetalle.codigo <= 99999999 THEN 1
                 ELSE 0
            END AS firma,
            ImprimeDetalle.mov,
            ImprimeDetalle.foto, ' +
            @subsTotal + '
            ImprimeDetalle.baseISN1,
            ImprimeDetalle.porcientoISN1,
            ImprimeDetalle.importeISN1,
            ImprimeDetalle.empleadosISN1,
            ImprimeDetalle.baseISN2,
            ImprimeDetalle.porcientoISN2,
            ImprimeDetalle.importeISN2,
            ImprimeDetalle.empleadosISN2,
            ImprimeDetalle.imprimirResumen ' +

            @campoNeto + ' ' + 
            @camposDomicilio + ' ' +
            @camposEmpleadoAdicional + 

            @camposclasificacion +
            
            ' FROM dbo.KardexImprimeRecibos AS ImprimeDetalle ' +
            
            @centroSeleccionado + ' ' +
            @codigoSeleccionado +

            @join + ' ' + 
            @joinDomicilio + ' ' +
            @joinEmpleadoAdicional + 

            @joinclasificacion + '

            WHERE ImprimeDetalle.horaProceso = ' + @apostrofe + @horaProceso + @apostrofe + '
                  AND ImprimeDetalle.fechaProceso = ' + @apostrofe + @fechaProceso + @apostrofe + '
                  AND ImprimeDetalle.proceso = ' + @apostrofe + @proceso + @apostrofe + '
                  AND ImprimeDetalle.codigo >= 1 AND ImprimeDetalle.codigo <= 999999999
            AND ImprimeDetalle.procesoName = ' + @apostrofe + @procesoName + @apostrofe + '
            ORDER BY ' + @orden)
        END
GO

IF OBJECT_ID('dbo.ObtieneDiasCotizados') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneDiasCotizados
GO
CREATE PROCEDURE dbo.ObtieneDiasCotizados
    @empresa INT ,
    @codigo INT ,
    @mesNon INT ,
    @mesPar INT ,
    @ayo INT ,
    @toparFaltas CHAR(1) -- Agregar rutina para topar faltas a 7 
AS 
    SET NOCOUNT ON

    DECLARE @fechaInicioMesNon DATETIME
    DECLARE @fechaFinMesNon DATETIME
    DECLARE @fechaInicioMesPar DATETIME
    DECLARE @fechaFinMesPar DATETIME
    DECLARE @fechaFinMes DATETIME
    DECLARE @diasMesNon INT
    DECLARE @diasMesPar INT
    DECLARE @codigoInicio INT
    DECLARE @codigoFin INT
    DECLARE @mesInicialNomina AS CHAR(5)
    DECLARE @mesFinalNomina AS CHAR(5)
    DECLARE @DivisorPercepcionesVariables VARCHAR(30)
    DECLARE @tDiasNomina TABLE
        (
          empresa INT ,
          codigo NUMERIC(8, 0) ,
          diastr FLOAT ,
          faltas FLOAT ,
          incapacidades FLOAT
        )

    SET @codigoInicio = CASE WHEN @codigo = 0 THEN 1
                             ELSE @codigo
                        END
    SET @codigoFin = CASE WHEN @codigo = 0 THEN 99999999
                          ELSE @codigo
                     END
     
    SELECT  @DivisorPercepcionesVariables = dbo.empresas.DivisorPercepcionesVariables
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa

    IF @DivisorPercepcionesVariables = 'DIASNOMINA' 
        BEGIN
            SET @mesInicialNomina = CASE WHEN @mesNon = 01 THEN 'ENE'
                                         WHEN @mesNon = 02 THEN 'FEB'
                                         WHEN @mesNon = 03 THEN 'MAR'
                                         WHEN @mesNon = 04 THEN 'ABR'
                                         WHEN @mesNon = 05 THEN 'MAY'
                                         WHEN @mesNon = 06 THEN 'JUN'
                                         WHEN @mesNon = 07 THEN 'JUL'
                                         WHEN @mesNon = 08 THEN 'AGO'
                                         WHEN @mesNon = 09 THEN 'SEP'
                                         WHEN @mesNon = 10 THEN 'OCT'
                                         WHEN @mesNon = 11 THEN 'NOV'
                                         WHEN @mesNon = 12 THEN 'DIC'
                                         ELSE ''
                                    END + RIGHT(CONVERT(CHAR(4), @ayo), 2)

            SET @mesFinalNomina = CASE WHEN @mesPar = 01 THEN 'ENE'
                                       WHEN @mesPar = 02 THEN 'FEB'
                                       WHEN @mesPar = 03 THEN 'MAR'
                                       WHEN @mesPar = 04 THEN 'ABR'
                                       WHEN @mesPar = 05 THEN 'MAY'
                                       WHEN @mesPar = 06 THEN 'JUN'
                                       WHEN @mesPar = 07 THEN 'JUL'
                                       WHEN @mesPar = 08 THEN 'AGO'
                                       WHEN @mesPar = 09 THEN 'SEP'
                                       WHEN @mesPar = 10 THEN 'OCT'
                                       WHEN @mesPar = 11 THEN 'NOV'
                                       WHEN @mesPar = 12 THEN 'DIC'
                                       ELSE ''
                                  END + RIGHT(CONVERT(CHAR(4), @ayo), 2)
                                                      
            INSERT  INTO @tDiasNomina
                    SELECT  dbo.nomina1_anual.empresa ,
                            dbo.nomina1_anual.codigo ,
                            SUM(dbo.nomina1_anual.diastr_nom) AS 'diastr' ,
                            0 AS faltas ,
                            0 AS incapacidades
                    FROM    dbo.nomina1_anual
                    WHERE   dbo.nomina1_anual.empresa = @empresa
                            AND dbo.nomina1_anual.codigo >= @codigoInicio
                            AND dbo.nomina1_anual.codigo <= @codigoFin
                            AND ( mes = @mesInicialNomina
                                  OR mes = @mesFinalNomina
                                )
                    GROUP BY empresa ,
                            codigo
                    ORDER BY empresa ,
                            codigo
                            
            UPDATE  tDiasNomina
            SET     tDiasNomina.diastr = 1
            FROM    @tDiasNomina AS tDiasNomina
            WHERE   tDiasNomina.empresa = @empresa
                    AND ( tDiasNomina.diastr IS NULL
                          OR tDiasNomina.diastr <= 0
                        )
        END
    ELSE 
       BEGIN
           IF @ayo > 0 
              BEGIN 
                  IF @mesNon > 0 
                     BEGIN 
                         SET @fechaInicioMesNon = CONVERT(DATETIME, LTRIM(STR(@ayo)) + RIGHT(STR(@mesNon + 100), 2) + '01')
                         SET @fechaFinMesNon = DATEADD(dd,-( DAY(DATEADD(mm,1,@fechaInicioMesNon))),DATEADD(mm,1,@fechaInicioMesNon))
                        
                         IF @toparFaltas = 'S'
                            SET @diasMesNon = 7
                         ELSE   
                            SET @diasMesNon = DATEDIFF(DD,@fechaInicioMesNon,@fechaFinMesNon) + 1
                        
                         EXECUTE dbo.asp_ds @empresa, @codigo, @ayo, @mesNon, @fechaFinMesNon
                         EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayo, @mesNon, @diasMesNon
                         EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayo, @mesNon
                     END
               
                  IF @mesPar > 0 
                     BEGIN 
                         SET @fechaInicioMesPar = CONVERT(DATETIME, LTRIM(STR(@ayo)) + RIGHT(STR(@mesPar + 100), 2) + '01')
                         SET @fechaFinMesPar = DATEADD(dd,-(DAY(DATEADD(mm,1,@fechaInicioMesPar))),DATEADD(mm,1,@fechaInicioMesPar))

                         IF @toparFaltas = 'S'
                            SET @diasMesPar = 7
                         ELSE   
                            SET @diasMesPar = DATEDIFF(DD,@fechaInicioMesPar,@fechaFinMesPar) + 1
                        
                         EXECUTE dbo.asp_ds @empresa, @codigo, @ayo, @mesPar, @fechaFinMesPar
                         EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayo, @mesPar, @diasMesPar
                         EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayo, @mesPar
                     END
                 
                  INSERT  @tDiasNomina
                          ( empresa ,
                            codigo ,
                            diastr ,
                            faltas ,
                            incapacidades 
                          )
                          SELECT  dbo.avisos_imss.empresa ,
                                  dbo.avisos_imss.codigo ,
                                  SUM(dbo.avisos_imss.diastr) AS daistr ,
                                  SUM(dbo.avisos_imss.ausen) AS faltas ,
                                  SUM(dbo.avisos_imss.incap) AS incapacidades
                          FROM    dbo.avisos_imss
                          WHERE   dbo.avisos_imss.empresa = @empresa
                                  AND dbo.avisos_imss.codigo >= @codigoInicio
                                  AND dbo.avisos_imss.codigo <= @codigoFin
                                  AND dbo.avisos_imss.ayo_operacion = @ayo
                                  AND ( dbo.avisos_imss.mes_operacion = @mesNon
                                        OR dbo.avisos_imss.mes_operacion = @mesPar
                                      )
                          GROUP BY dbo.avisos_imss.empresa ,
                                   dbo.avisos_imss.codigo
              END
       END            

    SELECT  tDiasNomina.empresa ,
            tDiasNomina.codigo ,
            tDiasNomina.diastr ,
            tDiasNomina.faltas ,
            tDiasNomina.incapacidades
    FROM    @tDiasNomina AS tDiasNomina
    ORDER BY tDiasNomina.codigo
GO

IF OBJECT_ID('dbo.ObtieneEmpleado') IS NOT NULL 
    DROP PROCEDURE [dbo].[ObtieneEmpleado]
GO

CREATE PROCEDURE [dbo].[ObtieneEmpleado] ( @empresa INT )
AS 
    SELECT  dbo.empleados.empresa ,
            dbo.empleados.codigo ,
            dbo.empleados.nombre ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.empleados.fchalta ,
            dbo.empleados.fchantigua ,
            dbo.empleados.curp ,
            dbo.empleados.rfcalfa ,
            dbo.empleados.rfcnum ,
            dbo.empleados.rfchomo
    FROM    dbo.empleados
    WHERE   dbo.empleados.activo = 'S'
            AND dbo.empleados.borrado = 'N'
    ORDER BY dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre 
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoActivo') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEmpleadoActivo
GO
CREATE PROCEDURE dbo.ObtieneEmpleadoActivo
@empresa INT,
@mes INT,
@ayo INT,
@fecha DATETIME,
@periodo INT,
@usuario VARCHAR(50),
@sistema VARCHAR(50)

AS 

  SET NOCOUNT ON

  DECLARE @fechaInicio DATETIME
  DECLARE @fechaFin DATETIME
  DECLARE @centroCostoEmpleado VARCHAR(50)
  DECLARE @tipoNominaEmpleado INT

  SET @centroCostoEmpleado = ''
  SET @tipoNominaEmpleado = 0

  IF @fecha IS NULL
     BEGIN
       SET @fecha = CONVERT(DATETIME, LTRIM(STR(@ayo)) + RIGHT(100 + @mes,2) + '01')
      SELECT @fechaInicio = fechaInicio, @fechaFin = fechaFin FROM [dbo].[ObtieneRangoFecha](@fecha, @periodo)
	 END 
  ELSE
     BEGIN
	   SELECT @fechaInicio = fechaInicio, @fechaFin = fechaFin FROM [dbo].[ObtieneRangoFecha](@fecha, @periodo)
       SET @fechaFin = @fecha
	 END

  -- Clase
  DECLARE @historicoClase TABLE (codigo INT, clase VARCHAR(2), fecha_captura DATETIME)

  INSERT @historicoClase (codigo, clase, fecha_captura)
  SELECT h.codigo,
         h.valor_nuevo AS clase,
         h.fecha_captura
  FROM dbo.Historico AS h
  WHERE h.campo = 'CLASE'
        AND h.empresa = @empresa
        AND h.folio = (SELECT TOP 1 
                              ha.folio
                       FROM dbo.Historico AS ha
                       WHERE ha.empresa = h.empresa
                             AND ha.codigo = h.codigo
                             AND ha.campo = h.campo 
                             AND ha.fecha_captura <= @fechaFin
                       ORDER BY ha.fecha_captura DESC)
  UNION
  SELECT h.codigo,
         h.valor_original AS clase,
         @fechaFin AS fecha_captura
  FROM dbo.Historico AS h
  WHERE h.empresa = @empresa
        AND h.campo = 'CLASE'
        AND h.folio = (SELECT TOP 1 
                              h1.folio
                       FROM dbo.Historico AS h1 
                       WHERE h1.empresa = h.empresa
                             AND h1.codigo = h.codigo
                             AND h1.campo = h.campo 
                             AND NOT EXISTS (SELECT TOP 1 1 
                                             FROM dbo.historico AS ha 
                                             WHERE ha.empresa = h1.empresa 
                                                   AND ha.campo = h1.campo 
                                                   AND ha.fecha_captura <= @fechaFin
                                                   AND ha.codigo = h1.codigo 
                                             ORDER BY ha.fecha_captura DESC) 
                             AND EXISTS (SELECT TOP 1 1 
                                         FROM dbo.historico AS hf 
                                         WHERE hf.empresa = h1.empresa
                                               AND hf.campo = h1.campo 
                                               AND hf.fecha_captura >= @fechaFin
                                               AND hf.codigo = h1.codigo 
                                         ORDER BY hf.fecha_captura ASC)
                       ORDER BY CONVERT(CHAR(10), h1.fecha_captura, 112) DESC,
                                CONVERT(CHAR(5), h1.fecha_captura, 108) ASC) 
  ORDER BY codigo,
           fecha_captura


  -- Centro de Costos
  DECLARE @historicoCentro TABLE (codigo INT, centro VARCHAR(15), fecha_captura DATETIME)

  INSERT @historicoCentro (codigo, centro, fecha_captura)
  SELECT h.codigo,
         h.valor_nuevo AS centro,
         h.fecha_captura
  FROM dbo.Historico AS h
  WHERE h.campo = 'CENTRO'
        AND h.empresa = @empresa
        AND h.folio = (SELECT TOP 1 
                              ha.folio
                       FROM dbo.Historico AS ha
                       WHERE ha.empresa = h.empresa
                             AND ha.codigo = h.codigo
                             AND ha.campo = h.campo 
                             AND ha.fecha_captura <= @fechaFin
                       ORDER BY ha.fecha_captura DESC)
  UNION
  SELECT h.codigo,
         h.valor_original AS centro,
         @fechaFin AS fecha_captura
  FROM dbo.Historico AS h
  WHERE h.empresa = @empresa
        AND h.campo = 'CENTRO'
        AND h.folio = (SELECT TOP 1 
                              h1.folio
                       FROM dbo.Historico AS h1 
                       WHERE h1.empresa = h.empresa
                             AND h1.codigo = h.codigo
                             AND h1.campo = h.campo 
                             AND NOT EXISTS (SELECT TOP 1 1 
                                             FROM dbo.historico AS ha 
                                             WHERE ha.empresa = h1.empresa 
                                                   AND ha.campo = h1.campo 
                                                   AND ha.fecha_captura <= @fechaFin
                                                   AND ha.codigo = h1.codigo 
                                             ORDER BY ha.fecha_captura DESC) 
                             AND EXISTS (SELECT TOP 1 1 
                                         FROM dbo.historico AS hf 
                                         WHERE hf.empresa = h1.empresa
                                               AND hf.campo = h1.campo 
                                               AND hf.fecha_captura >= @fechaFin
                                               AND hf.codigo = h1.codigo 
                                         ORDER BY hf.fecha_captura ASC)
                       ORDER BY CONVERT(CHAR(10), h1.fecha_captura, 112) DESC,
                                CONVERT(CHAR(5), h1.fecha_captura, 108) ASC) 
  ORDER BY codigo,
           fecha_captura

  -- Tipo Nmina
  DECLARE @historicoTipoNomina TABLE (codigo INT, tipoNomina INT, fecha_captura DATETIME)

  INSERT @historicoTipoNomina (codigo, tipoNomina, fecha_captura)
  SELECT h.codigo,
         CONVERT(INT, h.valor_nuevo) AS tipoNomina,
         h.fecha_captura
  FROM dbo.Historico AS h
  WHERE h.campo = 'TIPONOM'
        AND h.empresa = @empresa
        AND h.folio = (SELECT TOP 1 
                              ha.folio
                       FROM dbo.Historico AS ha
                       WHERE ha.empresa = h.empresa
                             AND ha.codigo = h.codigo
                             AND ha.campo = h.campo 
                             AND ha.fecha_captura <= @fechaFin
                       ORDER BY ha.fecha_captura DESC)
  UNION
  SELECT h.codigo,
         h.valor_original AS centro,
         @fechaFin AS fecha_captura
  FROM dbo.Historico AS h
  WHERE h.empresa = @empresa
        AND h.campo = 'TIPONOM'
        AND h.folio = (SELECT TOP 1 
                              h1.folio
                       FROM dbo.Historico AS h1 
                       WHERE h1.empresa = h.empresa
                             AND h1.codigo = h.codigo
                             AND h1.campo = h.campo 
                             AND NOT EXISTS (SELECT TOP 1 1 
                                             FROM dbo.historico AS ha 
                                             WHERE ha.empresa = h1.empresa 
                                                   AND ha.campo = h1.campo 
                                                   AND ha.fecha_captura <= @fechaFin
                                                   AND ha.codigo = h1.codigo 
                                             ORDER BY ha.fecha_captura DESC) 
                             AND EXISTS (SELECT TOP 1 1 
                                         FROM dbo.historico AS hf 
                                         WHERE hf.empresa = h1.empresa
                                               AND hf.campo = h1.campo 
                                               AND hf.fecha_captura >= @fechaFin
                                               AND hf.codigo = h1.codigo 
                                         ORDER BY hf.fecha_captura ASC)
                       ORDER BY CONVERT(CHAR(10), h1.fecha_captura, 112) DESC,
                                CONVERT(CHAR(5), h1.fecha_captura, 108) ASC) 
  ORDER BY codigo,
           fecha_captura

  SELECT e.codigo,
         e.ap_paterno,
		 e.ap_materno,
		 e.nombre,
		 e.afiliacion,
		 e.digvera,
		 e.rfcalfa + e.rfcnum + e.rfchomo AS rfc,
		 e.curp,
		 ISNULL(alta.fch_mov, e.fchalta) AS fechaAlta,
		 ISNULL(antiguedad.campo_07, e.fchantigua) AS fechaAntiguedad,
		 a.mov,
		 a.fch_mov,
         s.sueldo,
         s.saldiaint,
		 ISNULL(hClase.clase, ll.clase) AS clase,
		 clase.nombre AS nombreClase,
		 ISNULL(hCentro.centro, ll.centro) AS centro,
		 c.nomdepto AS nombreCentro,
		 ISNULL(hTipoNomina.tipoNomina, ll.tiponom) AS tipoNomina,
		 n.nomina AS nombreTipoNomina,
         @fechaInicio AS fechaInicio,
         @fechaFin AS fechaFin
  FROM dbo.empleados AS e
       INNER JOIN dbo.Llaves AS ll ON ll.codigo = e.codigo AND ll.empresa = e.empresa

	   OUTER APPLY (SELECT TOP 1
	                       hClase.clase
                    FROM @historicoClase AS hClase
					WHERE hClase.codigo = e.codigo) AS hClase

	   OUTER APPLY (SELECT TOP 1
	                       hCentro.centro
                    FROM @historicoCentro AS hCentro
					WHERE hCentro.codigo = e.codigo) AS hCentro

	   OUTER APPLY (SELECT TOP 1
	                       hTipoNomina.tipoNomina
                    FROM @historicoTipoNomina AS hTipoNomina
					WHERE hTipoNomina.codigo = e.codigo) AS hTipoNomina

       LEFT JOIN dbo.clases AS clase ON LTRIM(RTRIM(clase.clase)) = LTRIM(RTRIM(ISNULL(hClase.clase, ll.clase))) AND clase.empresa = ll.empresa
	   LEFT JOIN dbo.centros AS c ON LTRIM(RTRIM(c.centro)) = ISNULL(hCentro.centro, ll.centro) AND c.empresa = ll.empresa
	   LEFT JOIN dbo.Nominas AS n ON n.tiponom = ISNULL(hTipoNomina.tipoNomina, ll.tiponom) AND n.empresa = ll.empresa

       CROSS APPLY (SELECT TOP 1
                           a.codigo,
                           a.fch_mov,
                           a.mov
				    FROM dbo.avisos_imss AS a
					WHERE a.codigo = e.codigo
                          AND a.empresa = e.empresa
                          AND a.fch_mov <= @fechaFin
                    ORDER BY a.fch_mov DESC,
					         a.serial DESC) AS a

       CROSS APPLY (SELECT TOP 1
                           s.sueldo,
                           s.saldiaint
				    FROM dbo.avisos_imss AS s
					WHERE s.codigo = e.codigo
                          AND s.empresa = e.empresa
                          AND s.fch_mov <= @fechaFin
						  AND s.mov <> 'B'
                    ORDER BY s.fch_mov DESC,
					         s.serial DESC) AS s

       OUTER APPLY (SELECT TOP 1
	                       alta.fch_mov
					FROM dbo.avisos_imss AS alta
					WHERE alta.codigo = e.codigo
					      AND alta.empresa = e.empresa
						  AND (alta.mov = 'RI' OR alta.mov = 'A')
						  AND alta.fch_mov <= @fechaFin
					ORDER BY alta.fch_mov DESC,
					         alta.serial DESC) AS alta

       OUTER APPLY (SELECT TOP 1
	                       antiguedad.campo_07
					FROM dbo.avisos_imss AS antiguedad
					WHERE antiguedad.codigo = e.codigo
					      AND antiguedad.empresa = e.empresa
						  AND antiguedad.mov = 'B'
						  AND alta.fch_mov <= @fechaFin
					ORDER BY antiguedad.fch_mov DESC,
					         antiguedad.serial DESC) AS antiguedad

  WHERE e.empresa = @empresa
        AND a.mov <> CASE WHEN a.fch_mov = @fechaFin THEN 'X' ELSE 'B' END
		AND e.borrado = 'N'
		AND a.fch_mov >= @fechaInicio
		AND ll.centro IN (SELECT costCenter
                          FROM [dbo].[GetCostCenterByProfile](@usuario,
                                                              @centroCostoEmpleado,
                                                              @empresa,
                                                              @sistema))
        AND ll.tiponom IN (SELECT typePayroll
                           FROM [dbo].[GetTypePayrollByProfile](@usuario,
                                                                @tipoNominaEmpleado,
                                                                @empresa,
                                                                @sistema)) 
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoAntiguedad') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEmpleadoAntiguedad
GO
CREATE PROCEDURE dbo.ObtieneEmpleadoAntiguedad
@empresa INT,
@mes INT,
@ayo INT,
@periodo INT,
@paramFecha DATETIME,
@usuario VARCHAR(50),
@sistema VARCHAR(50)

AS 

  SET NOCOUNT ON
  
  DECLARE @fechaInicio DATETIME
  DECLARE @fechaFin DATETIME
  DECLARE @fecha DATETIME
  DECLARE @centroCostoEmpleado VARCHAR(50)
  DECLARE @tipoNominaEmpleado INT
  DECLARE @fechaFf DATETIME
  DECLARE @periodoFechaInicio CHAR(6)
  
  SET @fecha = CONVERT(DATETIME, LTRIM(STR(@ayo)) + RIGHT(100 + @mes,2) + '01')
  SET @centroCostoEmpleado = ''
  SET @tipoNominaEmpleado = 0

  SELECT @fechaFf = CONVERT(DATETIME, STR(e.ayo_operacion) + RIGHT(100 + e.mes_operacion,2) + '01')
  FROM dbo.empresas AS e
  WHERE e.empresa = @empresa
  
  IF @paramFecha IS NULL
     BEGIN
       SELECT @fechaInicio = fechaInicio,
              @fechaFin = fechaFin
       FROM [dbo].[ObtieneRangoFecha](@fecha, @periodo)

	   IF @fechaFin > @fechaFf
	      BEGIN
             SELECT @fechaInicio = fechaInicio
             FROM [dbo].[ObtieneRangoFecha](@fechaFf, @periodo)
		  END
     END
  ELSE
     BEGIN
       SET @fechaInicio = @paramFecha
       SET @fechaFin = @paramFecha
     END

  SET @periodoFechaInicio = RIGHT(YEAR(@fechaInicio),4) + RIGHT(100 + MONTH(@fechaInicio),2)

  SELECT e.codigo,
         e.ap_paterno,
         e.ap_materno,
         e.nombre,
         DAY(ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END)) AS dia,
         MONTH(ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END)) AS mes,
         YEAR(ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END)) AS ayo,
         ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END) AS fchantigua,
         DATEDIFF(DD, ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END), @fechaFin) + 1 AS dias,
         DATEDIFF(DD, ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END), @fechaFin) / 7 + 0 AS semanas,
		 DATEDIFF(MM, ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END), @fechaFin) - CASE WHEN DAY(ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END)) > DAY(@fechaFin) THEN 1 ELSE 0 END AS meses,
		 DATEDIFF(yy, ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END), @fechaFin) - CASE WHEN (MONTH(ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END)) > MONTH(@fechaFin)) OR (MONTH(ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END)) = MONTH(@fechaFin) AND DAY(ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END)) > DAY(@fechaFin)) THEN 1 ELSE 0 END AS ayos,
         @fechaInicio AS fechaInicio,
         @fechaFin AS fechaFin
  FROM dbo.empleados AS e

       OUTER APPLY (SELECT TOP 1
                           a.campo_07 AS fchantigua
                    FROM dbo.avisos_imss AS a
                    WHERE e.empresa = a.empresa
                          AND e.codigo = a.codigo
                          --AND a.mov = 'B'
                          AND a.fch_mov <= @fechaFin
                    ORDER BY a.fch_mov DESC,
                             a.serial DESC) AS a

       CROSS APPLY (SELECT TOP 1
	                       av.codigo
				    FROM dbo.avisos_imss AS av 
					WHERE av.codigo = e.codigo
					      AND av.empresa = e.empresa
						  AND RIGHT(YEAR(av.fch_mov),4) + RIGHT(100 + MONTH(av.fch_mov),2) = @periodoFechaInicio) AS av

       INNER JOIN dbo.Llaves AS ll ON ll.codigo = e.codigo AND ll.empresa = e.empresa

  WHERE e.borrado = 'N'
        --AND ISNULL(a.fchantigua, CASE WHEN e.fchantigua = '19000101' THEN NULL ELSE e.fchantigua END) <= @fechaFin
		AND e.empresa = @empresa
		AND ll.centro IN (SELECT costCenter
                          FROM [dbo].[GetCostCenterByProfile](@usuario,
                                                              @centroCostoEmpleado,
                                                              @empresa,
                                                              @sistema))
        AND ll.tiponom IN (SELECT typePayroll
                           FROM [dbo].[GetTypePayrollByProfile](@usuario,
                                                                @tipoNominaEmpleado,
                                                                @empresa,
                                                                @sistema)) 
  ORDER BY e.ap_paterno,
		   e.ap_materno,
		   e.nombre
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoAplicarVariable') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneEmpleadoAplicarVariable
GO
CREATE PROCEDURE dbo.ObtieneEmpleadoAplicarVariable @empresa INT
AS 
    SELECT  dbo.tmp_vars.codigo ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.empleados.fchantigua ,
            dbo.empleados.fchalta ,
            dbo.llaves.clase ,
            dbo.empleados.tiposal ,
            dbo.tmp_vars.varia_imss ,
            dbo.tmp_vars.diastrba ,
            dbo.tmp_vars.ausenba ,
            dbo.tmp_vars.incapba ,
            dbo.empleados.jornada ,
            dbo.empleados.cotiza_imss ,
            dbo.empleados.rpu ,
            dbo.tmp_vars.excedentes ,
            ( SELECT TOP 1 salarioMinimo.zona_a
              FROM dbo.salarios_minimos AS salarioMinimo
              WHERE dbo.tmp_vars.fecha >= salarioMinimo.fecha_ini
                    AND dbo.tmp_vars.fecha <= salarioMinimo.fecha_fin
              ORDER BY salarioMinimo.fecha_ini DESC ,
                      salarioMinimo.fecha_fin DESC) AS salarioMinimoDF ,
            ( SELECT TOP 1 CASE WHEN empresa.zona_geografica = 'A' THEN salarioMinimo.zona_a
                                WHEN empresa.zona_geografica = 'B' THEN salarioMinimo.zona_b
                                WHEN empresa.zona_geografica = 'C' THEN salarioMinimo.zona_c
                           END
              FROM dbo.salarios_minimos AS salarioMinimo
              WHERE dbo.tmp_vars.fecha >= salarioMinimo.fecha_ini
                    AND dbo.tmp_vars.fecha <= salarioMinimo.fecha_fin
              ORDER BY salarioMinimo.fecha_ini DESC ,
                      salarioMinimo.fecha_fin DESC) AS salarioMinimoRegion ,
            ( SELECT TOP 1
                        avisoImss.mov
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov)))
                        + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))),
                                    2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ) AS ultimoMovimiento ,
            ( SELECT TOP 1
                        avisoImss.fch_mov
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov)))
                        + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))),
                                    2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ) AS ultimaFechaMovimiento ,
            ( SELECT TOP 1
                        avisoImss.sueldo
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov)))
                        + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))),
                                    2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ) AS ultimaCuotaDiaria ,
            ( SELECT TOP 1
                        avisoImss.saldiaint
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov)))
                        + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))),
                                    2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ) AS ultimoSBC ,
            ( SELECT TOP 1
                        avisoImss.serial
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov)))
                        + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))),
                                    2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ) AS ultimoSerial ,
            ( SELECT TOP 1
                        ( SELECT TOP 1 
                                 salarioMinimo.zona_a
                          FROM dbo.salarios_minimos AS salarioMinimo
                          WHERE CASE WHEN avisoImss.mov = 'IM' AND MONTH(avisoImss.fch_mov) = 1 AND DAY(avisoImss.fch_mov) = 1
                                     THEN avisoImss.fch_mov - 1
                                     ELSE avisoImss.fch_mov
                                END >= salarioMinimo.fecha_ini AND CASE WHEN avisoImss.mov = 'IM' AND MONTH(avisoImss.fch_mov) = 1 AND DAY(avisoImss.fch_mov) = 1
                                                                        THEN avisoImss.fch_mov - 1
                                                                        ELSE avisoImss.fch_mov
                                                                   END <= salarioMinimo.fecha_fin
                          ORDER BY salarioMinimo.fecha_ini DESC ,
                                   salarioMinimo.fecha_fin DESC)
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov))) + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))), 2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                                                                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                                                                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                                                                                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ) AS salarioMinimoDfUltimoAviso ,
            
            ( SELECT TOP 1
                        ( SELECT TOP 1 
                                 CASE WHEN empresa.zona_geografica = 'A' THEN salarioMinimo.zona_a
                                      WHEN empresa.zona_geografica = 'B' THEN salarioMinimo.zona_b
                                      WHEN empresa.zona_geografica = 'C' THEN salarioMinimo.zona_c
                                      ELSE 0
                                 END
                          FROM dbo.salarios_minimos AS salarioMinimo
                          WHERE CASE WHEN avisoImss.mov = 'IM'
                                          AND MONTH(avisoImss.fch_mov) = 1
                                          AND DAY(avisoImss.fch_mov) = 1
                                     THEN avisoImss.fch_mov - 1
                                     ELSE avisoImss.fch_mov
                                END >= salarioMinimo.fecha_ini
                                AND CASE WHEN avisoImss.mov = 'IM'
                                              AND MONTH(avisoImss.fch_mov) = 1
                                              AND DAY(avisoImss.fch_mov) = 1
                                         THEN avisoImss.fch_mov - 1
                                         ELSE avisoImss.fch_mov
                                    END <= salarioMinimo.fecha_fin
                          ORDER BY salarioMinimo.fecha_ini DESC ,
                                   salarioMinimo.fecha_fin DESC)
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov)))
                        + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))),
                                    2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ) AS salarioMinimoRegionUltimoAviso ,
            ( SELECT TOP 1
                        'I'
              FROM      dbo.deducciones AS deduccion
              WHERE     deduccion.num_conc >= 109
                        AND deduccion.num_conc <= 111
                        AND dbo.tmp_vars.fecha >= deduccion.fchinicio
                        AND dbo.tmp_vars.fecha <= deduccion.fchtermino
                        AND deduccion.codigo = dbo.tmp_vars.codigo
                        AND deduccion.empresa = dbo.tmp_vars.empresa
            ) AS incapacitado,
            ISNULL((SELECT TOP 1
                           uma.umaDiario
                    FROM dbo.TblUMA AS uma
                    WHERE uma.fecha <= dbo.tmp_vars.fecha
                    ORDER BY uma.fecha DESC
            ),0) AS umaDiario,
            ISNULL(( SELECT TOP 1
                        ( SELECT TOP 1 
                                 uma.umaDiario 
                          FROM dbo.TblUMA AS uma
                          WHERE uma.fecha <= CASE WHEN avisoImss.mov = 'IM' 
                                                       AND MONTH(avisoImss.fch_mov) = 1 
                                                       AND DAY(avisoImss.fch_mov) = 1
                                                  THEN avisoImss.fch_mov - 1
                                                  ELSE avisoImss.fch_mov
                                             END 
                          ORDER BY uma.fecha DESC )
              FROM      dbo.avisos_imss AS avisoImss
              WHERE     LTRIM(STR(YEAR(avisoImss.fch_mov))) + SUBSTRING(LTRIM(STR(100 + MONTH(avisoImss.fch_mov))), 2, 2) >= CASE WHEN MONTH(dbo.tmp_vars.fecha) = 1 
                                                                                                                                  THEN LTRIM(STR(YEAR(dbo.tmp_vars.fecha) - 1)) + '12'
                                                                                                                                  ELSE LTRIM(STR(YEAR(dbo.tmp_vars.fecha),4)) + RIGHT(100 + (MONTH(dbo.tmp_vars.fecha) - 1),2)
                                                                                                                             END
                        AND avisoImss.codigo = dbo.tmp_vars.codigo
                        AND avisoImss.empresa = dbo.tmp_vars.empresa
              ORDER BY  avisoImss.fch_mov DESC ,
                        avisoImss.serial DESC
            ),0) AS umaDiarioUltimoAviso,
            
            llaves.ocupacion,
            llaves.centro,
            llaves.tiponom
    FROM    dbo.tmp_vars
            LEFT JOIN dbo.empleados ON ( dbo.empleados.codigo = dbo.tmp_vars.codigo
                                         AND dbo.tmp_vars.empresa = dbo.empleados.empresa
                                       )
            LEFT JOIN dbo.llaves ON ( dbo.llaves.codigo = dbo.tmp_vars.codigo
                                      AND dbo.tmp_vars.empresa = dbo.llaves.empresa
                                    )
            INNER JOIN dbo.empresas AS empresa ON dbo.tmp_vars.empresa = empresa.empresa
    WHERE   dbo.tmp_vars.baja = ' '
            AND dbo.tmp_vars.EMPRESA = @empresa
    ORDER BY dbo.tmp_vars.codigo
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoApsiReloj') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEmpleadoApsiReloj
GO
CREATE PROCEDURE dbo.ObtieneEmpleadoApsiReloj
@empresa INT,
@codigo INT

AS 
   SET NOCOUNT ON
   /*
   SELECT ea.NoChecar,
          ea.ChecaLibre,
          ea.NoTiempoExtra,
          ea.NoAusen,
          ea.Bloqueado,
          ea.NoExportar,
          ea.PremioPyA,
          ea.Comedor,
          ea.ExportaComedor,
          ea.FNomina,
          ea.Credencial,
          ea.MailRetardos,
          ea.MailTE,
          ea.MailSalidaAntes,
          ea.MailSupervisor,
          ea.MailNomina,
          ea.Enviar,
          ea.FechaUltimoEnvio,
          ea.ultimoMovimientoEnviado,
          ea.Enviado
   FROM dbo.EmpleadoApsiReloj AS ea
   WHERE ea.codigo = @codigo
         AND ea.empresa = @empresa
   */      
         
  SELECT 1 AS tipo,
         ea.Codigo,
         e.nombre AS Nombre,
         e.ap_paterno AS Paterno,
         e.ap_materno AS Materno,
         e.rfcalfa + e.rfcnum + e.rfchomo AS RFC,
         e.curp AS CURP,
         e.afiliacion + e.digvera AS Afiliacion,
         CASE WHEN ultimaAlta.ultimaFechaAlta IS NULL THEN e.fchalta ELSE ultimaAlta.ultimaFechaAlta END AS Alta,
         e.sueldo AS CuotaDiaria,
         e.sexo AS Sexo,
         ultimaBaja.ultimaFechaBaja AS Baja,
         e.fchnac AS Nacimiento,
         de.email AS email,
         de.telefono AS Telefono,
         ll.horario AS idHorario,
         ea.Clave,
         ll.supervisor AS supervisorAPSI,
         ta.actividad AS actividadAPSI,
         ll.tiponom AS tiponomAPSI,
         ea.NoChecar,
         ea.ChecaLibre,
         ea.NoTiempoExtra,
         ea.NoAusen,
         ea.Bloqueado,
         ea.NoExportar,
         ea.PremioPyA,
         ea.Comedor,
         ea.ExportaComedor,
         ea.FNomina,
         ea.Credencial,
         ll.centro AS idArea,
         cc.nomdepto AS Area,
         ea.MailRetardos,
         ea.MailTE,
         ea.MailSalidaAntes,
         ea.MailSupervisor,
         ea.MailNomina,
         e.activo,
         e.borrado,
         '' AS accion,
         ea.Enviar,
         ea.FechaUltimoEnvio,
         ea.ultimoMovimientoEnviado,
         ea.Enviado
  FROM dbo.EmpleadoApsiReloj AS ea
       INNER JOIN dbo.empleados AS e ON ea.codigo = e.codigo
                                        AND ea.empresa = e.empresa
       INNER JOIN dbo.datosemps AS de ON ea.codigo = de.codigo
                                         AND ea.empresa = de.empresa
       INNER JOIN dbo.Llaves AS ll ON ea.codigo = ll.codigo
                                      AND ea.empresa = ll.empresa
       INNER JOIN dbo.tabulador AS ta ON ll.ocupacion = ta.ocupacion
                                         AND ll.empresa = ta.empresa
       INNER JOIN dbo.centros AS cc ON LTRIM(RTRIM(ll.centro)) = LTRIM(RTRIM(cc.centro))
                                       AND ll.empresa = cc.empresa
       OUTER APPLY (SELECT TOP 1 
                           ultimaAlta.fch_mov AS ultimaFechaAlta
                    FROM dbo.avisos_imss AS ultimaAlta 
                    WHERE e.empresa = ultimaAlta.empresa
                          AND e.codigo = ultimaAlta.codigo
                          AND (ultimaAlta.mov = 'A'
                               OR ultimaAlta.mov = 'RI')
                    ORDER BY ultimaAlta.fch_mov DESC,
                             ultimaAlta.serial DESC) AS ultimaAlta        
       OUTER APPLY (SELECT TOP 1 
                           CASE WHEN ultimaBaja.mov = 'B' THEN ultimaBaja.fch_mov ELSE NULL END AS ultimaFechaBaja
                    FROM dbo.avisos_imss AS ultimaBaja
                         INNER JOIN dbo.empresas AS em ON ultimaBaja.empresa = em.empresa
                    WHERE e.empresa = ultimaBaja.empresa
                          AND e.codigo = ultimaBaja.codigo
                          AND ultimaBaja.fch_mov >= CONVERT(DATETIME, RIGHT(STR(10000 + em.ayo_operacion),4) + RIGHT(STR(100) + em.mes_operacion,2) + '01')
                    ORDER BY ultimaBaja.fch_mov DESC,
                             ultimaBaja.serial DESC) AS ultimaBaja        
   WHERE ea.codigo = @codigo
         AND ea.empresa = @empresa
         
         
         
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoArchivoAfiliatorio') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneEmpleadoArchivoAfiliatorio
GO
CREATE PROCEDURE [dbo].[ObtieneEmpleadoArchivoAfiliatorio]
    @empresa NUMERIC(5, 0) ,
    @user VARCHAR(50)
AS 
    DECLARE @costCenterEmployee VARCHAR(50)
    DECLARE @system VARCHAR(50)
    DECLARE @typePayrollEmployee INT
    DECLARE @ayo INT
    DECLARE @mes INT
    DECLARE @fecha DATETIME
    DECLARE @registroPatronal CHAR(11)
    DECLARE @rpu CHAR(3)

    SET @costCenterEmployee = ''
    SET @system = 'NO'
    SET @typePayrollEmployee = 0
    
    SELECT @ayo = e.ayo_operacion,
           @mes = e.mes_operacion,
           @registroPatronal = e.registro_patronal
    FROM dbo.empresas AS e
    WHERE e.empresa = @empresa
    
    SET @fecha = CONVERT(DATETIME, RIGHT(10000 + @ayo,4) + RIGHT(100 + @mes,2) + '01')
    SET @rpu = LEFT(@registroPatronal,3)
    
    SELECT DISTINCT
           1 AS tipo,
           e.codigo,
           e.afiliacion,
           e.digvera,
           e.ap_paterno,
           e.ap_materno,
           e.nombre,
           e.tiposal,
           ll.horario,
           e.jornada,
           ll.centro,
           e.sindicato,
           e.sexo,
           e.fchalta,
           e.fchantigua,
           ultimoSBC.sueldo,
           ultimoSBC.saldiaint,
           e.fchnac,
           e.rfcalfa,
           e.rfcnum,
           e.rfchomo,
           e.edonac,
           e.curp,
           d.edocivil,
           d.umf,
           d.nacional,
           ll.tiponom,
           @registroPatronal AS registroPatronal,
           ll.clase,
           ll.supervisor,
           e.manoobra,
           d.domicilio,
           d.numeroExterior,
           ISNULL(d.numeroInterior,'') AS numeroInterior,
           d.colonia,
           d.municipio,
           d.localidad,
           d.poblacion,
           d.codpostal,
           ll.ocupacion,
           ISNULL(d.email,'') AS email,
           ea.tipoContrato,
           ea.tipoRegimen,
           ea.Claveestado,
           ultimoAviso.mov,
           ultimoAviso.fch_mov,
           c.nomdepto,
           cla.nombre AS nombreClase,
           n.nomina AS nombreNomina,
           e.art39,
           CASE WHEN e.var_sigmes = 'T' THEN e.varia_next ELSE e.varia_imss END AS varia_imss,
           e.varia_next,
           e.var_sigmes,
           e.tipo_emp,
           ll.banco,
           e.cta_bco_no,
           ea.clabe,
           e.tipo_deposito,
           d.telefono,
           d.inegi,
           ISNULL(pensionCV.pensionCV,'N') AS pensionCV,
           ISNULL(pensionIV.pensionIV,'N') AS pensionIV,
           ISNULL(retieneIMSS.retieneIMSS,'S') AS retieneIMSS,
           ISNULL(aplicaSubsidioEmpleado.aplicaSubsidioEmpleado,'S') AS aplicaSubsidioEmpleado,
           e.cotiza_imss,
           e.pagar_nomina,
           ISNULL(ultimoAviso.rpu,@rpu) AS rpu,
           e.cuenta,
           ea.discapacitado,
           ISNULL(d.cta_vales,'') AS cta_vales,
           ISNULL(ea.claveSat,'') AS claveSat,
           ISNULL(ea.porcientoSat,0) AS porcientoSat
    FROM dbo.empleados AS e
         INNER JOIN dbo.Llaves AS ll ON e.codigo = ll.codigo
                                  AND e.empresa = ll.empresa
         INNER JOIN dbo.datosemps AS d ON e.codigo = d.codigo
                                          AND e.empresa = d.empresa
         INNER JOIN dbo.EmpleadoAdicional AS ea ON e.codigo = ea.codigo
                                                   AND e.empresa = ea.empresa
         INNER JOIN dbo.centros AS c ON LTRIM(RTRIM(ll.centro)) = LTRIM(RTRIM(c.centro))
                                        AND ll.empresa = c.empresa
         INNER JOIN dbo.clases AS cla ON LTRIM(RTRIM(ll.clase)) = LTRIM(RTRIM(cla.clase))
                                        AND ll.empresa = cla.empresa
         INNER JOIN dbo.Nominas AS n ON ll.tiponom = n.tiponom
                                        AND ll.empresa = n.empresa
         CROSS APPLY (SELECT TOP 1
                             a.mov,
                             a.fch_mov,
                             a.rpu
                      FROM dbo.avisos_imss AS a
                      WHERE a.fch_mov >= @fecha
                            AND a.codigo = e.codigo
                            AND a.empresa = e.empresa
                      ORDER BY a.fch_mov DESC,
                               a.serial DESC) AS ultimoAviso
         CROSS APPLY (SELECT TOP 1
                             a.sueldo,
                             a.saldiaint
                      FROM dbo.avisos_imss AS a
                      WHERE a.fch_mov >= @fecha
                            AND a.mov <> 'B'
                            AND a.codigo = e.codigo
                            AND a.empresa = e.empresa
                      ORDER BY a.fch_mov DESC,
                               a.serial DESC) AS ultimoSBC
          OUTER APPLY (SELECT CASE WHEN pensionCV.excepcion1 IS NULL 
                                   THEN 'N' 
                                   ELSE pensionCV.excepcion1 
                              END AS pensionCV
                       FROM dbo.excepciones AS pensionCV
                       WHERE pensionCV.empresa = e.empresa 
                             AND pensionCV.codigo = e.codigo 
                             AND pensionCV.excepcion1 = 'CV') AS pensionCV
          OUTER APPLY (SELECT CASE WHEN pensionIV.excepcion1 IS NULL 
                                   THEN 'N' 
                                   ELSE pensionIV.excepcion1 
                              END pensionIV 
                       FROM dbo.excepciones AS pensionIV
                       WHERE pensionIV.empresa = e.empresa 
                             AND pensionIV.codigo = e.codigo 
                             AND pensionIV.excepcion1 = 'IV') AS pensionIV
          OUTER APPLY (SELECT CASE WHEN retieneIMSS.excepcion1 IS NULL 
                                   THEN 'S' 
                                   ELSE retieneIMSS.excepcion1 
                              END AS retieneIMSS
                       FROM dbo.excepciones AS retieneIMSS
                       WHERE retieneIMSS.empresa = e.empresa 
                             AND retieneIMSS.codigo = e.codigo 
                             AND retieneIMSS.excepcion1 = 'NOIMSS') AS retieneIMSS
          OUTER APPLY (SELECT CASE WHEN aplicaSubsidioEmpleado.excepcion1 IS NULL 
                                   THEN 'S' 
                                   ELSE aplicaSubsidioEmpleado.excepcion1 
                              END aplicaSubsidioEmpleado
                       FROM dbo.excepciones AS aplicaSubsidioEmpleado
                       WHERE aplicaSubsidioEmpleado.empresa = e.empresa 
                             AND aplicaSubsidioEmpleado.codigo = e.codigo 
                             AND aplicaSubsidioEmpleado.excepcion1 = '115') AS aplicaSubsidioEmpleado
                             

    WHERE e.empresa = @empresa
          AND ll.centro IN (SELECT costCenter FROM [dbo].[GetCostCenterByProfile](@user, @costCenterEmployee, @empresa, @system))
          AND ll.tiponom IN (SELECT typePayroll FROM [dbo].[GetTypePayrollByProfile](@user, @typePayrollEmployee, @empresa, @system))
    ORDER BY e.codigo
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoBorrado') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEmpleadoBorrado
GO
CREATE PROCEDURE dbo.ObtieneEmpleadoBorrado
@empresa INT

AS 
  
  SET NOCOUNT ON
  
  SELECT e.codigo,
         e.ap_paterno,
         e.ap_materno,
         e.nombre,
         e.afiliacion,
         e.digvera
  FROM dbo.empleados AS e
  WHERE e.empresa = @empresa
        AND e.borrado = 'S'
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoCumpleAyoEdad') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEmpleadoCumpleAyoEdad
GO
CREATE PROCEDURE dbo.ObtieneEmpleadoCumpleAyoEdad
@empresa INT,
@mes INT,
@ayo INT,
@periodo INT,
@usuario VARCHAR(50),
@sistema VARCHAR(50)

AS 

  SET NOCOUNT ON
  
  DECLARE @fechaInicio DATETIME
  DECLARE @fechaFin DATETIME
  DECLARE @fecha DATETIME
  DECLARE @centroCostoEmpleado VARCHAR(50)
  DECLARE @tipoNominaEmpleado INT
  
  SET @fecha = CONVERT(DATETIME, LTRIM(STR(@ayo)) + RIGHT(100 + @mes,2) + '01')
  SET @centroCostoEmpleado = ''
  SET @tipoNominaEmpleado = 0
  
  SELECT @fechaInicio = fechaInicio,
         @fechaFin = fechaFin
  FROM [dbo].[ObtieneRangoFecha](@fecha, @periodo)

  SELECT e.codigo,
         e.ap_paterno,
         e.ap_materno,
         e.nombre,
         CASE WHEN e.fchnac IS NULL OR e.fchnac = '19000101' THEN NULL ELSE DAY(e.fchnac) END AS dia,
         CASE WHEN e.fchnac IS NULL OR e.fchnac = '19000101' THEN NULL ELSE MONTH(e.fchnac) END AS mes,
         CASE WHEN e.fchnac IS NULL OR e.fchnac = '19000101' THEN NULL ELSE YEAR(e.fchnac) END AS ayo,
         e.fchnac,
         CASE WHEN e.fchnac IS NULL OR e.fchnac = '19000101' THEN NULL ELSE CAST(DATEDIFF(DD, e.fchnac, @fechaFin) / 365.25 AS INT) END AS edad,
         @fechaInicio AS fechaInicio,
         @fechaFin AS fechaFin
  FROM dbo.empleados AS e
       INNER JOIN dbo.Llaves AS ll ON ll.codigo = e.codigo AND ll.empresa = e.empresa
  WHERE e.ultmov <> 'B'
        AND DATEADD(YEAR, YEAR(@fecha) - YEAR(e.fchnac), e.fchnac) BETWEEN @fechaInicio AND @fechaFin
        AND e.fchnac IS NOT NULL 
        AND e.fchnac <> '19000101'
        AND e.borrado = 'N'
		AND e.empresa = @empresa
		AND ll.centro IN (SELECT costCenter
                          FROM [dbo].[GetCostCenterByProfile](@usuario,
                                                              @centroCostoEmpleado,
                                                              @empresa,
                                                              @sistema))
        AND ll.tiponom IN (SELECT typePayroll
                           FROM [dbo].[GetTypePayrollByProfile](@usuario,
                                                                @tipoNominaEmpleado,
                                                                @empresa,
                                                                @sistema)) 
  ORDER BY MONTH(e.fchnac),
           DAY(e.fchnac),
           e.ap_paterno,
           e.ap_materno,
           e.nombre
GO

IF OBJECT_ID('dbo.ObtieneEmpleadosBimestre') IS NOT NULL 
    DROP PROCEDURE [dbo].[ObtieneEmpleadosBimestre]
GO

CREATE PROCEDURE [dbo].[ObtieneEmpleadosBimestre]
    (
      @empresa INT ,
      @codigo INT ,
      @ayo INT ,
      @mesNon INT ,
      @mesPar INT 
    )
AS 
    SELECT  DISTINCT
            dbo.empleados.empresa ,
            dbo.empleados.codigo ,
            dbo.empleados.nombre ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.empleados.curp ,
            dbo.empleados.rfcalfa ,
            dbo.empleados.rfcnum ,
            dbo.empleados.rfchomo ,
            dbo.centros.centro ,
            dbo.centros.nomdepto
    FROM    dbo.empresas
            INNER JOIN dbo.empleados ON dbo.empresas.empresa = dbo.empleados.empresa
            INNER JOIN dbo.avisos_imss ON dbo.empleados.empresa = dbo.avisos_imss.empresa
                                          AND dbo.empleados.codigo = dbo.avisos_imss.codigo
            INNER JOIN dbo.Llaves ON dbo.avisos_imss.empresa = dbo.Llaves.empresa
                                     AND dbo.avisos_imss.codigo = dbo.Llaves.codigo
            INNER JOIN dbo.centros ON dbo.Llaves.centro = dbo.centros.centro
                                      AND dbo.Llaves.empresa = dbo.centros.empresa
    WHERE   dbo.avisos_imss.mes_operacion >= @mesNon
            AND dbo.avisos_imss.mes_operacion <= @mesPar
            AND dbo.avisos_imss.ayo_operacion = @ayo
            AND dbo.empleados.cotiza_imss = 'S'
            AND dbo.empleados.borrado = 'N'
            AND dbo.avisos_imss.empresa >= CASE WHEN @empresa = 0 THEN 0
                                                ELSE @empresa
                                           END
            AND dbo.avisos_imss.empresa <= CASE WHEN @empresa = 0 THEN 9999
                                                ELSE @empresa
                                           END
            AND dbo.avisos_imss.codigo >= CASE WHEN @codigo = 0 THEN 0
                                               ELSE @codigo
                                          END
            AND dbo.avisos_imss.codigo <= CASE WHEN @codigo = 0 THEN 99999999
                                               ELSE @codigo
                                          END
    ORDER BY  dbo.empleados.codigo
GO

IF OBJECT_ID('dbo.ObtieneEmpleadoTopado') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEmpleadoTopado
GO
CREATE PROCEDURE dbo.ObtieneEmpleadoTopado
@empresa INT,
@codigo INT,
@mes INT,
@ayo INT,
@periodo INT,
@paramFecha DATETIME,
@usuario VARCHAR(50),
@sistema VARCHAR(50)

AS
  
  SET NOCOUNT ON

  DECLARE @fechaInicio DATETIME
  DECLARE @fechaFin DATETIME
  DECLARE @fecha DATETIME
  DECLARE @periodoFechaInicio CHAR(6)
  DECLARE @periodoFechaFin CHAR(6)
  DECLARE @centroCostoEmpleado VARCHAR(50)
  DECLARE @tipoNominaEmpleado INT
  DECLARE @mesAplicaUMA CHAR(6)
  DECLARE @mesProceso CHAR(6)

  SET @mesProceso = RIGHT(STR(@ayo),4) + RIGHT(STR(100 + @mes),2)
  SET @mesAplicaUMA = '201701'
  SET @centroCostoEmpleado = ''
  SET @tipoNominaEmpleado = 0

  IF @periodo = 11 OR @periodo = 12
     SET @fecha = CONVERT(DATETIME, LTRIM(STR(@ayo)) + '0101')
  ELSE
     SET @fecha = CONVERT(DATETIME, LTRIM(STR(@ayo)) + RIGHT(100 + @mes,2) + '01')

  IF @paramFecha IS NULL
     BEGIN
       SELECT @fechaInicio = fechaInicio,
              @fechaFin = fechaFin
       FROM [dbo].[ObtieneRangoFecha](@fecha, @periodo)
     END
  ELSE
     BEGIN
       SET @fechaInicio = @paramFecha
       SET @fechaFin = @paramFecha
     END

  SET @periodoFechaInicio = RIGHT(YEAR(@fechaInicio),4) + RIGHT(100 + MONTH(@fechaInicio),2)
  SET @periodoFechaFin = RIGHT(YEAR(@fechaFin),4) + RIGHT(100 + MONTH(@fechaFin),2)
--select @periodoFechaInicio, @periodoFechaFin

  SELECT e.codigo,
         e.ap_paterno,
         e.ap_materno,
         e.nombre,
         a.mov,
		 a.fch_mov,
		 a.saldiaint,
		 CASE WHEN @mesProceso >= @mesAplicaUMA THEN u.excedenteUma ELSE s.excedente END AS excedente,
		 CASE WHEN @mesProceso >= @mesAplicaUMA THEN u.uma ELSE s.salarioMinimoGeneral END AS salarioMinimo_Uma,
		 CASE WHEN @mesProceso >= @mesAplicaUMA THEN u.topeUma ELSE s.tope END AS tope,
		 CASE WHEN @mesProceso >= @mesAplicaUMA THEN u.fechaUma ELSE s.fecha_ini END AS fecha,
		 @fechaInicio AS fechaInicio,
		 @fechaFin AS fechaFin
  FROM dbo.avisos_imss AS a
       INNER JOIN dbo.empleados AS e ON e.codigo = a.codigo AND e.empresa = a.empresa AND e.borrado = 'N'
       INNER JOIN dbo.Llaves AS ll ON ll.codigo = e.codigo AND ll.empresa = e.empresa

	   OUTER APPLY (SELECT TOP 1
	                       s.zona_a AS salarioMinimoGeneral,
						   ROUND(s.zona_a * 25,2) AS tope,
						   a.saldiaint - ROUND(s.zona_a * 25,2) AS excedente,
						   s.fecha_ini
				    FROM dbo.salarios_minimos AS s
					WHERE s.fecha_ini <= a.fch_mov
                    ORDER BY s.fecha_ini DESC) AS s

		OUTER APPLY (SELECT TOP 1
		                    u.umaDiario AS uma,
							ROUND(u.umaDiario * 25,2) AS topeUma,
						    a.saldiaint - ROUND(u.umaDiario * 25,2) AS excedenteUma,
						    u.fecha AS fechaUma
					 FROM dbo.TblUMA AS u
					 WHERE u.fecha <= a.fch_mov
                     ORDER BY u.fecha DESC) AS u

  WHERE RIGHT(YEAR(a.fch_mov),4) + RIGHT(100 + MONTH(a.fch_mov),2) >= @periodoFechaInicio
        AND RIGHT(YEAR(a.fch_mov),4) + RIGHT(100 + MONTH(a.fch_mov),2) <= @periodoFechaFin
        AND a.mov <> 'B'
		AND a.saldiaint >= u.topeUma
        AND a.empresa = @empresa
        AND CASE WHEN @codigo = 0 OR @codigo IS NULL THEN 0 ELSE a.codigo END = ISNULL(@codigo,0)
		AND ll.centro IN (SELECT costCenter
                          FROM [dbo].[GetCostCenterByProfile](@usuario,
                                                              @centroCostoEmpleado,
                                                              @empresa,
                                                              @sistema))

        AND ll.tiponom IN (SELECT typePayroll
                           FROM [dbo].[GetTypePayrollByProfile](@usuario,
                                                                @tipoNominaEmpleado,
                                                                @empresa,
                                                                @sistema)) 

  ORDER BY e.ap_paterno,
		   e.ap_materno,
		   e.nombre,
		   a.fch_mov,
		   a.serial
GO

IF OBJECT_ID('dbo.ObtieneEmpresaPorPerfil') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneEmpresaPorPerfil
GO
CREATE PROCEDURE dbo.ObtieneEmpresaPorPerfil
    @usuario VARCHAR(50) ,
    @sistema VARCHAR(50)
AS 
    SET NOCOUNT ON

    DECLARE @empresa TABLE
        (
          empresa INT ,
          descripcion VARCHAR(70),
          referencia VARCHAR(70)
        )
    DECLARE @string VARCHAR(125)
    DECLARE @counter INT
    DECLARE @block VARCHAR(50)

    SET @string = ISNULL(( SELECT   dbo.perfiles.empresas
                           FROM     dbo.perfiles
                                    INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
                           WHERE    dbo.perfil_usuarios.usuario = @usuario
                                    AND dbo.perfiles.sistema = @sistema
                         ), '')

    IF @string = '{}' 
        INSERT  INTO @empresa
                ( empresa,
                  descripcion,
                  referencia
                )
                SELECT  dbo.empresas.empresa,
                        dbo.empresas.nombre_empresa,
						dbo.empresas.referencia
                FROM    dbo.empresas
                ORDER BY dbo.empresas.empresa
    ELSE 
        BEGIN 
            SET @string = SUBSTRING(@string, 2, LEN(@string) - 2)
            
            SET @counter = 1
            SET @block = ''
                
            WHILE @counter <= LEN(@string) 
                BEGIN

                    IF SUBSTRING(@string, @counter, 1) <> ','
                        OR @counter = LEN(@string) 
                        SET @block = @block + SUBSTRING(@string, @counter, 1)
                 
                    IF SUBSTRING(@string, @counter, 1) = ','
                        OR @counter = LEN(@string) 
                        BEGIN
                            INSERT  INTO @empresa
                                    ( empresa,
                                      descripcion,
                                      referencia
                                    )
                                    SELECT  dbo.empresas.empresa,
                                            dbo.empresas.nombre_empresa,
											dbo.empresas.referencia
                                    FROM    dbo.empresas
                                    WHERE   dbo.empresas.empresa = CONVERT(INT, @block)
                            SET @block = ''
                        END
                                                            
                    SET @counter = @counter + 1
                END
        END       

    SELECT  empresa,
            descripcion,
			referencia
    FROM    @empresa
    ORDER BY empresa
GO

IF OBJECT_ID('dbo.ObtieneEspecialEnviaCorreo') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneEspecialEnviaCorreo
GO
CREATE PROCEDURE dbo.ObtieneEspecialEnviaCorreo
    @empresa INT
AS 
    SET NOCOUNT ON
    
    IF (SELECT COUNT(*) FROM dbo.EspecialEnviaCorreo WHERE empresa = @empresa) = 0
       BEGIN
          INSERT dbo.EspecialEnviaCorreo
                 (empresa ,
                  direccionDeCorreo ,
                  servidorDeCorreo ,
                  puertoDeCorreo ,
                  usuarioDeCorreo ,
                  passwordDeCorreo ,
                  AutentificacionCorreo ,
                  TipoAutentificacionCorreo ,
                  SSL ,
                  TLS,
                  mensajeDeCorreo)
                  SELECT @empresa,
                         DireccionDeCorreo,
	                     ServidorDeCorreo,
	                     PuertoDeCorreo,
	                     UsuarioDeCorreo,
	                     PasswordDeCorreo,
	                     AutentificacionCorreo,
	                     TipoAutentificacionCorreo,
	                     SSL,
	                     TLS,
	                     MensajeDeCorreo
                  FROM dbo.Parametros_Empresas
                  WHERE empresa = @empresa
       END
        
    SELECT serial ,
           empresa ,
           direccionDeCorreo ,
           servidorDeCorreo ,
           puertoDeCorreo ,
           usuarioDeCorreo ,
           passwordDeCorreo ,
           AutentificacionCorreo ,
           TipoAutentificacionCorreo ,
           SSL ,
           TLS ,
           MensajeDeCorreo ,
           correoDestino ,
           asunto,
           correoDestino2,
           asunto2,
           MensajeDeCorreo2
    FROM dbo.EspecialEnviaCorreo
    WHERE empresa = @empresa      
    SET NOCOUNT OFF
GO

IF OBJECT_ID('dbo.ObtieneEspecialEnviaCorreoComplemento') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneEspecialEnviaCorreoComplemento
GO
CREATE PROCEDURE dbo.ObtieneEspecialEnviaCorreoComplemento
@empresa INT,
@nss CHAR(11),
@fecha DATETIME
AS
   SELECT llaves.centro, centro.nomdepto, aviso.mot_baja, aviso.codigo
   FROM dbo.avisos_imss AS aviso
        INNER JOIN dbo.empleados AS empleado ON aviso.codigo = empleado.codigo 
                                                AND aviso.empresa = empleado.empresa
        INNER JOIN dbo.Llaves AS llaves ON aviso.codigo = llaves.codigo
                                           AND aviso.empresa = llaves.empresa
        INNER JOIN dbo.centros AS centro ON LTRIM(RTRIM(llaves.centro)) = LTRIM(RTRIM(centro.centro))
                                            AND llaves.empresa = centro.empresa
   WHERE aviso.mov = 'B'
         AND aviso.fch_mov = @fecha
         AND aviso.empresa = @empresa
         AND empleado.afiliacion = SUBSTRING(@nss,1,10)
         AND empleado.digvera = SUBSTRING(@nss,11,1)
         AND empleado.empresa = @empresa
GO

IF OBJECT_ID('dbo.ObtieneFechaAntigua') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneFechaAntigua
GO
CREATE PROCEDURE dbo.ObtieneFechaAntigua
    @empresa INT ,
    @codigo INT
AS 
    SELECT  CASE WHEN dbo.empleados.fchantigua IS NULL
                 THEN dbo.empleados.fchalta
                 ELSE dbo.empleados.fchantigua
            END AS fechaAntiguedad
    FROM    dbo.empleados
    WHERE   dbo.empleados.empresa = @empresa
            AND dbo.empleados.codigo = @codigo
GO

IF OBJECT_ID('dbo.ObtieneFechaEnvio') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneFechaEnvio
GO
CREATE PROCEDURE dbo.ObtieneFechaEnvio
    @empresa INT ,
    @ayo INT ,
    @mes INT ,
    @origen VARCHAR(2)
AS 
    SET NOCOUNT ON

    DECLARE @aviso VARCHAR(2)
    DECLARE @avisosImss TABLE
        (
          mov VARCHAR(2) ,
          fechaEnvio CHAR(25) ,
          lote VARCHAR(25) ,
          fechaConfirmacion DATETIME ,
          registros INT
        )
    
    SET @aviso = ' '
    
    -- Todos
    INSERT  @avisosImss
            ( mov ,
              fechaEnvio ,
              lote ,
              fechaConfirmacion ,
              registros
            )
            SELECT DISTINCT
                    CASE WHEN dbo.avisos_imss.mov = 'A' THEN 'A'
                         WHEN dbo.avisos_imss.mov = 'RI' THEN 'A'
                         ELSE dbo.avisos_imss.mov
                    END AS mov ,
                    NULL AS fechaEnvio ,
                    NULL AS lote ,
                    NULL AS fechaConfirmacion ,
                    COUNT(*) AS registros
            FROM    dbo.avisos_imss
            WHERE   dbo.avisos_imss.empresa = @empresa
                    AND dbo.avisos_imss.ayo_operacion = @ayo
                    AND CASE WHEN @mes = 13 THEN 1
                             ELSE dbo.avisos_imss.mes_operacion
                        END = CASE WHEN @mes = 13 THEN 1
                                   ELSE @mes
                              END
                    AND dbo.avisos_imss.mov IN (
                    CASE WHEN @aviso = ' ' THEN 'A'
                         ELSE @aviso
                    END, CASE WHEN @aviso = ' ' THEN 'RI'
                              ELSE @aviso
                         END, CASE WHEN @aviso = ' ' THEN 'B'
                                   ELSE ''
                              END, CASE WHEN @aviso = ' ' THEN 'MS'
                                        ELSE ''
                                   END )
                    AND CASE WHEN @origen = 'XX' THEN '1'
                             ELSE dbo.avisos_imss.origen
                        END = CASE WHEN @origen = 'XX' THEN '1'
                                   ELSE @origen
                              END
            GROUP BY CASE WHEN dbo.avisos_imss.mov = 'A' THEN 'A'
                          WHEN dbo.avisos_imss.mov = 'RI' THEN 'A'
                          ELSE dbo.avisos_imss.mov
                     END
            ORDER BY CASE WHEN dbo.avisos_imss.mov = 'A' THEN 'A'
                          WHEN dbo.avisos_imss.mov = 'RI' THEN 'A'
                          ELSE dbo.avisos_imss.mov
                     END
    
    -- Por Lotes
    INSERT  @avisosImss
            ( mov ,
              fechaEnvio ,
              lote ,
              fechaConfirmacion ,
              registros
            )
            SELECT DISTINCT
                    CASE WHEN dbo.avisos_imss.mov = 'A' THEN 'A'
                         WHEN dbo.avisos_imss.mov = 'RI' THEN 'A'
                         ELSE dbo.avisos_imss.mov
                    END AS mov ,
                    CASE WHEN dbo.avisos_imss.fechaEnvio IS NULL
                         THEN '29991231'
                         ELSE RIGHT(10000 + YEAR(dbo.avisos_imss.fechaEnvio),
                                    4) + RIGHT(100
                                               + MONTH(dbo.avisos_imss.fechaEnvio),
                                               2) + RIGHT(100
                                                          + DAY(dbo.avisos_imss.fechaEnvio),
                                                          2) + ' ' + RIGHT(100
                                                              + DATEPART(HH,
                                                              dbo.avisos_imss.fechaEnvio),
                                                              2) + ':'
                              + RIGHT(100 + DATEPART(MI,
                                                     dbo.avisos_imss.fechaEnvio),
                                      2) + ':' + RIGHT(100 + DATEPART(SS,
                                                              dbo.avisos_imss.fechaEnvio),
                                                       2)
                    END AS fechaEnvio ,
                    dbo.avisos_imss.lote ,
                    dbo.avisos_imss.fechaConfirmacion ,
                    COUNT(*) AS registros
            FROM    dbo.avisos_imss
            WHERE   dbo.avisos_imss.empresa = @empresa
                    AND dbo.avisos_imss.ayo_operacion = @ayo
                    AND CASE WHEN @mes = 13 THEN 1
                             ELSE dbo.avisos_imss.mes_operacion
                        END = CASE WHEN @mes = 13 THEN 1
                                   ELSE @mes
                              END
                    AND dbo.avisos_imss.mov IN (
                    CASE WHEN @aviso = ' ' THEN 'A'
                         ELSE @aviso
                    END, CASE WHEN @aviso = ' ' THEN 'RI'
                              ELSE @aviso
                         END, CASE WHEN @aviso = ' ' THEN 'B'
                                   ELSE ''
                              END, CASE WHEN @aviso = ' ' THEN 'MS'
                                        ELSE ''
                                   END )
                    AND CASE WHEN @origen = 'XX' THEN '1'
                             ELSE dbo.avisos_imss.origen
                        END = CASE WHEN @origen = 'XX' THEN '1'
                                   ELSE @origen
                              END
            GROUP BY CASE WHEN dbo.avisos_imss.mov = 'A' THEN 'A'
                          WHEN dbo.avisos_imss.mov = 'RI' THEN 'A'
                          ELSE dbo.avisos_imss.mov
                     END ,
                    fechaEnvio ,
                    dbo.avisos_imss.lote ,
                    dbo.avisos_imss.fechaConfirmacion
            ORDER BY CASE WHEN dbo.avisos_imss.mov = 'A' THEN 'A'
                          WHEN dbo.avisos_imss.mov = 'RI' THEN 'A'
                          ELSE dbo.avisos_imss.mov
                     END ,
                    fechaEnvio DESC ,
                    dbo.avisos_imss.lote ,
                    dbo.avisos_imss.fechaConfirmacion
            
    SELECT  mov ,
            fechaEnvio ,
            lote ,
            fechaConfirmacion ,
            registros
    FROM    @avisosImss            
            
GO

IF OBJECT_ID('dbo.ObtieneFechaEnvioRpu') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneFechaEnvioRpu
GO
CREATE PROCEDURE dbo.ObtieneFechaEnvioRpu
    @empresa INT ,
    @ayo INT ,
    @mes INT
AS 
    SET NOCOUNT ON

    DECLARE @aviso VARCHAR(2)
    DECLARE @avisosImss TABLE
        (
          mov VARCHAR(2) ,
          fechaEnvio VARCHAR(25) ,
          lote VARCHAR(25) ,
          fechaConfirmacion DATETIME ,
          registros INT
        )
    
    SET @aviso = ' '

    -- Todos
    INSERT  @avisosImss
            ( mov ,
              fechaEnvio ,
              lote ,
              fechaConfirmacion ,
              registros
            )
            SELECT DISTINCT
                    CASE WHEN dbo.rpu_trabajador.mov = 'A' THEN 'AR'
                         WHEN dbo.rpu_trabajador.mov = 'B' THEN 'BR'
                         ELSE ' '
                    END AS mov ,
                    NULL AS fechaEnvio ,
                    NULL AS lote ,
                    NULL AS fechaConfirmacion ,
                    COUNT(*) AS registros
            FROM    dbo.rpu_trabajador
            WHERE   dbo.rpu_trabajador.empresa = @empresa
                    AND YEAR(dbo.rpu_trabajador.fch_mov) = @ayo
                    AND CASE WHEN @mes = 13 THEN 1
                             ELSE MONTH(dbo.rpu_trabajador.fch_mov)
                        END = CASE WHEN @mes = 13 THEN 1
                                   ELSE @mes
                              END
                    AND dbo.rpu_trabajador.mov IN (
                    CASE WHEN @aviso = ' ' THEN 'A'
                         ELSE @aviso
                    END, CASE WHEN @aviso = ' ' THEN 'B'
                              ELSE ''
                         END )
            GROUP BY CASE WHEN dbo.rpu_trabajador.mov = 'A' THEN 'AR'
                          WHEN dbo.rpu_trabajador.mov = 'B' THEN 'BR'
                          ELSE ' '
                     END 
            ORDER BY CASE WHEN dbo.rpu_trabajador.mov = 'A' THEN 'AR'
                          WHEN dbo.rpu_trabajador.mov = 'B' THEN 'BR'
                          ELSE ' '
                     END 

    -- Por Lotes
    INSERT  @avisosImss
            ( mov ,
              fechaEnvio ,
              lote ,
              fechaConfirmacion ,
              registros
            )
            SELECT DISTINCT
                    CASE WHEN dbo.rpu_trabajador.mov = 'A' THEN 'AR'
                         WHEN dbo.rpu_trabajador.mov = 'B' THEN 'BR'
                         ELSE ' '
                    END AS mov ,
                    CASE WHEN dbo.rpu_trabajador.fechaEnvio IS NULL
                         THEN '29991231'
                         ELSE RIGHT(10000 + YEAR(dbo.rpu_trabajador.fechaEnvio),
                                    4) + RIGHT(100
                                               + MONTH(dbo.rpu_trabajador.fechaEnvio),
                                               2) + RIGHT(100
                                                          + DAY(dbo.rpu_trabajador.fechaEnvio),
                                                          2) + ' ' + RIGHT(100
                                                              + DATEPART(HH,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                                              2) + ':'
                              + RIGHT(100 + DATEPART(MI,
                                                     dbo.rpu_trabajador.fechaEnvio),
                                      2) + ':' + RIGHT(100 + DATEPART(SS,
                                                              dbo.rpu_trabajador.fechaEnvio),
                                                       2)
                    END AS fechaEnvio ,
                    dbo.rpu_trabajador.lote ,
                    dbo.rpu_trabajador.fechaConfirmacion ,
                    COUNT(*) AS registros
            FROM    dbo.rpu_trabajador
            WHERE   dbo.rpu_trabajador.empresa = @empresa
                    AND YEAR(dbo.rpu_trabajador.fch_mov) = @ayo
                    AND CASE WHEN @mes = 13 THEN 1
                             ELSE MONTH(dbo.rpu_trabajador.fch_mov)
                        END = CASE WHEN @mes = 13 THEN 1
                                   ELSE @mes
                              END
                    AND dbo.rpu_trabajador.mov IN (
                    CASE WHEN @aviso = ' ' THEN 'A'
                         ELSE @aviso
                    END, CASE WHEN @aviso = ' ' THEN 'B'
                              ELSE ''
                         END )
            GROUP BY CASE WHEN dbo.rpu_trabajador.mov = 'A' THEN 'AR'
                          WHEN dbo.rpu_trabajador.mov = 'B' THEN 'BR'
                          ELSE ' '
                     END ,
                    fechaEnvio ,
                    dbo.rpu_trabajador.lote ,
                    dbo.rpu_trabajador.fechaConfirmacion
            ORDER BY CASE WHEN dbo.rpu_trabajador.mov = 'A' THEN 'AR'
                          WHEN dbo.rpu_trabajador.mov = 'B' THEN 'BR'
                          ELSE ' '
                     END ,
                    fechaEnvio DESC ,
                    dbo.rpu_trabajador.lote ,
                    dbo.rpu_trabajador.fechaConfirmacion 
            
    SELECT  mov ,
            fechaEnvio ,
            lote ,
            fechaConfirmacion ,
            registros
    FROM    @avisosImss            
            
GO

IF OBJECT_ID('dbo.ObtieneFuncionPorPerfil') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneFuncionPorPerfil
GO
CREATE PROCEDURE dbo.ObtieneFuncionPorPerfil
    @usuario VARCHAR(50) ,
    @sistema VARCHAR(50)
AS 
    SET NOCOUNT ON

    DECLARE @funciones TABLE
        (
          funcion VARCHAR(2) ,
          opcion VARCHAR(2) ,
          descripcion VARCHAR(100)
        )

    INSERT  @funciones
            ( funcion ,
              opcion ,
              descripcion
            )
            SELECT  DISTINCT
                    dbo.perfil_funcion.funcion ,
                    ' 0' ,
                    dbo.funciones.descripcion
            FROM    dbo.perfiles
                    INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
                    INNER JOIN dbo.perfil_funcion ON dbo.perfil_usuarios.idperfil = dbo.perfil_funcion.idperfil
                    INNER JOIN dbo.funciones ON dbo.perfil_funcion.funcion = dbo.funciones.funcion
            WHERE   dbo.perfil_usuarios.usuario = @usuario
                    AND dbo.perfiles.sistema = @sistema
                    AND dbo.funciones.sistema = @sistema
            ORDER BY dbo.perfil_funcion.funcion ,
                    dbo.funciones.descripcion

    INSERT  @funciones
            ( funcion ,
              opcion ,
              descripcion
            )
            --SELECT  DISTINCT
            --        dbo.perfil_funcion.funcion ,
            --        RIGHT(' ' + RTRIM(LTRIM(dbo.opciones.opcion)), 2) ,
            --        dbo.opciones.descripcion
            --FROM    dbo.perfiles
            --        INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
            --        INNER JOIN dbo.perfil_funcion ON dbo.perfil_usuarios.idperfil = dbo.perfil_funcion.idperfil
            --        INNER JOIN dbo.opciones ON dbo.perfil_funcion.funcion = dbo.opciones.funcion
            --WHERE   dbo.perfil_usuarios.usuario = @usuario
            --        AND dbo.perfiles.sistema = @sistema
            --        AND dbo.opciones.sistema = @sistema
            --ORDER BY dbo.perfil_funcion.funcion ,
            --        RIGHT(' ' + RTRIM(LTRIM(dbo.opciones.opcion)), 2) ,
            --        dbo.opciones.descripcion

            SELECT  DISTINCT
                    dbo.opciones.funcion ,
                    RIGHT(' ' + RTRIM(LTRIM(dbo.opciones.opcion)), 2) ,
                    dbo.opciones.descripcion
            FROM    dbo.perfiles
                    INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
                    INNER JOIN dbo.perfil_funcion ON dbo.perfil_usuarios.idperfil = dbo.perfil_funcion.idperfil
                    INNER JOIN dbo.opciones ON dbo.perfil_funcion.funcion = dbo.opciones.funcion AND LTRIM(RTRIM(dbo.perfil_funcion.opcion)) = LTRIM(RTRIM(dbo.opciones.opcion))
            WHERE   dbo.perfil_usuarios.usuario = @usuario
                    AND dbo.perfiles.sistema = @sistema
                    AND dbo.opciones.sistema = @sistema
            ORDER BY dbo.opciones.funcion ,
                    RIGHT(' ' + RTRIM(LTRIM(dbo.opciones.opcion)), 2) ,
                    dbo.opciones.descripcion
                    

    SELECT  funcion ,
            opcion ,
            descripcion
    FROM    @funciones
    ORDER BY funcion ,
            opcion
GO

IF OBJECT_ID('dbo.ObtieneGuiaAvisoImss') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneGuiaAvisoImss
GO
CREATE PROCEDURE dbo.ObtieneGuiaAvisoImss @empresa INT
AS 
    SELECT  dbo.empresas.Guia_avisos_imss
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa
GO

IF OBJECT_ID('dbo.ObtieneHistoricoDatos') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneHistoricoDatos
GO
CREATE PROCEDURE dbo.ObtieneHistoricoDatos
@empresa INT,
@codigo INT,
@fechaInicial DATETIME,
@fechaFinal DATETIME,
@registros INT

AS 

  DECLARE @fecha_captura DATETIME
  
  IF @fechaInicial <= @fechaFinal
     BEGIN
       SELECT TOP (@registros)
                  historico.folio,
                  historico.empresa,
                  historico.codigo,
                  CASE LTRIM(RTRIM(historico.campo)) WHEN 'AFILIACION' THEN 'N.S.S.'
                                                     WHEN 'DIG_VER' THEN 'Dgito Verificador N.S.S.'
                                                     WHEN 'AP_PATERNO' THEN 'Apellido Paterno'
                                                     WHEN 'AP_MATERNO' THEN 'Apellido Materno'
                                                     WHEN 'NOMBRE_TRA' THEN 'Nombre Empleado'
                                                     WHEN 'FCHALTA' THEN 'Fecha Alta'
                                                     WHEN 'FCHANTIGUA' THEN 'Fecha Antiguedad'
                                                     WHEN 'TABULADOR' THEN 'Tabulador'
                                                     WHEN 'CLASE' THEN 'Clase'
                                                     WHEN 'TIPOSAL' THEN 'Tipo Salario'
                                                     WHEN 'TIPONOM' THEN 'Tipo Nmina'
                                                     WHEN 'HORARIO' THEN 'Horario'
                                                     WHEN 'CENTRO' THEN 'Centro de Costos'
                                                     WHEN 'SINDICATO' THEN 'Sindicalizado'
                                                     WHEN 'SUELDO' THEN 'Cuota Diaria'
                                                     WHEN 'VARIMSS' THEN 'Parte Variable'
                                                     WHEN 'SALDIAINT' THEN 'Salario Base de Cotizacin'
                                                     WHEN 'TIPOEMP' THEN 'Tipo Empleado'
                                                     WHEN 'ART33' THEN 'Artculo'
                                                     WHEN 'SEXO' THEN 'Sexo'
                                                     WHEN 'ENT_NACI' THEN 'Entidad Nacimiento'
                                                     WHEN 'FCH_NACI' THEN 'Fecha Nacimiento'
                                                     WHEN 'RFCALFA' THEN 'R.F.C. (Parte Alfabtica)'
                                                     WHEN 'RFCNUM' THEN 'R.F.C. (Parte Nmerica)'
                                                     WHEN 'RFCHOMO' THEN 'R.F.C. (Parte HomoClave)'
                                                     WHEN 'CURP' THEN 'C.U.R.P.'
                                                     WHEN 'EDO_CIVIL' THEN 'Estado Civil'
                                                     WHEN 'TELEFONO' THEN 'Telfono'
                                                     WHEN 'MANO_OBRA' THEN 'Mano Obra'
                                                     WHEN 'SUPERVISOR' THEN 'Supervisor'
                                                     WHEN 'INEGI' THEN 'INEGI'
                                                     WHEN 'UMF' THEN 'UMF'
                                                     WHEN 'AFORE' THEN 'Afore'
                                                     WHEN 'NACIONALID' THEN 'Nacionalidad'
                                                     WHEN 'NOM_BANCO' THEN 'Banco (Institucin)'
                                                     WHEN 'TIPOCTABCO' THEN 'Mtodo de Pago'
                                                     WHEN 'CTA_BANCO' THEN 'Cuenta Bancaria'
                                                     WHEN 'CALLE' THEN 'Calle'
                                                     WHEN 'COLONIA' THEN 'Colonia'
                                                     WHEN 'POBLACION' THEN 'Entidad Federativa'
                                                     WHEN 'CODPOSTAL' THEN 'Cdigo Postal'
                                                     WHEN 'TURNO' THEN 'Tueno'
                                                     WHEN 'JORNADA' THEN 'Jornada'
                                                     WHEN 'PENSION_CV' THEN 'Pensin C.V.'
                                                     WHEN 'PENSION_IV' THEN 'Pensin I.V.'
                                                     WHEN 'RET_IMSS' THEN 'Retener I.M.S.S.'
                                                     WHEN 'ART_115' THEN 'Aplicar Sub. P/Empleo' --'CHOFER' 'ISR_CHOFER' 'AYU_CHOFER' 'AISRCHOFER'
                                                     WHEN 'NUM_BANCO' THEN 'Banco (Clave)'
                                                     WHEN 'COTIZA_IMSS' THEN 'Cotiza I.M.S.S.'
                                                     WHEN 'PAGAR_NOMINA' THEN 'Pagar Nmina'
                                                     WHEN 'RPU' THEN 'R.P.U.' --'MULTIOFICIO'
                                                     WHEN 'CUENTA' THEN 'Cuenta Contable'
                                                     WHEN 'FACTOR' THEN 'Factor de Integracin'
                                                     WHEN 'DIAS_LAB' THEN 'Das Laborados'
                                                     WHEN 'DIAS_DES' THEN 'Das Descanso'
                                                     WHEN 'Discapacitado' THEN 'Discapacitado'
                                                     WHEN 'CLABE' THEN 'Clabe'
                                                     WHEN 'TIPOREGIMEN' THEN 'Tipo Rgimen'
                                                     WHEN 'TIPOCONTRATO' THEN 'Tipo Contrato'
                                                     WHEN 'MAILEMPLEADO' THEN 'Correo Electrnico'
                                                     WHEN 'CTAVALESDESP' THEN 'Cuenta Vales Despensa'
                                                     WHEN 'NUMEROEXTERIOR' THEN 'No Exterior'
                                                     WHEN 'NUMEROINTERIOR' THEN 'No Interior'
                                                     WHEN 'MUNICIPIO' THEN 'Municipio'
                                                     WHEN 'LOCALIDAD' THEN 'Localidad'
                                                     WHEN 'CLAVESAT' THEN 'Clave S.A.T.'
                                                     WHEN 'PORCIENTOSAT' THEN 'Pociento S.A.T.'
                                                     WHEN 'CLAVEESTADO' THEN 'Clave Entidad Federativa' --'NSS'
                                                     ELSE LTRIM(RTRIM(historico.campo))
                  END AS campo,
                  LTRIM(RTRIM(ISNULL(historico.valor_original, ''))) AS valor_original,
                  LTRIM(RTRIM(historico.valor_nuevo)) AS valor_nuevo,
                  historico.ayo_operacion,
                  historico.mes_operacion,
                  historico.periodo,
                  historico.capturo,
                  CONVERT(DATETIME, CONVERT (CHAR(10), historico.fecha_captura, 112)) AS fecha_captura,
                  CONVERT(VARCHAR(8), historico.fecha_captura, 108) AS hora_captura,
                  ISNULL(historico.tipo_motivo, '') AS tipo_motivo,
                  ISNULL(historico.num_motivo, '') AS num_motivo,
                  ISNULL(motivoCambio.descripcion, '') AS descripcion,
                  LTRIM(RTRIM(origenAviso.descripcion)) + ' (' + CASE WHEN origenAviso.funcion = 'N' THEN 'Utilerias' ELSE 'Funcin ' + origenAviso.funcion END + ')' AS origen
           FROM dbo.historico AS historico
                LEFT JOIN dbo.motivo_cambio AS motivoCambio ON historico.tipo_motivo = motivoCambio.dato
                                                               AND historico.num_motivo = motivoCambio.num_motivo
                LEFT JOIN dbo.OrigenAvisoImss AS origenAviso ON historico.origen = origenAviso.origen
           WHERE historico.empresa = @empresa
                 AND historico.codigo = @codigo
                 AND CONVERT(DATETIME, CONVERT (CHAR(10), historico.fecha_captura, 112)) >= @fechaInicial
                 AND CONVERT(DATETIME, CONVERT (CHAR(10), historico.fecha_captura, 112)) <= @fechaFinal
           ORDER BY CONVERT(DATETIME, CONVERT (CHAR(10), historico.fecha_captura, 112)) DESC,
                    CONVERT(VARCHAR(8), historico.fecha_captura, 108) DESC
     END
  ELSE
     BEGIN
       SELECT 0 AS folio,
              @empresa AS empresa,
              @codigo AS codigo,
              '' AS campo,
              '' AS valor_original,
              '' AS valor_nuevo,
              0 AS ayo_operacion,
              0 AS mes_operacion,
              0 AS periodo,
              '' AS capturo,
              @fecha_captura AS fecha_captura,
              '' AS hora_captura,
              '' AS tipo_motivo,
              0 AS num_motivo,
              '' AS descripcion,
              '' AS origen
     END
GO

IF OBJECT_ID('dbo.ObtieneICVEmpleado') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneICVEmpleado
GO
CREATE PROCEDURE dbo.ObtieneICVEmpleado
@empresa INT,
@codigo INT

AS 

  SET NOCOUNT ON

  SELECT ISNULL(ic.numcredito, i.numcredito) AS numcredito,
         ISNULL(ic.fecha, i.fecha) AS fecha,
		 ISNULL(ic.tipo_cred, i.tipo_cred) AS tipo_cred,
		 ISNULL(ic.descuento, i.descuento) AS descuento
  FROM dbo.infonavit AS i
       OUTER APPLY (SELECT TOP 1
	                       ic.numcredito,
						   ic.fecha,
						   ic.tipo_cred,
						   ic.descuento
	                FROM dbo.infonavit_cambios AS ic
					WHERE ic.codigo = i.codigo 
					      AND ic.empresa = i.empresa
						  AND ic.cambio = 'ICV') AS ic

  WHERE CASE WHEN @codigo = 0 THEN @codigo ELSE i.codigo END = @codigo
        AND i.empresa = @empresa
GO

/**************************************************************************************************
 * Name          : ObtieneInfonavitBimestre
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total aportacion Infonavit Con o Sin credito
 * Table name    : 
 * Return        : tabla con total aportacion Infonavi Con o Sin credito
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneInfonavitBimestre' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneInfonavitBimestre]
    END
go


CREATE PROCEDURE [dbo].[ObtieneInfonavitBimestre]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mesNon INT ,
    @mesPar INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT,
	@filtroInfonavit INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
AS 
    SELECT  --calculoBimestre.empresa ,
            --calculoBimestre.clase ,
            --calculoBimestre.casos ,
            --calculoBimestre.diastr ,
            --calculoBimestre.incap ,
            --calculoBimestre.ausen ,
            --[dbo].[LlenaTotalCuotasBimestre].retiro ,
            --[dbo].[LlenaTotalCuotasBimestre].cesantiaVejez ,
            --calculoBimestre.cesantiaVejezPatron ,
            --calculoBimestre.cesantiaVejezTrabajador ,
            --[dbo].[LlenaTotalCuotasBimestre].aportacionInfonavit ,
            --[dbo].[LlenaTotalCuotasBimestre].amortizacion ,
            --[dbo].[LlenaTotalCuotasBimestre].seguroVivienda ,
            [dbo].[LlenaInfonavitBimestre].infonavitSinCredito ,
            [dbo].[LlenaInfonavitBimestre].infonavitConCredito ,
            --calculoBimestre.casosSinCredito ,
            --calculoBimestre.casosConCredito ,
            --calculoBimestre.baseCotizacionRetiro ,
            --calculoBimestre.baseCotizacionCV ,
            --calculoBimestre.baseCotizacionAportacionSinCredito ,
            --calculoBimestre.baseCotizacionAportacionConCredito ,
            --calculoBimestre.articulo168I ,
            --calculoBimestre.articulo168II ,
            --calculoBimestre.articulo29
            [dbo].[LlenaInfonavitBimestre].campo ,
            [dbo].[LlenaInfonavitBimestre].valor
    FROM    [dbo].[LlenaInfonavitBimestre](@empresa, @codigo, @ayo, @mesNon,
                                           @mesPar, @porRenglon, @proceso, @fechaProceso, @horaProceso, @simulaReforma, @filtroInfonavit) --AS calculoBimestre
    --ORDER BY calculoBimestre.empresa ,
    --        calculoBimestre.clase
GO

/**************************************************************************************************
 * Name          : ObtieneInfonavitMensual
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total aportacion Infonavit Con o Sin credito
 * Table name    : 
 * Return        : tabla con total aportacion Infonavi Con o Sin credito
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneInfonavitMensual' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneInfonavitMensual]
    END
GO
CREATE PROCEDURE [dbo].[ObtieneInfonavitMensual]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mesNon INT,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT
AS 
    SELECT  [dbo].[LlenaInfonavitMensual].infonavitSinCredito ,
            [dbo].[LlenaInfonavitMensual].infonavitConCredito ,
            [dbo].[LlenaInfonavitMensual].campo ,
            [dbo].[LlenaInfonavitMensual].valor
    FROM    [dbo].[LlenaInfonavitMensual](@empresa, @codigo, @ayo, @mesNon, @porRenglon, @proceso, @fechaProceso, @horaProceso, @simulaReforma)
GO

IF OBJECT_ID('dbo.ObtieneInformacionBaseDatos') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneInformacionBaseDatos
GO
CREATE PROCEDURE dbo.ObtieneInformacionBaseDatos
@baseDatos VARCHAR(150)

AS 
  
  SET NOCOUNT ON

  DECLARE @version VARCHAR(500)
  DECLARE @compatibilidad VARCHAR(50)
  DECLARE @tblNivelCompatibilidad TABLE 
         (id INT IDENTITY,
          Compatibilidad VARCHAR(50),
          Motor VARCHAR(50),
          Nivel INT)

  INSERT @tblNivelCompatibilidad (Compatibilidad, Motor, Nivel) VALUES ('SQL Server 2017', '14', 140)
  INSERT @tblNivelCompatibilidad (Compatibilidad, Motor, Nivel) VALUES ('SQL Server 2016', '13', 130)
  INSERT @tblNivelCompatibilidad (Compatibilidad, Motor, Nivel) VALUES ('SQL Server 2014', '12', 120)
  INSERT @tblNivelCompatibilidad (Compatibilidad, Motor, Nivel) VALUES ('SQL Server 2012', '11', 110)
  INSERT @tblNivelCompatibilidad (Compatibilidad, Motor, Nivel) VALUES ('SQL Server 2008', '10', 100)
  INSERT @tblNivelCompatibilidad (Compatibilidad, Motor, Nivel) VALUES ('SQL Server 2005', '9' , 90)
  INSERT @tblNivelCompatibilidad (Compatibilidad, Motor, Nivel) VALUES ('SQL Server 2000', '8' , 80)

  SELECT @version = @@VERSION

  SELECT @compatibilidad = nc.Compatibilidad --db.compatibility_level
  FROM sys.databases AS db
       LEFT JOIN @tblNivelCompatibilidad AS nc ON nc.Nivel = db.compatibility_level
  WHERE name = @baseDatos

  SELECT 1 AS tipo, --dbid, --DB_NAME(dbid) as DBName, 
         COUNT(dbid) AS conexiones, --, loginame as LoginName
         '' AS cliente,
         '' AS VersionSQL,
         '' AS Compatibilidad,
         '' AS idArchivo,
         0 AS tamanoArchivoMB,
         0 AS espacioUsadoMB,
         0 AS espacioLibreMB,
         '' AS nombreBD,
         '' AS archivoBD
  FROM sys.sysprocesses
  WHERE dbid > 0
        AND DB_NAME(dbid) = @baseDatos --GROUP BY  dbid, loginame
  
  UNION

  SELECT DISTINCT
         2 AS tipo,
         0 AS conexiones,
         hostname AS cliente,
         '' AS VersionSQL,
         '' AS Compatibilidad,
         '' AS idArchivo,
         0 AS tamanoArchivoMB,
         0 AS espacioUsadoMB,
         0 AS espacioLibreMB,
         '' AS nombreBD,
         '' AS archivoBD
         --  DB_NAME(dbid) as DBName, 
         --  COUNT(dbid) as NumberOfConnections,
         --  loginame as LoginName
  FROM sys.sysprocesses
  WHERE dbid > 0
        AND DB_NAME(dbid) = @baseDatos --GROUP BY dbid, loginame

  UNION

  SELECT 3 AS tipo,
         0 AS conexiones,
         '' AS cliente,
         @version AS VersionSQL,
         @Compatibilidad AS Compatibilidad,
         bd.fileid AS idArchivo,
         CONVERT(DECIMAL(12,2), ROUND(bd.size / 128.000,2)) AS tamanoArchivoMB,
         CONVERT(DECIMAL(12,2), ROUND(FILEPROPERTY(bd.name, 'SpaceUsed') / 128.000,2)) AS espacioUsadoMB,
         CONVERT(DECIMAL(12,2), ROUND((bd.size - FILEPROPERTY(bd.name, 'SpaceUsed')) / 128.000,2)) AS espacioLibreMB,
         bd.NAME AS nombreBD,
         bd.FILENAME AS archivoBD
  FROM dbo.sysfiles bd
GO

IF OBJECT_ID('dbo.ObtieneListaEmpresasValidaV4') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneListaEmpresasValidaV4
GO
CREATE PROCEDURE dbo.ObtieneListaEmpresasValidaV4
@usuario VARCHAR(20)

AS

  BEGIN
    SET NOCOUNT ON
    SET XACT_ABORT ON	
    BEGIN TRANSACTION
      BEGIN TRY

        DECLARE @stringEmpresas VARCHAR(500)
		DECLARE @delimitador CHAR(1)
		DECLARE @sistema CHAR(2)
		DECLARE @tieneControlempresas INT

		SET @delimitador = ','
		SET @sistema = 'NO'

        SELECT @stringEmpresas = perfiles.empresas
        FROM dbo.usuarios
             left join dbo.perfil_usuarios on usuarios.usuario=perfil_usuarios.usuario
             left join dbo.perfiles on  perfil_usuarios.idperfil=perfiles.idperfil
        WHERE usuarios.usuario = @usuario
              and perfiles.sistema = @sistema

		SET @stringEmpresas = SUBSTRING(@stringEmpresas, 2, LEN(@stringEmpresas) - 2)
		SET @tieneControlempresas = LEN(@stringEmpresas)

        SELECT e.empresa
               , ISNULL(e.referencia, nombre_empresa) AS nombreEmpresa
               , e.mes_operacion
               , e.ayo_operacion
               , tes.seleccionada
        FROM dbo.empresas AS e
             INNER JOIN (SELECT CONVERT(INT, valor) AS valorNuevo
                         FROM [dbo].[CadenaATabla](@stringEmpresas, @delimitador)) AS listaEmpresas ON CASE WHEN @tieneControlempresas = 0 THEN e.empresa ELSE listaEmpresas.valorNuevo END = e.empresa
             OUTER APPLY (SELECT TOP 1
                                 tes.seleccionada
                          FROM dbo.Tbl_EmpresasSeleccionadasV4 AS tes
                          WHERE tes.usuarioApsi = @usuario
                                AND tes.empresa = e.empresa) AS tes
      END TRY

      BEGIN CATCH
        IF XACT_STATE() = -1
           OR @@TRANCOUNT > 0
           ROLLBACK TRANSACTION

        SELECT ERROR_NUMBER() AS ErrorNumber ,
               ERROR_SEVERITY() AS ErrorSeverity ,
               ERROR_STATE() AS ErrorState ,
               ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
               ERROR_LINE() AS ErrorLine ,
               ERROR_MESSAGE() AS ErrorMessage
      END CATCH

      IF @@TRANCOUNT > 0
         COMMIT TRANSACTION
  END 
GO

/**************************************************************************************************
 * Name          : ObtieneMarcaConvenioReembolso
 * Project       : APSI Nomina
 * Description   : Obtiene la marca de convenio de reversion de cuotas
 * Table name    : conceptos
 * Return        : Campo
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Lunes, Mayo 03, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneMarcaConvenioReembolso' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneMarcaConvenioReembolso]
    END
go


CREATE PROCEDURE [dbo].[ObtieneMarcaConvenioReembolso] ( @empresa NUMERIC(5) )
AS 
    SELECT  CASE WHEN dbo.conceptos.variable1 = 'CONVENIO' THEN 'SI'
                 ELSE 'NO'
            END AS convenioReembolso
    FROM    dbo.conceptos
    WHERE   dbo.conceptos.empresa = @empresa
            AND dbo.conceptos.num_conc = 112
GO

IF OBJECT_ID('dbo.ObtieneMaster') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneMaster
GO

CREATE PROCEDURE dbo.ObtieneMaster
AS 
    SELECT  sf.name ,
            sf.filename
    FROM    master.dbo.sysaltfiles sf
            INNER JOIN master.sys.databases sd ON sf.dbid = sd.database_id
    WHERE   state_desc = 'online'
GO

IF OBJECT_ID('dbo.ObtieneMesAviso') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneMesAviso
GO
CREATE PROCEDURE dbo.ObtieneMesAviso @empresa INT = 0
AS 
    SET NOCOUNT ON

    DECLARE @tabla TABLE
        (
          mes INT ,
          ayo INT ,
          grupo INT
        )

    INSERT  @tabla
            ( mes ,
              ayo ,
              grupo
            )
            SELECT DISTINCT
                    CASE WHEN dbo.avisos_imss.mes_operacion IS NULL THEN 0
                         ELSE dbo.avisos_imss.mes_operacion
                    END AS mes_operacion ,
                    dbo.avisos_imss.ayo_operacion ,
                    GROUPING(dbo.avisos_imss.mes_operacion) AS mes
            FROM    dbo.avisos_imss
            WHERE   dbo.avisos_imss.empresa = @empresa
                    AND dbo.avisos_imss.mov <> 'IM'
                    AND dbo.avisos_imss.ayo_operacion IS NOT NULL
            GROUP BY ayo_operacion ,
                    mes_operacion
                    WITH ROLLUP
            ORDER BY ayo_operacion DESC ,
                    mes_operacion DESC
                    
    DELETE  @tabla
    WHERE   ayo IS NULL

    SELECT  mes ,
            ayo ,
            CASE mes
              WHEN 0 THEN 'E  j  e  r  c  i  c  i  o'
              WHEN 1 THEN 'Enero'
              WHEN 2 THEN 'Febrero'
              WHEN 3 THEN 'Marzo'
              WHEN 4 THEN 'Abril'
              WHEN 5 THEN 'Mayo'
              WHEN 6 THEN 'Junio'
              WHEN 7 THEN 'Julio'
              WHEN 8 THEN 'Agosto'
              WHEN 9 THEN 'Septiembre'
              WHEN 10 THEN 'Octubre'
              WHEN 11 THEN 'Noviembre'
              WHEN 12 THEN 'Diciembre'
              ELSE 'Sin Mes'
            END + ' / ' + LTRIM(STR(ayo)) AS 'mesTexto'
    FROM    @tabla
    ORDER BY ayo DESC ,
            mes DESC                
GO

IF OBJECT_ID('dbo.ObtieneMotivoBaja') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneMotivoBaja
GO
CREATE PROCEDURE dbo.ObtieneMotivoBaja
AS

  SET NOCOUNT ON
  
  SELECT idbaja,
         motivo 
  FROM dbo.rh_motivosbaja
  ORDER BY idbaja
GO

IF OBJECT_ID('dbo.ObtieneMotivoCambio') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneMotivoCambio
GO
CREATE PROCEDURE dbo.ObtieneMotivoCambio
AS

  SET NOCOUNT ON
  
  SELECT dato,
         num_motivo,
         descripcion
  FROM dbo.motivo_cambio
  ORDER BY dato,
           num_motivo
GO

IF OBJECT_Id('dbo.ObtieneNomina2') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneNomina2
GO
CREATE PROCEDURE dbo.ObtieneNomina2
@empresa INT
AS
  SET NOCOUNT ON
  
  SELECT tiponom,
         nomina,
         ctacuadre,
         nombrecta,
         frecuencia,
         periodicidadpagosat 
  FROM dbo.nominas 
  WHERE tiponom > 0 
        AND nominas.EMPRESA = @empresa
  ORDER BY tiponom
GO

IF OBJECT_ID('dbo.ObtieneNominaPorPerfil') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneNominaPorPerfil
GO
CREATE PROCEDURE dbo.ObtieneNominaPorPerfil
    @usuario VARCHAR(50) ,
    @sistema VARCHAR(50)
AS 
    SET NOCOUNT ON

    DECLARE @nomina TABLE
        (
          empresa INT ,
          tipoNomina INT ,
          descripcion VARCHAR(70)
        )
        
    DECLARE @nominaPerfil TABLE ( tipoNomina INT )    
    DECLARE @empresaPerfil TABLE ( empresa INT )    
    DECLARE @nominaTemporal TABLE
        (
          empresa INT ,
          tipoNomina INT
        )
    DECLARE @stringEmpresa VARCHAR(50)
    DECLARE @stringNomina VARCHAR(50)
    DECLARE @counter INT
    DECLARE @block VARCHAR(50)

    SELECT  @stringEmpresa = dbo.perfiles.empresas ,
            @stringNomina = dbo.perfiles.nomina
    FROM    dbo.perfiles
            INNER JOIN dbo.perfil_usuarios ON dbo.perfiles.idperfil = dbo.perfil_usuarios.idperfil
    WHERE   dbo.perfil_usuarios.usuario = @usuario
            AND dbo.perfiles.sistema = @sistema


    IF @stringEmpresa = '{}' 
        BEGIN
            INSERT  @empresaPerfil
                    ( empresa 
                    )
                    SELECT  dbo.empresas.empresa
                    FROM    dbo.empresas
                    ORDER BY dbo.empresas.empresa
        END
    ELSE 
        BEGIN
            SET @stringEmpresa = SUBSTRING(@stringEmpresa, 2,
                                           LEN(@stringEmpresa) - 2)
            
            SET @counter = 1
            SET @block = ''
                
            WHILE @counter <= LEN(@stringEmpresa) 
                BEGIN

                    IF SUBSTRING(@stringEmpresa, @counter, 1) <> ','
                        OR @counter = LEN(@stringEmpresa) 
                        SET @block = @block + SUBSTRING(@stringEmpresa,
                                                        @counter, 1)
                 
                    IF SUBSTRING(@stringEmpresa, @counter, 1) = ','
                        OR @counter = LEN(@stringEmpresa) 
                        BEGIN
                            INSERT  @empresaPerfil
                                    ( empresa )
                            VALUES  ( CONVERT(INT, @block) )
                            SET @block = ''
                        END
                                                            
                    SET @counter = @counter + 1
                END
        END

    IF @stringNomina = '{}' 
        BEGIN
            INSERT  @nominaPerfil
                    ( tipoNomina 
                    )
                    SELECT  dbo.Nominas.tiponom
                    FROM    dbo.Nominas
                    ORDER BY dbo.Nominas.empresa ,
                            dbo.Nominas.tiponom
        END 
    ELSE 
        BEGIN 
            SET @stringNomina = SUBSTRING(@stringNomina, 2,
                                          LEN(@stringNomina) - 2)
            
            SET @counter = 1
            SET @block = ''
                
            WHILE @counter <= LEN(@stringNomina) 
                BEGIN

                    IF SUBSTRING(@stringNomina, @counter, 1) <> ','
                        OR @counter = LEN(@stringNomina) 
                        SET @block = @block + SUBSTRING(@stringNomina,
                                                        @counter, 1)
                 
                    IF SUBSTRING(@stringNomina, @counter, 1) = ','
                        OR @counter = LEN(@stringNomina) 
                        BEGIN
                            INSERT  @nominaPerfil
                                    ( tipoNomina )
                            VALUES  ( CONVERT(INT, @block) )
                            SET @block = ''
                        END
                                                            
                    SET @counter = @counter + 1
                END
        END               


    INSERT  @nominaTemporal
            ( empresa ,
              tipoNomina 
            )
            SELECT DISTINCT
                    empresaPerfil.empresa ,
                    nominaPerfil.tipoNomina
            FROM    @empresaPerfil AS empresaPerfil ,
                    @nominaPerfil AS nominaPerfil
            --WHERE nominaPerfil.tipoNomina <> 0
            ORDER BY empresaPerfil.empresa ,
                    nominaPerfil.tipoNomina

    INSERT  @nomina
            ( empresa ,
              tipoNomina ,
              descripcion 
            )
            SELECT  nominaTemporal.empresa ,
                    nominaTemporal.tipoNomina ,
                    dbo.Nominas.nomina
            FROM    @nominaTemporal AS nominaTemporal
                    INNER JOIN dbo.Nominas ON nominaTemporal.empresa = dbo.Nominas.empresa
                                              AND nominaTemporal.tipoNomina = dbo.Nominas.tiponom
            ORDER BY nominaTemporal.empresa ,
                    nominaTemporal.tipoNomina
                    
    INSERT  @nomina
            ( empresa ,
              tipoNomina ,
              descripcion 
            )
            SELECT DISTINCT
                    nomina1.empresa ,
                    0 ,
                    'No hay'
            FROM    @nomina AS nomina1
            WHERE   NOT EXISTS ( SELECT DISTINCT
                                        nomina2.empresa
                                 FROM   @nomina AS nomina2
                                 WHERE  nomina1.empresa = nomina2.empresa
                                        AND nomina2.tipoNomina = 0 )
                            
    
    SELECT  nomina.empresa ,
            dbo.empresas.nombre_empresa ,
            nomina.tipoNomina ,
            nomina.descripcion
    FROM    @nomina AS nomina
            INNER JOIN dbo.empresas ON nomina.empresa = dbo.empresas.empresa
    ORDER BY nomina.empresa ,
            nomina.tipoNomina
GO

IF OBJECT_ID('dbo.ObtieneOtrosDatosEmpresa') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneOtrosDatosEmpresa
GO
CREATE PROCEDURE dbo.ObtieneOtrosDatosEmpresa
@empresa INT

AS 
  
  SET NOCOUNT ON
  
  SELECT empresa.proveedor_reloj,
         empresa.rpu,
         empresa.conexionReloj
  FROM dbo.empresas AS empresa
  WHERE  empresa.empresa = @empresa
GO

IF OBJECT_ID('dbo.ObtienePatron') IS NOT NULL 
    DROP PROCEDURE dbo.ObtienePatron
GO

CREATE PROCEDURE dbo.ObtienePatron
AS 
    SELECT  dbo.empresas.registro_patronal ,
            dbo.empresas.rfc_empresa
    FROM    dbo.empresas
    ORDER BY dbo.empresas.registro_patronal
GO

IF OBJECT_ID('dbo.ObtienePercepcionesIntegrables') IS NOT NULL
   DROP PROCEDURE dbo.ObtienePercepcionesIntegrables
GO
CREATE PROCEDURE dbo.ObtienePercepcionesIntegrables
@empresa INT,
@codigo INT,
@ayo INT,
@mes1 INT

AS 
  
  SET NOCOUNT ON
  
  SELECT percepcion.empresa,
        percepcion.codigo,
        percepcion.periodo,
        percepcion.num_conc,
        concepto.concepto,
        ISNULL(percepcion.nomina,0) AS importe,
		percepcion.origen,
        percepcion.fch_real AS fechaPago,
        percepcion.fch_pago AS fechaCaptura
  FROM dbo.percepciones AS percepcion
       LEFT JOIN dbo.conceptos AS concepto ON percepcion.empresa = concepto.empresa
                                              AND percepcion.num_conc = concepto.num_conc
                                              AND percepcion.centro = concepto.centro
                                              AND percepcion.clase = concepto.clase
  WHERE percepcion.empresa = @empresa
        AND CASE WHEN @codigo > 0 THEN percepcion.codigo ELSE 0 END = @codigo
        AND percepcion.ayo_operacion = @ayo
        AND percepcion.mes_operacion = @mes1
		AND concepto.Cfdi < 91

  ORDER BY percepcion.codigo,
           percepcion.periodo,
           percepcion.num_conc,
           percepcion.fch_real,
           percepcion.fch_pago
GO

IF OBJECT_ID('dbo.ObtienePercepcionesVariables') IS NOT NULL
   DROP PROCEDURE dbo.ObtienePercepcionesVariables
GO
CREATE PROCEDURE dbo.ObtienePercepcionesVariables
@empresa INT,
@codigo INT,
@ayo INT,
@mes1 INT,
@mes2 INT

AS 
  
  SET NOCOUNT ON
  
  SELECT percepcion.empresa,
        percepcion.codigo,
        percepcion.periodo,
        percepcion.num_conc,
        concepto.concepto,
        ISNULL(percepcion.nomina,0) AS importe,
        ISNULL(percepcion.varia_imss, 0) AS percepcionVariable,
        percepcion.fch_real AS fechaPago,
        percepcion.fch_pago AS fechaCaptura
  FROM dbo.percepciones AS percepcion
       LEFT JOIN dbo.conceptos AS concepto ON percepcion.empresa = concepto.empresa
                                              AND percepcion.num_conc = concepto.num_conc
                                              AND LTRIM(RTRIM(percepcion.centro)) = LTRIM(RTRIM(concepto.centro))
                                              AND LTRIM(RTRIM(percepcion.clase)) = LTRIM(RTRIM(concepto.clase))
  WHERE percepcion.empresa = @empresa
        AND CASE WHEN @codigo > 0 THEN percepcion.codigo ELSE 0 END = @codigo
        AND percepcion.ayo_operacion = @ayo
        AND percepcion.mes_operacion >= @mes1
        AND percepcion.mes_operacion <= @mes2
  ORDER BY percepcion.codigo,
           percepcion.periodo,
           percepcion.num_conc,
           percepcion.fch_real,
           percepcion.fch_pago
GO

IF OBJECT_ID('dbo.ObtienePeriodo2') IS NOT NULL
   DROP PROCEDURE dbo.ObtienePeriodo2
GO
CREATE PROCEDURE dbo.ObtienePeriodo2
@empresa INT,
@tipoNom INT
AS
  SET NOCOUNT ON
  
  SELECT Periodos.estatus,
         Periodos.periodo,
         Periodos.inicio,
         Periodos.cierre,
         Periodos.pago,
         Periodos.dias,
         Periodos.dias_anticipados,
         Periodos.ayo_operacion,
         CASE WHEN ABS(Periodos.periodo - SiguientePeriodo.periodo) > 1
                   OR ABS(Periodos.dias - DATEDIFF(DD, Periodos.inicio, SiguientePeriodo.inicio)) > 3 
                   OR ABS(Periodos.dias - DATEDIFF(DD, Periodos.cierre, SiguientePeriodo.cierre)) > 3
                   OR ABS(Periodos.dias - DATEDIFF(DD, Periodos.pago, SiguientePeriodo.pago)) > 3 THEN 1 
              WHEN Month(siguientePeriodo.pago) > Month(periodos.pago) THEN 2
              ELSE 0 
         END AS observacionPeriodo
  FROM dbo.periodos AS Periodos
       OUTER APPLY (SELECT TOP 1
                         SiguientePeriodo.periodo,
                         SiguientePeriodo.inicio,
                         SiguientePeriodo.cierre,
                         SiguientePeriodo.pago
                  FROM dbo.Periodos AS SiguientePeriodo
                  WHERE Periodos.tiponom = SiguientePeriodo.tiponom
                        AND Periodos.ayo_operacion = SiguientePeriodo.ayo_operacion
                        AND Periodos.empresa = SiguientePeriodo.empresa
                        AND Periodos.periodo < SiguientePeriodo.periodo 
                  ORDER BY SiguientePeriodo.periodo ASC) AS SiguientePeriodo

  WHERE Periodos.tiponom = @tipoNom
        AND Periodos.empresa = @empresa
  ORDER BY Periodos.ayo_operacion,
           Periodos.periodo
GO

IF OBJECT_ID('dbo.ObtienePrimasImss') IS NOT NULL 
    DROP PROCEDURE dbo.ObtienePrimasImss
GO
CREATE PROCEDURE dbo.ObtienePrimasImss
    @empresa INT ,
    @ayo INT ,
    @simulaReforma INT
AS 
    SELECT  primasImss.eymArt25 ,
            primasImss.eymPat25 ,
            primasImss.eymTra25 ,
            primasImss.eymArt106I ,
            primasImss.eymArt1062 ,
            primasImss.eymPat1062 ,
            primasImss.eymTra1062 ,
            primasImss.eymArt107 ,
            primasImss.eymPat107 ,
            primasImss.eymTra107 ,
            primasImss.ivArt147 ,
            primasImss.ivPat147 ,
            primasImss.ivTra147 ,
            primasImss.cvArt168II ,
            primasImss.cvPat168II ,
            primasImss.cvTra168II ,
            primasImss.cvArt168I ,
            primasImss.infonavitPorciento ,
            primasImss.art211 ,
            primasImss.seguroDesempleoPorciento
    FROM    dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss

/*
    IF @simularReforma2014 = 0 
        SELECT TOP 1
                primasImss.periodo ,
                primasImss.eymart25 ,
                primasImss.eympat25 ,
                primasImss.eymtra25 ,
                primasImss.eymart106I ,
                primasImss.eymart1062 ,
                primasImss.eympat1062 ,
                primasImss.eymtra1062 ,
                primasImss.eymart107 ,
                primasImss.eympat107 ,
                primasImss.eymtra107 ,
                primasImss.ivart147 ,
                primasImss.ivpat147 ,
                primasImss.ivtra147 ,
                primasImss.retiro ,
                primasImss.cvart168II ,
                primasImss.cvpat168II ,
                primasImss.cvtra168ii ,
                primasImss.infonavit ,
                primasImss.art211 ,
                primasImss.seguroDesempleo
        FROM    dbo.primas_imss AS primasImss
        WHERE   primasImss.periodo <= @fecha
        ORDER BY primasImss.periodo DESC
    ELSE 
        SELECT  3.17500 AS eymart25 ,
                2.80000 AS eympat25 ,
                0.37500 AS eymtra25 ,
                10.0000 AS eymart106I ,
                1.5000 AS eymart1062 ,
                1.10000 AS eympat1062 ,
                0.40000 AS eymtra1062 ,
                2.05000 AS eymart107 ,
                1.80000 AS eympat107 ,
                0.25000 AS eymtra107 ,
                2.37500 AS ivart147 ,
                1.75000 AS ivpat147 ,
                0.62500 AS ivtra147 ,
                2.00000 AS retiro ,
                4.27500 AS cvart168II ,
                3.15000 AS cvpat168II ,
                1.12500 AS cvtra168II ,
                2 AS infonavitporciento ,
                1 AS art211 ,
                3 AS segurodesempleo
*/                
GO

IF OBJECT_ID('dbo.ObtienePrimerEmpleado') IS NOT NULL 
    DROP PROCEDURE dbo.ObtienePrimerEmpleado
GO
CREATE PROCEDURE dbo.ObtienePrimerEmpleado
    @companyId INT ,
    @user VARCHAR(50) ,
    @costCenterEmployee VARCHAR(50) ,
    @typePayrollEmployee INT ,
    @system VARCHAR(50)
AS 
    SELECT TOP 1
            dbo.empleados.codigo
    FROM    dbo.empleados
            INNER JOIN dbo.llaves ON dbo.Llaves.empresa = dbo.empleados.empresa
                                     AND dbo.Llaves.codigo = dbo.empleados.codigo
    WHERE   dbo.empleados.empresa = @companyId
            AND dbo.empleados.activo = 'S'
            AND dbo.Llaves.centro IN (
            SELECT  costCenter
            FROM    [dbo].[GetCostCenterByProfile](@user, @costCenterEmployee,
                                                   @companyId, @system) )
            AND dbo.Llaves.tiponom IN (
            SELECT  typePayroll
            FROM    [dbo].[GetTypePayrollByProfile](@user,
                                                    @typePayrollEmployee,
                                                    @companyId, @system) )
    ORDER BY dbo.empleados.codigo
GO

-- Jorge Mtz
-- Septiembre, Viernes 17 de 2010

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'P'
--                    AND name = 'ObtieneRegistrosPorClase' ) 
--    BEGIN
--        DROP  PROCEDURE [dbo].[ObtieneRegistrosPorClase]
--    END
--GO

-- Jorge Mtz
-- 17/05/2017
IF OBJECT_ID('dbo.ObtieneRegistrosPorClase')  IS NOT NULL
   DROP  PROCEDURE dbo.ObtieneRegistrosPorClase
GO
CREATE PROCEDURE [dbo].[ObtieneRegistrosPorClase] 
@empresa NUMERIC(5, 0),
@usuario VARCHAR(30),
@ip VARCHAR(15),
@mac VARCHAR(17),
@nombreEquipo VARCHAR(50),
@origen VARCHAR(2)
AS 
-- Grafica por clase
    SELECT RTRIM(LTRIM(dbo.auditoria.clase)) + '.- ' + dbo.clases.nombre AS campo ,
           COUNT(dbo.auditoria.clase) AS valor
    FROM dbo.auditoria
         INNER JOIN dbo.clases ON dbo.auditoria.empresa = dbo.clases.empresa
                                  AND dbo.auditoria.clase = dbo.clases.clase
    WHERE dbo.auditoria.empresa = @empresa
          AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario)) 
          --AND LTRIM(RTRIM(auditoria.ip)) = LTRIM(RTRIM(@ip)) 
          AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac)) 
          AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreEquipo)) 
          AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
    GROUP BY dbo.auditoria.clase ,
            dbo.clases.nombre
    ORDER BY dbo.auditoria.clase
GO

-- Jorge Mtz
-- Septiembre, Viernes 17 de 2010

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'P'
--                    AND name = 'ObtieneRegistrosPorIntegracion' ) 
--    BEGIN
--        DROP  PROCEDURE [dbo].[ObtieneRegistrosPorIntegracion]
--    END
--GO

-- Jorge Mtz
-- 17/05/2017
IF OBJECT_ID('dbo.ObtieneRegistrosPorIntegracion')  IS NOT NULL
   DROP  PROCEDURE dbo.ObtieneRegistrosPorIntegracion
GO
CREATE PROCEDURE [dbo].[ObtieneRegistrosPorIntegracion] 
@empresa NUMERIC(5, 0),
@usuario VARCHAR(30),
@ip VARCHAR(15),
@mac VARCHAR(17),
@nombreEquipo VARCHAR(50),
@origen VARCHAR(2)
AS -- Grafica por bien y mal integrados
    SELECT CASE WHEN CHARINDEX('OK', dbo.auditoria.observacion) > 0
                THEN 'Bien Integrados'
                WHEN CHARINDEX('3', dbo.auditoria.observacion) > 0
                THEN 'Error en Integracin'
                WHEN CHARINDEX('4', dbo.auditoria.observacion) > 0
                THEN 'Error en Integracin'
                ELSE 'Bien Integrados'
           END AS campo ,
           COUNT(codigo) AS valor
    FROM dbo.auditoria
    WHERE dbo.auditoria.empresa = @empresa
          AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario)) 
          --AND LTRIM(RTRIM(auditoria.ip)) = LTRIM(RTRIM(@ip)) 
          AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac)) 
          AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreEquipo)) 
          AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
          AND ( CHARINDEX('OK', dbo.auditoria.observacion) > 0
                OR CHARINDEX('3', dbo.auditoria.observacion) > 0
                OR CHARINDEX('4', dbo.auditoria.observacion) > 0
                OR ( CHARINDEX('OK', dbo.auditoria.observacion) = 0
                     OR CHARINDEX('3', dbo.auditoria.observacion) = 0
                     OR CHARINDEX('4', dbo.auditoria.observacion) = 0
                   )
              )
    GROUP BY CASE WHEN CHARINDEX('OK', dbo.auditoria.observacion) > 0
                  THEN 'Bien Integrados'
                  WHEN CHARINDEX('3', dbo.auditoria.observacion) > 0
                  THEN 'Error en Integracin'
                  WHEN CHARINDEX('4', dbo.auditoria.observacion) > 0
                  THEN 'Error en Integracin'
                  ELSE 'Bien Integrados'
             END ,
            CASE WHEN CHARINDEX('OK', dbo.auditoria.observacion) > 0 THEN 1
                 WHEN CHARINDEX('3', dbo.auditoria.observacion) > 0 THEN 2
                 WHEN CHARINDEX('4', dbo.auditoria.observacion) > 0 THEN 2
                 ELSE 1
            END
GO

-- Jorge Mtz
-- Septiembre, Viernes 17 de 2010

--IF EXISTS ( SELECT  *
--            FROM    sysobjects
--            WHERE   type = 'P'
--                    AND name = 'ObtieneRegistrosTopados' ) 
--    BEGIN
--        DROP  PROCEDURE [dbo].[ObtieneRegistrosTopados]
--    END
--GO

-- Jorge Mtz
-- 17/05/2017
IF OBJECT_ID('dbo.ObtieneRegistrosTopados')  IS NOT NULL
   DROP  PROCEDURE dbo.ObtieneRegistrosTopados
GO
CREATE PROCEDURE [dbo].[ObtieneRegistrosTopados] 
@empresa NUMERIC(5, 0),
@usuario VARCHAR(30),
@ip VARCHAR(15),
@mac VARCHAR(17),
@nombreEquipo VARCHAR(50),
@origen VARCHAR(2)
AS -- Grafica topados y no topados
    SELECT CASE WHEN dbo.auditoria.sdi_ok >= ROUND(CASE WHEN RIGHT(10000 + dbo.auditoria.ayo,4) + RIGHT(100 + dbo.auditoria.mes,2) > '201701' 
                                                        THEN dbo.auditoria.umaDiario
                                                        ELSE dbo.auditoria.salDf
                                                   END * 25,2)
                THEN 'Empleado Topado'
                ELSE 'Sin Topar'
           END AS campo ,
           COUNT(codigo) AS valor
    FROM dbo.auditoria
    WHERE empresa = @empresa
          AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario)) 
          --AND LTRIM(RTRIM(auditoria.ip)) = LTRIM(RTRIM(@ip)) 
          AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac)) 
          AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreEquipo)) 
          AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
    GROUP BY CASE WHEN dbo.auditoria.sdi_ok >= ROUND(CASE WHEN RIGHT(10000 + dbo.auditoria.ayo,4) + RIGHT(100 + dbo.auditoria.mes,2) > '201701' 
                                                          THEN dbo.auditoria.umaDiario
                                                          ELSE dbo.auditoria.salDf
                                                     END * 25,2) 
                  THEN 'Empleado Topado'
                  ELSE 'Sin Topar'
             END ,
             CASE WHEN dbo.auditoria.sdi_ok >= ROUND(CASE WHEN RIGHT(10000 + dbo.auditoria.ayo,4) + RIGHT(100 + dbo.auditoria.mes,2) > '201701' 
                                                          THEN dbo.auditoria.umaDiario
                                                          ELSE dbo.auditoria.salDf
                                                     END * 25,2) 
                  THEN 1
                  ELSE 2
            END
GO

IF OBJECT_ID('dbo.ObtieneRegPatDeRpu') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneRegPatDeRpu
GO
CREATE PROCEDURE dbo.ObtieneRegPatDeRpu
@empresa INT
, @rpu CHAR(3)

AS 

  SET NOCOUNT ON

  SELECT reg_pat 
  FROM dbo.rpu 
  WHERE empresa = @empresa
		AND rpu = @rpu
GO

IF OBJECT_ID('dbo.ObtieneReporteSeguridadSocial') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneReporteSeguridadSocial
GO
CREATE PROCEDURE dbo.ObtieneReporteSeguridadSocial
    @empresa INT ,
    @nomina VARCHAR(3) ,
    @tipoNomina INT ,
    @regimen_seguridad_social INT

--SET @empresa = 1
--SET @nomina = 'SEM'
--SET @regimen_seguridad_social = 2
--SET @tipoNomina = 1
AS 
    SET NOCOUNT ON

    DECLARE @concepto VARCHAR(250)
    DECLARE @columna INT
    DECLARE @columnaEmpleado INT
    DECLARE @columnaPatron INT

    SET @concepto = ''
    SET @columna = 0
    SET @columnaEmpleado = 0
    SET @columnaPatron = 0
    
    DECLARE @primaColumna TABLE
        (
          columnaEmpleado INT ,
          numeroConceptoEmpleado INT ,
          ColumnaPatron INT ,
          numeroConceptoPatron INT
        )

    INSERT  @primaColumna
            ( numeroConceptoEmpleado ,
              numeroConceptoPatron
            )
            SELECT  dbo.Primas_ISSSTE.num_conc_empleado ,
                    dbo.Primas_ISSSTE.num_conc_patron
            FROM    dbo.Primas_ISSSTE
            WHERE   dbo.Primas_ISSSTE.regimen_seguridad_social = @regimen_seguridad_social
            ORDER BY CASE WHEN dbo.Primas_ISSSTE.num_conc_empleado = 0
                          THEN 999
                          ELSE dbo.Primas_ISSSTE.num_conc_empleado
                     END ASC ,
                    CASE WHEN dbo.Primas_ISSSTE.num_conc_patron = 0 THEN 999
                         ELSE dbo.Primas_ISSSTE.num_conc_patron
                    END ASC

    UPDATE  primaColumna
    SET     @columnaEmpleado = @columnaPatron + 1 , --CASE WHEN numeroConceptoEmpleado > 0 THEN 1 ELSE 0 END,
            primaColumna.columnaEmpleado = @columnaEmpleado , -- CASE WHEN numeroConceptoEmpleado > 0 THEN @columnaEmpleado ELSE 0 END,
            @columnaPatron = @columnaEmpleado + 1 , --CASE WHEN numeroConceptoPatron > 0 THEN 1 ELSE 0 END,
            primaColumna.columnaPatron = @columnaPatron -- CASE WHEN numeroConceptoPatron > 0 THEN @columnaPatron ELSE 0 END
    FROM    @primacolumna AS primaColumna

    SELECT  dbo.empleados.codigo ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.clasificacion_empleados.campo_02 ,
            kardexNomina.impor_base AS sueldo ,
            ( SELECT    SUM(kardexDias.dias)
              FROM      dbo.kardex AS kardexDias
              WHERE     kardexDias.empresa = kardexNomina.empresa
                        AND kardexDias.codigo = kardexNomina.codigo
                        AND kardexDias.nomina = @nomina
                        AND kardexDias.num_conc = @tipoNomina
              GROUP BY  kardexDias.empresa ,
                        kardexDias.codigo
            ) AS dias ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 1
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna1 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 2
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna2 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 3
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna3 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 4
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna4 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 5
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna5 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 6
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna6 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 7
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna7 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 8
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna8 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 9
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna9 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 10
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna10 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 11
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna11 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 12
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna12 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 13
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna13 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 14
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna14 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 15
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna15 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 16
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna16 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 17
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna17 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 18
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna18 ,
            SUM(CASE WHEN primaColumna.columnaEmpleado = 19
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna19 ,
            SUM(CASE WHEN primaColumna.ColumnaPatron = 20
                          AND kardexNomina.num_conc = primaColumna.numeroConceptoPatron
                     THEN kardexNomina.importe
                     ELSE 0
                END) AS columna20
    FROM    dbo.kardex AS kardexNomina
            INNER JOIN dbo.empleados ON kardexNomina.empresa = dbo.empleados.empresa
                                        AND kardexNomina.codigo = dbo.empleados.codigo
            INNER JOIN dbo.clasificacion_empleados ON dbo.empleados.empresa = dbo.clasificacion_empleados.empresa
                                                      AND dbo.empleados.codigo = dbo.clasificacion_empleados.codigo
            INNER JOIN @primaColumna AS primaColumna ON kardexNomina.num_conc = primaColumna.numeroConceptoEmpleado
                                                        OR kardexNomina.num_conc = primaColumna.numeroConceptoPatron
    WHERE   kardexNomina.empresa = @empresa
    GROUP BY dbo.empleados.codigo ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.clasificacion_empleados.campo_02 ,
            kardexNomina.impor_base ,
            kardexNomina.empresa ,
            kardexNomina.codigo
    ORDER BY dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre
GO

/**************************************************************************************************
 * Name          : ObtieneResumenClase
 * Project       : APSI Nomina
 * Description   : Obtiene la tabla con el resumen
 * Table name    : 
 * Return        : tabla con resumen por clase
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Agosto 19, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneResumenClase' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneResumenClase]
    END
go


CREATE PROCEDURE [dbo].[ObtieneResumenClase]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mes INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT
AS 
    SELECT  salario ,
            diastr ,
            incap ,
            ausen ,
            cuotaFija ,
            excedente ,
            excedentePatron ,
            exccedenteTrabajador ,
            prestacionesDinero ,
            prestacionesPatron ,
            prestacionesTrabajador ,
            gmp ,
            gmpPatron ,
            gmpTrabajador ,
            rt ,
            invalidezVida ,
            invalidezVidaPatron ,
            invalidezVidaTrabajador ,
            guarderias ,
            cesantiaVejez ,
            cesantiaVejezPatron ,
            cesantiaVejezTrabajador ,
            clase ,
            registroPorClase ,
            registroExc ,
            baseCotizacionCuotaFija ,
            baseCotizacionExc ,
            baseCotizacionPD ,
            baseCotizacionGMP ,
            baseCotizacionRT ,
            baseCotizacionIV ,
            baseCotizacionGPS ,
            baseCotizacionCV ,
            nombreClase ,
            articulo106I ,
            articulo106II ,
            articulo107 ,
            articulo25 ,
            articulo71 ,
            articulo147 ,
            articulo211,
			lic
    FROM    [dbo].[LlenaResumenClase](@empresa, @codigo, @ayo, @mes, @proceso, @fechaProceso, @horaProceso, @simulaReforma)
    ORDER BY clase
GO

/**************************************************************************************************
 * Name          : CedulaBimestral
 * Project       : APSI Nomina
 * Description   : Calcula cedula bimestral de aportaciones IMSS
 * Table name    : empleados, avisos_imss, conceptos
 * Return        : tabla con la cedula bimestral
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 18, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneResumenClaseBimestre' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneResumenClaseBimestre]
    END
go


CREATE PROCEDURE [dbo].[ObtieneResumenClaseBimestre]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mesNon INT ,
    @mesPar INT ,
    @porRenglon  INT ,
    @proceso VARCHAR(250) ,
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT,
	@filtroInfonavit INT -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
AS 
/*
    SELECT  calculoBimestre.empresa ,
            calculoBimestre.clase ,
            calculoBimestre.casos ,
            calculoBimestre.diastr ,
            calculoBimestre.incap ,
            calculoBimestre.ausen ,
            calculoBimestre.retiro ,
            calculoBimestre.cesantiaVejez ,
            calculoBimestre.cesantiaVejezPatron ,
            calculoBimestre.cesantiaVejezTrabajador ,
            calculoBimestre.aportacionInfonavit ,
            calculoBimestre.amortizacion ,
            calculoBimestre.seguroVivienda ,
            calculoBimestre.infonavitSinCredito ,
            calculoBimestre.infonavitConCredito ,
            calculoBimestre.casosSinCredito ,
            calculoBimestre.casosConCredito ,
            calculoBimestre.baseCotizacionRetiro ,
            calculoBimestre.baseCotizacionCV ,
            calculoBimestre.baseCotizacionAportacionSinCredito ,
            calculoBimestre.baseCotizacionAportacionConCredito ,
            calculoBimestre.articulo168I ,
            calculoBimestre.articulo168II ,
            calculoBimestre.articulo29 ,
            calculoBimestre.seguroDesempleoPorciento ,
            calculoBimestre.seguroDesempleoCuota,
            calculoBimestre.nombreClase,
			calculoBimestre.lic
    FROM    [dbo].[LlenaResumenClaseBimestre](@empresa, @codigo, @ayo, @mesNon,
                                              @mesPar, @porRenglon, @proceso, @fechaProceso, @horaProceso, @simulaReforma, @filtroInfonavit) AS calculoBimestre
    ORDER BY calculoBimestre.empresa ,
            calculoBimestre.clase
*/
  SET NOCOUNT ON

  DECLARE @cedulaBimestral TABLE
          (empresa INT NOT NULL DEFAULT 0,
           diastr INT NOT NULL DEFAULT 0,
           incap INT NOT NULL DEFAULT 0,
           ausen INT NOT NULL DEFAULT 0,
           retiro NUMERIC(12,2) NOT NULL DEFAULT 0,
           cesantiaVejez NUMERIC(12,2) NOT NULL DEFAULT 0,
           cesantiaVejezPatron NUMERIC(12,2) NOT NULL DEFAULT 0,
           cesantiaVejezTrabajador NUMERIC(12,2) NOT NULL DEFAULT 0,
           aportacionInfonavit NUMERIC(12,2) NOT NULL DEFAULT 0,
           amortizacion NUMERIC(12,2) NOT NULL DEFAULT 0,
           seguroVivienda NUMERIC(12,2) NOT NULL DEFAULT 0,
           infonavitSinCredito NUMERIC(12,2) NOT NULL DEFAULT 0,
           infonavitConCredito NUMERIC(12,2) NOT NULL DEFAULT 0, 
           clase VARCHAR(2) COLLATE database_default,
           baseCotizacionRetiro NUMERIC(12,2),
           baseCotizacionCV NUMERIC(12,2),
           baseCotizacionAportacionSinCredito NUMERIC(12,2),
           baseCotizacionAportacionConCredito NUMERIC(12,2),
           casos INT,
           casosSinCredito INT,
           casosConCredito INT,
           articulo168I NUMERIC(8,5),
           articulo168II NUMERIC(8,5),
           articulo29 NUMERIC(8,5),
           seguroDesempleoPorciento NUMERIC(8,5),
           seguroDesempleoCuota NUMERIC(12,2),
           nombreClase VARCHAR(20),
           lic INT NOT NULL DEFAULT 0 
          )

        DECLARE @diasFaltaTope INT
        DECLARE @fiNon DATETIME
        DECLARE @ffNon DATETIME
        DECLARE @fiPar DATETIME
        DECLARE @ffPar DATETIME
        DECLARE @esBimestre CHAR(1)
        DECLARE @salarioRegionA FLOAT
        DECLARE @salarioRegionB FLOAT
        DECLARE @salarioRegionC FLOAT
        DECLARE @salarioRegion FLOAT
        DECLARE @salarioDF FLOAT
        DECLARE @areaGeografica CHAR(1)
        DECLARE @topeDF FLOAT
        DECLARE @topeRegion FLOAT
        DECLARE @retiro FLOAT
        DECLARE @cvArt168II FLOAT
        DECLARE @cvPat168II FLOAT
        DECLARE @cvTra168II FLOAT
        DECLARE @infonavit FLOAT
        DECLARE @patronPagaIMSS CHAR(1)
        DECLARE @ayoEmpresa INT
        DECLARE @cDiasLab CHAR(1)
        DECLARE @cRetenido CHAR(1)
        DECLARE @cPropCred CHAR(1)
        DECLARE @cConvenio VARCHAR(30)
        DECLARE @seguroVivienda INT
        DECLARE @seguroDesempleoPorciento FLOAT
        DECLARE @fechaAplicaUMA DATETIME
        DECLARE @FechaFinita DATETIME

        SET @FechaFinita = '29991231'
        
        SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
        
        SET @diasFaltaTope = 7
        SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
        SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
        SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo)
            + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
        SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

        IF @mesPar / 2 = FLOOR(@mesPar / 2)
            AND @mesNon < @mesPar 
            BEGIN
                SET @esBimestre = 'S'
            END
        ELSE 
            BEGIN
                SET @esBimestre = 'N'
            END
    
    
-- Obtiene Area Geografica
        SELECT  @areaGeografica = dbo.empresas.zona_geografica ,
                @patronPagaIMSS = dbo.empresas.patron_paga_cuotas_imss ,
                @ayoEmpresa = dbo.empresas.ayo_operacion
        FROM    dbo.empresas
        WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
        SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
                @salarioRegionB = ISNULL(zona_b, 0) ,
                @salarioRegionC = ISNULL(zona_c, 0)
        FROM    [dbo].[GetMinimumWage](@mesPar, @ayo)
        
        SET @salarioDF = @salarioRegionA
        
        SET @salarioRegion = CASE @areaGeografica
                               WHEN 'A' THEN @salarioRegionA
                               WHEN 'B' THEN @salarioRegionB
                               WHEN 'C' THEN @salarioRegionC
                               ELSE 0
                             END
                     
        SET @topeDF = ROUND(@salarioDF * 25, 2)
        SET @topeRegion = @salarioRegion    
    

-- Obtiene Primas IMSS
        SELECT  @retiro = primasImss.cvArt168I,
                @cvArt168II = primasImss.cvArt168II,
                @cvPat168II = primasImss.cvPat168II,
                @cvTra168II = primasImss.cvTra168II,
                @infonavit = primasImss.infonavitPorciento,
                @seguroDesempleoPorciento = primasImss.seguroDesempleoPorciento
        FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
                                                
-- saca parametros infonavit
        SELECT  @cDiasLab = CASE WHEN hrs_min2 = 999 THEN 'N'
                                 ELSE 'S'
                            END ,
                @cRetenido = CASE WHEN hrs_min3 = 999 THEN 'S'
                                  ELSE 'N'
                             END ,
                @cPropCred = CASE WHEN marca2 = 'M' THEN 'N'
                                  ELSE 'S'
                             END ,
                @cConvenio = variable1
        FROM    conceptos
        WHERE   empresa = @empresa
                AND num_conc = 112                                                
    

        SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                                   WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                                   WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                                   ELSE 0
                              END

    SELECT empresa ,
           clase ,
           casos ,
           diastr ,
           incap ,
           ausen ,
           retiro ,
           cesantiaVejez ,
           cesantiaVejezPatron ,
           cesantiaVejezTrabajador ,
           aportacionInfonavit ,
           amortizacion ,
           seguroVivienda ,
           infonavitSinCredito ,
           infonavitConCredito ,
           casos - casosConCredito AS casosSinCredito ,
           casosConCredito ,
           baseCotizacionRetiro ,
           baseCotizacionCV ,
           baseCotizacionAportacionSinCredito ,
           baseCotizacionAportacionConCredito ,
           CASE WHEN resumenClase.Renglon = 1 THEN @retiro ELSE NULL END AS articulo168I,
           CASE WHEN resumenClase.Renglon = 1 THEN @cvArt168II ELSE NULL END AS articulo168II,
           CASE WHEN resumenClase.Renglon = 1 THEN @infonavit ELSE NULL END AS articulo29,
           CASE WHEN resumenClase.Renglon = 1 THEN @seguroDesempleoPorciento ELSE NULL END AS seguroDesempleoPorciento,
           seguroDesempleoCuota,
           nombreClase,
           lic

           , baseCotizacionCV1
           , baseCotizacionCV2
           , baseCotizacionCV3
           , baseCotizacionCV4
           , baseCotizacionCV5
           , baseCotizacionCV6
           , baseCotizacionCV7
           , baseCotizacionCV8

           , casos1
           , casos2
           , casos3
           , casos4
           , casos5
           , casos6
           , casos7
           , casos8

           , diasTr1
           , diasTr2
           , diasTr3
           , diasTr4
           , diasTr5
           , diasTr6
           , diasTr7
           , diasTr8

           , incap1
           , incap2
           , incap3
           , incap4
           , incap5
           , incap6
           , incap7
           , incap8

           , ausen1
           , ausen2
           , ausen3
           , ausen4
           , ausen5
           , ausen6
           , ausen7
           , ausen8

           , lic1
           , lic2
           , lic3
           , lic4
           , lic5
           , lic6
           , lic7
           , lic8

           , cesantiaVejez1
           , cesantiaVejez2
           , cesantiaVejez3
           , cesantiaVejez4
           , cesantiaVejez5
           , cesantiaVejez6
           , cesantiaVejez7
           , cesantiaVejez8

    FROM (
          SELECT aItc.empresa AS empresa,
                 llaves.clase,
                 COUNT(DISTINCT aItc.codigo) AS casos,   
                 SUM(aItc.diastr) AS diasTr,
                 SUM(aItc.incap - aItc.lic) AS incap,
                 SUM(aItc.ausen) AS ausen,
                 ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @retiro, 0)),2) AS retiro,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvPat168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezPatron,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvTra168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezTrabajador,
                 ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II)),2) AS cesantiaVejez,
                 ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvPat168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, tblCV.cvPat168II, tblCV.cvTra168II)),2) AS cesantiaVejezPatron,
                 ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvTra168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, tblCV.cvPat168II, tblCV.cvTra168II)),2) AS cesantiaVejezTrabajador,

                 ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0)),2) AS aportacionInfonavit,
                 SUM(ISNULL(infonavit.amortizacion,0)) AS amortizacion,  
                 SUM(ISNULL(infonavit.seguroVivienda,0)) AS seguroVivienda,  
                 ROUND(SUM(CASE WHEN infonavit.casosConCredito IS NULL THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitSinCredito, 
                 ROUND(SUM(CASE WHEN ISNULL(infonavit.casosConCredito2,0) = 1 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, @topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END),2) AS infonavitConCredito,
                 SUM(CASE WHEN aItc.serial = 1 AND infonavit.amortizacion IS NULL THEN 1 ELSE 0 END) AS casosSinCredito,
                 SUM(ISNULL(infonavit.casosConCredito,0)) AS casosConCredito,
                 ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen)),2) AS baseCotizacionRetiro,
                 ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV,
                 ROUND(SUM(CASE WHEN infonavit.casosConCredito IS NULL THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen) ELSE 0 END),2) AS baseCotizacionAportacionSinCredito,
                 ROUND(SUM(CASE WHEN ISNULL(infonavit.casosConCredito2,0) = 1 THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen) ELSE 0 END),2) AS baseCotizacionAportacionConCredito,
                 ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@seguroDesempleoPorciento, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @seguroDesempleoPorciento, 0)),2) AS seguroDesempleoCuota,
                 clase.nombre AS nombreClase,
                 SUM(aItc.lic) AS lic,
                 ROW_NUMBER() OVER(ORDER BY llaves.clase ASC) AS Renglon

                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc1, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV1
                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc2, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV2
                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc3, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV3
                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc4, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV4
                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc5, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV5
                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc6, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV6
                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc7, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV7
                 , ROUND(SUM([dbo].[AjustaSaldiaInt](tblCV.sbc8, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, tblCV.topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV8

				 --, COUNT(DISTINCT CASE WHEN tblCV.rango1 > 0 THEN aItc.codigo ELSE NULL END) AS casos1   
				 --, COUNT(DISTINCT CASE WHEN tblCV.rango2 > 0 THEN aItc.codigo ELSE NULL END) AS casos2   
				 --, COUNT(DISTINCT CASE WHEN tblCV.rango3 > 0 THEN aItc.codigo ELSE NULL END) AS casos3   
				 --, COUNT(DISTINCT CASE WHEN tblCV.rango4 > 0 THEN aItc.codigo ELSE NULL END) AS casos4   
				 --, COUNT(DISTINCT CASE WHEN tblCV.rango5 > 0 THEN aItc.codigo ELSE NULL END) AS casos5   
				 --, COUNT(DISTINCT CASE WHEN tblCV.rango6 > 0 THEN aItc.codigo ELSE NULL END) AS casos6   
				 --, COUNT(DISTINCT CASE WHEN tblCV.rango7 > 0 THEN aItc.codigo ELSE NULL END) AS casos7   
				 --, COUNT(DISTINCT CASE WHEN tblCV.rango8 > 0 THEN aItc.codigo ELSE NULL END) AS casos8

				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango1 > 0 THEN aItc.codigo ELSE NULL END) AS casos1   
				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango2 > 0 THEN aItc.codigo ELSE NULL END) AS casos2   
				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango3 > 0 THEN aItc.codigo ELSE NULL END) AS casos3   
				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango4 > 0 THEN aItc.codigo ELSE NULL END) AS casos4   
				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango5 > 0 THEN aItc.codigo ELSE NULL END) AS casos5   
				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango6 > 0 THEN aItc.codigo ELSE NULL END) AS casos6   
				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango7 > 0 THEN aItc.codigo ELSE NULL END) AS casos7   
				 , COUNT(DISTINCT CASE WHEN aItc.serial = 1 AND tblCV.rango8 > 0 THEN aItc.codigo ELSE NULL END) AS casos8


                 , SUM(CASE WHEN tblCV.rango1 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr1
                 , SUM(CASE WHEN tblCV.rango2 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr2
                 , SUM(CASE WHEN tblCV.rango3 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr3
                 , SUM(CASE WHEN tblCV.rango4 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr4
                 , SUM(CASE WHEN tblCV.rango5 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr5
                 , SUM(CASE WHEN tblCV.rango6 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr6
                 , SUM(CASE WHEN tblCV.rango7 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr7
                 , SUM(CASE WHEN tblCV.rango8 > 0 THEN aItc.diastr ELSE 0 END) AS diasTr8

                 , SUM(CASE WHEN tblCV.rango1 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap1
                 , SUM(CASE WHEN tblCV.rango2 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap2
                 , SUM(CASE WHEN tblCV.rango3 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap3
                 , SUM(CASE WHEN tblCV.rango4 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap4
                 , SUM(CASE WHEN tblCV.rango5 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap5
                 , SUM(CASE WHEN tblCV.rango6 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap6
                 , SUM(CASE WHEN tblCV.rango7 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap7
                 , SUM(CASE WHEN tblCV.rango8 > 0 THEN aItc.incap - aItc.lic ELSE 0 END) AS incap8

                 , SUM(CASE WHEN tblCV.rango1 > 0 THEN aItc.ausen ELSE 0 END) AS ausen1
                 , SUM(CASE WHEN tblCV.rango2 > 0 THEN aItc.ausen ELSE 0 END) AS ausen2
                 , SUM(CASE WHEN tblCV.rango3 > 0 THEN aItc.ausen ELSE 0 END) AS ausen3
                 , SUM(CASE WHEN tblCV.rango4 > 0 THEN aItc.ausen ELSE 0 END) AS ausen4
                 , SUM(CASE WHEN tblCV.rango5 > 0 THEN aItc.ausen ELSE 0 END) AS ausen5
                 , SUM(CASE WHEN tblCV.rango6 > 0 THEN aItc.ausen ELSE 0 END) AS ausen6
                 , SUM(CASE WHEN tblCV.rango7 > 0 THEN aItc.ausen ELSE 0 END) AS ausen7
                 , SUM(CASE WHEN tblCV.rango8 > 0 THEN aItc.ausen ELSE 0 END) AS ausen8

                 , SUM(CASE WHEN tblCV.rango1 > 0 THEN aItc.lic ELSE 0 END) AS lic1
                 , SUM(CASE WHEN tblCV.rango2 > 0 THEN aItc.lic ELSE 0 END) AS lic2
                 , SUM(CASE WHEN tblCV.rango3 > 0 THEN aItc.lic ELSE 0 END) AS lic3
                 , SUM(CASE WHEN tblCV.rango4 > 0 THEN aItc.lic ELSE 0 END) AS lic4
                 , SUM(CASE WHEN tblCV.rango5 > 0 THEN aItc.lic ELSE 0 END) AS lic5
                 , SUM(CASE WHEN tblCV.rango6 > 0 THEN aItc.lic ELSE 0 END) AS lic6
                 , SUM(CASE WHEN tblCV.rango7 > 0 THEN aItc.lic ELSE 0 END) AS lic7
                 , SUM(CASE WHEN tblCV.rango8 > 0 THEN aItc.lic ELSE 0 END) AS lic8

                 , ROUND(SUM(CASE WHEN tblCV.rango1 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez1
                 , ROUND(SUM(CASE WHEN tblCV.rango2 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez2
                 , ROUND(SUM(CASE WHEN tblCV.rango3 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez3
                 , ROUND(SUM(CASE WHEN tblCV.rango4 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez4
                 , ROUND(SUM(CASE WHEN tblCV.rango5 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez5
                 , ROUND(SUM(CASE WHEN tblCV.rango6 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez6
                 , ROUND(SUM(CASE WHEN tblCV.rango7 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez7
                 , ROUND(SUM(CASE WHEN tblCV.rango8 > 0 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,tblCV.cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvPat168II, tblCV.cvTra168II) ELSE 0 END),2) AS cesantiaVejez8


                FROM dbo.AvisosImssTemporalCalculo AS aItc 

                     OUTER APPLY (SELECT rango 
			                             , cvArt168II
                                         , cvPat168II
                                         , cvTra168II

										 , CASE WHEN rango = 1 THEN aItc.saldiaint ELSE 0 END AS sbc1
										 , CASE WHEN rango = 2 THEN aItc.saldiaint ELSE 0 END AS sbc2
										 , CASE WHEN rango = 3 THEN aItc.saldiaint ELSE 0 END AS sbc3
										 , CASE WHEN rango = 4 THEN aItc.saldiaint ELSE 0 END AS sbc4
										 , CASE WHEN rango = 5 THEN aItc.saldiaint ELSE 0 END AS sbc5
										 , CASE WHEN rango = 6 THEN aItc.saldiaint ELSE 0 END AS sbc6
										 , CASE WHEN rango = 7 THEN aItc.saldiaint ELSE 0 END AS sbc7
										 , CASE WHEN rango = 8 THEN aItc.saldiaint ELSE 0 END AS sbc8
										 , 0 AS topeRegion 

										 , CASE WHEN rango = 1 THEN 1 ELSE 0 END AS rango1
										 , CASE WHEN rango = 2 THEN 1 ELSE 0 END AS rango2
										 , CASE WHEN rango = 3 THEN 1 ELSE 0 END AS rango3
										 , CASE WHEN rango = 4 THEN 1 ELSE 0 END AS rango4
										 , CASE WHEN rango = 5 THEN 1 ELSE 0 END AS rango5
										 , CASE WHEN rango = 6 THEN 1 ELSE 0 END AS rango6
										 , CASE WHEN rango = 7 THEN 1 ELSE 0 END AS rango7
										 , CASE WHEN rango = 8 THEN 1 ELSE 0 END AS rango8

			                      FROM dbo.NOM_FUN_ObtienePrimaCVPatron2023(aItc.empresa, aItc.fch_mov, YEAR(aItc.fch_mov), aItc.saldiaint, @cvArt168II, @cvPat168II, @cvTra168II)
							      WHERE aItc.mov <> 'B'
								        --AND (aItc.diastr - aItc.ausen - aItc.incap) > 0
						         ) AS tblCV
/*
                     CROSS APPLY (SELECT COUNT(CASE WHEN tblCV.rango = 1 THEN 1 ELSE NULL END) AS casos1
										 , COUNT(CASE WHEN tblCV.rango = 2 THEN 1 ELSE NULL END) AS casos2
										 , COUNT(CASE WHEN tblCV.rango = 3 THEN 1 ELSE NULL END) AS casos3
										 , COUNT(CASE WHEN tblCV.rango = 4 THEN 1 ELSE NULL END) AS casos4
										 , COUNT(CASE WHEN tblCV.rango = 5 THEN 1 ELSE NULL END) AS casos5
										 , COUNT(CASE WHEN tblCV.rango = 6 THEN 1 ELSE NULL END) AS casos6
										 , COUNT(CASE WHEN tblCV.rango = 7 THEN 1 ELSE NULL END) AS casos7
										 , COUNT(CASE WHEN tblCV.rango = 8 THEN 1 ELSE NULL END) AS casos8
								  FROM tblCV ) AS tblCV2 
*/
				   
                     INNER JOIN dbo.empleados AS empleado ON empleado.empresa = aItc.empresa AND empleado.codigo = aItc.codigo
                     INNER JOIN dbo.Llaves AS llaves ON llaves.empresa = aItc.empresa AND llaves.codigo = aItc.codigo
                     INNER JOIN dbo.clases AS clase ON clase.empresa = llaves.empresa AND LTRIM(RTRIM(clase.clase)) = LTRIM(RTRIM(llaves.clase))
                     OUTER APPLY(SELECT CASE WHEN aItc.serial = 1 THEN ISNULL(dbo.TemporalAmortizacion.amortizacion,0) ELSE NULL END AS amortizacion,
                                        CASE WHEN aItc.serial = 1 THEN @seguroVivienda ELSE NULL END AS seguroVivienda,
			                            CASE WHEN aItc.serial = 1 THEN 'Si' ELSE '' END AS tieneCredito,
										CASE WHEN aItc.serial = 1 THEN 1 ELSE 0 END AS casosConCredito,
										1 AS casosConCredito2
                                 FROM dbo.TemporalAmortizacion
                                 WHERE dbo.TemporalAmortizacion.empresa = aItc.empresa
                                       AND dbo.TemporalAmortizacion.codigo = aItc.codigo
									   AND dbo.TemporalAmortizacion.amortizacion > 0) AS infonavit

                WHERE aItc.empresa >= CASE WHEN @empresa = 0 THEN 0 ELSE @empresa END 
                      AND aItc.empresa <= CASE WHEN @empresa = 0 THEN 9999 ELSE @empresa END 
                      AND aItc.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END 
                      AND aItc.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END
                      AND aItc.mes_operacion >= @mesNon 
                      AND aItc.mes_operacion <= @mesPar 
                      AND YEAR(aItc.fch_mov) = @ayo
                      AND aItc.horaProceso = @horaproceso
                      AND aItc.fechaProceso = @fechaproceso
                      AND aItc.proceso = @proceso
                GROUP BY aItc.empresa,
                         llaves.clase,
                         clase.nombre
						 ) AS resumenClase

/*
--DECLARE @cedula VARCHAR(25) = 'CedulaBimestre21'
--DECLARE @rpu CHAR(1) = 'N'

          SELECT


		  --aItc.empresa AS empresa,
                 --llaves.clase,
				 aItc.codigo,
                 --COUNT(DISTINCT aItc.codigo) AS casos,   
                 --SUM(aItc.diastr) AS diasTr,
                 --SUM(aItc.incap - aItc.lic) AS incap,
                 --SUM(aItc.ausen) AS ausen,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @retiro, 0)),2) AS retiro,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvPat168II, @cvTra168II)),2) AS cesantiaVejez,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvPat168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 1, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezPatron,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvTra168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 2, @cvPat168II, @cvTra168II)),2) AS cesantiaVejezTrabajador,
                 [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) AS aportacionInfonavit,
                 infonavit.amortizacion AS amortizacion,  
                 infonavit.seguroVivienda,0 AS seguroVivienda,  
                 CASE WHEN infonavit.casosConCredito IS NULL THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END AS infonavitSinCredito, 
                 CASE WHEN ISNULL(infonavit.casosConCredito2,0) = 1 THEN [dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint, CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END, @topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0) ELSE 0 END AS infonavitConCredito,
                 CASE WHEN aItc.serial = 1 AND infonavit.amortizacion IS NULL THEN 1 ELSE 0 END AS casosSinCredito,
                 infonavit.casosConCredito AS casosConCredito
                 --ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen)),2) AS baseCotizacionRetiro,
                 --ROUND(SUM([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen - aItc.incap)),2) AS baseCotizacionCV,
                 --ROUND(SUM(CASE WHEN infonavit.casosConCredito IS NULL THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen) ELSE 0 END),2) AS baseCotizacionAportacionSinCredito,
                 --ROUND(SUM(CASE WHEN ISNULL(infonavit.casosConCredito2,0) = 1 THEN [dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov) * (aItc.diastr - aItc.ausen) ELSE 0 END),2) AS baseCotizacionAportacionConCredito,
                 --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,empleado.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@seguroDesempleoPorciento, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @seguroDesempleoPorciento, 0)),2) AS seguroDesempleoCuota,
                 --clase.nombre AS nombreClase,
                 --SUM(aItc.lic) AS lic,
                 --ROW_NUMBER() OVER(ORDER BY llaves.clase ASC) AS Renglon

                FROM dbo.AvisosImssTemporalCalculo AS aItc 
                     INNER JOIN dbo.empleados AS empleado ON empleado.empresa = aItc.empresa AND empleado.codigo = aItc.codigo
                     INNER JOIN dbo.Llaves AS llaves ON llaves.empresa = aItc.empresa AND llaves.codigo = aItc.codigo
                     INNER JOIN dbo.clases AS clase ON clase.empresa = llaves.empresa AND LTRIM(RTRIM(clase.clase)) = LTRIM(RTRIM(llaves.clase))
                     OUTER APPLY(SELECT CASE WHEN aItc.serial = 1 THEN ISNULL(dbo.TemporalAmortizacion.amortizacion,0) ELSE NULL END AS amortizacion,
                                        CASE WHEN aItc.serial = 1 THEN @seguroVivienda ELSE NULL END AS seguroVivienda,
			                            CASE WHEN aItc.serial = 1 THEN 'Si' ELSE '' END AS tieneCredito,
										CASE WHEN aItc.serial = 1 THEN 1 ELSE 0 END AS casosConCredito,
										1 AS casosConCredito2
                                 FROM dbo.TemporalAmortizacion
                                 WHERE dbo.TemporalAmortizacion.empresa = aItc.empresa
                                       AND dbo.TemporalAmortizacion.codigo = aItc.codigo
									   AND dbo.TemporalAmortizacion.amortizacion > 0) AS infonavit

                WHERE aItc.empresa >= CASE WHEN @empresa = 0 THEN 0 ELSE @empresa END 
                      AND aItc.empresa <= CASE WHEN @empresa = 0 THEN 9999 ELSE @empresa END 
                      AND aItc.codigo >= CASE WHEN @codigo = 0 THEN 0 ELSE @codigo END 
                      AND aItc.codigo <= CASE WHEN @codigo = 0 THEN 99999999 ELSE @codigo END
                      AND aItc.mes_operacion >= @mesNon 
                      AND aItc.mes_operacion <= @mesPar 
                      AND YEAR(aItc.fch_mov) = @ayo
                      AND aItc.horaProceso = @horaproceso
                      AND aItc.fechaProceso = @fechaproceso
                      AND aItc.proceso = @proceso
                      AND ((aItc.mov = 'IM' AND aItc.diastr > 0)
                           OR (aItc.mov = 'MS' AND aItc.diastr IS NOT NULL)
                           OR (aItc.mov = 'RI' AND aItc.diastr IS NOT NULL)
                           OR (aItc.mov = 'B' AND aItc.diastr IS NOT NULL)
                           OR (aItc.mov = 'A' AND aItc.diastr IS NOT NULL)
                           OR (aItc.mov = 'UM' AND aItc.diastr IS NOT NULL))

       ORDER BY empleado.ap_paterno,
                empleado.ap_materno,
                empleado.nombre,
                aItc.fch_mov,
                aItc.serial 
*/
GO

/**************************************************************************************************
 * Name          : ObtieneResumenClaseInfonavit
 * Project       : APSI Nomina
 * Description   : Obtiene la tabla con el resumen
 * Table name    : 
 * Return        : tabla con resumen por clase
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Agosto 19, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneResumenClaseInfonavit' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneResumenClaseinfonavit]
    END
go


CREATE PROCEDURE [dbo].[ObtieneResumenClaseInfonavit]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mes INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT
AS 
    SELECT  salario ,
            diastr ,
            incap ,
            ausen ,
            cuotaFija ,
            excedente ,
            excedentePatron ,
            exccedenteTrabajador ,
            prestacionesDinero ,
            prestacionesPatron ,
            prestacionesTrabajador ,
            gmp ,
            gmpPatron ,
            gmpTrabajador ,
            rt ,
            invalidezVida ,
            invalidezVidaPatron ,
            invalidezVidaTrabajador ,
            guarderias ,
            cesantiaVejez ,
            cesantiaVejezPatron ,
            cesantiaVejezTrabajador ,
            clase ,
            registroPorClase ,
            registroExc ,
            baseCotizacionCuotaFija ,
            baseCotizacionExc ,
            baseCotizacionPD ,
            baseCotizacionGMP ,
            baseCotizacionRT ,
            baseCotizacionIV ,
            baseCotizacionGPS ,
            baseCotizacionCV ,
            nombreClase ,
            articulo106I ,
            articulo106II ,
            articulo107 ,
            articulo25 ,
            articulo71 ,
            articulo147 ,
            articulo211,
            infonavit,
            infonavitSinCredito ,
            infonavitConCredito ,
            sinCreditado ,
            conCreditado ,
            seguroVivienda ,
            amortizacion ,
            baseCotizacionInfonavitSin,
            baseCotizacionInfonavitCon,
            articulo168II,
            diasCotizadosSin,
            diasCotizadosCon
    FROM    [dbo].[LlenaResumenClaseInfonavit](@empresa, @codigo, @ayo, @mes, @proceso, @fechaProceso, @horaProceso, @simulaReforma)
    ORDER BY clase

GO

/**************************************************************************************************
 * Name          : ObtieneResumenISN
 * Project       : APSI Nomina
 * Description   : Obtiene total ISN
 * Table name    : 
 * Return        : tabla con resumen ISN
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Agosto 16, 2016
 **************************************************************************************************/
IF OBJECT_ID('dbo.ObtieneResumenISN') IS NOT NULL
   DROP  PROCEDURE [dbo].[ObtieneResumenISN]
GO
CREATE PROCEDURE [dbo].[ObtieneResumenISN]
    @empresa INT ,
    @tipoNomina INT ,
    @nomina CHAR(3) ,
    @ordenadoPor INT ,
    @procesoId INT ,
    @procesoName VARCHAR(100) ,
    @incluirProvisiones CHAR(1) ,
    @desglosadoPor INT ,
    @esRecibo INT ,
    @ayoEjercicio INT ,
    @saltoPagina CHAR(1) ,
    @proceso VARCHAR(250) ,
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS
    SET NOCOUNT ON

    DECLARE @apostrofe CHAR(1)
    DECLARE @centroSeleccionado VARCHAR(500)
    DECLARE @codigoSeleccionado VARCHAR(500)
    --DECLARE @whereSinProvisiones VARCHAR(500)
    --DECLARE @grupo VARCHAR(500)
    --DECLARE @textoGrupo VARCHAR(500)
    DECLARE @porCentro INT
    DECLARE @queFuncion VARCHAR(50)
    DECLARE @saltaPagina VARCHAR(50)
    DECLARE @campoSaltaPagina VARCHAR(50)
    --DECLARE @regPatronal CHAR(10)
    --DECLARE @subsTotal VARCHAR(50)
    --DECLARE @sql VARCHAR(4000)
    DECLARE @fechaProcesoChar CHAR(10)
    
    SET @apostrofe = CHAR(39)
    --SET @subsTotal = CASE WHEN @esRecibo = 1 AND
    --                           EXISTS (SELECT Num_Conc FROM Conceptos WHERE Num_Conc = 36 AND Variable2 = 'MUESTRA' AND Empresa = @empresa)
    --                      THEN 'ISNULL(ImprimeDetalle.subsTotal,0) as subsTotal,'
    --                      ELSE '0 as subsTotal,'
    --                 END

    IF @procesoName = 'NominaDetalle'
        OR @procesoName = 'NominaNoOrdinaria'
        OR @procesoName = 'ReciboFondoAhorro'
        BEGIN
         -- Checa los centro de costos seleccionados
            IF ( ( @ordenadoPor & 4 > 0
                   OR @ordenadoPor & 8 > 0
                   OR @ordenadoPor & 16 > 0
                   OR @ordenadoPor & 32 > 0
                 )
                 OR ( ( @ordenadoPor & 1 > 0
                        OR @ordenadoPor & 2 > 0
                      )
                      AND @desglosadoPor = 2
                    )
               )
                BEGIN
                    IF EXISTS ( SELECT  dbo.SeleccionElementos.centro
                                FROM    dbo.SeleccionElementos
                                WHERE   dbo.SeleccionElementos.empresa = @empresa
                                        AND dbo.SeleccionElementos.procesoName = 'NominaDetalle'
                                        AND dbo.SeleccionElementos.tipoNomina = @tipoNomina
                                        AND dbo.SeleccionElementos.nomina = @nomina
                                        AND dbo.SeleccionElementos.centro > '' )
                        AND @esRecibo = 0
                        BEGIN
                            SET @centroSeleccionado = 'INNER JOIN dbo.SeleccionElementos AS porCentro ON ImprimeDetalle.empresa = porCentro.empresa AND LTRIM(RTRIM(ImprimeDetalle.centro)) = LTRIM(RTRIM(porCentro.centro)) AND ImprimeDetalle.procesoName = porCentro.procesoName AND ImprimeDetalle.nomina = porCentro.nomina '
                            SET @porCentro = 1
                        END
                    ELSE
                        BEGIN
                            SET @centroSeleccionado = ''
                            SET @porCentro = 0
                        END
                END
            ELSE
                BEGIN
                    SET @porCentro = 0
                END


         -- Checa los codigos seleccionados
            IF EXISTS ( SELECT  codigo
                        FROM    dbo.SeleccionElementos
                        WHERE   empresa = @empresa
                                AND procesoName = @procesoName
                                AND codigo > 0
                                AND ( @esRecibo = 1
                                      OR @esRecibo = 2
                                      --OR @esRecibo = 3
                                    ) )
                SET @codigoSeleccionado = 'INNER JOIN dbo.SeleccionElementos AS porCodigo ON ImprimeDetalle.empresa = porCodigo.empresa AND ImprimeDetalle.codigo = porCodigo.codigo AND ImprimeDetalle.procesoName = porCodigo.procesoName AND ImprimeDetalle.nomina = porCodigo.nomina '
            ELSE
                SET @codigoSeleccionado = ''

        END

    SET @campoSaltaPagina = ', ImprimeDetalle.saltarPagina '
    SET @saltaPagina = ''

    IF @esRecibo = 0
        BEGIN
            SET @queFuncion = 'dbo.LlenaImpresionNomina'
            IF @saltoPagina = 'S'
               SET @saltaPagina = ',' + @apostrofe + @saltoPagina + @apostrofe
            ELSE
               SET @saltaPagina = ',' + @apostrofe + 'N' + @apostrofe
        END
    ELSE
        IF @esRecibo = 1
            SET @queFuncion = 'dbo.LlenaImpresionRecibo'
        ELSE
            IF @esRecibo = 2
                SET @queFuncion = 'dbo.LlenaImpresionReciboNoOrdinaria'
            --ELSE
            --    IF @esRecibo = 3 -- Recibo completo (se imprime todos los conceptos)
            --        SET @queFuncion = 'dbo.LlenaImpresionReciboFondoAhorro'

    IF @procesoName = 'NominaDetalle'
        OR @procesoName = 'NominaNoOrdinaria'
        OR @procesoName = 'ReciboFondoAhorro'
        BEGIN
          DECLARE @join VARCHAR(500) 
		  SET @join = ''
          DECLARE @campoNeto VARCHAR(500)
          SET @campoNeto = ', NULL    AS Disfrute, NULL    AS Fin_Disfru, NULL    AS Fch_Pago, CASE WHEN ImprimeDetalle.renglon = 1 THEN 0 ELSE 0 END AS NETO, CASE WHEN ImprimeDetalle.renglon = 1 THEN '''' ELSE '''' END AS netoEnLetra '
          
            DECLARE @joinDomicilio VARCHAR(500)
            DECLARE @camposDomicilio VARCHAR(900)

            SET @joinDomicilio = 'LEFT JOIN dbo.Parametros_Empresas AS parametroEmpresa ON parametroEmpresa.empresa = ImprimeDetalle.Empresa ' 
            SET @camposDomicilio = ', CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.CalleFiscal      ELSE '''' END AS CalleFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.NoExteriorFiscal ELSE '''' END AS NoExteriorFiscal, ' + 
                                   '   CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.NoInteriorFiscal ELSE '''' END AS NoInteriorFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.ColoniaFiscal    ELSE '''' END AS ColoniaFiscal, ' +
                                   '   CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.EstadoFiscal     ELSE '''' END AS EstadoFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.LocalidadFiscal  ELSE '''' END AS LocalidadFiscal, ' +
                                   '   CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.MunicipioFiscal  ELSE '''' END AS MunicipioFiscal, ' +
                                   '  CASE WHEN ImprimeDetalle.renglon = 1 THEN parametroEmpresa.CPFiscal         ELSE '''' END AS CPFiscal '

            SET @centroSeleccionado = ISNULL(@centroSeleccionado, '')
            SET @codigoSeleccionado = ISNULL(@codigoSeleccionado,'')
            SET @fechaProcesoChar = @apostrofe + RIGHT(10000 + YEAR(@fechaProceso),4) + RIGHT(100 + MONTH(@fechaProceso),2) + RIGHT(100 + DAY(@fechaProceso),2) + @apostrofe

            EXECUTE('SELECT ImprimeDetalle.empresa, ' +
            'RTRIM(LTRIM(ImprimeDetalle.centro)) AS centro, ' +
            'ImprimeDetalle.nombreCentro , ' +
            'ImprimeDetalle.numeroConceptoProvision , ' +
            'ImprimeDetalle.nombreConceptoProvision , ' +
            'ImprimeDetalle.importeConceptoProvision , ' +
            'ImprimeDetalle.empleados , ' +
            'ImprimeDetalle.basePorcientoSobreNomina , ' +
            'ImprimeDetalle.porcientoSobreNomina ' +
            'FROM dbo.KardexImprimeResumenISN AS ImprimeDetalle ' +
            @centroSeleccionado + ' ' +
            @codigoSeleccionado + ' ' +
            @join + ' ' + 
            'WHERE ImprimeDetalle.horaProceso = ' + @apostrofe + @horaProceso + @apostrofe + '
                  AND ImprimeDetalle.fechaProceso = ' + @fechaProcesoChar + '
                  AND ImprimeDetalle.proceso = ' + @apostrofe + @proceso + @apostrofe + '
            AND ImprimeDetalle.procesoName = ' + @apostrofe + @procesoName + @apostrofe + '
            ORDER BY ImprimeDetalle.centro,
                     ImprimeDetalle.nombreCentro')
        END
GO

IF OBJECT_Id('dbo.ObtieneRpu') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneRpu
GO
CREATE PROCEDURE dbo.ObtieneRpu
@empresa INT

AS

  SET NOCOUNT ON
  
  SELECT empresa,
         rpu,
         reg_pat,
         nombre,
         referencia,
         direccion,
         colonia,
         poblacion,
         delegacion,
         subdelegacion,
         zona_geografica,
         guia,
         entidad,
         nomentidad,
         folio_primer_empleo,
         representante_legal,
         puesto_representante,
         actividad,
         nombre_sub_delegacion,
         patron_paga_cuotas_imss,
         clase,
         fraccion_rt,
         regimen_seguridad_social,
         cod_postal,
         prima_rt,
         clave,
         rfc,
         [control],
         numeroExterior,
         numeroInterior,
         municipio,
         localidad
  FROM dbo.rpu
  WHERE CASE WHEN @empresa = 0 THEN @empresa ELSE empresa END = @empresa
  ORDER BY rpu
GO

/**************************************************************************************************
 * Name          : ObtieneSalarioMinimo
 * Project       : APSI Nomina
 * Description   : Obtiene salario minimo 
 * Table name    : salarios_minimos
 * Return        : tabla con salarios minimos
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Lunes, Mayo 03, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneSalarioMinimo' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneSalarioMinimo]
    END
go


CREATE PROCEDURE [dbo].[ObtieneSalarioMinimo]
    @empresa INT ,
    @ayo INT ,
    @mes INT
AS 
    DECLARE @salarioRegionA FLOAT
    DECLARE @salarioRegionB FLOAT
    DECLARE @salarioRegionC FLOAT
    DECLARE @salarioRegion FLOAT
    DECLARE @salarioDF FLOAT
    DECLARE @areaGeografica CHAR(1)
    DECLARE @fechaSalario DATETIME

    SELECT  @areaGeografica = dbo.empresas.zona_geografica
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa


-- Obtiene Salario Minimo
    SELECT  @salarioRegionA = ISNULL(zona_a, 0) ,
            @salarioRegionB = ISNULL(zona_b, 0) ,
            @salarioRegionC = ISNULL(zona_c, 0) ,
            @fechaSalario = fecha_ini
    FROM    [dbo].[GetMinimumWage](@mes, @ayo)
        
    SET @salarioDF = @salarioRegionA
        
    SET @salarioRegion = CASE @areaGeografica
                           WHEN 'A' THEN @salarioRegionA
                           WHEN 'B' THEN @salarioRegionB
                           WHEN 'C' THEN @salarioRegionC
                           ELSE 0
                         END
                         
    SELECT @salarioDF AS salarioDF, @salarioRegion AS salarioRegion, @fechaSalario AS fechaSalario
GO

IF OBJECT_Id('dbo.ObtieneSalarioUMAPorFechaFuncion') IS NOT NULL
   DROP FUNCTION dbo.ObtieneSalarioUMAPorFechaFuncion
GO
CREATE FUNCTION dbo.ObtieneSalarioUMAPorFechaFuncion (@empresa INT, @fecha DATETIME)
RETURNS @tablaSalarioMinimoUMA TABLE
        (empresa INT,
         fechaUMA DATETIME, 
         umaDiario NUMERIC(12,2),
         umaMensual NUMERIC(12,2),
         umaAnual NUMERIC(12,2),
         fechaSM DATETIME,
         salarioMinimoDF NUMERIC(12,2),
         salarioMinimoRegion NUMERIC(12,2),
         tope25Veces NUMERIC(12,2),
         topeMinimo NUMERIC(12,2),
         topeMinimoIntegrado NUMERIC(12,2),
         topeDespensa NUMERIC(12,2))
AS
  BEGIN
    DECLARE @fechaUMA DATETIME
    DECLARE @umaDiario NUMERIC(12,2)
    DECLARE @umaMensual NUMERIC(12,2)
    DECLARE @umaAnual NUMERIC(12,2)
    DECLARE @fechaSM DATETIME
    DECLARE @salarioMinimoDF NUMERIC(12,2)
    DECLARE @salarioMinimoRegion NUMERIC(12,2)
    DECLARE @tope25Veces NUMERIC(12,2)
    DECLARE @topeMinimo NUMERIC(12,2)
    DECLARE @topeMinimoIntegrado NUMERIC(12,2)
    DECLARE @zonaGeografica CHAR(1)
    DECLARE @topeDespensa NUMERIC(12,2)
    
    SELECT @zonaGeografica = empresa.zona_geografica
    FROM dbo.empresas AS empresa
    WHERE empresa.empresa = @empresa
    
    SELECT TOP 1
           @fechaUMA = uma.fecha,
           @umaDiario = uma.umaDiario,
           @umaMensual = uma.umaMensual,
           @umaAnual = uma.umaAnual
    FROM dbo.TblUMA AS uma
    WHERE uma.fecha <= @fecha
    ORDER BY uma.fecha DESC

    SET @fechaUMA = CASE WHEN @fechaUMA IS NULL THEN '' ELSE @fechaUMA END
    SET @umaDiario = CASE WHEN @umaDiario IS NULL THEN 0 ELSE @umaDiario END
    SET @umaMensual = CASE WHEN @umaMensual IS NULL THEN 0 ELSE @umaMensual END
    SET @umaAnual = CASE WHEN @umaAnual IS NULL THEN 0 ELSE @umaAnual END

    SELECT TOP 1
           @fechaSM = salarioMinimo.fecha_ini,
           @salarioMinimoDF = salarioMinimo.zona_a,
           @salarioMinimoRegion = CASE @zonaGeografica WHEN 'A' THEN salarioMinimo.zona_a
                                                       WHEN 'B' THEN salarioMinimo.zona_b
                                                       WHEN 'C' THEN salarioMinimo.zona_c
                                                       ELSE 0
                                  END
    FROM dbo.salarios_minimos AS salarioMinimo
    WHERE salarioMinimo.fecha_ini <= @fecha
    ORDER BY fecha_ini DESC
    
  SET @fechaSM = CASE WHEN @fechaSM IS NULL THEN '' ELSE @fechaSM END
  SET @salarioMinimoDF = CASE WHEN @salarioMinimoDF IS NULL THEN 0 ELSE @salarioMinimoDF END
  SET @salarioMinimoRegion = CASE WHEN @salarioMinimoRegion IS NULL THEN 0 ELSE @salarioMinimoRegion END
    
  IF @fecha >= '20170101'
     BEGIN
       SET @tope25Veces = ROUND(@umaDiario * 25,2)
       SET @topeMinimo = @umaDiario
       SET @topeDespensa = ROUND(@umaDiario * 0.40,2)
     END
  ELSE
     BEGIN
       SET @tope25Veces = ROUND(@salarioMinimoDF * 25,2)
       SET @topeMinimo = @salarioMinimoRegion
       SET @topeDespensa = ROUND(@salarioMinimoDF * 0.40,2)
     END
    
  SET @topeMinimoIntegrado = ROUND(@salarioMinimoRegion * dbo.Fun_ObtieneFactorIntegracion(@fecha),2)
  
  INSERT @tablaSalarioMinimoUMA 
        (empresa,
         fechaUMA, umaDiario, umaMensual, umaAnual,
         fechaSM, salarioMinimoDF, salarioMinimoRegion,
         tope25Veces, topeMinimo, topeMinimoIntegrado,
         topeDespensa)
         
         VALUES
         
         (@empresa,
          @fechaUMA, @umaDiario, @umaMensual, @umaAnual,
          @fechaSM, @salarioMinimoDF, @salarioMinimoRegion,
          @tope25Veces, @topeMinimo, @topeMinimoIntegrado,
          @topeDespensa)
            
    RETURN
  END
GO

IF OBJECT_ID('dbo.ObtieneSBC') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneSBC
GO
CREATE PROCEDURE dbo.ObtieneSBC
@empresa INT,
@codigo INT,
@fecha DATETIME,
@cuotadiaria NUMERIC(12,2),
@accion INT,
@usuario VARCHAR(30),
@ip VARCHAR(15),
@mac VARCHAR(17),
@nombreequipo VARCHAR(50),
@origen VARCHAR(2),
@clase VARCHAR(2),
@partevariablecalculadausuario NUMERIC(12,2),
@fechaantigua DATETIME,
@jornada INT,
@nombre VARCHAR(90),
@tiposalario INT,
@rpu CHAR(3),
@ocupacion INT,
@centro VARCHAR(15),
@tiponom INT,
@soloerror BIT,
@tipoaumento BIT,
@aumentoporciento NUMERIC(12,5),
@aumentocantidad NUMERIC(12,5)

AS

  SET NOCOUNT ON

  -- @accion 1.- Audita, 2.- AutoRegula, 3.- Calcula SBC codigo especifico
  DECLARE @fechainiciomes DATETIME
  DECLARE @fechafinmes DATETIME
  DECLARE @ayofechafinmes INT
  DECLARE @mesfechafinmes INT
  DECLARE @usardias VARCHAR(30)
  DECLARE @ayoanterior INT
  DECLARE @mesanterior1 INT
  DECLARE @mesanterior2 INT
  DECLARE @diasanterior1 INT
  DECLARE @diasanterior2 INT
  DECLARE @fechainiciomesanterior1 DATETIME
  DECLARE @fechafinmesanterior1 DATETIME
  DECLARE @fechainiciomesanterior2 DATETIME
  DECLARE @fechafinmesanterior2 DATETIME
  DECLARE @fechainiciomesoperacion DATETIME
  DECLARE @fechafinmesoperacion DATETIME
  DECLARE @topadespensa VARCHAR(30)
  DECLARE @registropatronal VARCHAR(11)
  DECLARE @sueldo NUMERIC(12,2)
  DECLARE @partevariable NUMERIC(12,2)
  DECLARE @fondoahorro NUMERIC(12,2)
  DECLARE @sbc_ok NUMERIC(12,2)
  DECLARE @obs_baja CHAR(1)
  DECLARE @obs_fecha CHAR(1)
  DECLARE @obs_factor CHAR(1)
  DECLARE @obs_otros VARCHAR(4)
  DECLARE @observacion VARCHAR(25)
  DECLARE @existecodigo BIT
  DECLARE @obs_auto VARCHAR(50)
  DECLARE @factor NUMERIC(7,4)
  DECLARE @sbclaboral NUMERIC(12,2)
  DECLARE @factorlaboral NUMERIC(7,4)
  DECLARE @importesfijos NUMERIC(12,2)
  DECLARE @importefijolaboral NUMERIC(12,2)
  DECLARE @despensalaboral NUMERIC(12,2)
  DECLARE @sbccalculado NUMERIC(12,2)
  DECLARE @topeminimointegrado NUMERIC(12,2)
  DECLARE @historia BIT
  DECLARE @percepcionvariable NUMERIC(12,2)
  DECLARE @diastr INT
  DECLARE @ausen INT
  DECLARE @incap INT
  DECLARE @centroperfil TABLE (costCenter VARCHAR(15))
  DECLARE @nominaperfil TABLE (typePayroll INT)
  DECLARE @bimestreoperacion CHAR(6)
  DECLARE @bimestreiniciomes CHAR(6)
  DECLARE @diasfechafinmes INT
  DECLARE @ayonon INT
  DECLARE @mesnon INT
  DECLARE @fechainicionon DATETIME
  DECLARE @fechafinnon DATETIME
  DECLARE @diasnon INT
  DECLARE @sueldotmp NUMERIC(12,2)
  DECLARE @aguinaldo decimal(8, 4)
  DECLARE @prima_vac decimal(8, 4)
  DECLARE @dias_vac decimal(8, 4)
  DECLARE @pmavacdias decimal(6, 2)
  DECLARE @dias_ayo decimal(8, 4)
  DECLARE @porc_ayo decimal(8, 4)
  DECLARE @porc_mes decimal(8, 4)
  DECLARE @porc_dia decimal(8, 4)
  DECLARE @pmo1ayopor decimal(8, 4)
  DECLARE @pmo2ayopor decimal(8, 4)
  DECLARE @dias_mes decimal(8, 4)
  DECLARE @fdoahopatp decimal(8, 4)
  DECLARE @ayotmp INT


  DELETE dbo.auditoria
  WHERE empresa = @empresa
        AND ISNULL(mac,'') = ''

  DELETE dbo.auditoria
  WHERE empresa = @empresa
        AND LTRIM(RTRIM(usuario)) = LTRIM(RTRIM(@usuario))
        AND LTRIM(RTRIM(mac)) = LTRIM(RTRIM(@mac))

  IF @fecha IS NOT NULL OR @fecha <> '19000101'
     BEGIN
       IF @origen <> 'VA'
          BEGIN
            INSERT @centroperfil (costCenter)
                   SELECT costCenter
                   FROM [dbo].[GetCostCenterByProfile](@usuario,
                                                       '', --@centrocostoempleado,
                                                       @empresa,
                                                       'NO')

            INSERT @nominaperfil (typePayroll)
                   SELECT typePayroll
                   FROM [dbo].[GetTypePayrollByProfile](@usuario,
                                                        0,
                                                        @empresa,
                                                        'NO')
          END
       ELSE
          BEGIN
            INSERT @centroperfil (costCenter) VALUES ('')
            INSERT @nominaperfil (typePayroll) VALUES (9)
          END

       SET @ayofechafinmes = YEAR(@fecha)
       SET @mesfechafinmes = MONTH(@fecha)
       SET @fechainiciomes = CONVERT(DATETIME, RIGHT(10000 + @ayofechafinmes,4) + RIGHT(100 + @mesfechafinmes,2) + '01')
       SET @fechafinmes = dbo.fin_mes(@mesfechafinmes, @ayofechafinmes)
       SET @bimestreiniciomes = LTRIM(RTRIM(STR((MONTH(@fecha) % 2) + (MONTH(@fecha) / 2)))) + RIGHT(YEAR(@fecha),4)
       SET @diasfechafinmes = DATEDIFF(DD, @fechainiciomes, @fechafinmes) + 1

       IF @mesfechafinmes % 2 = 0
          BEGIN
            SET @ayonon = YEAR(@fecha)
            SET @mesnon = @mesfechafinmes - 1
            SET @fechainicionon = CONVERT(DATETIME, RIGHT(10000 + @ayofechafinmes,4) + RIGHT(100 + @mesfechafinmes - 1,2) + '01')
            SET @fechafinnon = dbo.fin_mes(@mesnon, @ayonon)
            SET @diasnon = DATEDIFF(DD, @fechainicionon, @fechafinnon) + 1
          END

       IF @accion = 1
          BEGIN
            SET @codigo = 0
            SET @cuotadiaria = 0
          END

       IF @accion = 2
          BEGIN
            SET @codigo = 0
            SET @cuotadiaria = 0
          END

       IF @accion = 3
          BEGIN
            IF EXISTS (SELECT empleado.codigo FROM dbo.empleados AS empleado WHERE empleado.empresa = @empresa AND empleado.codigo = @codigo)
               BEGIN
                 SET @existecodigo = 1

                 SELECT @historia = CASE WHEN empleado.activo = 'S' THEN 0 ELSE 1 END
                 FROM dbo.empleados AS empleado
                 WHERE empleado.empresa = @empresa AND empleado.codigo = @codigo

                 IF @historia IS NULL
                    SET @historia = 1
               END
            ELSE
               SET @existecodigo = 0
          END

       -- Valor permitido DIASNOMINA, DIASNATURALES
       SELECT @usardias = ISNULL(empresa.DivisorPercepcionesVariables, 'DIASNATURALES'),
              @fechainiciomesoperacion = CONVERT(DATETIME, RIGHT(empresa.ayo_operacion,4) + RIGHT(100 + empresa.mes_operacion,2) + '01'),
              @fechafinmesoperacion = dbo.fin_mes(empresa.mes_operacion, empresa.ayo_operacion),
              @registropatronal = empresa.registro_patronal,
              @bimestreoperacion = LTRIM(RTRIM(STR((empresa.mes_operacion % 2) + (empresa.mes_operacion / 2)))) + RIGHT(empresa.ayo_operacion,4)
       FROM dbo.empresas AS empresa WHERE empresa.empresa = @empresa

       SET @topadespensa = UPPER(RTRIM(LTRIM(ISNULL(( SELECT TOP 1
                                                             variable2
                                                      FROM dbo.conceptos
                                                      WHERE empresa = @empresa
                                                            AND num_conc = 31), 'SINTOPE'))))

       IF @mesfechafinmes % 2 = 1
          BEGIN
            SET @ayoanterior = YEAR(DATEADD(MM, -1,@fechainiciomes))
            SET @mesanterior1 = MONTH(DATEADD(MM, -2,@fechainiciomes))
            SET @mesanterior2 = MONTH(DATEADD(MM, -1,@fechainiciomes))
          END

       IF @mesfechafinmes % 2 = 0
          BEGIN
            SET @ayoanterior = YEAR(DATEADD(MM, -2,@fechainiciomes))
            SET @mesanterior1 = MONTH(DATEADD(MM, -3,@fechainiciomes))
            SET @mesanterior2 = MONTH(DATEADD(MM, -2,@fechainiciomes))
          END

       SET @fechainiciomesanterior1 = CONVERT(DATETIME, RIGHT(@ayoanterior,4) + RIGHT(100 + @mesanterior1,2) + '01')
       SET @fechafinmesanterior1 = dbo.fin_mes(@mesanterior1, @ayoanterior)
       SET @diasanterior1 = DATEDIFF(DD, @fechainiciomesanterior1, @fechafinmesanterior1) + 1

       SET @fechainiciomesanterior2 = CONVERT(DATETIME, RIGHT(@ayoanterior,4) + RIGHT(100 + @mesanterior2,2) + '01')
       SET @fechafinmesanterior2 = dbo.fin_mes(@mesanterior2, @ayoanterior)
       SET @diasanterior2 = DATEDIFF(DD, @fechainiciomesanterior2, @fechafinmesanterior2) + 1

       --IF @usardias = 'DIASNATURALES'
       --   BEGIN
            EXECUTE dbo.asp_ds @empresa, @codigo, @ayoanterior, @mesanterior1, @fechafinmesanterior1
            EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayoanterior, @mesanterior1, @diasanterior1
            EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayoanterior, @mesanterior1

            EXECUTE dbo.asp_ds @empresa, @codigo, @ayoanterior, @mesanterior2, @fechafinmesanterior2
            EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayoanterior, @mesanterior2, @diasanterior2
            EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayoanterior, @mesanterior2

            EXECUTE dbo.asp_ds @empresa, @codigo, @ayofechafinmes, @mesfechafinmes, @fechafinmes
            EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayofechafinmes, @mesfechafinmes, @diasanterior1
            EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayofechafinmes, @mesfechafinmes

            IF @mesfechafinmes % 2 = 0
               BEGIN
                 EXECUTE dbo.asp_ds @empresa, @codigo, @ayonon, @mesnon, @fechafinnon
                 EXECUTE dbo.asp_ds_aus @empresa, @codigo, @ayonon, @mesnon, @diasnon
                 EXECUTE dbo.asp_ds_inc @empresa, @codigo, @ayonon, @mesnon
               END
       --   END

       IF @tiposalario IS NOT NULL
          BEGIN
            SET @tiposalario = CASE WHEN @tiposalario >= 0 AND @tiposalario <= 2 THEN @tiposalario ELSE 2 END
          END

       IF (@accion = 1 AND @codigo = 0 AND @cuotadiaria = 0) OR (@accion = 2 AND @codigo = 0 AND @cuotadiaria = 0) OR (@accion = 3 AND @codigo > 0 AND @existecodigo = 1 AND @historia = 0)
          BEGIN
            INSERT dbo.auditoria
                   ( empresa,
                     codigo,
                     ayos,
                     sueldo,
                     factor ,
                     excedenteDespensa,
                     importesFijos,
                     percepcionVariable,
                     sdi_reportado ,
                     clase,
                     nombre,
                     fch_antigua,
                     tipo_salario,
                     mes,
                     ayo,
                     usuario ,
                     incapacitado ,
                     mov ,
                     fch_mov ,
                     fchalta ,
                     rpu,
                     nombreClase,
                     ocupacion,
                     centro,
                     jornada,
                     salDf,
                     salMin,
                     umaDiario,
                     tiponom,
                     diastr,
                     ausen,
                     incap,
                     DivisorPercepcionesVariables,
                     ip,
                     mac,
                     nombreEquipo,
                     origen,
                     obs_auto,
                     topaDespensa,
                     fondoAhorroPatron,
                     fondoAhorroEmpleado,
                     fecha_auto,
                     accion,
                     topeDespensa,
                     ultimoAvisoMov,
                     ultimoAvisoFch_Mov,
                     topeUltimoAviso,
                     minimoUltimoAviso,
                     topeAuditoria,
                     minimoAuditoria,
                     minimoAuditoriaIntegrado,
                     existeCodigo,
                     parte_variable,
                     despensa,
                     despensaim,
                     fechaUMA,
                     factorLaboral,
                     despensaLaboral,
                     tieneAvisoAnterior,
                     serial,
                                         diasLaboral,
                                         percepcionVariableLaboral,
                                         parteVariableLaboral)

                   SELECT empleado.empresa,
                          empleado.codigo,

                          -- Aos antiguedad
                          [dbo].[CalculaAyosAntiguedad](CASE WHEN @codigo > 0 AND @fechaantigua IS NOT NULL
                                                             THEN @fechaantigua
                                                             ELSE ISNULL(antiguedad.fchantigua, CASE WHEN empleado.fchantigua = '19000101' OR empleado.fchantigua IS NULL
                                                                                                     THEN empleado.fchalta
                                                                                                     ELSE empleado.fchantigua
                                                                                                END)
                                                        END, CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion THEN CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(mm,1,ultimaIntegracion.fch_mov))),DATEADD(mm,1,ultimaIntegracion.fch_mov)),112) ELSE @fechafinmes END) AS ayos,

                          -- Sueldo
                          CASE WHEN CASE WHEN @tiposalario IS NULL
                                         THEN empleado.tiposal
                                         ELSE @tiposalario
                                    END = 1
                               THEN 0
                               ELSE ultimoSueldo.sueldo
                          END AS sueldo,

                          -- Factor
                          CONVERT(NUMERIC(7,4), ROUND(1 + -- Constante
                                                (ISNULL(tablasInt.aguinaldo,0) / 365) + -- Aguinaldo
                                                (ISNULL(tablasInt.dias_vac,0) / 365) * (ISNULL(tablasInt.prima_vac,0) / 100) + -- Prima Vacacional dias y porcentaje
                                                (ISNULL(tablasInt.pmavacdias,0) / 365) + -- Dias Prima vacacional
                                                (ISNULL(tablasInt.dias_ayo,0) / 365) + -- dias x ao
                                                (ISNULL(tablasInt.porc_ayo,0) / 100) + -- Porcentaje por ao
                                                (ISNULL(tablasInt.porc_mes,0) / 100) + -- Porcentaje por mes
                                                (ISNULL(tablasInt.porc_dia,0) / 100) + -- Porcentaje por dia
                                                (ISNULL(tablasInt.pmo1ayopor,0) / 100) + -- Porcentaje premio Anual 1
                                                (ISNULL(tablasInt.pmo2ayopor,0) / 100) + -- Porcentaje premio Anual 2
                                                (ISNULL(tablasInt.dias_mes,0) / 30.4167),4)) AS factor,  -- Dias por mes

                          -- Excedente despensa
                          CONVERT(NUMERIC(10, 2), CASE WHEN @topadespensa = 'CONTOPE'
                                                       THEN CASE WHEN CASE WHEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0) ),2) > parametrosFechaAuditoria.topeMinimo --@salarioumaminimo
                                                                           THEN parametrosFechaAuditoria.topeMinimo
                                                                           ELSE ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2)
                                                                      END > parametrosFechaAuditoria.topeDespensa
                                                                 THEN CASE WHEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2) > parametrosFechaAuditoria.topeMinimo --@salarioumaminimo
                                                                           THEN parametrosFechaAuditoria.topeMinimo
                                                                           ELSE ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2)
                                                                      END - parametrosFechaAuditoria.topeDespensa
                                                                 ELSE 0
                                                            END
                                                       ELSE CASE WHEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2) > parametrosFechaAuditoria.topeDespensa --@ntope_despensa
                                                                 THEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2) - parametrosFechaAuditoria.topeDespensa --@ntope_despensa
                                                                 ELSE 0
                                                            END
                                                  END) AS exedente_despensa ,

                          -- Importes fijos
                          CONVERT(NUMERIC(12, 2), ISNULL((ROUND(tablasInt.imp_ayo / 365,2)
                                                          + ROUND(tablasInt.pmo1ayoimp / 365, 2)
                                                          + ROUND(tablasInt.pmo2ayoimp / 365, 2)
                                                          + ROUND(tablasInt.Imp_mes / 30.4167, 2)
                                                          + tablasInt.imp_dia ), 0)) AS importes_fijos,

                          -- Percepcion variable
                          CASE WHEN @accion = 3 AND ISNULL(percepcion.percepcionVariable,0) = 0 THEN 0 ELSE ISNULL(percepcion.percepcionVariable,0) END AS percepcionVariable,

                          -- sdi_reportado
                          ultimoSueldo.saldiaint,

                          CASE WHEN @clase = '' THEN llaves.clase ELSE @clase END AS clase, --llaves.clase,
                          RTRIM(empleado.ap_paterno) + ' ' + RTRIM(empleado.ap_materno) + ' ' + RTRIM(empleado.nombre) AS nombre,

                          CASE WHEN @codigo > 0 AND @fechaantigua IS NOT NULL
                               THEN @fechaantigua
                               ELSE ISNULL(antiguedad.fchantigua, CASE WHEN empleado.fchantigua = '19000101' OR empleado.fchantigua IS NULL THEN empleado.fchalta ELSE empleado.fchantigua END)
                          END AS fch_antigua,

                          --CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END AS tiposal,
                                                  CASE WHEN @codigo > 0 THEN @tiposalario ELSE empleado.tiposal END AS tiposal,

                          @mesfechafinmes AS mes,
                          @ayofechafinmes AS ayo,
                          @usuario,
                          ISNULL(incapacitado.incapacitado,'N') AS incapacitado,
                          ultimaIntegracion.mov,
                          ultimaIntegracion.fch_mov,
                          CASE WHEN empleado.fchalta IS NULL THEN CONVERT(DATETIME, '19000101') ELSE empleado.fchalta END AS fchalta,
                          empleado.rpu,
                          ISNULL(clase.nombre,' ') AS nombreClase,
                          llaves.ocupacion,
                          llaves.centro,
                          empleado.jornada,
                          parametrosFechaAuditoria.salarioMinimoDF,
                          parametrosFechaAuditoria.salarioMinimoRegion,
                          parametrosFechaAuditoria.umaDiario,
                          llaves.tiponom,

                          --CASE @usardias WHEN 'DIASNATURALES' THEN ISNULL(avisosImssDias.diastr,0)
                          --               --WHEN 'DIASNOMINA' THEN ISNULL(CASE WHEN CASE WHEN @codigo > 0 THEN @tiposalario ELSE empleado.tiposal END = 1 THEN nominaDias.diastr ELSE avisosImssDias.diastr END,0)
                          --               WHEN 'DIASNOMINA' THEN ISNULL(nominaDias.diastr,0)
                          --               ELSE 0
                          --END AS diastr,
                          CASE @usardias WHEN 'DIASNATURALES' THEN ISNULL(avisosImssDias.diastr,1)
                                         WHEN 'DIASNOMINA' THEN ISNULL(nominaDias.diastr,1)
                                         ELSE 0
                          END AS diastr,

                          CASE @usardias WHEN 'DIASNATURALES' THEN ISNULL(avisosImssDias.ausen,0) ELSE 0 END AS ausen,
                          CASE @usardias WHEN 'DIASNATURALES' THEN ISNULL(avisosImssDias.incap,0) ELSE 0 END AS incap,
                          @usardias,
                          LTRIM(RTRIM(@ip)) AS ip,
                          LTRIM(RTRIM(@mac)) AS mac,
                          LTRIM(RTRIM(@nombreequipo)) AS nombreEquipo,
                          LTRIM(RTRIM(@origen)) AS origen,
                          '' AS obs_auto,
                          @topadespensa AS topaDespensa,
                          ROUND((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.fdoahopatp,0)/100)) + ISNULL(tablasInt.fdoahopati,0),2) AS fondoAhorroPatron,
                          ROUND((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.fdoahotrap,0)/100)) + ISNULL(tablasInt.fdoahotrai,0),2) AS fondoAhorroEmpleado,
                          @fecha AS fecha_auto,
                          @accion AS accion,
                          parametrosFechaAuditoria.topeDespensa,
                          ultimoAviso.mov,
                          ultimoAviso.fch_mov,
                          parametrosUltimaIntegracion.tope25Veces,
                          parametrosUltimaIntegracion.topeMinimo,
                          parametrosFechaAuditoria.tope25Veces,
                          parametrosFechaAuditoria.topeMinimo,
                          0 AS topeMinimoIntegrado,
                          1 AS existeCodigo,

                          CASE WHEN @origen = 'VA'
                               THEN 0
                               ELSE CASE WHEN @fechainiciomes >= @fechainiciomesoperacion
                                         THEN CASE WHEN empleado.var_sigmes = 'T'
                                                   THEN empleado.varia_next
                                                   ELSE empleado.varia_imss
                                              END
                                         ELSE 0
                                    END
                          END AS parte_variable,

                          ISNULL(tablasInt.despensa,0) AS despensa,
                          ISNULL(tablasInt.despensaim,0) AS despensaim,
                          parametrosFechaAuditoria.fechaUMA,

                          -- Factor Laboral
                          CONVERT(NUMERIC(7,4), ROUND(1 + -- Constante
                                                + (ISNULL(tablasInt.aguinaldo,0) / 365)  -- Aguinaldo
                                                + (ISNULL(tablasInt.dias_vac,0) / 365) * (ISNULL(tablasInt.prima_vac,0) / 100)  -- Prima Vacacional dias y porcentaje
                                                + (ISNULL(tablasInt.pmavacdias,0) / 365)  -- Dias Prima vacacional
                                                + (ISNULL(tablasInt.dias_ayo,0) / 365)  -- dias x ao
                                                + (ISNULL(tablasInt.porc_ayo,0) / 100)  -- Porcentaje por ao
                                                + (ISNULL(tablasInt.porc_mes,0) / 100)  -- Porcentaje por mes
                                                + (ISNULL(tablasInt.porc_dia,0) / 100)  -- Porcentaje por dia
                                                + (ISNULL(tablasInt.pmo1ayopor,0) / 100)  -- Porcentaje premio Anual 1
                                                + (ISNULL(tablasInt.pmo2ayopor,0) / 100)  -- Porcentaje premio Anual 2
                                                + (ISNULL(tablasInt.dias_mes,0) / 30.4167),4))  -- Dias por mes
                                                --(ISNULL(tablasInt.fdoahopatp,0) / 100),4))
                                                                                                AS factorLaboral, -- + -- Fondo ahorro patron

                          CONVERT(NUMERIC(10, 2), CASE WHEN @topadespensa = 'CONTOPE'
                                                       THEN CASE WHEN CASE WHEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0) ),2) > parametrosFechaAuditoria.topeMinimo --@salarioumaminimo
                                                                           THEN parametrosFechaAuditoria.topeMinimo
                                                                           ELSE ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2)
                                                                      END > parametrosFechaAuditoria.topeDespensa
                                                                 THEN CASE WHEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2) > parametrosFechaAuditoria.topeMinimo --@salarioumaminimo
                                                                           THEN parametrosFechaAuditoria.topeMinimo
                                                                           ELSE ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2)
                                                                      END -- - parametrosFechaAuditoria.topeDespensa
                                                                 ELSE 0
                                                            END
                                                       ELSE --CASE WHEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2) > parametrosFechaAuditoria.topeDespensa --@ntope_despensa
                                                            --     THEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2) - parametrosFechaAuditoria.topeDespensa --@ntope_despensa
                                                            --     ELSE 0
                                                            --END
															CASE WHEN ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2) > parametrosFechaAuditoria.topeDespensa --@ntope_despensa
                                                                 THEN parametrosFechaAuditoria.topeDespensa 
                                                                 ELSE ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0)),2)
                                                            END
                                                  END) AS despensaLaboral,
						  --ROUND(((CASE WHEN CASE WHEN @tiposalario IS NULL THEN empleado.tiposal ELSE @tiposalario END = 1 THEN 0 ELSE ultimoSueldo.sueldo END * (ISNULL(tablasInt.despensa,0) / 100)) + ISNULL(tablasInt.despensaim,0) ),2) AS despensaLaboral,

                          ISNULL(avisoAnterior.tieneAvisoAnterior,0) AS tieneAvisoAnterior,
                          ISNULL(ultimoAviso.serial,0) AS serial,
                                                  ISNULL(nominaDiasLaboral.diasLaboral,0) AS diasLaboral,
                                                  ISNULL(percepcionLaboral.PercepcionVariableLaboral,0) AS percepcionVariableLaboral,

                                                  CASE WHEN ISNULL(nominaDiasLaboral.diasLaboral,0) > 0 AND ISNULL(percepcionLaboral.PercepcionVariableLaboral,0) > 0
                                                       THEN ROUND(ISNULL(percepcionLaboral.PercepcionVariableLaboral,0) / ISNULL(nominaDiasLaboral.diasLaboral,0),2)
                               ELSE 0
                          END AS parteVariableLaboral

                   FROM dbo.empleados AS empleado

                        INNER JOIN dbo.Llaves AS llaves ON empleado.empresa = llaves.empresa AND empleado.codigo = llaves.codigo
                        INNER JOIN dbo.empresas AS empresa ON empleado.empresa = empresa.empresa

                        CROSS APPLY (SELECT centroPerfil.costCenter
                                     FROM @centroperfil AS centroPerfil
                                     WHERE LTRIM(RTRIM(centroPerfil.costCenter)) = CASE WHEN @origen = 'VA' THEN '' ELSE LTRIM(RTRIM(llaves.centro)) END) AS centroPerfil

                        CROSS APPLY (SELECT nominaPerfil.typePayroll
                                     FROM @nominaperfil AS nominaPerfil
                                     WHERE nominaPerfil.typePayroll = CASE WHEN @origen = 'VA' THEN 9 ELSE llaves.tiponom END) AS nominaPerfil

                        CROSS APPLY (SELECT DISTINCT
                                            avisos.codigo
                                    FROM dbo.avisos_imss AS avisos
                                    WHERE avisos.empresa = empleado.empresa
                                          AND avisos.codigo = CASE WHEN @codigo > 0 THEN @codigo ELSE empleado.codigo END
                                          AND avisos.fch_mov >= CASE WHEN @fechafinmes > @fechafinmesoperacion THEN @fechainiciomesoperacion ELSE @fechainiciomes END
                                          AND avisos.fch_mov <= CASE WHEN @fechafinmes = @fechafinmesoperacion THEN DATEADD(MM,2, @fechafinmes) WHEN @fechafinmes > @fechafinmesoperacion THEN DATEADD(MM,1, @fechafinmes) ELSE @fechafinmes END) AS selectAvisos

                        CROSS APPLY (SELECT TOP 1
                                           ultimoSueldo.empresa,
                                           ultimoSueldo.codigo,
                                           ultimoSueldo.mov,
                                           CASE WHEN @codigo > 0 THEN @fecha ELSE ultimoSueldo.fch_mov END AS fch_mov,
                                           ultimoSueldo.serial,
                                           CASE WHEN @codigo > 0
                                                                                        THEN @cuotadiaria

                                                                                                ELSE CASE WHEN @origen <> 'AM'
                                                          THEN ultimoSueldo.sueldo
                                                          ELSE CASE WHEN @aumentoporciento > 0
                                                                    THEN ROUND(ultimoSueldo.sueldo + (ultimoSueldo.sueldo * (@aumentoporciento / 100) * CASE WHEN @tipoaumento = 1
                                                                                                                                                             THEN 1
                                                                                                                                                             ELSE -1
                                                                                                                                                        END),2)
                                                                    ELSE ultimoSueldo.sueldo
                                                               END + CASE WHEN @aumentocantidad > 0
                                                                          THEN (CASE WHEN @tipoaumento = 1
                                                                                     THEN 1
                                                                                     ELSE -1
                                                                                END * @aumentocantidad)
                                                                          ELSE 0
                                                                     END
                                                     END
                                                                                   END AS sueldo,
                                           ultimoSueldo.saldiaint
                                    FROM dbo.avisos_imss AS ultimoSueldo
                                    WHERE ultimoSueldo.empresa = empleado.empresa
                                          AND ultimoSueldo.codigo = empleado.codigo
                                          AND ultimoSueldo.fch_mov >= CASE WHEN @fechafinmes > @fechafinmesoperacion THEN @fechainiciomesoperacion ELSE @fechainiciomes END
                                          AND ultimoSueldo.fch_mov <= CASE WHEN @fechafinmes = @fechafinmesoperacion THEN DATEADD(MM,2, @fechafinmes) WHEN @fechafinmes > @fechafinmesoperacion THEN DATEADD(MM,1, @fechafinmes) ELSE @fechafinmes END
                                          AND ultimoSueldo.mov <> 'B'
                                    ORDER BY ultimoSueldo.fch_mov DESC ,
                                             ultimoSueldo.serial DESC) AS ultimoSueldo

                        CROSS APPLY (SELECT TOP 1 CASE WHEN ultMov.mov <> 'IM'  THEN 'IM' ELSE '' END AS mov
                                     FROM dbo.avisos_imss AS ultMov
                                     WHERE ultMov.empresa = empleado.empresa
                                           AND ultMov.codigo = empleado.codigo
                                           AND ultMov.fch_mov <= CASE WHEN @fechafinmes = @fechafinmesoperacion THEN DATEADD(MM,2, @fechafinmes) WHEN @fechafinmes > @fechafinmesoperacion THEN DATEADD(MM,1, @fechafinmes) ELSE @fechafinmes END
                                           AND ultMov.mov <> ISNULL((SELECT TOP 1 CASE WHEN ultMov2.mov <> 'IM'  THEN 'IM' ELSE '' END AS mov
                                                                     FROM dbo.avisos_imss AS ultMov2
                                                                     WHERE ultMov2.empresa = empleado.empresa
                                                                           AND ultMov2.codigo = empleado.codigo
                                                                           AND ultMov2.fch_mov <= CASE WHEN @fechafinmes = @fechafinmesoperacion THEN DATEADD(MM,2, @fechafinmes) WHEN @fechafinmes > @fechafinmesoperacion THEN DATEADD(MM,1, @fechafinmes) ELSE @fechafinmes END
                                                                           AND ultMov2.mov <> 'IM'
                                                                           AND ultMov2.mov <> 'B'
                                                                     ORDER BY ultMov2.fch_mov DESC ,
                                                                              ultMov2.serial DESC),'')
                                           AND ultMov.mov <> 'B'
                                     ORDER BY ultMov.fch_mov DESC ,
                                              ultMov.serial DESC) AS ultMov

                        CROSS APPLY (SELECT TOP 1
                                            ultimaIntegracion.empresa,
                                            ultimaIntegracion.codigo,
                                            ultimaIntegracion.mov,
                                            ultimaIntegracion.fch_mov,
                                            ultimaIntegracion.serial
                                     FROM dbo.avisos_imss AS ultimaIntegracion
                                     WHERE ultimaIntegracion.empresa = empleado.empresa
                                           AND ultimaIntegracion.codigo = CASE WHEN @codigo > 0 THEN @codigo ELSE empleado.codigo END
                                           AND ultimaIntegracion.fch_mov <= CASE WHEN @fechafinmes = @fechafinmesoperacion THEN DATEADD(MM,2, @fechafinmes) WHEN @fechafinmes > @fechafinmesoperacion THEN DATEADD(MM,1, @fechafinmes) ELSE @fechafinmes END
                                           AND ultimaIntegracion.mov <> ultMov.mov
                                           AND ultimaIntegracion.mov <> 'B'
                                     ORDER BY ultimaIntegracion.fch_mov DESC ,
                                              ultimaIntegracion.serial DESC) AS ultimaIntegracion

                        CROSS APPLY (SELECT TOP 1
                                            ultimoAviso.empresa,
                                            ultimoAviso.codigo,
                                            ultimoAviso.mov,
                                            ultimoAviso.fch_mov,
                                            ultimoAviso.serial
                                    FROM dbo.avisos_imss AS ultimoAviso
                                    WHERE ultimoAviso.empresa = empleado.empresa
                                          AND ultimoAviso.codigo = empleado.codigo
                                          AND ultimoAviso.fch_mov <= CASE WHEN @fechafinmes = @fechafinmesoperacion THEN DATEADD(MM,2, @fechafinmes) WHEN @fechafinmes > @fechafinmesoperacion THEN DATEADD(MM,1, @fechafinmes) ELSE @fechafinmes END
                                    ORDER BY ultimoAviso.fch_mov DESC ,
                                             ultimoAviso.serial DESC) AS ultimoAviso

                        OUTER APPLY (SELECT TOP 1 1 AS tieneAvisoAnterior
                                    FROM dbo.avisos_imss AS avisos
                                    WHERE avisos.empresa = empleado.empresa
                                          AND avisos.codigo = CASE WHEN @codigo > 0 THEN @codigo ELSE empleado.codigo END
                                          AND avisos.fch_mov >= CASE WHEN MONTH(@fecha) % 2 = 1
                                                                     THEN CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(MM, -2,@fecha))-1),DATEADD(MM, -2,@fecha)),112)
                                                                     ELSE CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(MM, -3,@fecha))-1),DATEADD(MM, -3,@fecha)),112)
                                                                END

                                          AND avisos.fch_mov <= CASE WHEN MONTH(@fecha) % 2 = 1
                                                                     THEN CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(mm,1,DATEADD(MM, -1,@fecha)))),DATEADD(mm,1,DATEADD(MM, -1,@fecha))),112)
                                                                     ELSE CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(mm,1,DATEADD(MM, -2,@fecha)))),DATEADD(mm,1,DATEADD(MM, -2,@fecha))),112)
                                                                END) AS avisoAnterior

                        OUTER APPLY (SELECT CASE WHEN @codigo > 0 AND @fechaantigua IS NOT NULL
                                                 THEN @fechaantigua
                                                 ELSE antiguedad.campo_07
                                            END AS fchantigua
                                   FROM dbo.avisos_imss AS antiguedad
                                   WHERE antiguedad.empresa = empleado.empresa
                                         AND antiguedad.codigo = empleado.codigo
                                         AND LTRIM(RTRIM(STR(antiguedad.empresa)))
                                             + LTRIM(RTRIM(STR(antiguedad.codigo)))
                                             + LTRIM(RTRIM(antiguedad.mov))
                                             + CONVERT(VARCHAR(10), antiguedad.fch_mov, 120)
                                             + LTRIM(RTRIM(STR(antiguedad.serial))) IN (SELECT TOP 1
                                                                                               LTRIM(RTRIM(STR(avisosImss2.empresa)))
                                                                                               + LTRIM(RTRIM(STR(avisosImss2.codigo)))
                                                                                               + LTRIM(RTRIM(avisosImss2.mov))
                                                                                               + CONVERT(VARCHAR(10), avisosImss2.fch_mov, 120)
                                                                                               + LTRIM(RTRIM(STR(avisosImss2.serial)))
                                                                                        FROM dbo.avisos_imss AS avisosImss2
                                                                                        WHERE avisosImss2.empresa = antiguedad.empresa
                                                                                              AND avisosImss2.codigo = antiguedad.codigo
                                                                                              AND avisosImss2.fch_mov >= @fechainiciomes
                                                                                              AND avisosImss2.mov = 'B'
                                                                                           ORDER BY avisosImss2.fch_mov DESC ,
                                                                                                    avisosImss2.serial DESC)) AS antiguedad


                        LEFT JOIN dbo.tablas_int AS tablasInt ON tablasInt.empresa = empleado.empresa
                                                                  AND tablasInt.clase = CASE WHEN @clase = '' THEN llaves.clase ELSE @clase END
                                                                  AND tablasInt.ayos = CASE WHEN [dbo].[CalculaAyosAntiguedad](CASE WHEN @codigo > 0 AND @fechaantigua IS NOT NULL
                                                                                                                                    THEN @fechaantigua
                                                                                                                                    ELSE ISNULL(antiguedad.fchantigua, CASE WHEN empleado.fchantigua = '19000101' OR empleado.fchantigua IS NULL
                                                                                                                                                                            THEN empleado.fchalta
                                                                                                                                                                            ELSE empleado.fchantigua
                                                                                                                                                                       END)
                                                                                                                               END, CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                                                                         THEN CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(mm,1,ultimaIntegracion.fch_mov))),DATEADD(mm,1,ultimaIntegracion.fch_mov)),112)
                                                                                                                                         ELSE @fechafinmes
                                                                                                                                    END) > 45
                                                                                            THEN 45
                                                                                            ELSE CASE WHEN [dbo].[CalculaAyosAntiguedad](CASE WHEN @codigo > 0 AND @fechaantigua IS NOT NULL
                                                                                                                                              THEN @fechaantigua
                                                                                                                                              ELSE ISNULL(antiguedad.fchantigua, CASE WHEN empleado.fchantigua = '19000101' OR empleado.fchantigua IS NULL
                                                                                                                                                                                      THEN empleado.fchalta
                                                                                                                                                                                      ELSE empleado.fchantigua
                                                                                                                                                                                 END)
                                                                                                                                         END, CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                                                                                   THEN CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(mm,1,ultimaIntegracion.fch_mov))),DATEADD(mm,1,ultimaIntegracion.fch_mov)),112)
                                                                                                                                                   ELSE @fechafinmes
                                                                                                                                              END) < 0
                                                                                                      THEN 0
                                                                                                      ELSE [dbo].[CalculaAyosAntiguedad](CASE WHEN @codigo > 0 AND @fechaantigua IS NOT NULL
                                                                                                                                              THEN @fechaantigua
                                                                                                                                              ELSE ISNULL(antiguedad.fchantigua, CASE WHEN empleado.fchantigua = '19000101' OR empleado.fchantigua IS NULL
                                                                                                                                                                                      THEN empleado.fchalta
                                                                                                                                                                                      ELSE empleado.fchantigua
                                                                                                                                                                                 END)
                                                                                                                                         END, CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                                                                                   THEN CONVERT(DATETIME,DATEADD(dd,-(DAY(DATEADD(mm,1,ultimaIntegracion.fch_mov))),DATEADD(mm,1,ultimaIntegracion.fch_mov)),112)
                                                                                                                                                   ELSE @fechafinmes
                                                                                                                                              END)
                                                                                                 END
                                                                                       END
                                         AND tablasInt.ayo_operacion = CASE WHEN @fechafinmes > @fechafinmesoperacion THEN empresa.ayo_operacion ELSE @ayofechafinmes END
                                         AND tablasInt.mes_operacion = CASE WHEN @fechafinmes > @fechafinmesoperacion THEN empresa.mes_operacion ELSE @mesfechafinmes END

                        LEFT JOIN dbo.clases AS clase ON tablasInt.empresa = clase.empresa
                                                          AND LTRIM(RTRIM(tablasInt.clase)) = LTRIM(RTRIM(clase.clase))

                        OUTER APPLY (SELECT percepcion.empresa,
                                          percepcion.codigo,
                                          SUM(ISNULL(percepcion.varia_imss, 0)) AS percepcionVariable
                                   FROM   dbo.percepciones AS percepcion
                                   WHERE percepcion.empresa = empleado.empresa
                                         AND percepcion.codigo = empleado.codigo
                                         AND percepcion.ayo_operacion = CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                             THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                       THEN YEAR(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                                       ELSE YEAR(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                  END
                                                                             ELSE @ayoanterior
                                                                        END

                                         AND percepcion.mes_operacion >= CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                              THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                        THEN MONTH(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                        ELSE MONTH(DATEADD(MM, -3,ultimaIntegracion.fch_mov))
                                                                                   END
                                                                              ELSE @mesanterior1
                                                                         END

                                         AND percepcion.mes_operacion <= CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                              THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                        THEN MONTH(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                                        ELSE MONTH(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                   END
                                                                              ELSE @mesanterior2
                                                                         END

                                   GROUP BY percepcion.empresa,
                                            percepcion.codigo) AS percepcion

                                                                                            -- CASE WHEN percepcionLaboral.origen = 'C' THEN percepcionLaboral.nomina ELSE 0 END) AS PercepcionVariableLaboral
                        OUTER APPLY (SELECT SUM(CASE WHEN ((percepcionLaboral.num_conc >= 8 AND percepcionLaboral.num_conc <= 13)
                                                           OR percepcionLaboral.num_conc = 15
                                                           OR (percepcionLaboral.num_conc >= 37 AND percepcionLaboral.num_conc <= 99))
                                                     THEN percepcionLaboral.nomina
                                                     ELSE 0
                                                END) AS PercepcionVariableLaboral
                                     FROM   dbo.percepciones AS percepcionLaboral
                                            LEFT JOIN dbo.conceptos AS c ON c.empresa = percepcionLaboral.empresa
                                                                            AND c.num_conc = percepcionLaboral.num_conc
                                                                            AND c.centro = percepcionLaboral.centro
                                                                            AND c.clase = percepcionLaboral.clase
                                     WHERE empleado.tiposal = 1 AND
                                           percepcionLaboral.empresa = empleado.empresa
                                           AND percepcionLaboral.codigo = empleado.codigo
                                           --AND percepcionLaboral.origen = 'C'
                                           AND RIGHT('0000' + percepcionLaboral.ayo_operacion,4)
                                               + RIGHT('00' + percepcionLaboral.mes_operacion,2) = RIGHT('0000' + YEAR(DATEADD(MM, -1,ultimaIntegracion.fch_mov)),4)
                                               + RIGHT('00' + MONTH(DATEADD(MM, -1,ultimaIntegracion.fch_mov)),2)
                                           AND c.Cfdi < 91
                                    ) AS percepcionLaboral


                        OUTER APPLY (SELECT DISTINCT
                                          'S' AS incapacitado
                                   FROM dbo.deducciones AS deduccion
                                   WHERE deduccion.empresa = empleado.empresa
                                         AND deduccion.codigo = empleado.codigo
                                         AND deduccion.num_conc IN (109, 110, 111)
                                         AND CASE WHEN @fecha > @fechainiciomes THEN @fecha ELSE @fechainiciomes END >= deduccion.fchinicio
                                         AND CASE WHEN @fecha > @fechainiciomes THEN @fecha ELSE @fechainiciomes END <= deduccion.fchtermino) AS incapacitado

                        OUTER APPLY (SELECT SUM(ISNULL(AvisosImssDias.diastr, 0)) AS diastr,
                                            SUM(ISNULL(AvisosImssDias.ausen, 0)) AS ausen,
                                            SUM(ISNULL(AvisosImssDias.incap, 0)) AS incap
                                     FROM dbo.avisos_imss AS AvisosImssDias
                                     WHERE @usardias = 'DIASNATURALES' AND
                                                                               --CASE WHEN @codigo > 0 THEN @tiposalario ELSE empleado.tiposal END <> 1 AND
                                           AvisosImssDias.empresa = empleado.empresa
                                           AND AvisosImssDias.codigo = empleado.codigo
                                           AND YEAR(AvisosImssDias.fch_mov) = CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                   THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                             THEN YEAR(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                                             ELSE YEAR(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                        END
                                                                                   ELSE @ayoanterior
                                                                              END

                                           AND MONTH(AvisosImssDias.fch_mov) >= CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                     THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                               THEN MONTH(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                               ELSE MONTH(DATEADD(MM, -3,ultimaIntegracion.fch_mov))
                                                                                          END
                                                                                     ELSE @mesanterior1
                                                                                END

                                           AND MONTH(AvisosImssDias.fch_mov) <= CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                     THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                               THEN MONTH(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                                               ELSE MONTH(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                          END
                                                                                     ELSE @mesanterior2
                                                                                END

                                     GROUP BY AvisosImssDias.empresa,
                                              AvisosImssDias.codigo) AS avisosImssDias

                        OUTER APPLY (SELECT SUM(nominaDias.diastr_nom) AS 'diastr'
                                     FROM dbo.nomina1_anual AS nominaDias
                                     WHERE @usardias = 'DIASNOMINA' AND
                                                                               --AND empleado.tiposal <> 1
                                                                                   --CASE WHEN @codigo > 0 THEN @tiposalario ELSE empleado.tiposal END = 1 AND
                                           nominaDias.empresa = empleado.empresa
                                           AND nominaDias.codigo = empleado.codigo
                                           AND ( nominaDias.mes = CASE CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                            THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                      THEN MONTH(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                      ELSE MONTH(DATEADD(MM, -3,ultimaIntegracion.fch_mov))
                                                                                 END
                                                                            ELSE @mesanterior1
                                                                       END WHEN 01 THEN 'ENE'
                                                                           WHEN 02 THEN 'FEB'
                                                                           WHEN 03 THEN 'MAR'
                                                                           WHEN 04 THEN 'ABR'
                                                                           WHEN 05 THEN 'MAY'
                                                                           WHEN 06 THEN 'JUN'
                                                                           WHEN 07 THEN 'JUL'
                                                                           WHEN 08 THEN 'AGO'
                                                                           WHEN 09 THEN 'SEP'
                                                                           WHEN 10 THEN 'OCT'
                                                                           WHEN 11 THEN 'NOV'
                                                                           WHEN 12 THEN 'DIC'
                                                                           ELSE '' END + RIGHT(CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                                    THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                                              THEN YEAR(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                                                              ELSE YEAR(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                                         END
                                                                                                    ELSE @ayoanterior
                                                                                               END,2)



                                                OR nominaDias.mes = CASE CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                              THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                        THEN MONTH(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                                        ELSE MONTH(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                   END
                                                                              ELSE @mesanterior2
                                                                         END WHEN 01 THEN 'ENE'
                                                                             WHEN 02 THEN 'FEB'
                                                                             WHEN 03 THEN 'MAR'
                                                                             WHEN 04 THEN 'ABR'
                                                                             WHEN 05 THEN 'MAY'
                                                                             WHEN 06 THEN 'JUN'
                                                                             WHEN 07 THEN 'JUL'
                                                                             WHEN 08 THEN 'AGO'
                                                                             WHEN 09 THEN 'SEP'
                                                                             WHEN 10 THEN 'OCT'
                                                                             WHEN 11 THEN 'NOV'
                                                                             WHEN 12 THEN 'DIC'
                                                                             ELSE '' END + RIGHT(CASE WHEN ultimaIntegracion.fch_mov > @fechafinmesoperacion
                                                                                                      THEN CASE WHEN MONTH(ultimaIntegracion.fch_mov) % 2 = 1
                                                                                                                THEN YEAR(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                                                                ELSE YEAR(DATEADD(MM, -2,ultimaIntegracion.fch_mov))
                                                                                                           END
                                                                                                      ELSE @ayoanterior
                                                                                                 END,2)
                                               )

                                     --GROUP BY nominaDias.empresa ,
                                     --         nominaDias.codigo
                                                                                          ) AS nominaDias


                        OUTER APPLY (SELECT SUM(nominaDiasLaboral.Dias_Pagar) AS diasLaboral
                                     FROM dbo.nomina1_anual AS nominaDiasLaboral
                                     WHERE --@usardias = 'DIASNOMINA' AND
                                                                               --AND empleado.tiposal <> 1
                                                                                   --CASE WHEN @codigo > 0 THEN @tiposalario ELSE empleado.tiposal END = 1 AND
                                                                                   ----empleado.tiposal = 1 AND
                                           nominaDiasLaboral.empresa = empleado.empresa
                                           AND nominaDiasLaboral.codigo = empleado.codigo
                                           AND (nominaDiasLaboral.mes = CASE MONTH(DATEADD(MM, -1,ultimaIntegracion.fch_mov))
                                                                             WHEN 01 THEN 'ENE'
                                                                             WHEN 02 THEN 'FEB'
                                                                             WHEN 03 THEN 'MAR'
                                                                             WHEN 04 THEN 'ABR'
                                                                             WHEN 05 THEN 'MAY'
                                                                             WHEN 06 THEN 'JUN'
                                                                             WHEN 07 THEN 'JUL'
                                                                             WHEN 08 THEN 'AGO'
                                                                             WHEN 09 THEN 'SEP'
                                                                             WHEN 10 THEN 'OCT'
                                                                             WHEN 11 THEN 'NOV'
                                                                             WHEN 12 THEN 'DIC'
                                                                             ELSE '' END + RIGHT(YEAR(DATEADD(MM, -1,ultimaIntegracion.fch_mov)),2)
                                               )

                                    ) AS nominaDiasLaboral


                        CROSS APPLY dbo.ObtieneSalarioUMAPorFechaFuncion(empleado.empresa,CASE WHEN ultimoAviso.fch_mov > @fechafinmes THEN ultimoAviso.fch_mov ELSE @fechafinmes END) AS parametrosFechaAuditoria
                        CROSS APPLY dbo.ObtieneSalarioUMAPorFechaFuncion(ultimaIntegracion.empresa,ultimaIntegracion.fch_mov) AS parametrosUltimaIntegracion

                   WHERE empleado.empresa = @empresa
                         AND CASE WHEN @codigo > 0 THEN empleado.codigo ELSE 0 END = @codigo
                         AND ISNULL(CASE WHEN @codigo > 0 AND @fechaantigua IS NOT NULL
                                         THEN @fechaantigua
                                         ELSE antiguedad.fchantigua
                                    END, CASE WHEN empleado.fchantigua = '19000101' OR empleado.fchantigua IS NULL THEN empleado.fchalta ELSE empleado.fchantigua END) <= CASE WHEN @fechafinmes = @fechafinmesoperacion THEN DATEADD(MM, 1, @fechafinmes) ELSE @fechafinmes END
                         AND empleado.borrado = 'N'
                         AND CASE WHEN @fecha >= @fechainiciomesoperacion THEN empleado.activo ELSE '' END = CASE WHEN @fecha >= @fechainiciomesoperacion THEN 'S' ELSE '' END
                         AND ultimoAviso.mov <> CASE WHEN @fechafinmes > @fechafinmesoperacion
                                                     THEN CASE WHEN @accion = 3
                                                               THEN ''
                                                               ELSE CASE WHEN ultimoAviso.fch_mov > @fechainiciomes
                                                                         THEN ''
                                                                         ELSE 'B'
                                                                    END
                                                          END
                                                     ELSE ''
                                                END

                   UPDATE dbo.auditoria
                   SET @sueldo = CASE WHEN auditoria.tipo_salario = 1
                                      THEN 0
                                      ELSE CASE WHEN auditoria.jornada = 0 OR auditoria.jornada = 6
                                                THEN auditoria.sueldo
                                                ELSE ((auditoria.sueldo * auditoria.jornada) / 7)
                                           END
                                 END,

                       @partevariable = CASE WHEN auditoria.tieneAvisoAnterior = 1 OR @origen = 'VA'
                                             THEN ROUND(auditoria.percepcionVariable / CASE WHEN (auditoria.diastr - auditoria.ausen - auditoria.incap) = 0
                                                                                            THEN 1
                                                                                            ELSE (auditoria.diastr - auditoria.ausen - auditoria.incap)
                                                                                       END,2)
                                             ELSE CASE WHEN @fechainiciomes >= @fechainiciomesoperacion
                                                       THEN CASE WHEN @accion = 3
                                                                 THEN @partevariablecalculadausuario
                                                                 ELSE auditoria.parte_variable
                                                            END
                                                       ELSE 0
                                                  END
                                        END,

                       @fondoahorro = CASE WHEN auditoria.fondoAhorroPatron > auditoria.fondoAhorroEmpleado
                                           THEN CASE WHEN SUBSTRING(@registropatronal,1,10) = 'C121910510'
                                                     THEN auditoria.fondoAhorroPatron - auditoria.fondoAhorroEmpleado
                                                     ELSE auditoria.fondoAhorroPatron
                                                END
                                           ELSE 0
                                      END,
                       @factor = auditoria.factor,

                       @importesfijos = auditoria.importesFijos + @fondoahorro,

                       @sbc_ok = CASE WHEN (auditoria.fch_antigua <> '19000101' AND auditoria.fch_antigua IS NOT NULL) AND @factor > 1
                                      THEN ROUND((@sueldo * @factor)
                                                 + auditoria.excedenteDespensa
                                                 + @importesfijos
                                                 + @partevariable,2)
                                      ELSE 0
                                 END,

                       auditoria.sdiCalculado = CASE WHEN (auditoria.fch_antigua <> '19000101' AND auditoria.fch_antigua IS NOT NULL) AND @factor > 1
                                                     THEN ROUND((@sueldo * @factor)
                                                                + auditoria.excedenteDespensa
                                                                + @importesfijos
                                                                + @partevariable,2)
                                                     ELSE 0
                                                END,

                       @topeminimointegrado = ROUND(auditoria.salMin * @factor,2),
                       auditoria.minimoAuditoriaIntegrado = @topeminimointegrado,

                       @sbc_ok = CASE WHEN @sbc_ok < CASE WHEN auditoria.jornada = 6
                                                          THEN auditoria.salMin
                                                          ELSE @topeminimointegrado
                                                     END
                                      THEN CASE WHEN auditoria.jornada = 6
                                                THEN auditoria.salMin
                                                ELSE @topeminimointegrado
                                           END
                                      ELSE @sbc_ok
                                 END,

                       @factorlaboral = auditoria.factorLaboral,
                       @importefijolaboral = auditoria.importesFijos
                                             + CASE WHEN TopaFondoAhorro.Marca = 'T' AND fondoAhorroPatron > (auditoria.UmaDiario * 10.00 * 0.13)
                                                    THEN (auditoria.UmaDiario * 10.00 * 0.13)
                                                    ELSE fondoAhorroPatron  -- Parte diario de fdo. de ahorro
                                               END,

                       @sbclaboral = CASE WHEN (auditoria.fch_antigua <> '19000101' AND auditoria.fch_antigua IS NOT NULL) AND @factorlaboral > 1
                                          THEN CASE WHEN auditoria.tipo_salario = 1
										            THEN ROUND((auditoria.parteVariableLaboral * @factorlaboral)
                                                               + @importefijolaboral
                                                               + auditoria.despensaLaboral
                                                               ,2)
													ELSE ROUND((@sueldo * @factorlaboral)
                                                     + @importefijolaboral
                                                     + auditoria.despensaLaboral
                                                     + auditoria.parteVariableLaboral
                                                     ,2)
										       END
                                          ELSE 0
                                     END,
                       @sbclaboral = CASE WHEN @sbclaboral < CASE WHEN @jornada = 6
                                                                  THEN auditoria.salMin
                                                                  ELSE @topeminimointegrado
                                                             END
                                          THEN CASE WHEN @jornada = 6
                                                    THEN auditoria.salMin
                                                    ELSE @topeminimointegrado
                                               END
                                          ELSE @sbclaboral
                                     END,

                       auditoria.sdiLaboral = @sbclaboral,
                       auditoria.sdi_ok = @sbc_ok,
                       auditoria.sdi_fijo = CASE WHEN @factor > 1 THEN ROUND(@sueldo * @factor,2) ELSE 0 END,
                       auditoria.parte_variable = @partevariable,
                       auditoria.importes_excedentes = auditoria.excedenteDespensa + @importesfijos,
                       auditoria.importesFijos = @importesfijos,
                       auditoria.importeFijoLaboral = @importefijolaboral,

                       @obs_baja = CASE WHEN auditoria.ultimoAvisoMov = 'B' THEN 'B' ELSE '' END,
                       @obs_fecha = CASE WHEN auditoria.fch_antigua = '19000101' OR auditoria.fch_antigua IS NULL THEN '1' ELSE '' END,
                       @obs_factor = CASE WHEN @factor = 0 OR @factor = 1 THEN '2' ELSE '' END,
                       @obs_otros = CASE WHEN (auditoria.fch_antigua <> '19000101'
                                               AND auditoria.fch_antigua IS NOT NULL)
                                              AND @factor > 1
                                              AND auditoria.ultimoAvisoMov <> 'B'
                                         THEN CASE WHEN ABS(auditoria.sdi_reportado - @sbc_ok) > 0.03
                                                   THEN CASE WHEN @sbc_ok < auditoria.topeAuditoria
                                                             THEN CASE WHEN @sbc_ok >= auditoria.minimoAuditoria
                                                                       THEN CASE WHEN MONTH(auditoria.fch_antigua) = @mesfechafinmes AND YEAR(auditoria.fch_antigua) < @ayofechafinmes
                                                                                 THEN '4'
                                                                                 ELSE '3'
                                                                            END
                                                                       ELSE CASE WHEN auditoria.minimoUltimoAviso <> auditoria.minimoAuditoria THEN '3' ELSE 'J' END
                                                                  END
                                                             ELSE CASE WHEN CASE WHEN auditoria.sdi_reportado < auditoria.topeUltimoAviso THEN auditoria.sdi_reportado ELSE auditoria.topeUltimoAviso END <> auditoria.topeAuditoria THEN '3' ELSE 'OK,T' END --'T'
                                                        END
                                                   ELSE CASE WHEN (@sbc_ok >= auditoria.topeUltimoAviso OR @sbc_ok >= auditoria.topeAuditoria) And auditoria.topeUltimoAviso <> auditoria.topeAuditoria THEN '3' ELSE 'OK' END --'OK'
                                              END
                                         ELSE ''
                                    END,

                       @observacion = RTRIM(@obs_baja) + CASE WHEN LEN(@obs_baja) > 0 AND LEN(@obs_fecha) > 0 THEN ',' ELSE '' END + RTRIM(@obs_fecha) + CASE WHEN LEN(@obs_fecha) > 0 AND LEN(@obs_factor) > 0 THEN ',' ELSE '' END + RTRIM(@obs_factor) + CASE WHEN LEN(@obs_factor) > 0 AND LEN(@obs_otros) > 0 THEN ',' ELSE '' END + @obs_otros,

                       @observacion = CASE WHEN (LTRIM(RTRIM(@observacion)) = 'OK' OR LTRIM(RTRIM(@observacion)) = 'OK,T')
                                                AND @sbc_ok >= auditoria.topeAuditoria
                                                AND (auditoria.mov = 'MS' OR auditoria.mov = 'RI' OR auditoria.mov = 'A')
                                                AND auditoria.sdi_reportado >= auditoria.topeUltimoAviso
                                           THEN 'OK,L'
                                           ELSE @observacion
                                      END,

                       @observacion = LTRIM(RTRIM(@observacion)) + CASE WHEN auditoria.incapacitado = 'S' THEN CASE WHEN LEN(@observacion) > 0 THEN ',' ELSE '' END + 'I' ELSE '' END,

                       @obs_auto = CASE WHEN @obs_factor = ''
                                        THEN CASE WHEN auditoria.ultimoAvisoMov = 'B'
                                                  THEN 'ES BAJA'
                                                  ELSE CASE WHEN auditoria.ultimoAvisoFch_Mov > @fecha
                                                            THEN 'TIENE AVISO(S) POSTERIOR(ES)'
                                                            ELSE CASE WHEN auditoria.fchalta > @fecha
                                                                      THEN 'ALTA MAYOR A AUTOREGULARIZACION'
                                                                      ELSE CASE WHEN auditoria.incapacitado = 'S'
                                                                                THEN 'INCAPACITADO'
                                                                                ELSE 'OK'
                                                                           END
                                                                 END
                                                       END
                                             END
                                        ELSE 'FACTOR INTEGRACION INCORRECTO'
                                   END,
                       auditoria.observacion = @observacion,
                       auditoria.obs_auto = @obs_auto

                   FROM dbo.auditoria AS auditoria
                        OUTER APPLY (SELECT TOP 1 Marca2 AS Marca
                                     FROM dbo.conceptos AS c
                                     WHERE c.num_conc = 27 AND
                                           c.clase = auditoria.clase AND
                                           c.empresa = auditoria.empresa) AS TopaFondoAhorro -- T = Topar   S = Sin tope

                   WHERE auditoria.empresa = @empresa
                         AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario))
                         AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac))
                         AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreequipo))
                         AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))

            SELECT @ayotmp = ayos
                        FROM dbo.auditoria
            WHERE auditoria.empresa = @empresa
                  AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario))
                  AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac))
                  AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreequipo))
                  AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))

            SELECT @aguinaldo = ISNULL(tablasInt.aguinaldo,0),
                               @prima_vac = ISNULL(tablasInt.prima_vac,0),
                   @dias_vac = ISNULL(tablasInt.dias_vac,0),
                   @pmavacdias = ISNULL(tablasInt.pmavacdias,0),
                   @dias_ayo = ISNULL(tablasInt.dias_ayo,0),
                   @porc_ayo = ISNULL(tablasInt.porc_ayo,0),
                   @porc_mes = ISNULL(tablasInt.porc_mes,0),
                   @porc_dia = ISNULL(tablasInt.porc_dia,0),
                   @pmo1ayopor = ISNULL(tablasInt.pmo1ayopor,0),
                   @pmo2ayopor = ISNULL(tablasInt.pmo2ayopor,0),
                   @dias_mes = ISNULL(tablasInt.dias_mes,0),
                   @fdoahopatp = ISNULL(tablasInt.fdoahopatp,0)
            FROM dbo.tablas_int AS tablasInt
            WHERE tablasInt.empresa = @empresa
                  AND tablasInt.clase = @clase
                  AND tablasInt.ayos = @ayotmp
                  AND tablasInt.ayo_operacion = CASE WHEN @fechafinmes > @fechafinmesoperacion THEN YEAR(@fechainiciomesoperacion) ELSE @ayofechafinmes END
                  AND tablasInt.mes_operacion = CASE WHEN @fechafinmes > @fechafinmesoperacion THEN MONTH(@fechainiciomesoperacion) ELSE @mesfechafinmes END
         END

       IF (@accion = 3 AND @codigo > 0 AND @existecodigo = 0) OR @historia = 1
          BEGIN
            DECLARE @ayos INT
            DECLARE @despensaporciento NUMERIC(12,2)
            DECLARE @despensaimporte NUMERIC(12,2)
            DECLARE @excedentedespensa NUMERIC(12,2)
            DECLARE @topeminimo NUMERIC(12,2)
            DECLARE @topedespensa NUMERIC(12,2)
            DECLARE @importefijo NUMERIC(12,2)
            DECLARE @importeexcedente NUMERIC(12,2)
            DECLARE @sdi_fijo NUMERIC(12,2)
            DECLARE @fondoahorropatron NUMERIC(12,2)
            DECLARE @fondoahorroempleado NUMERIC(12,2)
            DECLARE @nombreclase VARCHAR(20)
            DECLARE @salariominimodf NUMERIC(12,2)
            DECLARE @salariominimoregion NUMERIC(12,2)
            DECLARE @umadiario NUMERIC(12,2)
            DECLARE @topeultimoaviso NUMERIC(12,2)
            DECLARE @minimoultimoaviso NUMERIC(12,2)
            DECLARE @topeauditoria NUMERIC(12,2)
            DECLARE @minimoauditoria NUMERIC(12,2)
            DECLARE @minimoauditoriaintegrado NUMERIC(12,2)
            DECLARE @fechauma DATETIME
            DECLARE @diaslaboral NUMERIC(12,2)
            DECLARE @percepcionvariablelaboral NUMERIC(12,2)
            DECLARE @partevariablelaboral NUMERIC(12,2)
                        DECLARE @fechalaboral DATETIME
                        DECLARE @ctopafondoahorro CHAR(1)

            SET @diaslaboral = 0
                        SET @percepcionvariablelaboral = 0
                        SET @partevariablelaboral = 0
                        SET @percepcionvariable = 0
                        SET @fechalaboral = (SELECT fechaFin FROM [dbo].[ObtieneRangoFecha](@fecha, 8))

            SET @sueldo = CASE WHEN @tiposalario = 1
                               THEN 0
                               ELSE @cuotadiaria
                          END
            SET @sueldo = CASE WHEN @jornada = 0 OR @jornada = 6
                               THEN @sueldo
                               ELSE ((@sueldo * @jornada) / 7)
                          END


            SET @ayos = dbo.CalculaAyosAntiguedad(@fechaantigua, CASE WHEN @fechaantigua > @fechafinmes THEN @fechaantigua ELSE @fechafinmes END)

            SELECT @factor = tablasInt.factor,
                   @despensaporciento = tablasInt.despensa,
                   @despensaimporte = tablasInt.despensaim,
                   @importefijo = ROUND(tablasInt.imp_ayo / 365,2)
                                  + ROUND(tablasInt.pmo1ayoimp / 365, 2)
                                  + ROUND(tablasInt.pmo2ayoimp / 365, 2)
                                  + ROUND(tablasInt.Imp_mes / 30.4167, 2)
                                  + tablasInt.imp_dia,
                   @fondoahorropatron = ROUND((@cuotadiaria * (ISNULL(tablasInt.fdoahopatp,0)/100)) + ISNULL(tablasInt.fdoahopati,0),2),
                   @fondoahorroempleado = ROUND((@cuotadiaria * (ISNULL(tablasInt.fdoahotrap,0)/100)) + ISNULL(tablasInt.fdoahotrai,0),2),

                   -- Factor Laboral
                   @factorlaboral = ROUND(1  -- Constante
                                          + (ISNULL(tablasInt.aguinaldo,0) / 365)  -- Aguinaldo
                                          + (ISNULL(tablasInt.dias_vac,0) / 365) * (ISNULL(tablasInt.prima_vac,0) / 100)  -- Prima Vacacional dias y porcentaje
                                          + (ISNULL(tablasInt.pmavacdias,0) / 365)  -- Dias Prima vacacional
                                          + (ISNULL(tablasInt.dias_ayo,0) / 365)  -- dias x ao
                                          + (ISNULL(tablasInt.porc_ayo,0) / 100)  -- Porcentaje por ao
                                          + (ISNULL(tablasInt.porc_mes,0) / 100)  -- Porcentaje por mes
                                          + (ISNULL(tablasInt.porc_dia,0) / 100)  -- Porcentaje por dia
                                          + (ISNULL(tablasInt.pmo1ayopor,0) / 100)  -- Porcentaje premio Anual 1
                                          + (ISNULL(tablasInt.pmo2ayopor,0) / 100)  -- Porcentaje premio Anual 2
                                          + (ISNULL(tablasInt.dias_mes,0) / 30.4167),4),  -- Dias por mes
                                          --+ (ISNULL(tablasInt.fdoahopatp,0) / 100),4),  -- Fondo ahorro patron

                   @aguinaldo = ISNULL(tablasInt.aguinaldo,0),
                                   @prima_vac = ISNULL(tablasInt.prima_vac,0),
                   @dias_vac = ISNULL(tablasInt.dias_vac,0),
                   @pmavacdias = ISNULL(tablasInt.pmavacdias,0),
                   @dias_ayo = ISNULL(tablasInt.dias_ayo,0),
                   @porc_ayo = ISNULL(tablasInt.porc_ayo,0),
                   @porc_mes = ISNULL(tablasInt.porc_mes,0),
                   @porc_dia = ISNULL(tablasInt.porc_dia,0),
                   @pmo1ayopor = ISNULL(tablasInt.pmo1ayopor,0),
                   @pmo2ayopor = ISNULL(tablasInt.pmo2ayopor,0),
                   @dias_mes = ISNULL(tablasInt.dias_mes,0),
                   @fdoahopatp = ISNULL(tablasInt.fdoahopatp,0)
            FROM dbo.tablas_int AS tablasInt
            WHERE tablasInt.empresa = @empresa
                  AND tablasInt.clase = @clase
                  AND tablasInt.ayos = @ayos
                  AND tablasInt.ayo_operacion = CASE WHEN @fechafinmes > @fechafinmesoperacion THEN YEAR(@fechainiciomesoperacion) ELSE @ayofechafinmes END
                  AND tablasInt.mes_operacion = CASE WHEN @fechafinmes > @fechafinmesoperacion THEN MONTH(@fechainiciomesoperacion) ELSE @mesfechafinmes END

            SET @factor = CASE WHEN @factor IS NULL THEN 0 ELSE @factor END
            SET @despensaporciento = CASE WHEN @despensaporciento IS NULL THEN 0 ELSE @despensaporciento END
            SET @despensaimporte = CASE WHEN @despensaimporte IS NULL THEN 0 ELSE @despensaimporte END
            SET @fondoahorropatron = CASE WHEN @fondoahorropatron IS NULL THEN 0 ELSE @fondoahorropatron END
            SET @fondoahorroempleado = CASE WHEN @fondoahorroempleado IS NULL THEN 0 ELSE @fondoahorroempleado END

            SELECT @topeminimo = parametrosFechaAuditoria.topeMinimo,
                   @topedespensa = parametrosFechaAuditoria.topeDespensa,
                   @topeminimointegrado = parametrosFechaAuditoria.topeMinimoIntegrado,
                   @salariominimodf = parametrosFechaAuditoria.salarioMinimoDF,
                   @salariominimoregion = parametrosFechaAuditoria.salarioMinimoRegion,
                   @umadiario = parametrosFechaAuditoria.umaDiario,
                   @topeultimoaviso = parametrosFechaAuditoria.tope25Veces,
                   @minimoultimoaviso = parametrosFechaAuditoria.topeMinimo,
                   @topeauditoria = parametrosFechaAuditoria.tope25Veces,
                   @minimoauditoria = parametrosFechaAuditoria.topeMinimo,
                   @minimoauditoriaintegrado = parametrosFechaAuditoria.topeMinimoIntegrado,
                   @fechauma = parametrosFechaAuditoria.fechaUMA
            FROM dbo.ObtieneSalarioUMAPorFechaFuncion(@empresa, CASE WHEN @fechaantigua > @fechafinmes THEN @fechaantigua ELSE @fechafinmes END) AS parametrosFechaAuditoria

            SET @topeminimo = CASE WHEN @topeminimo IS NULL THEN 0 ELSE @topeminimo END
            SET @topedespensa = CASE WHEN @topedespensa IS NULL THEN 0 ELSE @topedespensa END
            SET @salariominimodf = CASE WHEN @salariominimodf IS NULL THEN 0 ELSE @salariominimodf END
            SET @salariominimoregion = CASE WHEN @salariominimoregion IS NULL THEN 0 ELSE @salariominimoregion END
            SET @umadiario = CASE WHEN @umadiario IS NULL THEN 0 ELSE @umadiario END
            SET @topeultimoaviso = CASE WHEN @topeultimoaviso IS NULL THEN 0 ELSE @topeultimoaviso END
            SET @minimoultimoaviso = CASE WHEN @minimoultimoaviso IS NULL THEN 0 ELSE @minimoultimoaviso END
            SET @topeauditoria = CASE WHEN @topeauditoria IS NULL THEN 0 ELSE @topeauditoria END
            SET @minimoauditoria = CASE WHEN @minimoauditoria IS NULL THEN 0 ELSE @minimoauditoria END
            SET @minimoauditoriaintegrado = CASE WHEN @minimoauditoriaintegrado IS NULL THEN 0 ELSE @minimoauditoriaintegrado END

            SET @excedentedespensa = ISNULL(CONVERT(NUMERIC(10, 2), CASE WHEN @topadespensa = 'CONTOPE'
                                                                         THEN CASE WHEN CASE WHEN ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2) > @topeminimo
                                                                                             THEN @topeminimo
                                                                                             ELSE ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2)
                                                                                        END > @topedespensa
                                                                                   THEN CASE WHEN ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2) > @topeminimo
                                                                                             THEN @topeminimo
                                                                                             ELSE ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2)
                                                                                        END - @topedespensa
                                                                                   ELSE 0
                                                                              END
                                                                         ELSE CASE WHEN ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2) > @topedespensa
                                                                                   THEN ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2) - @topedespensa
                                                                                   ELSE 0
                                                                              END
																			  --CASE WHEN ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2) > @topedespensa
                                                                              --     THEN @topedespensa
                                                                              --     ELSE ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2)
                                                                              --END
                                                                    END),0)
			--SET @excedentedespensa = ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2)

            SET @fondoahorro = CASE WHEN @fondoahorropatron > @fondoahorroempleado
                                    THEN CASE WHEN SUBSTRING(@registropatronal,1,10) = 'C121910510'
                                              THEN @fondoahorropatron - @fondoahorroempleado
                                              ELSE @fondoahorropatron
                                         END
                                    ELSE 0
                               END

            SET @importefijo = CASE WHEN @importefijo IS NULL THEN 0 ELSE @importefijo END + @fondoahorro

            SET @importeexcedente = @excedentedespensa + @importefijo
            SET @sdi_fijo = ROUND(@sueldo * @factor,2)

            IF @existecodigo = 1
               BEGIN
                 IF @historia = 1
                    BEGIN
                                          DECLARE @existecodigobimestreanterior INT

                                          SET @existecodigobimestreanterior = ISNULL((SELECT TOP 1
                                                                                     1
                                                                                                                  FROM dbo.avisos_imss AS a
                                                                                                                  WHERE a.empresa = @empresa
                                                                                                                        AND a.codigo = @codigo
                                                                                                                        AND a.fch_mov >= @fechainiciomesanterior1
                                                                                                                                AND a.fch_mov <= @fechafinmesanterior2),0)

                      -- Validacin para cuando el empleado no tuvo avisos en el bimetre inmediato anterior
                                          -- no consedire las percepciones variables tales como pagos de finiquitos.
                                          IF @existecodigobimestreanterior = 1
                                             BEGIN
                           SELECT @percepcionvariable = SUM(ISNULL(percepcion.varia_imss,0))
                           FROM dbo.percepciones AS percepcion
                           WHERE percepcion.empresa = @empresa
                                 AND percepcion.codigo = @codigo
                                 AND percepcion.ayo_operacion = @ayoanterior
                                 AND percepcion.mes_operacion >= @mesanterior1
                                 AND percepcion.mes_operacion <= @mesanterior2
                                             END
                                                               --SELECT SUM(CASE WHEN percepcionLaboral.origen = 'C' THEN percepcionLaboral.nomina ELSE 0 END)
                      SET @percepcionvariablelaboral = ISNULL((SELECT SUM(CASE WHEN ((percepcionLaboral.num_conc >= 8 AND percepcionLaboral.num_conc <= 13)
                                                                                     OR percepcionLaboral.num_conc = 15
                                                                                     OR (percepcionLaboral.num_conc >= 37 AND percepcionLaboral.num_conc <= 99))
                                                                               THEN percepcionLaboral.nomina
                                                                               ELSE 0
                                                                          END)
                                                               FROM dbo.percepciones AS percepcionLaboral
                                                                    LEFT JOIN dbo.conceptos AS c ON c.empresa = percepcionLaboral.empresa
                                                                                                    AND c.num_conc = percepcionLaboral.num_conc
                                                                                                    AND c.centro = percepcionLaboral.centro
                                                                                                    AND c.clase = percepcionLaboral.clase
                                                               WHERE @tiposalario = 1 AND
                                                                     percepcionLaboral.empresa = @empresa
                                                                     AND percepcionLaboral.codigo = @codigo
                                                                     --AND percepcionLaboral.origen = 'C'
                                                                     AND RIGHT('0000' + percepcionLaboral.ayo_operacion,4)
                                                                         + RIGHT('00' + percepcionLaboral.mes_operacion,2) = RIGHT('0000' + YEAR(@fechalaboral),4)
                                                                                                                            + RIGHT('00' + MONTH(@fechalaboral),2)
                                                                     AND c.Cfdi < 91
                                                              ),0)

                      SET @diaslaboral = ISNULL((SELECT SUM(nominaDiasLaboral.Dias_Pagar)
                                                 FROM dbo.nomina1_anual AS nominaDiasLaboral
                                     WHERE --@tiposalario = 1 AND
                                           nominaDiasLaboral.empresa = @empresa
                                           AND nominaDiasLaboral.codigo = @codigo
                                           AND nominaDiasLaboral.mes = CASE MONTH(@fechalaboral)
                                                                            WHEN 01 THEN 'ENE'
                                                                            WHEN 02 THEN 'FEB'
                                                                            WHEN 03 THEN 'MAR'
                                                                            WHEN 04 THEN 'ABR'
                                                                            WHEN 05 THEN 'MAY'
                                                                            WHEN 06 THEN 'JUN'
                                                                            WHEN 07 THEN 'JUL'
                                                                            WHEN 08 THEN 'AGO'
                                                                            WHEN 09 THEN 'SEP'
                                                                            WHEN 10 THEN 'OCT'
                                                                            WHEN 11 THEN 'NOV'
                                                                            WHEN 12 THEN 'DIC'
                                                                            ELSE '' END + RIGHT(YEAR(@fechalaboral),2)),0)

                      SET @partevariablelaboral = CASE WHEN @diaslaboral = 0 THEN 0 ELSE ROUND(@percepcionvariablelaboral / @diaslaboral,2) END

                      IF @usardias = 'DIASNOMINA'
                         BEGIN
                           SELECT @diastr = SUM(nominaDias.diastr_nom)
                           FROM dbo.nomina1_anual AS nominaDias
                           WHERE nominaDias.empresa = @empresa
                                 AND nominaDias.codigo = @codigo
                                 AND (nominaDias.mes = CASE @mesanterior1 WHEN 01 THEN 'ENE'
                                                                          WHEN 02 THEN 'FEB'
                                                                          WHEN 03 THEN 'MAR'
                                                                          WHEN 04 THEN 'ABR'
                                                                          WHEN 05 THEN 'MAY'
                                                                          WHEN 06 THEN 'JUN'
                                                                          WHEN 07 THEN 'JUL'
                                                                          WHEN 08 THEN 'AGO'
                                                                          WHEN 09 THEN 'SEP'
                                                                          WHEN 10 THEN 'OCT'
                                                                          WHEN 11 THEN 'NOV'
                                                                          WHEN 12 THEN 'DIC'
                                                                          ELSE '' END + RIGHT(@ayoanterior, 2)

                                      OR nominaDias.mes = CASE @mesanterior2 WHEN 01 THEN 'ENE'
                                                                             WHEN 02 THEN 'FEB'
                                                                             WHEN 03 THEN 'MAR'
                                                                             WHEN 04 THEN 'ABR'
                                                                             WHEN 05 THEN 'MAY'
                                                                             WHEN 06 THEN 'JUN'
                                                                             WHEN 07 THEN 'JUL'
                                                                             WHEN 08 THEN 'AGO'
                                                                             WHEN 09 THEN 'SEP'
                                                                             WHEN 10 THEN 'OCT'
                                                                             WHEN 11 THEN 'NOV'
                                                                             WHEN 12 THEN 'DIC'
                                                                             ELSE '' END + RIGHT(@ayoanterior, 2))
                         END
                      ELSE
                         BEGIN
                           IF @usardias = 'DIASNATURALES'
                              BEGIN
                                SELECT @diastr = SUM(ISNULL(AvisosImssDias.diastr, 0)),
                                       @ausen = SUM(ISNULL(AvisosImssDias.ausen, 0)),
                                       @incap = SUM(ISNULL(AvisosImssDias.incap, 0))
                                FROM dbo.avisos_imss AS AvisosImssDias
                                WHERE AvisosImssDias.empresa = @empresa
                                      AND AvisosImssDias.codigo = @codigo
                                      AND YEAR(AvisosImssDias.fch_mov) = @ayoanterior
                                      AND MONTH(AvisosImssDias.fch_mov) >= @mesanterior1
                                      AND MONTH(AvisosImssDias.fch_mov) <= @mesanterior2
                              END
                         END

                      SET @percepcionvariable = CASE WHEN @percepcionvariable IS NULL THEN 0 ELSE @percepcionvariable END
                      SET @diastr = CASE WHEN @diastr IS NULL THEN 0 ELSE @diastr END
                      SET @ausen = CASE WHEN @ausen IS NULL THEN 0 ELSE @ausen END
                      SET @incap = CASE WHEN @incap IS NULL THEN 0 ELSE @incap END

                      SET @partevariablecalculadausuario = CASE WHEN @percepcionvariable = 0
                                                                THEN @partevariablecalculadausuario
                                                                ELSE ROUND(@percepcionvariable / CASE WHEN (@diastr - @ausen - @incap) = 0
                                                                                                      THEN 1
                                                                                                      ELSE (@diastr - @ausen - @incap)
                                                                                                 END,2)
                                                           END
                    END
               END
            ELSE
               BEGIN
                 SET @diastr = 0
                 SET @ausen = 0
                 SET @incap = 0
               END

            SET @sbc_ok = ROUND((@sueldo * @factor)
                                + @excedentedespensa
                                + @importefijo
                                + @partevariablecalculadausuario,2)

            SET @sbccalculado = @sbc_ok

            SET @topeminimointegrado = ROUND(@salariominimoregion * @factor,2)

            IF @jornada = 6
                           BEGIN
                 SET @sbc_ok = CASE WHEN @sbc_ok < @topeminimo THEN @topeminimo ELSE @sbc_ok END
                           END
                        ELSE
                           BEGIN
                 SET @sbc_ok = CASE WHEN @sbc_ok < @topeminimointegrado THEN @topeminimointegrado ELSE @sbc_ok END
               END

            --SET @importefijolaboral = CASE WHEN @importefijo IS NULL THEN 0 ELSE @importefijo END
            SET @ctopafondoahorro = ISNULL((SELECT TOP 1 Marca2 AS Marca
                                            FROM dbo.conceptos AS c
                                            WHERE c.num_conc = 27 AND
                                                  c.clase = @clase AND
                                                  c.empresa = @empresa), 'S') -- T = Topar   S = Sin tope

            SET @importefijolaboral = @importefijo
                                      + CASE WHEN @ctopafondoahorro = 'T' AND @fondoahorropatron > (@umadiario * 10.00 * 0.13)
                                             THEN (@umadiario * 10.00 * 0.13)
                                             ELSE @fondoahorropatron  -- Parte diario de fdo. de ahorro
                                        END

            --SET @despensalaboral = @excedentedespensa --ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2)
            SET @despensalaboral = ROUND(((@sueldo * (@despensaporciento / 100)) + @despensaimporte),2)

			IF @tiposalario = 1
			   BEGIN
                 SET @sbclaboral = ROUND((@partevariablelaboral * @factorlaboral)
                                         + @importefijolaboral
                                         + @despensalaboral, 2)
			   END
			ELSE
			   BEGIN 
                 SET @sbclaboral = ROUND((@sueldo * @factorlaboral)
                                         + @importefijolaboral
                                         + @despensalaboral
                                         + CASE WHEN @tiposalario <> 0 THEN @partevariablelaboral ELSE 0 END, 2)
			   END

            IF @jornada = 6
               BEGIN
                 SET @sbclaboral = CASE WHEN @sbclaboral < @topeminimo THEN @topeminimo ELSE @sbclaboral END
               END
            ELSE
               BEGIN
                 SET @sbclaboral = CASE WHEN @sbclaboral < @topeminimointegrado THEN @topeminimointegrado ELSE @sbclaboral END
               END

            SELECT @nombreclase = clase.nombre
            FROM dbo.clases AS clase
            WHERE clase.empresa = @empresa
                  AND LTRIM(RTRIM(clase.clase))= @clase

            SET @nombreclase = CASE WHEN @nombreclase IS NULL THEN 'CLASE NO ENCONTRADA' ELSE @nombreclase END

            SET @obs_factor = CASE WHEN @factor = 0 OR @factor = 1 THEN '2' ELSE '' END
            SET @observacion = CASE WHEN @obs_factor = '2' THEN @obs_factor ELSE 'OK' END

            SET @obs_auto = CASE WHEN @obs_factor = '2' THEN 'FACTOR INTEGRACION INCORRECTO' ELSE 'OK' END

            INSERT dbo.auditoria
                   (empresa,
                    codigo,
                    ayos,
                    sueldo,
                    factor,
                    importes_excedentes,
                    sdi_fijo,
                    percepcionVariable,
                    sdi_reportado,
                    sdi_ok,
                    observacion,
                    clase,
                    nombre,
                    fch_antigua,
                    tipo_salario,
                    mes,
                    ayo,
                    usuario,
                    fecha_auto,
                    marca,
                    incapacitado,
                    mov,
                    fch_mov,
                    obs_auto,
                    fchalta,
                    rpu,
                    nombreClase,
                    multiple,
                    ocupacion,
                    centro,
                    jornada,
                    salDf,
                    salMin,
                    umaDiario,
                    tiponom,
                    excedenteDespensa,
                    importesFijos,
                    diastr,
                    ausen,
                    incap,
                    DivisorPercepcionesVariables,
                    origen,
                    ip,
                    mac,
                    nombreEquipo,
                    topaDespensa,
                    fondoAhorroPatron,
                    fondoAhorroEmpleado,
                    accion,
                    topeDespensa,
                    ultimoAvisoMov,
                    ultimoAvisoFch_Mov,
                    topeUltimoAviso,
                    minimoUltimoAviso,
                    topeAuditoria,
                    minimoAuditoria,
                    minimoAuditoriaIntegrado,
                    existeCodigo,
                    parte_variable,
                    despensa,
                    despensaim,
                    fechaUMA,
                    factorLaboral,
                    sdiLaboral,
                    importeFijoLaboral,
                    despensaLaboral,
                    sdiCalculado,
                    tieneAvisoAnterior,
                    serial,
                    diasLaboral,
                    percepcionVariableLaboral,
                    parteVariableLaboral)

              VALUES (@empresa,
                      @codigo,
                      @ayos,
                      @sueldo,
                      @factor,
                      @importeexcedente,
                      @sdi_fijo,
                      0,
                      0,
                      @sbc_ok,
                      @observacion,
                      @clase,
                      @nombre,
                      @fechaantigua,
                      @tiposalario,
                      @mesfechafinmes,
                      @ayofechafinmes,
                      @usuario,
                      @fecha,
                      NULL,
                      'N',
                      'A',
                      @fecha,
                      @obs_auto,
                      @fecha,
                      @rpu,
                      @nombreclase,
                      NULL,
                      @ocupacion,
                      @centro,
                      @jornada,
                      @salariominimodf,
                      @salariominimoregion,
                      @umadiario,
                      @tiponom,
                      @excedentedespensa,
                      @importefijo,
                      @diastr,
                      @ausen,
                      @incap,
                      @usardias,
                      @origen,
                      @ip,
                      @mac,
                      @nombreequipo,
                      @topadespensa,
                      @fondoahorropatron,
                      @fondoahorroempleado,
                      @accion,
                      @topedespensa,
                      'A',
                      @fecha,
                      @topeultimoaviso,
                      @minimoultimoaviso,
                      @topeauditoria,
                      @minimoauditoria,
                      @minimoauditoriaintegrado,
                      @existecodigo,
                      @partevariablecalculadausuario,
                      @despensaporciento,
                      @despensaimporte,
                      @fechauma,
                      @factorlaboral,
                      @sbclaboral,
                      @importefijolaboral,
                      @despensalaboral,
                      @sbccalculado,
                      0,
                      0,
                                          @diaslaboral,
                                          @percepcionvariablelaboral,
                                          @partevariablelaboral)
          END
     END

  IF @soloerror = 1
     BEGIN
       DELETE auditoria
       FROM dbo.auditoria AS auditoria
       WHERE auditoria.empresa = @empresa
             AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario))
             AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac))
             AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreequipo))
             AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
             AND CHARINDEX('OK', auditoria.observacion) > 0
     END

  IF @origen = 'AM'
     BEGIN
       DELETE dbo.auditoria
       WHERE auditoria.empresa = @empresa
             AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario))
             AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac))
             AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreequipo))
             AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
             AND CHARINDEX('B', auditoria.observacion) > 0
     END

  IF @origen = 'VA'
     BEGIN
       DELETE dbo.auditoria
       WHERE auditoria.empresa = @empresa
             AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario))
             AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac))
             AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreequipo))
             AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
             AND ((auditoria.obs_auto <> 'INCAPACITADO'
                   AND auditoria.obs_auto <> 'OK')
                  OR auditoria.sdi_reportado = auditoria.sdi_ok
                  OR (CHARINDEX('OK,T', auditoria.observacion) > 0 AND SUBSTRING(@registropatronal,1,10) <> 'C534476410')
                  OR (CHARINDEX('OK,L', auditoria.observacion) > 0 AND SUBSTRING(@registropatronal,1,10) <> 'C534476410')
                  OR ABS(auditoria.sdi_reportado - auditoria.sdi_ok) <= 0.03)
     END

  IF @accion = 3 AND (@origen = 'CI' OR @origen = 'EN')
     BEGIN
       SELECT empresa,
              codigo,
              ayos,
              sueldo,
              factor,
              importes_excedentes,
              sdi_fijo,
              parte_variable,
              sdi_reportado,
              sdi_ok,
              observacion,
              clase,
              nombre,
              fch_antigua,
              tipo_salario,
              mes,
              ayo,
              usuario,
              fecha_auto,
              marca,
              incapacitado,
              mov,
              fch_mov,
              obs_auto,
              fchalta,
              rpu,
              nombreClase,
              multiple,
              ocupacion,
              centro,
              jornada,
              salDf,
              salMin,
              umaDiario,
              tiponom,
              excedenteDespensa,
              importesFijos,
              diastr,
              ausen,
              incap,
              percepcionVariable,
              DivisorPercepcionesVariables,
              id,
              origen,
              ip,
              mac,
              nombreEquipo,
              topaDespensa,
              fondoAhorroPatron,
              fondoAhorroEmpleado,
              accion,
              topeDespensa,
              ultimoAvisoMov,
              ultimoAvisoFch_Mov,
              topeUltimoAviso,
              minimoUltimoAviso,
              topeAuditoria,
              minimoAuditoria,
              minimoAuditoriaIntegrado,
              convert(char(1), ' ') as observa,
              convert(char(1), 'N') as hay_error,
              convert(char(1), 'N') as error3_4,
              convert(char(1), 'N') as autoregularizacion,
              existeCodigo,
              despensa,
              despensaim,
              fechaUMA,
              factorLaboral,
              sdiLaboral,
              importeFijoLaboral,
              despensaLaboral,
              sdiCalculado,
              tieneAvisoAnterior,
              serial,
              @aguinaldo AS aguinaldo,
                          @prima_vac AS prima_vac,
              @dias_vac AS dias_vac,
              @pmavacdias AS pmavacdias,
              @dias_ayo AS dias_ayo,
              @porc_ayo AS porc_ayo,
              @porc_mes AS porc_mes,
              @porc_dia AS porc_dia,
              @pmo1ayopor AS pmo1ayopor,
              @pmo2ayopor AS pmo2ayopor,
              @dias_mes AS dias_mes,
              @fdoahopatp AS fdoahopatp,
              diasLaboral,
              percepcionVariableLaboral,
                          parteVariableLaboral
       FROM dbo.auditoria AS auditoria
       WHERE auditoria.empresa = @empresa
             AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario))
             AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac))
             AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreequipo))
             AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
       ORDER BY auditoria.clase,
                auditoria.codigo
     END
  ELSE
     BEGIN
       SELECT empresa,
              codigo,
              ayos,
              sueldo,
              factor,
              importes_excedentes,
              sdi_fijo,
              parte_variable,
              sdi_reportado,
              sdi_ok,
              observacion,
              clase,
              nombre,
              fch_antigua,
              tipo_salario,
              mes,
              ayo,
              usuario,
              fecha_auto,
              marca,
              incapacitado,
              mov,
              fch_mov,
              obs_auto,
              fchalta,
              rpu,
              nombreClase,
              multiple,
              ocupacion,
              centro,
              jornada,
              salDf,
              salMin,
              umaDiario,
              tiponom,
              excedenteDespensa,
              importesFijos,
              diastr,
              ausen,
              incap,
              percepcionVariable,
              DivisorPercepcionesVariables,
              id,
              origen,
              ip,
              mac,
              nombreEquipo,
              topaDespensa,
              fondoAhorroPatron,
              fondoAhorroEmpleado,
              accion,
              topeDespensa,
              ultimoAvisoMov,
              ultimoAvisoFch_Mov,
              topeUltimoAviso,
              minimoUltimoAviso,
              topeAuditoria,
              minimoAuditoria,
              minimoAuditoriaIntegrado,
              convert(char(1), ' ') as observa,
              convert(char(1), 'N') as hay_error,
              convert(char(1), 'N') as error3_4,
              convert(char(1), 'N') as autoregularizacion,
              existeCodigo,
              despensa,
              despensaim,
              fechaUMA,
              factorLaboral,
              sdiLaboral,
              importeFijoLaboral,
              despensaLaboral,
              sdiCalculado,
              tieneAvisoAnterior,
              serial,
              0 AS diasLaboral,
              0 AS percepcionVariableLaboral,
                          0 AS parteVariableLaboral
       FROM dbo.auditoria AS auditoria
       WHERE auditoria.empresa = @empresa
             AND LTRIM(RTRIM(auditoria.usuario)) = LTRIM(RTRIM(@usuario))
             AND LTRIM(RTRIM(auditoria.mac)) = LTRIM(RTRIM(@mac))
             AND LTRIM(RTRIM(auditoria.nombreEquipo)) = LTRIM(RTRIM(@nombreequipo))
             AND LTRIM(RTRIM(auditoria.origen)) = LTRIM(RTRIM(@origen))
       ORDER BY auditoria.clase,
                auditoria.codigo
         END
GO

IF OBJECT_ID('dbo.ObtieneSeleccionSalarioMinimo') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneSeleccionSalarioMinimo
GO
CREATE PROCEDURE dbo.ObtieneSeleccionSalarioMinimo @empresa INT
AS 
    SELECT  ISNULL(dbo.empresas.usarSalarioMinimo, 'R') AS 'seleccionSalarioMinimo'
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa
GO

IF OBJECT_ID('dbo.ObtieneTblUMA') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneTblUMA
GO
CREATE PROCEDURE dbo.ObtieneTblUMA
AS

  SET NOCOUNT ON
  
  SELECT uma.idUma,
         uma.fecha,
         uma.umaDiario,
         uma.umaMensual,
         uma.umaAnual
  FROM dbo.TblUMA AS uma
  ORDER BY uma.fecha ASC
GO

IF OBJECT_ID('dbo.ObtieneTblUMAFD') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneTblUMAFD
GO
CREATE PROCEDURE dbo.ObtieneTblUMAFD
AS

  SET NOCOUNT ON
  
  SELECT uma.idUma,
         uma.fecha,
         uma.umaDiario,
         uma.umaMensual,
         uma.umaAnual
  FROM dbo.TblUMAFD AS uma
  ORDER BY uma.fecha ASC
GO

/**************************************************************************************************
 * Name          : ObtieneTotalAusentismos
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total ausentismos del mes seleccionado
 * Table name    : 
 * Return        : tabla con total ausentismos del mes seleccionado
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Septiembre 14, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneTotalAusentismos' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneTotalAusentismos]
    END
go


CREATE PROCEDURE [dbo].[ObtieneTotalAusentismos]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mes INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
AS 
    SELECT  [dbo].[LlenaAusentismoMes].diastr ,
            [dbo].[LlenaAusentismoMes].incap ,
            [dbo].[LlenaAusentismoMes].ausen ,
            [dbo].[LlenaAusentismoMes].campo ,
            [dbo].[LlenaAusentismoMes].valor ,
			[dbo].[LlenaAusentismoMes].lic
    FROM    [dbo].[LlenaAusentismoMes](@empresa, @codigo, @ayo, @mes, @porRenglon, @proceso, @fechaProceso, @horaProceso)
GO

/**************************************************************************************************
 * Name          : ObtieneTotalAusentismosBimestre
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total ausentismos del mes seleccionado
 * Table name    : 
 * Return        : tabla con total ausentismos del mes seleccionado
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Septiembre 14, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneTotalAusentismosBimestre' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneTotalAusentismosBimestre]
    END
go


CREATE PROCEDURE [dbo].[ObtieneTotalAusentismosBimestre]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mesNon INT ,
    @mesPar INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8),
	@filtroInfonavit INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
AS 
    SELECT  [dbo].[LlenaAusentismoBimestre].diastr ,
            [dbo].[LlenaAusentismoBimestre].incap ,
            [dbo].[LlenaAusentismoBimestre].ausen ,
            [dbo].[LlenaAusentismoBimestre].campo ,
            [dbo].[LlenaAusentismoBimestre].valor ,
			[dbo].[LlenaAusentismoBimestre].lic
    FROM    [dbo].[LlenaAusentismoBimestre](@empresa, @codigo, @ayo, @mesNon,
                                              @mesPar, @porRenglon, @proceso, @fechaProceso, @horaProceso, @filtroInfonavit)
GO

/**************************************************************************************************
 * Name          : ObtieneTotalCuotasBimestre
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total cuotas bimestre
 * Table name    : 
 * Return        : tabla con total cuotas bimestre
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneTotalCuotasBimestre' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneTotalCuotasBimestre]
    END
go


CREATE PROCEDURE [dbo].[ObtieneTotalCuotasBimestre]
@empresa NUMERIC(5) ,
@codigo NUMERIC(8, 0) ,
@ayo INT ,
@mesNon INT ,
@mesPar INT ,
@porRenglon INT ,
@proceso VARCHAR(250),
@fechaProceso DATETIME ,
@horaProceso VARCHAR(8) ,
@simulaReforma INT,
@filtroInfonavit INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito

AS 

  SET NOCOUNT ON

  DECLARE @diasFaltaTope INT
  DECLARE @fiNon DATETIME
  DECLARE @ffNon DATETIME
  DECLARE @fiPar DATETIME
  DECLARE @ffPar DATETIME
  DECLARE @esBimestre CHAR(1)
  DECLARE @salarioRegionA NUMERIC(12,2)
  DECLARE @salarioRegionB NUMERIC(12,2)
  DECLARE @salarioRegionC NUMERIC(12,2)
  DECLARE @salarioRegion NUMERIC(12,2)
  DECLARE @salarioDF NUMERIC(12,2)
  DECLARE @areaGeografica CHAR(1)
  DECLARE @topeDF NUMERIC(12,2)
  DECLARE @topeRegion NUMERIC(12,2)
  DECLARE @retiro NUMERIC(8,5)
  DECLARE @cvArt168II NUMERIC(8,5)
  DECLARE @cvPat168II NUMERIC(8,5)
  DECLARE @cvTra168II NUMERIC(8,5)
  DECLARE @infonavit NUMERIC(8,5)
  DECLARE @ayoEmpresa INT
  DECLARE @cDiasLab CHAR(1)
  DECLARE @cRetenido CHAR(1)
  DECLARE @cPropCred CHAR(1)
  DECLARE @cConvenio VARCHAR(30)
  DECLARE @seguroVivienda INT
  DECLARE @retiroCuota NUMERIC(12,2)
  DECLARE @cesantiaVejez NUMERIC(12,2)
  DECLARE @aportacionInfonavit NUMERIC(12,2)
  DECLARE @amortizacion NUMERIC(12,2)
  DECLARE @seguroViviendaCuota NUMERIC(12,2)
  DECLARE @seguroDesempleo NUMERIC(12,2)
  DECLARE @fechaAplicaUMA DATETIME
  DECLARE @FechaFinita DATETIME

  SET @FechaFinita = '29991231'
  SET @fechaAplicaUMA = CONVERT(DATETIME, '20170101')
  SET @diasFaltaTope = 7
  SET @fiNon = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + ( @mesNon )), 2, 2) + '01')
  SET @ffNon = dbo.fin_mes(@mesNon, @ayo)
  SET @fiPar = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + SUBSTRING(CONVERT(CHAR(3), 100 + @mesPar), 2, 2) + '01')
  SET @ffPar = dbo.fin_mes(@mesPar, @ayo)

  IF @mesPar / 2 = FLOOR(@mesPar / 2) AND @mesNon < @mesPar 
     BEGIN
       SET @esBimestre = 'S'
     END
  ELSE 
     BEGIN
       SET @esBimestre = 'N'
     END
    
    
  -- Obtiene Area Geografica
  SELECT @areaGeografica = empresa.zona_geografica ,
         @ayoEmpresa = empresa.ayo_operacion
  FROM dbo.empresas AS empresa
  WHERE empresa.empresa = @empresa


  -- Obtiene Salario Minimo
  SELECT @salarioRegionA = ISNULL(salarioMinimo.zona_a, 0) ,
         @salarioRegionB = ISNULL(salarioMinimo.zona_b, 0) ,
         @salarioRegionC = ISNULL(salarioMinimo.zona_c, 0)
  FROM [dbo].[GetMinimumWage](@mesPar, @ayo) AS salarioMinimo
        
  SET @salarioDF = @salarioRegionA
  SET @salarioRegion = CASE @areaGeografica
                            WHEN 'A' THEN @salarioRegionA
                            WHEN 'B' THEN @salarioRegionB
                            WHEN 'C' THEN @salarioRegionC
                            ELSE 0
                       END
  SET @topeDF = ROUND(@salarioDF * 25, 2)
  SET @topeRegion = @salarioRegion    
    
  -- Obtiene Primas IMSS
  SELECT @retiro = primasImss.cvArt168I, 
         @cvArt168II = primasImss.cvArt168II,
         @cvPat168II = primasImss.cvPat168II,
         @cvTra168II = primasImss.cvTra168ii,
         @infonavit = primasImss.infonavitPorciento,
         @seguroDesempleo = primasImss.seguroDesempleoPorciento
  FROM dbo.ObtienePrimasImssFuncion(@empresa, @ayo, @simulaReforma) AS primasImss
                                                
  -- saca parametros infonavit
  SELECT  @cDiasLab = CASE WHEN concepto.hrs_min2 = 999 THEN 'N' ELSE 'S' END,
          @cRetenido = CASE WHEN concepto.hrs_min3 = 999 THEN 'S' ELSE 'N' END,
          @cPropCred = CASE WHEN concepto.marca2 = 'M' THEN 'N' ELSE 'S' END,
          @cConvenio = concepto.variable1
  FROM dbo.conceptos AS concepto
  WHERE concepto.empresa = @empresa
        AND concepto.num_conc = 112                                                
    
  SET @seguroVivienda = CASE WHEN @fiNon >= CONVERT(DATETIME, '20060101') AND @ffPar <= CONVERT(DATETIME, '20081231') THEN 8
                             WHEN @fiNon >= CONVERT(DATETIME, '20090101') AND @ffPar <= CONVERT(DATETIME, '20101031') THEN 13
                             WHEN @fiNon >= CONVERT(DATETIME, '20101101') THEN 15
                             ELSE 0
                        END

  DECLARE @Renglon TABLE (Renglon INT)
  INSERT @Renglon VALUES (1)
  INSERT @Renglon VALUES (2)
  INSERT @Renglon VALUES (3)
  INSERT @Renglon VALUES (4)
  INSERT @Renglon VALUES (5)

  -- @porRenglon = 0.- Es un registro por cada prima IMSS
  --               1.- Es un solo registro y en cada columna su cuota IMSS correspondiente
  SELECT CASE WHEN @porRenglon = 1 THEN retiro ELSE NULL END AS retiro,
         CASE WHEN @porRenglon = 1 THEN cesantiaVejez ELSE NULL END AS cesantiaVejez,
         CASE WHEN @porRenglon = 1 THEN aportacionInfonavit ELSE NULL END AS aportacionInfonavit,
         CASE WHEN @porRenglon = 1 THEN amortizacion ELSE NULL END AS amortizacion,
         CASE WHEN @porRenglon = 1 THEN seguroVivienda ELSE NULL END AS seguroVivienda,
         CASE WHEN @porRenglon = 1 THEN NULL ELSE CASE Renglon.Renglon 
		                                               WHEN 1 THEN 'Retiro'
                                                       WHEN 2 THEN 'Cesantia y Vejez'
                                                       WHEN 3 THEN 'Aportacin INFONAVIT'
                                                       WHEN 4 THEN 'Amortizacion'
                                                       WHEN 5 THEN 'Seguro Vivienda'
													          ELSE NULL END END AS nombrePrimaImss,
         CASE WHEN @porRenglon = 1 THEN NULL ELSE CASE Renglon.Renglon 
		                                               WHEN 1 THEN retiro
                                                       WHEN 2 THEN cesantiaVejez
                                                       WHEN 3 THEN aportacionInfonavit
                                                       WHEN 4 THEN amortizacion
                                                       WHEN 5 THEN seguroVivienda
													          ELSE NULL END END AS cuotaPrimaImss 

  FROM (SELECT ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@retiro, 'N', 0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @retiro, 0)),2) AS retiro ,
               --ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen,@cvArt168II,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @cvArt168II, 0)),2) AS cesantiaVejez ,
               ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,aItc.incap,aItc.ausen, tblCV.cvArt168II, 'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, tblCV.cvArt168II, 0)),2) AS cesantiaVejez ,
               ROUND(SUM([dbo].[CalculaCuotaImss]([dbo].[AjustaSaldiaInt](aItc.saldiaint,CASE WHEN aItc.fch_mov >= @fechaAplicaUMA THEN ROUND(aItc.umaDiario * 25,2) ELSE @topeDF END,@topeRegion,dbo.empleados.art39,aItc.mov),aItc.diastr,0,aItc.ausen,@infonavit,'N',0, aItc.sueldo, aItc.fch_mov, @simulaReforma, @salarioRegion, 0, @infonavit, 0)),2) AS aportacionInfonavit ,
			   SUM(ISNULL(infonavit.amortizacion,0)) AS amortizacion,
			   SUM(ISNULL(infonavit.seguroVivienda,0)) AS seguroVivienda
        FROM dbo.empleados

             INNER JOIN dbo.AvisosImssTemporalCalculo AS aItc ON dbo.empleados.empresa = aItc.empresa
                                                                 AND dbo.empleados.codigo = aItc.codigo
                                                                 AND aItc.mes_operacion >= @mesNon 
                                                                 AND aItc.mes_operacion <= @mesPar 
                                                                 AND YEAR(aItc.fch_mov) = @ayo
                                                                 AND aItc.horaProceso = @horaproceso
                                                                 AND aItc.fechaProceso = @fechaproceso
                                                                 AND aItc.proceso = @proceso

             OUTER APPLY (SELECT CASE WHEN aItc.mov = 'B' THEN 0 ELSE rango END rango
			                     , cvArt168II
                                 , cvPat168II
                                 , cvTra168II
			              FROM dbo.NOM_FUN_ObtienePrimaCVPatron2023(aItc.empresa, aItc.fch_mov, YEAR(aItc.fch_mov), aItc.saldiaint, @cvArt168II, @cvPat168II, @cvTra168II)
					     ) AS tblCV

             OUTER APPLY(SELECT CASE WHEN aItc.serial = 1 THEN ISNULL(dbo.TemporalAmortizacion.amortizacion,0) ELSE 0 END AS amortizacion,
                                CASE WHEN aItc.serial = 1 THEN @seguroVivienda ELSE 0 END AS seguroVivienda,
			                    CASE WHEN aItc.serial = 1 THEN 'Si' ELSE '' END AS tieneCredito
                         FROM dbo.TemporalAmortizacion
                         WHERE dbo.TemporalAmortizacion.empresa = dbo.empleados.empresa
                               AND dbo.TemporalAmortizacion.codigo = dbo.empleados.codigo
							   AND dbo.TemporalAmortizacion.amortizacion > 0) AS infonavit

        WHERE dbo.empleados.empresa >= CASE WHEN @empresa = 0
                                            THEN 0
                                            ELSE @empresa
                                       END
              AND dbo.empleados.empresa <= CASE WHEN @empresa = 0
                                                THEN 9999
                                                ELSE @empresa
                                           END
              AND dbo.empleados.cotiza_imss = 'S'
              AND dbo.empleados.borrado = 'N'
              AND dbo.empleados.codigo >= CASE WHEN @codigo = 0
                                               THEN 0
                                               ELSE @codigo
                                          END
              AND dbo.empleados.codigo <= CASE WHEN @codigo = 0
                                               THEN 99999999
                                               ELSE @codigo
                                          END
              AND CASE @filtroInfonavit WHEN 1 THEN 'Todos'
                                        WHEN 2 THEN 'Si'
                                        WHEN 3 THEN 'No'
                                        ELSE 'Ninguno' END = CASE WHEN @filtroInfonavit = 1 THEN 'Todos' ELSE ISNULL(infonavit.tieneCredito, 'No') END) AS CuotasImss

  INNER JOIN (SELECT Renglon FROM @Renglon) AS Renglon ON (Renglon.Renglon <= 7 AND @porRenglon = 0) OR (Renglon.Renglon = 1 AND @porRenglon = 1)
GO

/**************************************************************************************************
 * Name          : ObtieneTotalCuotasBimestre
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total cuotas bimestre
 * Table name    : 
 * Return        : tabla con total cuotas bimestre
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Miercoles, Septiembre 15, 2010
 **************************************************************************************************/
IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneTotalCuotasBimestreSinInfonavit' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneTotalCuotasBimestreSinInfonavit]
    END
go


CREATE PROCEDURE [dbo].[ObtieneTotalCuotasBimestreSinInfonavit]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mesNon INT ,
    @mesPar INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT
AS 
    SELECT  CuotasBimestre.retiro ,
            CuotasBimestre.cesantiaVejez ,
            CuotasBimestre.aportacionInfonavit ,
            CuotasBimestre.amortizacion ,
            CuotasBimestre.seguroVivienda ,
            CuotasBimestre.nombrePrimaImss ,
            CuotasBimestre.cuotaPrimaImss
    FROM    [dbo].[LlenaTotalCuotasBimestreSinInfonavit](@empresa, @codigo, @ayo, @mesNon, @mesPar, @porRenglon, @proceso, @fechaProceso, @horaProceso, @simulaReforma) AS CuotasBimestre
GO

/**************************************************************************************************
 * Name          : ObtieneTotalCuotasImss
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total cuotas imss
 * Table name    : 
 * Return        : tabla con total cuotas imss
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Septiembre 14, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneTotalCuotasImss' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneTotalCuotasImss]
    END
go


CREATE PROCEDURE [dbo].[ObtieneTotalCuotasImss]
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mes INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT
AS 
    SELECT  [dbo].[LlenaTotalCuotaImss].cuotaFija ,
            [dbo].[LlenaTotalCuotaImss].excedente ,
            [dbo].[LlenaTotalCuotaImss].prestacionesDinero ,
            [dbo].[LlenaTotalCuotaImss].gmp ,
            [dbo].[LlenaTotalCuotaImss].rt ,
            [dbo].[LlenaTotalCuotaImss].invalidezVida ,
            [dbo].[LlenaTotalCuotaImss].guarderias ,
            [dbo].[LlenaTotalCuotaImss].cesantiaVejez ,
            [dbo].[LlenaTotalCuotaImss].nombrePrimaImss ,
            [dbo].[LlenaTotalCuotaImss].cuotaPrimaImss 
    FROM    [dbo].[LlenaTotalCuotaImss](@empresa, @codigo, @ayo, @mes, @porRenglon, @proceso, @fechaProceso, @horaProceso, @simulaReforma)
GO

/**************************************************************************************************
 * Name          : ObtieneTotalCuotasImss
 * Project       : APSI Nomina
 * Description   : Obtiene tabla con total cuotas imss
 * Table name    : 
 * Return        : tabla con total cuotas imss
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Martes, Septiembre 14, 2010
 **************************************************************************************************/
IF OBJECT_ID('dbo.ObtieneTotalCuotasImssInfonavit') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneTotalCuotasImssinfonavit
GO
CREATE PROCEDURE dbo.ObtieneTotalCuotasImssInfonavit
    @empresa NUMERIC(5) ,
    @codigo NUMERIC(8, 0) ,
    @ayo INT ,
    @mes INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8) ,
    @simulaReforma INT
AS 
    SELECT  LlenaTotalCuotaImss.cuotaFija,
            LlenaTotalCuotaImss.excedente,
            LlenaTotalCuotaImss.prestacionesDinero,
            LlenaTotalCuotaImss.gmp,
            LlenaTotalCuotaImss.rt,
            LlenaTotalCuotaImss.invalidezVida,
            LlenaTotalCuotaImss.guarderias,
            LlenaTotalCuotaImss.cesantiaVejez,
            LlenaTotalCuotaImss.nombrePrimaImss,
            LlenaTotalCuotaImss.cuotaPrimaImss 
    FROM    dbo.LlenaTotalCuotaImssInfonavit(@empresa, @codigo, @ayo, @mes, @porRenglon, @proceso, @fechaProceso, @horaProceso, @simulaReforma) AS LlenaTotalCuotaImss
GO

IF OBJECT_ID('dbo.ObtieneUltimaFechaModificacionDatos') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneUltimaFechaModificacionDatos
GO
CREATE PROCEDURE dbo.ObtieneUltimaFechaModificacionDatos
@empresa INT,
@codigo INT

AS 

  SET  NOCOUNT ON

  SELECT TOP 1
         CONVERT(DATETIME, CONVERT (CHAR(10), historico.fecha_captura, 112)) AS fecha_captura,
         CONVERT(VARCHAR(8), historico.fecha_captura, 108) AS hora_captura,
         historico.capturo
  FROM dbo.historico AS historico
  WHERE historico.empresa = @empresa
        AND historico.codigo = @codigo
  ORDER BY CONVERT(DATETIME, CONVERT (CHAR(10), historico.fecha_captura, 112)) DESC,
           CONVERT(VARCHAR(8), historico.fecha_captura, 108) DESC
GO

IF OBJECT_ID('dbo.ObtieneUMAFDPorRangoFecha') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneUMAFDPorRangoFecha
GO
CREATE PROCEDURE dbo.ObtieneUMAFDPorRangoFecha
@fechaInicio DATETIME,
@fechaFin DATETIME

AS 
  SET NOCOUNT ON
  
  DECLARE @uma TABLE (fecha DATETIME, umaDiario NUMERIC(12,2), dias INT)

  INSERT @uma (fecha, umaDiario, dias)
  SELECT TOP 1
         CASE WHEN uma.fecha < @fechaInicio 
              THEN @fechaInicio 
              ELSE uma.fecha 
         END AS fecha,
         uma.umaDiario,
         CONVERT(INT, ISNULL((SELECT TOP 1
                        CASE WHEN uma1.fecha > @fechaFin THEN @fechaFin + 1 ELSE uma1.fecha END
                 FROM dbo.TblUMAFD AS uma1
                 WHERE uma1.fecha > @fechaInicio
                 ORDER BY uma1.fecha ASC), @fechaFin + 1) - CASE WHEN uma.fecha < @fechaInicio 
                                                                 THEN @fechaInicio 
                                                                 ELSE uma.fecha 
                                                            END) AS dias
         
  FROM dbo.TblUMAFD AS uma
  WHERE uma.fecha <= @fechaInicio
  ORDER BY uma.fecha DESC
  
  INSERT @uma (fecha, umaDiario, dias)
  SELECT uma.fecha,
         uma.umaDiario,
         CONVERT(INT, ISNULL((SELECT TOP 1
                        CASE WHEN uma1.fecha > @fechaFin THEN @fechaFin + 1 ELSE uma1.fecha END
                 FROM dbo.TblUMAFD AS uma1
                 WHERE uma1.fecha > uma.fecha
                 ORDER BY uma1.fecha ASC), @fechaFin + 1) - uma.fecha) AS dias
  FROM dbo.TblUMAFD AS uma
  WHERE uma.fecha > @fechaInicio
        AND uma.fecha <= @fechaFin
  ORDER BY uma.fecha DESC
  
  SELECT uma.fecha, uma.umaDiario, dias
  FROM @uma AS uma
  ORDER BY uma.fecha ASC
GO

IF OBJECT_Id('dbo.ObtieneUMAPorFecha') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneUMAPorFecha
GO
CREATE PROCEDURE dbo.ObtieneUMAPorFecha
@fecha DATETIME
AS

  SET NOCOUNT ON
  
  SELECT TOP 1
         uma.fecha,
         uma.umaDiario,
         uma.umaMensual,
         uma.umaAnual
  FROM dbo.TblUMA AS uma
  WHERE uma.fecha <= @fecha
  ORDER BY uma.fecha DESC
GO

IF OBJECT_ID('dbo.ObtieneUMAPorRangoFecha') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneUMAPorRangoFecha
GO
CREATE PROCEDURE dbo.ObtieneUMAPorRangoFecha
@fechaInicio DATETIME,
@fechaFin DATETIME

AS 
  SET NOCOUNT ON
  
  DECLARE @uma TABLE (fecha DATETIME, umaDiario NUMERIC(12,2), umaMensual NUMERIC(12,2), umaAnual NUMERIC(12,2), dias INT)

  INSERT @uma (fecha, umaDiario, umaMensual, umaAnual, dias)
  SELECT TOP 1
         CASE WHEN uma.fecha < @fechaInicio 
              THEN @fechaInicio 
              ELSE uma.fecha 
         END AS fecha,
         uma.umaDiario,
         uma.umaMensual,
         uma.umaAnual,
         
         CONVERT(INT, ISNULL((SELECT TOP 1
                        CASE WHEN uma1.fecha > @fechaFin THEN @fechaFin + 1 ELSE uma1.fecha END
                 FROM dbo.TblUMA AS uma1
                 WHERE uma1.fecha > @fechaInicio
                 ORDER BY uma1.fecha ASC), @fechaFin + 1) - CASE WHEN uma.fecha < @fechaInicio 
                                                                 THEN @fechaInicio 
                                                                 ELSE uma.fecha 
                                                            END) AS dias
         
  FROM dbo.TblUMA AS uma
  WHERE uma.fecha <= @fechaInicio
  ORDER BY uma.fecha DESC
  
  INSERT @uma (fecha, umaDiario, umaMensual, umaAnual, dias)
  SELECT uma.fecha,
         uma.umaDiario,
         uma.umaMensual,
         uma.umaAnual,
         
         CONVERT(INT, ISNULL((SELECT TOP 1
                        CASE WHEN uma1.fecha > @fechaFin THEN @fechaFin + 1 ELSE uma1.fecha END
                 FROM dbo.TblUMA AS uma1
                 WHERE uma1.fecha > uma.fecha
                 ORDER BY uma1.fecha ASC), @fechaFin + 1) - uma.fecha) AS dias
  FROM dbo.TblUMA AS uma
  WHERE uma.fecha > @fechaInicio
        AND uma.fecha <= @fechaFin
  ORDER BY uma.fecha DESC
  
  SELECT uma.fecha, uma.umaDiario, uma.umaMensual, uma.umaAnual, dias
  FROM @uma AS uma
  ORDER BY uma.fecha ASC
GO

/**************************************************************************************************
 * Name          : ObtieneUsoRpu
 * Project       : APSI Nomina
 * Description   : Regresa marca de uso de rpu 
 * Table name    : empresas
 * Return        : campo
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Lunes, Enero 10, 2011
 **************************************************************************************************/

IF OBJECT_ID('dbo.ObtieneUsoRpu') IS NOT NULL
    DROP  PROCEDURE [dbo].[ObtieneUsoRpu]
GO


CREATE PROCEDURE [dbo].[ObtieneUsoRpu] @empresa INT
AS 
    SELECT  ISNULL(dbo.empresas.Rpu, 'N') AS rpu
    FROM    dbo.empresas
    WHERE   dbo.empresas.empresa = @empresa
GO

IF NOT EXISTS(SELECT syscolumns.name
              FROM syscolumns
              LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
              WHERE syscolumns.name = 'email' AND sysobjects.name='usuarios')
  ALTER TABLE usuarios ADD email VARCHAR(250) NULL
GO
IF OBJECT_ID('dbo.ObtieneUsuario') IS NOT NULL 
    DROP PROCEDURE dbo.ObtieneUsuario
GO
CREATE PROCEDURE dbo.ObtieneUsuario @usuario VARCHAR(30)
AS 
    SELECT  dbo.usuarios.usuario ,
            dbo.usuarios.descripcion ,
            dbo.usuarios.password ,
            dbo.usuarios.expiracion ,
            dbo.usuarios.email
    FROM    dbo.usuarios
    WHERE   LTRIM(RTRIM(dbo.usuarios.usuario)) = LTRIM(RTRIM(@usuario))
GO

IF OBJECT_ID('dbo.ObtieneUsuarioBitacora') IS NOT NULL
   DROP PROCEDURE dbo.ObtieneUsuarioBitacora
GO
CREATE PROCEDURE dbo.ObtieneUsuarioBitacora
AS
  SET NOCOUNT ON
  
  SELECT DISTINCT 
         u.usuario
  FROM dbo.perfil_usuarios AS u
       INNER JOIN dbo.perfiles AS p ON u.idperfil = p.idperfil
  WHERE p.sistema = 'NO'
  ORDER BY u.usuario ASC
GO

IF OBJECT_ID('dbo.PasaVacacionesRI') IS NOT NULL
  DROP PROCEDURE dbo.PasaVacacionesRI

GO


--EXEC dbo.PasaVacacionesRI 11,2,1

CREATE PROCEDURE dbo.PasaVacacionesRI
@nCodigo         INTEGER,
@nEmpresaOrigen  INTEGER,
@nEmpresaDestino INTEGER

AS

SET NOCOUNT ON

/*
DECLARE @nCodigo INTEGER
DECLARE @nEmpresaOrigen INTEGER
DECLARE @nEmpresaDestino INTEGER

SET @nCodigo         = 11
SET @nEmpresaOrigen  = 1
SET @nEmpresaDestino = 2
*/

SET XACT_ABORT ON

BEGIN TRANSACTION
  BEGIN TRY

    DELETE dbo.Vacaciones
    WHERE Codigo = @nCodigo AND
          Empresa = @nEmpresaDestino


    INSERT INTO dbo.Vacaciones(Codigo, Empresa, FchAlta, Sueldo, SalDiaInt, Dias_Tab, Disfruto, Dias_Saldo, Prima_Vac, Prima_V_Im, Prima_V_Ds,
                               Fch_Prima, Pagada, Vence, Salio, Disfrute, Dias_Disfr, Disf_Ant, Fin_Disfru, Descansos, Festivos, Ordinaria,
                               FactorInt, Marca, Percepcion, Deduccion, Neto, Ds_Tab_Ant, Dias_Ant, Prima_Ant, P_V_Ant_Imp, P_V_Ant_Ds,
                               Paga_Ant, Estado, Grava_Prima, CredTotal, Subsidio, SubsidioN, Acumulado, Fch_Pago, Observaciones)
    SELECT Vacaciones.Codigo,
           @nEmpresaDestino AS Empresa,
           Vacaciones.FchAlta,
           Empleados.Sueldo,
           Empleados.SalDiaInt,
           Vacaciones.Dias_Tab,
           Vacaciones.Disfruto,
           Vacaciones.Dias_Saldo,
           Vacaciones.Prima_Vac,
           Vacaciones.Prima_V_Im,
           Vacaciones.Prima_V_Ds,
           Vacaciones.Fch_Prima,
           Vacaciones.Pagada,
           Vacaciones.Vence,
           Vacaciones.Salio,
           Vacaciones.Disfrute,
           0 AS Dias_Disfr,
           0 AS Disf_Ant,
           Vacaciones.Fin_Disfru,
           0 AS Descansos,
           0 AS Festivos,
           'F' AS Ordinaria,
           Vacaciones.FactorInt,
           Vacaciones.Marca,
           0 AS Percepcion,
           0 AS Deduccion,
           0 AS Neto,
           Vacaciones.Ds_Tab_Ant,
           Vacaciones.Dias_Ant,
           Vacaciones.Prima_Ant,
           Vacaciones.P_V_Ant_Imp,
           Vacaciones.P_V_Ant_Ds,
           Vacaciones.Paga_Ant,
           Vacaciones.Estado,
           0 AS Grava_Prima,
           0 AS CredTotal,
           0 AS Subsidio,
           0 AS SubsidioN,
           'F' AS Acumulado,
           NULL AS Fch_Pago,
           '' AS Observaciones
    FROM Vacaciones
    INNER JOIN Empleados ON Empleados.Codigo = Vacaciones.Codigo AND Empleados.Empresa = @nEmpresaDestino
    WHERE Vacaciones.Codigo = @nCodigo AND Vacaciones.Empresa = @nEmpresaOrigen
    
    
    
    DELETE Hist_Vac
    WHERE Codigo = @nCodigo AND
          Marca = 'A' AND
          Empresa = @nEmpresaDestino
    
    
    INSERT INTO dbo.Hist_Vac(Empresa, Codigo, Disfrute, Marca, FchAlta, Prima_Vac, Prima_V_Im, Prima_V_Ds, Dias_Tab,
                             Dias_Disfr, Dias_Ant, Disf_Ant, Descansos, Festivos, Dias_Saldo, Fin_Disfru, Fch_Pago,
                             Periodo, Ayo_Operacion, Observaciones, Ejercicio, Ejercicio_Ant)
    SELECT @nEmpresaDestino AS Empresa,
           Hist_Vac.Codigo,
           Hist_Vac.Disfrute,
           Hist_Vac.Marca,
           Hist_Vac.FchAlta,
           Hist_Vac.Prima_Vac,
           Hist_Vac.Prima_V_Im,
           Hist_Vac.Prima_V_Ds,
           Hist_Vac.Dias_Tab,
           Hist_Vac.Dias_Disfr,
           Hist_Vac.Dias_Ant,
           Hist_Vac.Disf_Ant,
           Hist_Vac.Descansos,
           Hist_Vac.Festivos,
           Hist_Vac.Dias_Saldo,
           Hist_Vac.Fin_Disfru,
           Hist_Vac.Fch_Pago,
           Hist_Vac.Periodo,
           Hist_Vac.Ayo_Operacion,
           Hist_Vac.Observaciones,
           Hist_Vac.Ejercicio,
           Hist_Vac.Ejercicio_Ant
    FROM Hist_Vac
    WHERE Hist_Vac.Codigo = @nCodigo AND
          Hist_Vac.Marca = 'A' AND
          Hist_Vac.Dias_Saldo > 0 AND
          Hist_Vac.Empresa = @nEmpresaOrigen

  END TRY
  BEGIN CATCH

    DECLARE @ErrorSeverity INTEGER
    DECLARE @ErrorState    INTEGER
    DECLARE @ErrorMessage  VARCHAR(1000)

    SET @ErrorSeverity = ERROR_SEVERITY()
    SET @ErrorState    = ERROR_STATE()
    SET @ErrorMessage  = 'State: ' + LTRIM(RTRIM(STR(@ErrorState))) + CHAR(13) + CHAR(10) + 'Severity: ' + LTRIM(RTRIM(STR(@ErrorSeverity))) + CHAR(13) + CHAR(10) + 'Error number:  ' + LTRIM(RTRIM(STR(ERROR_NUMBER()))) + CHAR(13) + CHAR(10) + 'Message: ' + ERROR_MESSAGE() + CHAR(13) + CHAR(10) + 'Procedure: ' + ERROR_PROCEDURE() + CHAR(13) + CHAR(10) + 'Line: ' + LTRIM(RTRIM(STR(ERROR_LINE())))

    IF ( XACT_STATE() ) = -1 OR @@TRANCOUNT > 0 
        ROLLBACK TRANSACTION

    RAISERROR ( @ErrorMessage, @ErrorSeverity, @ErrorState )

  END CATCH

  IF @@TRANCOUNT > 0 
    BEGIN
      COMMIT TRANSACTION 
      DECLARE @nRecordID INTEGER
      SELECT @nRecordID AS 'recordId'

      RETURN @nRecordID
    END 


GO

IF OBJECT_ID('dbo.ObtienePendientesEnviarReloj') IS NOT NULL
   DROP PROCEDURE dbo.ObtienePendientesEnviarReloj
GO
CREATE PROCEDURE dbo.ObtienePendientesEnviarReloj
@empresa INT

AS 
  
  SET NOCOUNT ON

  SELECT 1 AS tipo,
         ea.Codigo,
         e.nombre AS Nombre,
         e.ap_paterno AS Paterno,
         e.ap_materno AS Materno,
         e.rfcalfa + e.rfcnum + e.rfchomo AS RFC,
         e.curp AS CURP,
         e.afiliacion + e.digvera AS Afiliacion,
         CASE WHEN ultimaAlta.ultimaFechaAlta IS NULL THEN e.fchalta ELSE ultimaAlta.ultimaFechaAlta END AS Alta,
         e.sueldo AS CuotaDiaria,
         e.sexo AS Sexo,
         ultimaBaja.ultimaFechaBaja AS Baja,
         e.fchnac AS Nacimiento,
         de.email AS email,
         de.telefono AS Telefono,
         ll.horario AS idHorario,
         ea.Clave,
         ll.supervisor AS supervisorAPSI,
         ta.actividad AS actividadAPSI,
         ll.tiponom AS tiponomAPSI,
         ea.NoChecar,
         ea.ChecaLibre,
         ea.NoTiempoExtra,
         ea.NoAusen,
         ea.Bloqueado,
         ea.NoExportar,
         ea.PremioPyA,
         ea.Comedor,
         ea.ExportaComedor,
         ea.FNomina,
         ea.Credencial,
         ll.centro AS idArea,
         cc.nomdepto AS Area,
         ea.MailRetardos,
         ea.MailTE,
         ea.MailSalidaAntes,
         ea.MailSupervisor,
         ea.MailNomina,
         e.activo,
         e.borrado,
         ea.ultimoMovimientoEnviado,
         '' AS accion
  FROM dbo.EmpleadoApsiReloj AS ea
       INNER JOIN dbo.empleados AS e ON ea.codigo = e.codigo
                                        AND ea.empresa = e.empresa
       INNER JOIN dbo.datosemps AS de ON ea.codigo = de.codigo
                                         AND ea.empresa = de.empresa
       INNER JOIN dbo.Llaves AS ll ON ea.codigo = ll.codigo
                                      AND ea.empresa = ll.empresa
       INNER JOIN dbo.tabulador AS ta ON ll.ocupacion = ta.ocupacion
                                         AND ll.empresa = ta.empresa
       INNER JOIN dbo.centros AS cc ON LTRIM(RTRIM(ll.centro)) = LTRIM(RTRIM(cc.centro))
                                       AND ll.empresa = cc.empresa
       OUTER APPLY (SELECT TOP 1 
                           ultimaAlta.fch_mov AS ultimaFechaAlta
                    FROM dbo.avisos_imss AS ultimaAlta 
                    WHERE e.empresa = ultimaAlta.empresa
                          AND e.codigo = ultimaAlta.codigo
                          AND (ultimaAlta.mov = 'A'
                               OR ultimaAlta.mov = 'RI')
                    ORDER BY ultimaAlta.fch_mov DESC,
                             ultimaAlta.serial DESC) AS ultimaAlta        
       OUTER APPLY (SELECT TOP 1 
                           CASE WHEN ultimaBaja.mov = 'B' THEN ultimaBaja.fch_mov ELSE NULL END AS ultimaFechaBaja
                    FROM dbo.avisos_imss AS ultimaBaja
                         INNER JOIN dbo.empresas AS em ON ultimaBaja.empresa = em.empresa
                    WHERE e.empresa = ultimaBaja.empresa
                          AND e.codigo = ultimaBaja.codigo
                          --AND ultimaBaja.mov = 'B'
                          AND ultimaBaja.fch_mov >= CONVERT(DATETIME, RIGHT(STR(10000 + em.ayo_operacion),4) + RIGHT(STR(100) + em.mes_operacion,2) + '01')
                    ORDER BY ultimaBaja.fch_mov DESC,
                             ultimaBaja.serial DESC) AS ultimaBaja        
  WHERE ea.empresa = @empresa
        AND ea.Enviar = 1
        AND ea.Enviado = 0
      
  UNION

  SELECT 2 AS tipo,
         aa.Codigo,
         e.nombre AS Nombre,
         e.ap_paterno AS Paterno,
         e.ap_materno AS Materno,
         e.rfcalfa + e.rfcnum + e.rfchomo AS RFC,
         e.curp AS CURP,
         e.afiliacion + e.digvera AS Afiliacion,
         CASE WHEN aa.mov = 'RI' THEN aa.fecha ELSE NULL END AS Alta,
         e.sueldo AS CuotaDiaria,
         e.sexo AS Sexo,
         CASE WHEN aa.mov = 'B' THEN aa.fecha ELSE NULL END AS Baja,
         e.fchnac AS Nacimiento,
         de.email AS email,
         de.telefono AS Telefono,
         ll.horario AS idHorario,
         ea.Clave,
         ll.supervisor AS supervisorAPSI,
         ta.actividad AS actividadAPSI,
         ll.tiponom AS tiponomAPSI,
         ea.NoChecar,
         ea.ChecaLibre,
         ea.NoTiempoExtra,
         ea.NoAusen,
         ea.Bloqueado,
         ea.NoExportar,
         ea.PremioPyA,
         ea.Comedor,
         ea.ExportaComedor,
         ea.FNomina,
         ea.Credencial,
         ll.centro AS idArea,
         cc.nomdepto AS Area,
         ea.MailRetardos,
         ea.MailTE,
         ea.MailSalidaAntes,
         ea.MailSupervisor,
         ea.MailNomina,
         e.activo,
         e.borrado,
         aa.mov AS ultimoMovimientoEnviado,
         aa.accion
  FROM dbo.AvisosApsireloj AS aa
       INNER JOIN dbo.EmpleadoApsiReloj AS ea ON aa.codigo = ea.codigo
                                                 AND aa.empresa = ea.empresa
       INNER JOIN dbo.empleados AS e ON aa.codigo = e.codigo
                                        AND aa.empresa = e.empresa
       INNER JOIN dbo.datosemps AS de ON aa.codigo = de.codigo
                                         AND aa.empresa = de.empresa
       INNER JOIN dbo.Llaves AS ll ON aa.codigo = ll.codigo
                                      AND aa.empresa = ll.empresa
       INNER JOIN dbo.tabulador AS ta ON ll.ocupacion = ta.ocupacion
                                         AND ll.empresa = ta.empresa
       INNER JOIN dbo.centros AS cc ON LTRIM(RTRIM(ll.centro)) = LTRIM(RTRIM(cc.centro))
                                       AND ll.empresa = cc.empresa
  WHERE aa.empresa = @empresa
  

  ORDER BY Codigo, tipo 
GO

IF OBJECT_ID('dbo.PlantillaCampoSeleccionadoActualiza') IS NOT NULL 
   DROP PROCEDURE dbo.PlantillaCampoSeleccionadoActualiza
GO
CREATE PROCEDURE dbo.PlantillaCampoSeleccionadoActualiza
@id INT,
@accion CHAR(1),
@empresa INT,
@usuario VARCHAR(50),
@CentrodeCostos BIT,
@Tabulador BIT,
@Clase BIT,
@Sexo BIT,
@EntidadNacimiento BIT,
@FechaNacimiento BIT,
@Rfc BIT,
@Curp BIT,
@DirectoInderecto BIT,
@Supervisor BIT,
@Horaro BIT,
@Banco BIT,
@TipoDesposito BIT,
@CuentaBancaria BIT,
@Clabe BIT,
@Calle BIT,
@NoExterior BIT,
@NoInterior BIT,
@Colonia BIT,
@Municipio BIT,
@Localidad BIT,
@EntidadFederativa BIT,
@CodigoPostal BIT,
@CuentaContable BIT,
@TipoRegimen BIT,
@TipoContrato BIT,
@CorreoElectronico BIT,
@CtaValesDespensa BIT,
@CampoLibre1 BIT,
@CampoLibre2 BIT,
@CampoLibre3 BIT,
@CampoLibre4 BIT,
@CampoLibre5 BIT,
@CampoLibre6 BIT,
@CampoLibre7 BIT,
@CampoLibre8 BIT,
@CampoLibre9 BIT,
@CampoLibre10 BIT,
@CampoLibre11 BIT,
@CampoLibre12 BIT,
@CampoLibre13 BIT,
@CampoLibre14 BIT,
@CampoLibre15 BIT,
@TipoSalario BIT,
@Sindicalizado BIT,
@EstadoCivil BIT,
@ClaveEntidadFederativa BIT,
@Telefono BIT,
@fechaGeneracion DATETIME,
@fechaActualizacion DATETIME

AS

  SET  NOCOUNT ON
  
  INSERT dbo.PlantillaCampoSeleccionado (empresa, usuario, CentrodeCostos, Tabulador, Clase, Sexo, EntidadNacimiento, FechaNacimiento, Rfc, Curp, DirectoInderecto, Supervisor, Horaro, Banco, TipoDesposito, CuentaBancaria, Clabe, Calle, NoExterior, NoInterior, Colonia, Municipio, Localidad, EntidadFederativa, CodigoPostal, CuentaContable, TipoRegimen, TipoContrato, CorreoElectronico, CtaValesDespensa, CampoLibre1, CampoLibre2, CampoLibre3, CampoLibre4, CampoLibre5, CampoLibre6, CampoLibre7, CampoLibre8, TipoSalario, Sindicalizado, EstadoCivil, ClaveEntidadFederativa, Telefono, fechaGeneracion, fechaActualizacion) SELECT @empresa, @usuario, @CentrodeCostos, @Tabulador, @Clase, @Sexo, @EntidadNacimiento, @FechaNacimiento, @Rfc, @Curp, @DirectoInderecto, @Supervisor, @Horaro, @Banco, @TipoDesposito, @CuentaBancaria, @Clabe, @Calle, @NoExterior, @NoInterior, @Colonia, @Municipio, @Localidad, @EntidadFederativa, @CodigoPostal, @CuentaContable, @TipoRegimen, @TipoContrato, @CorreoElectronico, @CtaValesDespensa, @CampoLibre1, @CampoLibre2, @CampoLibre3, @CampoLibre4, @CampoLibre5, @CampoLibre6, @CampoLibre7, @CampoLibre8, @TipoSalario, @Sindicalizado, @EstadoCivil, @ClaveEntidadFederativa, @Telefono, @fechaGeneracion, @fechaActualizacion WHERE NOT EXISTS (SELECT 1 FROM dbo.PlantillaCampoSeleccionado WHERE id = @id)
  
  UPDATE dbo.PlantillaCampoSeleccionado
  SET empresa = @empresa,
      usuario = @usuario,
      CentrodeCostos = @CentrodeCostos,
      Tabulador = @Tabulador,
      Clase = @Clase,
      Sexo = @Sexo,
      EntidadNacimiento = @EntidadNacimiento,
      FechaNacimiento = @FechaNacimiento,
      Rfc = @Rfc,
      Curp = @Curp,
      DirectoInderecto = @DirectoInderecto,
      Supervisor = @Supervisor,
      Horaro = @Horaro,
      Banco = @Banco,
      TipoDesposito = @TipoDesposito,
      CuentaBancaria = @CuentaBancaria,
      Clabe = @Clabe,
      Calle = @Calle,
      NoExterior = @NoExterior,
      NoInterior = @NoInterior,
      Colonia = @Colonia,
      Municipio = @Municipio,
      Localidad = @Localidad,
      EntidadFederativa = @EntidadFederativa,
      CodigoPostal = @CodigoPostal,
      CuentaContable = @CuentaContable,
      TipoRegimen = @TipoRegimen,
      TipoContrato = @TipoContrato,
      CorreoElectronico = @CorreoElectronico,
      CtaValesDespensa = @CtaValesDespensa,
      CampoLibre1 = @CampoLibre1,
      CampoLibre2 = @CampoLibre2,
      CampoLibre3 = @CampoLibre3,
      CampoLibre4 = @CampoLibre4,
      CampoLibre5 = @CampoLibre5,
      CampoLibre6 = @CampoLibre6,
      CampoLibre7 = @CampoLibre7,
      CampoLibre8 = @CampoLibre8,
      CampoLibre9 = @CampoLibre9,
      CampoLibre10 = @CampoLibre10,
      CampoLibre11 = @CampoLibre11,
      CampoLibre12 = @CampoLibre12,
      CampoLibre13 = @CampoLibre13,
      CampoLibre14 = @CampoLibre14,
      CampoLibre15 = @CampoLibre15,
      TipoSalario = @TipoSalario,
      Sindicalizado = @Sindicalizado,
      EstadoCivil = @EstadoCivil,
      ClaveEntidadFederativa = @ClaveEntidadFederativa,
      Telefono = @Telefono,
      fechaGeneracion = CASE WHEN @accion = 'P' THEN @fechaGeneracion ELSE fechaGeneracion END,
      fechaActualizacion = CASE WHEN @accion = 'A' THEN @fechaActualizacion ELSE fechaActualizacion END
  WHERE id = @id
GO

IF OBJECT_ID('dbo.PlantillaCampoSeleccionadoObtiene') IS NOT NULL 
   DROP PROCEDURE dbo.PlantillaCampoSeleccionadoObtiene
GO
CREATE PROCEDURE dbo.PlantillaCampoSeleccionadoObtiene
@empresa INT,
@usuario VARCHAR(50)

AS
 
  SET NOCOUNT ON
  
  DECLARE @ultimoUsuarioGeneracion VARCHAR(50)
  DECLARE @ultimaFechaGeneracion CHAR(19)
  DECLARE @ultimoUsuarioActualizacion VARCHAR(50)
  DECLARE @ultimaFechaActualizacion CHAR(19)
  
  DECLARE @id INT
  DECLARE @CentrodeCostos BIT
  DECLARE @Tabulador BIT
  DECLARE @Clase BIT
  DECLARE @Sexo BIT
  DECLARE @EntidadNacimiento BIT
  DECLARE @FechaNacimiento BIT
  DECLARE @Rfc BIT
  DECLARE @Curp BIT
  DECLARE @DirectoInderecto BIT
  DECLARE @Supervisor BIT
  DECLARE @Horaro BIT
  DECLARE @Banco BIT
  DECLARE @TipoDesposito BIT
  DECLARE @CuentaBancaria BIT
  DECLARE @Clabe BIT
  DECLARE @Calle BIT
  DECLARE @NoExterior BIT
  DECLARE @NoInterior BIT
  DECLARE @Colonia BIT
  DECLARE @Municipio BIT
  DECLARE @Localidad BIT
  DECLARE @EntidadFederativa BIT
  DECLARE @CodigoPostal BIT
  DECLARE @CuentaContable BIT
  DECLARE @TipoRegimen BIT
  DECLARE @TipoContrato BIT
  DECLARE @CorreoElectronico BIT
  DECLARE @CtaValesDespensa BIT
  DECLARE @CampoLibre1 BIT
  DECLARE @CampoLibre2 BIT
  DECLARE @CampoLibre3 BIT
  DECLARE @CampoLibre4 BIT
  DECLARE @CampoLibre5 BIT
  DECLARE @CampoLibre6 BIT
  DECLARE @CampoLibre7 BIT
  DECLARE @CampoLibre8 BIT
  DECLARE @CampoLibre9 BIT
  DECLARE @CampoLibre10 BIT
  DECLARE @CampoLibre11 BIT
  DECLARE @CampoLibre12 BIT
  DECLARE @CampoLibre13 BIT
  DECLARE @CampoLibre14 BIT
  DECLARE @CampoLibre15 BIT
  DECLARE @TipoSalario BIT
  DECLARE @Sindicalizado BIT
  DECLARE @EstadoCivil BIT
  DECLARE @ClaveEntidadFederativa BIT
  DECLARE @Telefono BIT
  
  
  SELECT TOP 1 
         @ultimoUsuarioGeneracion = usuario, 
         @ultimaFechaGeneracion = CONVERT (CHAR(10), fechaGeneracion, 103) + ' ' + LEFT(CONVERT(VARCHAR(8),fechaGeneracion,108),8)
  FROM dbo.PlantillaCampoSeleccionado 
  WHERE empresa = @empresa
  ORDER BY fechaGeneracion DESC
  
  SET @ultimoUsuarioGeneracion = ISNULL(@ultimoUsuarioGeneracion, 'Ninguno')
         
  SELECT TOP 1
         @ultimoUsuarioActualizacion = usuario,
         @ultimaFechaActualizacion = CONVERT (CHAR(10), fechaActualizacion, 103) + ' ' + LEFT(CONVERT(VARCHAR(8),fechaActualizacion,108),8)
  FROM dbo.PlantillaCampoSeleccionado 
  WHERE empresa = @empresa 
        AND fechaActualizacion IS NOT NULL
  ORDER BY fechaActualizacion DESC

  SET @ultimoUsuarioActualizacion = ISNULL(@ultimoUsuarioActualizacion, 'Ninguno')
  
  SELECT @id = id,
         @CentrodeCostos = CentrodeCostos,
         @Tabulador = Tabulador,
         @Clase = Clase,
         @Sexo = Sexo,
         @EntidadNacimiento = EntidadNacimiento,
         @FechaNacimiento = FechaNacimiento,
         @Rfc = Rfc,
         @Curp = Curp,
         @DirectoInderecto = DirectoInderecto,
         @Supervisor = Supervisor,
         @Horaro = Horaro,
         @Banco = Banco,
         @TipoDesposito = TipoDesposito,
         @CuentaBancaria = CuentaBancaria,
         @Clabe = Clabe,
         @Calle = Calle,
         @NoExterior = NoExterior,
         @NoInterior = NoInterior,
         @Colonia = Colonia,
         @Municipio = Municipio,
         @Localidad = Localidad,
         @EntidadFederativa = EntidadFederativa,
         @CodigoPostal = CodigoPostal,
         @CuentaContable = CuentaContable,
         @TipoRegimen = TipoRegimen,
         @TipoContrato = TipoContrato,
         @CorreoElectronico = CorreoElectronico,
         @CtaValesDespensa = CtaValesDespensa,
         @CampoLibre1 = CampoLibre1,
         @CampoLibre2 = CampoLibre2,
         @CampoLibre3 = CampoLibre3,
         @CampoLibre4 = CampoLibre4,
         @CampoLibre5 = CampoLibre5,
         @CampoLibre6 = CampoLibre6,
         @CampoLibre7 = CampoLibre7,
         @CampoLibre8 = CampoLibre8,
         @CampoLibre9 = CampoLibre9,
         @CampoLibre10 = CampoLibre10,
         @CampoLibre11 = CampoLibre11,
         @CampoLibre12 = CampoLibre12,
         @CampoLibre13 = CampoLibre13,
         @CampoLibre14 = CampoLibre14,
         @CampoLibre15 = CampoLibre15,
         @TipoSalario = TipoSalario,
         @Sindicalizado = Sindicalizado,
         @EstadoCivil = EstadoCivil,
         @ClaveEntidadFederativa = ClaveEntidadFederativa,
         @Telefono = Telefono
  FROM dbo.PlantillaCampoSeleccionado
  WHERE empresa = @empresa
        AND LTRIM(RTRIM(usuario)) = LTRIM(RTRIM(@usuario))
  
  
  SELECT ISNULL(@id,0) AS id,
         @empresa AS empresa,
         @usuario AS usuario,
         ISNULL(@CentrodeCostos,0) AS CentrodeCostos,
         ISNULL(@Tabulador,0) AS Tabulador,
         ISNULL(@Clase,0) AS Clase,
         ISNULL(@Sexo,0) AS Sexo,
         ISNULL(@EntidadNacimiento,0) AS EntidadNacimiento,
         ISNULL(@FechaNacimiento,0) AS FechaNacimiento,
         ISNULL(@Rfc,0) AS Rfc,
         ISNULL(@Curp,0) AS Curp,
         ISNULL(@DirectoInderecto,0) AS DirectoInderecto,
         ISNULL(@Supervisor,0) AS Supervisor,
         ISNULL(@Horaro,0) AS Horaro,
         ISNULL(@Banco,0) AS Banco,
         ISNULL(@TipoDesposito,0) AS TipoDesposito,
         ISNULL(@CuentaBancaria,0) AS CuentaBancaria,
         ISNULL(@Clabe,0) AS Clabe,
         ISNULL(@Calle,0) AS Calle,
         ISNULL(@NoExterior,0) AS NoExterior,
         ISNULL(@NoInterior,0) AS NoInterior,
         ISNULL(@Colonia,0) AS Colonia,
         ISNULL(@Municipio,0) AS Municipio,
         ISNULL(@Localidad,0) AS Localidad,
         ISNULL(@EntidadFederativa,0) AS EntidadFederativa,
         ISNULL(@CodigoPostal,0) AS CodigoPostal,
         ISNULL(@CuentaContable,0) AS CuentaContable,
         ISNULL(@TipoRegimen,0) AS TipoRegimen,
         ISNULL(@TipoContrato,0) AS TipoContrato,
         ISNULL(@CorreoElectronico,0) AS CorreoElectronico,
         ISNULL(@CtaValesDespensa,0) AS CtaValesDespensa,
         ISNULL(@CampoLibre1,0) AS CampoLibre1,
         ISNULL(@CampoLibre2,0) AS CampoLibre2,
         ISNULL(@CampoLibre3,0) AS CampoLibre3,
         ISNULL(@CampoLibre4,0) AS CampoLibre4,
         ISNULL(@CampoLibre5,0) AS CampoLibre5,
         ISNULL(@CampoLibre6,0) AS CampoLibre6,
         ISNULL(@CampoLibre7,0) AS CampoLibre7,
         ISNULL(@CampoLibre8,0) AS CampoLibre8,
         ISNULL(@CampoLibre9,0) AS CampoLibre9,
         ISNULL(@CampoLibre10,0) AS CampoLibre10,
         ISNULL(@CampoLibre11,0) AS CampoLibre11,
         ISNULL(@CampoLibre12,0) AS CampoLibre12,
         ISNULL(@CampoLibre13,0) AS CampoLibre13,
         ISNULL(@CampoLibre14,0) AS CampoLibre14,
         ISNULL(@CampoLibre15,0) AS CampoLibre15,
         ISNULL(@TipoSalario,0) AS TipoSalario,
         ISNULL(@Sindicalizado,0) AS Sindicalizado,
         ISNULL(@EstadoCivil,0) AS EstadoCivil,
         ISNULL(@ClaveEntidadFederativa,0) AS ClaveEntidadFederativa,
         ISNULL(@Telefono,0) AS Telefono,
         @ultimoUsuarioGeneracion AS ultimoUsuarioGeneracion,
         @ultimaFechaGeneracion AS ultimaFechaGeneracion,
         @ultimoUsuarioActualizacion AS ultimoUsuarioActualizacion,
         @ultimaFechaActualizacion AS ultimaFechaActualizacion
GO

IF NOT EXISTS(SELECT syscolumns.name  
              FROM syscolumns 
	               LEFT JOIN sysobjects ON syscolumns.id=sysobjects.id
	          WHERE syscolumns.name = 'activa' 
	                AND sysobjects.name='plantillas')
   ALTER TABLE dbo.plantillas ADD activa VARCHAR(1) NULL    
GO

UPDATE dbo.plantillas SET activa ='N' WHERE activa IS NULL 
GO


/**************************************************************************************************
 * Name          : plantillasBusquedaEmpleado
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 8 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasValidaPlazas'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasValidaPlazas
GO

CREATE PROCEDURE dbo.plantillasValidaPlazas
(	@idEmpresa as bigint,
	@ocupacion as bigint,
	@centrocostos as char(15) )
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY

	SELECT dbo.plantillas.nombre,
	       dbo.plantillas_puestos.disponibles 
	FROM dbo.plantillas_puestos
	     INNER JOIN dbo.plantillas ON dbo.plantillas.plantilla_id = dbo.plantillas_puestos.plantilla_id
	                                  AND dbo.plantillas.empresa = dbo.plantillas_puestos.empresa
	WHERE dbo.plantillas_puestos.empresa = @idEmpresa
		  AND dbo.plantillas_puestos.ocupacion = @ocupacion
		  AND LTRIM(RTRIM(dbo.plantillas_puestos.centro)) = LTRIM(RTRIM(@centrocostos))
		  AND dbo.plantillas_puestos.plantilla_id = (SELECT plantilla_id 
									                 FROM dbo.plantillas 
									                 WHERE activa='S'
									                       AND empresa = @idEmpresa)
GO

IF OBJECT_ID('dbo.RelacionSarSindicato') IS NOT NULL
   DROP PROCEDURE [dbo].[RelacionSarSindicato]
GO

CREATE PROCEDURE [dbo].[RelacionSarSindicato]
@empresa INT

AS

INSERT  dbo.SeleccionElementos
        ( empresa ,
          procesoId ,
          procesoName ,
          codigo ,
          nomina ,
          tipoNomina ,
          centro ,
          clase ,
          supvervisor
        )
        SELECT  dbo.empleados.empresa ,
                0 ,
                'RelacionSarSindicato' ,
                dbo.empleados.codigo ,
                '' ,
                0 ,
                '' ,
                '' ,
                0
        FROM    dbo.empleados
        WHERE   dbo.empleados.empresa = @empresa
                AND dbo.empleados.sindicato = 'S'
                AND dbo.empleados.cotiza_imss = 'S'
                AND dbo.empleados.borrado = 'N'
GO

IF OBJECT_ID('dbo.RenviaAvisoImss') IS NOT NULL 
    DROP PROCEDURE dbo.RenviaAvisoImss
GO
CREATE PROCEDURE dbo.RenviaAvisoImss
    @empresa INT ,
    @codigo INT ,
    @fechaEnvio DATETIME
AS 
    UPDATE  dbo.avisos_imss
    SET     dbo.avisos_imss.fechaEnvio = NULL ,
            dbo.avisos_imss.lote = NULL ,
            dbo.avisos_imss.fechaConfirmacion = NULL
    WHERE   dbo.avisos_imss.empresa = @empresa
            AND dbo.avisos_imss.codigo = @codigo
            AND dbo.avisos_imss.fechaEnvio = @fechaEnvio
GO

/**************************************************************************************************
 * Name          : ObtieneResumenAvisosImssBimestre
 * Project       : APSI Nomina
 * Description   : Obtiene el total de Altas, Reingresos, Bajas, Modificaciones de Salario
 * Table name    : empleados, avisos_imss
 * Return        : tabla con total de registros
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 11, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ObtieneResumenAvisosImssBimestre' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ObtieneResumenAvisosImssBimestre]
    END
go


CREATE PROCEDURE [dbo].[ObtieneResumenAvisosImssBimestre]
    @empresa NUMERIC(5) ,
    @ayo INT ,
    @mesNon INT,
    @mesPar INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8),
	@filtroInfonavit INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
AS 
    SELECT  [dbo].[ResumenAvisosImssBimestre].registros ,
            [dbo].[ResumenAvisosImssBimestre].altas ,
            [dbo].[ResumenAvisosImssBimestre].bajas ,
            [dbo].[ResumenAvisosImssBimestre].modificacionSalario ,
            [dbo].[ResumenAvisosImssBimestre].campo,
            [dbo].[ResumenAvisosImssBimestre].valor,
            CASE WHEN [dbo].[ResumenAvisosImssBimestre].campo = 'Altas' THEN 'clLime'
                 WHEN [dbo].[ResumenAvisosImssBimestre].campo = 'Bajas' THEN 'clRed'
                 WHEN [dbo].[ResumenAvisosImssBimestre].campo = 'Modificacin Salario' THEN 'clYellow'
                 ELSE ''
            END AS color
    FROM    [dbo].[ResumenAvisosImssBimestre](@empresa, @ayo, @mesNon, @mesPar, @porRenglon, @proceso, @fechaProceso, @horaProceso, @filtroInfonavit)
GO

/**************************************************************************************************
 * Name          : ResumenAvisosImssMensual
 * Project       : APSI Nomina
 * Description   : Obtiene el total de Altas, Reingresos, Bajas, Modificaciones de Salario
 * Table name    : empleados, avisos_imss
 * Return        : tabla con total de registros
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Marzo 11, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ResumenAvisosImssMensual' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ResumenAvisosImssMensual]
    END
go


CREATE PROCEDURE [dbo].[ResumenAvisosImssMensual]
    @empresa NUMERIC(5) ,
    @ayo INT ,
    @mes INT ,
    @porRenglon INT ,
    @proceso VARCHAR(250),
    @fechaProceso DATETIME ,
    @horaProceso VARCHAR(8)
    
AS 
    SELECT  [dbo].[ResumenAvisosImss].registros ,
            [dbo].[ResumenAvisosImss].altas ,
            [dbo].[ResumenAvisosImss].bajas ,
            [dbo].[ResumenAvisosImss].modificacionSalario,
            [dbo].[ResumenAvisosImss].campo,
            [dbo].[ResumenAvisosImss].valor,
            CASE WHEN [dbo].[ResumenAvisosImss].campo = 'Altas' THEN 'clLime'
                 WHEN [dbo].[ResumenAvisosImss].campo = 'Bajas' THEN 'clRed'
                 WHEN [dbo].[ResumenAvisosImss].campo = 'Modificacin Salario' THEN 'clYellow'
                 ELSE ''
            END AS color
    FROM    [dbo].[ResumenAvisosImss](@empresa, @ayo, @mes, @porRenglon, @proceso, @fechaProceso, @horaProceso)
GO

IF OBJECT_ID('dbo.ResumenEmpresaVista') IS NOT NULL
   DROP PROCEDURE dbo.ResumenEmpresaVista
GO
CREATE PROCEDURE dbo.ResumenEmpresaVista
AS
  SELECT emp.empresa,
         emp.nombre_empresa,
         ISNULL(d.Ausen,0) AS Ausen,
         ISNULL(d.Incap,0) AS Incap,
         ISNULL(a.Altas,0) AS Altas,
         ISNULL(a.Bajas,0) AS Bajas,
         ISNULL(a.Ms,0) AS Ms,
         ISNULL(e.Emps,0) AS Emps,
         emp.registro_patronal,
         emp.mes_operacion,
         emp.ayo_operacion,
         emp.direccion_empresa,
         emp.poblacion_empresa,
         emp.rfc_empresa,
         emp.colonia_empresa,
         emp.codigo_postal_empresa,
         emp.primag, infonavit,
         emp.fraccion_rt,
         emp.clave,
         emp.clase,
         emp.representante_legal,
         emp.puesto_representante,
         emp.actividad_empresa,
         emp.telefono_empresa,
         emp.delegacion_imss,
         emp.sub_delegacion,
         emp.nombre_sub_delegacion,
         emp.patron_paga_cuotas_imss,
         emp.zona_geografica,
         emp.entidad,
         emp.nomentidad,
         emp.Rpu,
         emp.Regimen_Seguridad_Social,
         emp.referencia,
         emp.vers,
         emp.folio_primer_empleo
  FROM dbo.empresas AS emp
       OUTER APPLY (SELECT SUM(ISNULL(CASE WHEN d.num_conc = 108 
                                           THEN CASE WHEN d.fchinicio < empresaFecha.mesInicio 
                                                     THEN DATEDIFF(dd, empresaFecha.mesInicio, d.fchtermino) + 1 
                                                     ELSE d.dias 
                                                END 
                                           ELSE 0
                                      END,0)) AS Ausen,
                           SUM(ISNULL(CASE WHEN d.num_conc >= 109 AND d.num_conc <= 111 
                                           THEN CASE WHEN d.fchinicio < empresaFecha.mesInicio 
                                                     THEN DATEDIFF(dd, empresaFecha.mesInicio, d.fchtermino) + 1 
                                                     ELSE d.dias 
                                                END 
                                           ELSE 0 
                                      END,0)) AS Incap
                    FROM dbo.deducciones AS d
                         INNER JOIN (SELECT empresaFecha.empresa,
                                            CONVERT(DATETIME, RIGHT(STR(empresaFecha.ayo_operacion),4) + RIGHT(STR(100 + empresaFecha.mes_operacion),2) + '01') AS mesInicio,
                                            dbo.fin_mes(CASE WHEN empresaFecha.mes_operacion = 12 
                                                             THEN 1 
                                                             ELSE empresaFecha.mes_operacion + 1
                                                        END, 
                                                        CASE WHEN empresaFecha.mes_operacion = 12 
                                                             THEN empresaFecha.ayo_operacion + 1 
                                                             ELSE empresaFecha.ayo_operacion 
                                                        END) AS mesFin
                                     FROM dbo.empresas AS empresaFecha
                                     WHERE emp.empresa = empresaFecha.empresa) AS empresaFecha ON d.empresa = empresaFecha.empresa
                    
                    WHERE emp.empresa = d.empresa
                          AND d.num_conc >= 108 
                          AND d.num_conc <= 111 
                          AND d.fchtermino >= empresaFecha.mesInicio
                          --AND ( ( d.fchinicio <= empresaFecha.mesInicio
                          --        AND d.fchtermino >= empresaFecha.mesInicio
                          --        AND d.fchinicio <= empresaFecha.mesFin
                          --      )
                          --      OR ( d.fchinicio >= empresaFecha.mesInicio
                          --           AND d.fchtermino <= empresaFecha.mesFin
                          --         )
                          --      OR ( d.fchinicio >= empresaFecha.mesInicio
                          --           AND d.fchinicio <= empresaFecha.mesFin
                          --           AND d.fchtermino >= empresaFecha.mesFin
                          --         )
                          --      OR ( d.fchinicio <= empresaFecha.mesInicio
                          --           AND d.fchtermino >= empresaFecha.mesFin
                          --         )
                          --    )
                   ) AS d
                   
       OUTER APPLY (SELECT SUM(CASE WHEN a.mov = 'A' OR a.mov = 'RI' THEN 1 ELSE 0 END) AS Altas,
                           SUM(CASE WHEN a.mov = 'B'                 THEN 1 ELSE 0 END) AS Bajas,
                           SUM(CASE WHEN a.mov = 'MS'                THEN 1 ELSE 0 END) AS Ms
                    FROM dbo.avisos_imss AS a 
                    WHERE emp.empresa = a.empresa
                          AND (a.mov = 'A'
                               OR a.mov = 'RI'
                               OR a.mov = 'B'
                          OR a.mov = 'MS')
                          AND RIGHT(10000 + YEAR(a.fch_mov),4) + RIGHT(100 + MONTH(a.fch_mov),2) >= RIGHT(10000 + emp.ayo_operacion,4) + RIGHT(100 + emp.mes_operacion,2)
                   ) AS a
       
       OUTER APPLY (SELECT COUNT(1) AS Emps
                    FROM dbo.empleados AS e
                    WHERE emp.empresa = e.empresa
                          AND e.borrado = 'N'
                          AND RIGHT(10000 + YEAR(e.ultfchmov),4) + RIGHT(100 + MONTH(e.ultfchmov),2) >= RIGHT(10000 + emp.ayo_operacion,4) + RIGHT(100 + emp.mes_operacion,2)
                   ) AS e
                    
GO

IF OBJECT_ID('dbo.RevisaListaNegraCodigo') IS NOT NULL 
    DROP PROCEDURE dbo.RevisaListaNegraCodigo
GO

CREATE PROCEDURE dbo.RevisaListaNegraCodigo
    @empresa INT ,
    @codigo INT ,
    @nss VARCHAR(11) ,
    @rfc VARCHAR(13) ,
    @curp VARCHAR(18)
AS 
    SET NOCOUNT ON
   
    DECLARE @lista CHAR(1)
    
    IF EXISTS ( SELECT  dbo.empleados.codigo
                FROM    dbo.empleados
                WHERE   dbo.empleados.empresa = @empresa
                        AND ( dbo.empleados.codigo = @codigo
                              OR dbo.empleados.afiliacion
                              + dbo.empleados.digvera = @nss
                              OR ( dbo.empleados.rfcalfa
                                   + dbo.empleados.rfcnum
                                   + dbo.empleados.rfchomo = @rfc )
                              OR dbo.empleados.curp = @curp
                            ) ) 
        SELECT  @lista = ISNULL(dbo.rhcatalogo.lista, 'N')
        FROM    dbo.empleados
                INNER JOIN dbo.rhcatalogo ON dbo.empleados.empresa = dbo.rhcatalogo.empresa
                                             AND dbo.empleados.codigo = dbo.rhcatalogo.codigo
        WHERE   dbo.empleados.empresa = @empresa
                AND ( dbo.empleados.codigo = @codigo
                      OR dbo.empleados.afiliacion + dbo.empleados.digvera = @nss
                      OR ( dbo.empleados.rfcalfa
                           + dbo.empleados.rfcnum
                           + dbo.empleados.rfchomo = @rfc )
                      OR dbo.empleados.curp = @curp
                    )
                    
    ELSE 
        SELECT  @lista = ISNULL(dbo.rhcatalogo.lista, 'N')
        FROM    dbo.rhcatalogo
                INNER JOIN dbo.rhpersonal ON dbo.rhcatalogo.Idcatalogo = dbo.rhpersonal.Idcatalogo
        WHERE   dbo.rhcatalogo.empresa = @empresa
                AND ( dbo.rhcatalogo.codigo = @codigo
                      OR dbo.rhpersonal.afiliacion = @nss
                      OR dbo.rhpersonal.rfc = @rfc
                      OR dbo.rhpersonal.curp = @curp
                    )

    SELECT  @lista AS lista
GO

IF OBJECT_ID('dbo.RevisaPrimasImss') IS NOT NULL
   DROP PROCEDURE dbo.RevisaPrimasImss
GO
CREATE PROCEDURE [dbo].[RevisaPrimasImss] @ayo INT

AS 
    SET NOCOUNT ON

    DECLARE @periodo DATETIME
    DECLARE @eymart25 FLOAT
    DECLARE @eympat25 FLOAT
    DECLARE @eymtra25 FLOAT
    DECLARE @eymart106i FLOAT
    DECLARE @eymart1062 FLOAT
    DECLARE @eympat1062 FLOAT
    DECLARE @eymtra1062 FLOAT
    DECLARE @eymart107 FLOAT
    DECLARE @eympat107 FLOAT
    DECLARE @eymtra107 FLOAT
    DECLARE @ivart147 FLOAT
    DECLARE @ivpat147 FLOAT
    DECLARE @ivtra147 FLOAT
    DECLARE @retiro FLOAT
    DECLARE @cvart168ii FLOAT
    DECLARE @cvpat168ii FLOAT
    DECLARE @cvtra168ii FLOAT
    DECLARE @infonavit FLOAT
    DECLARE @art211 FLOAT
    DECLARE @seguroDesempleo FLOAT
    
    --DECLARE @return INT
    --SET @return = 0

    SET @eymart25 = 0
    SET @eympat25 = 0
    SET @eymtra25 = 0
    SET @eymart106i = 0
    SET @eymart1062 = 0
    SET @eympat1062 = 0
    SET @eymtra1062 = 0
    SET @eymart107 = 0
    SET @eympat107 = 0
    SET @eymtra107 = 0
    SET @ivart147 = 0
    SET @ivpat147 = 0
    SET @ivtra147 = 0
    SET @retiro = 0
    SET @cvart168ii = 0
    SET @cvpat168ii = 0
    SET @cvtra168ii = 0
    SET @infonavit = 0
    SET @art211 = 0
    SET @seguroDesempleo = 0

    SET @periodo = CONVERT(DATETIME, CONVERT(CHAR(4), @ayo) + '0101')

    SELECT  @eymart25 = primasImss.eymart25 ,
            @eympat25 = primasImss.eympat25 ,
            @eymtra25 = primasImss.eymtra25 ,
            @eymart106i = primasImss.eymart106I ,
            @eymart1062 = primasImss.eymart1062 ,
            @eympat1062 = primasImss.eympat1062 ,
            @eymtra1062 = primasImss.eymtra1062 ,
            @eymart107 = primasImss.eymart107 ,
            @eympat107 = primasImss.eympat107 ,
            @eymtra107 = primasImss.eymtra107 ,
            @ivart147 = primasImss.ivart147 ,
            @ivpat147 = primasImss.ivpat147 ,
            @ivtra147 = primasImss.ivtra147 ,
            @retiro = primasImss.retiro ,
            @cvart168ii = primasImss.cvart168II ,
            @cvpat168ii = primasImss.cvpat168II ,
            @cvtra168ii = primasImss.cvtra168ii ,
            @infonavit = ISNULL(primasImss.infonavit,5) ,
            @art211 = ISNULL(primasImss.art211,1) ,
            @seguroDesempleo = primasImss.seguroDesempleo
    FROM    dbo.primas_imss AS primasImss
    WHERE   primasImss.periodo = @periodo


--SELECT @eymart25, @eympat25, @eymtra25, @eymart106i, @eymart1062, @eympat1062, @eymtra1062, @eymart107, @eympat107, @eymtra107, @ivart147, @ivpat147, @ivtra147, @retiro, @cvart168ii, @cvpat168ii, @cvtra168ii, @art211, @seguroDesempleo
--UNION
--SELECT 1.42500  , 1.05000  , 0.37500  , 20.4000    , 1.50000    , 1.10000    , 0.40000    , 0.95000   , 0.70000   , 0.25000   , 2.37500  , 1.75000  , 0.62500  , 2.00000, 4.27500    , 3.15000    , 1.12500    , 1      , 0

--              1.425                 1.05                 0.375                   20.4	                  1.5                   1.1                   0.4                  0.95                  0.7	              0.25	               2.375	             1.75                 0.625	              2                   4.275                   3.15	                 1.125	             1	                      0
--IF @eymart25 <> 1.425 OR @eympat25 <> 1.05 OR @eymtra25 <> 0.375 OR @eymart106i <> 20.4 OR @eymart1062 <> 1.5 OR @eympat1062 <> 1.1 OR @eymtra1062 <> 0.4 OR @eymart107 <> 0.95 OR @eympat107 <> 0.7 OR @eymtra107 <> 0.25 OR @ivart147 <> 2.375 OR @ivpat147 <> 1.75 OR @ivtra147 <> 0.625 OR @retiro <> 2 OR @cvart168ii <> 4.275 OR @cvpat168ii <> 3.15 OR @cvtra168ii <> 1.125 OR @art211 <> 1 OR @seguroDesempleo <> 0
--begin
--select 'entro'
--end


--    BEGIN
--        IF @ayo = 2006 
--            BEGIN
--                IF NOT EXISTS ( SELECT primasImss.periodo FROM dbo.primas_imss AS primasImss WHERE primasImss.periodo = @periodo ) 
--                   BEGIN
--                       INSERT  dbo.primas_imss (periodo , eymart25, eympat25, eymtra25, eymart106I, eymart1062, eympat1062, eymtra1062, eymart107, eympat107, eymtra107, ivart147, ivpat147, ivtra147, retiro , cvart168II, cvpat168II, cvtra168ii, infonavit, art211, seguroDesempleo) 
--                       VALUES                  (@periodo, 1.42500 , 1.05000 , 0.37500 , 19.10000  , 2.80000   , 2.08000   , 0.72000   , 0.95000  , 0.70000  , 0.25000  , 2.37500 , 1.75000 , 0.62500 , 2.00000, 4.27500   , 3.15000   , 1.12500   , 5        , 1     , 0) 
                       --SET @return = 1
--                   END
--                ELSE 
--                    IF @eymart25 <> 1.42500 OR @eympat25 <> 1.05000 OR @eymtra25 <> 0.37500 OR @eymart106i <> 19.10000 OR @eymart1062 <> 2.80000 OR @eympat1062 <> 2.08000 OR @eymtra1062 <> 0.72000 OR @eymart107 <> 0.95000 OR @eympat107 <> 0.70000 OR @eymtra107 <> 0.25000 OR @ivart147 <> 2.37500 OR @ivpat147 <> 1.75000 OR @ivtra147 <> 0.62500 OR @retiro <> 2.00000 OR @cvart168ii <> 4.27500 OR @cvpat168ii <> 3.15000 OR @cvtra168ii <> 1.12500 OR @infonavit <> 5 OR @art211 <> 1 OR @seguroDesempleo <> 0
--                       BEGIN
--                            UPDATE dbo.primas_imss SET eymart25 = 1.42500, eympat25 = 1.05000, eymtra25 = 0.37500, eymart106I = 19.10000, eymart1062 = 2.80000, eympat1062 = 2.08000, eymtra1062 = 0.72000, eymart107 = 0.95000, eympat107 = 0.70000, eymtra107 = 0.25000, ivart147 = 2.37500, ivpat147 = 1.75000, ivtra147 = 0.62500, retiro = 2.00000, cvart168II = 4.27500, cvpat168II = 3.15000, cvtra168ii = 1.12500, infonavit = 5, art211 = 1, seguroDesempleo = 0 WHERE periodo = @periodo
--                            --SET @return = 1
--                        END
--            END
--        ELSE 
--            IF @ayo = 2007 
--                BEGIN
--                    IF NOT EXISTS ( SELECT primasImss.periodo FROM dbo.primas_imss AS primasImss WHERE primasImss.periodo = @periodo )
--                        BEGIN
--                            INSERT  dbo.primas_Imss (periodo , eymart25, eympat25, eymtra25, eymart106I, eymart1062, eympat1062, eymtra1062, eymart107, eympat107, eymtra107, ivart147, ivpat147, ivtra147, retiro , cvart168II, cvpat168II, cvtra168ii, infonavit, art211, seguroDesempleo)
--                            VALUES                  (@periodo, 1.42500 , 1.05000 , 0.37500 , 19.75000  , 2.15000   , 1.59000   , 0.56000   , 0.95000  , 0.70000  , 0.25000  , 2.37500 , 1.75000 , 0.62500 , 2.00000, 4.27500   , 3.15000   , 1.12500   , 5        , 1     , 0)
--                            --SET @return = 1
--                        END
--                    ELSE 
--                        IF @eymart25 <> 1.42500 OR @eympat25 <> 1.05000 OR @eymtra25 <> 0.37500 OR @eymart106i <> 19.75000 OR @eymart1062 <> 2.15000 OR @eympat1062 <> 1.59000 OR @eymtra1062 <> 0.56000 OR @eymart107 <> 0.95000 OR @eympat107 <> 0.70000 OR @eymtra107 <> 0.25000 OR @ivart147 <> 2.37500 OR @ivpat147 <> 1.75000 OR @ivtra147 <> 0.62500 OR @retiro <> 2.00000 OR @cvart168ii <> 4.27500 OR @cvpat168ii <> 3.15000 OR @cvtra168ii <> 1.12500 OR @infonavit <> 5 OR @art211 <> 1 OR @seguroDesempleo <> 0
--                            BEGIN
--                                UPDATE dbo.primas_imss SET eymart25 = 1.42500, eympat25 = 1.05000, eymtra25 = 0.37500, eymart106I = 19.75000, eymart1062 = 2.15000, eympat1062 = 1.59000, eymtra1062 = 0.56000, eymart107 = 0.95000, eympat107 = 0.70000, eymtra107 = 0.25000, ivart147 = 2.37500, ivpat147 = 1.75000, ivtra147 = 0.62500, retiro = 2.00000, cvart168II = 4.27500, cvpat168II = 3.15000, cvtra168ii = 1.12500, infonavit = 5, art211 = 1, seguroDesempleo = 0 WHERE  periodo = @periodo
--                                --SET @return = 1
--                            END
--                END
--            ELSE 
                IF @ayo >= 2008
                    BEGIN
                        IF NOT EXISTS ( SELECT primasImss.periodo FROM primas_imss AS primasImss WHERE primasImss.periodo = @periodo ) 
                            BEGIN
                                INSERT dbo.primas_Imss (periodo , eymart25, eympat25, eymtra25, eymart106I, eymart1062, eympat1062, eymtra1062, eymart107, eympat107, eymtra107, ivart147, ivpat147, ivtra147, retiro , cvart168II, cvpat168II, cvtra168ii, infonavit, art211, seguroDesempleo)
                                VALUES                 (@periodo, 1.42500 , 1.05000 , 0.37500 , 20.40000  , 1.50000   , 1.10000   , 0.40000   , 0.95000  , 0.70000  , 0.25000  , 2.37500 , 1.75000 , 0.62500 , 2.00000, 4.27500   , 3.15000   , 1.12500   , 5        , 1     , 0)
                                --SET @return = 1
                            END
                        ELSE 
--                            IF @eymart25 <> 1.42500 OR @eympat25 <> 1.05000 OR @eymtra25 <> 0.37500 OR @eymart106i <> 20.4000 OR @eymart1062 <> 1.50000 OR @eympat1062 <> 1.10000 OR @eymtra1062 <> 0.40000 OR @eymart107 <> 0.95000 OR @eympat107 <> 0.70000 OR @eymtra107 <> 0.25000 OR @ivart147 <> 2.37500 OR @ivpat147 <> 1.75000 OR @ivtra147 <> 0.62500 OR @retiro <> 2.00000 OR @cvart168ii <> 4.27500 OR @cvpat168ii <> 3.15000 OR @cvtra168ii <> 1.12500 OR @art211 <> 1 OR @seguroDesempleo <> 0
                                BEGIN
                                    --UPDATE dbo.primas_imss SET eymart25 = 1.42500, eympat25 = 1.05000, eymtra25 = 0.37500, eymart106I = 20.4000, eymart1062 = 1.5000, eympat1062 = 1.10000, eymtra1062 = 0.40000, eymart107 = 0.95000, eympat107 = 0.70000, eymtra107 = 0.25000, ivart147 = 2.37500, ivpat147 = 1.75000, ivtra147 = 0.62500, retiro = 2.00000, cvart168II = 4.27500, cvpat168II = 3.15000, cvtra168ii = 1.12500, art211 = 1, seguroDesempleo = 0 WHERE periodo = @periodo
                                  UPDATE dbo.primas_imss 
                                  SET eymart25 = @eymart25
                                  WHERE periodo = @periodo
                                        AND ISNULL(eymart25,0) <> @eymart25

                                  UPDATE dbo.primas_imss 
                                  SET eympat25 = @eympat25
                                  WHERE periodo = @periodo
                                        AND ISNULL(eympat25,0) <> @eympat25

                                  UPDATE dbo.primas_imss 
                                  SET eymtra25 = @eymtra25
                                  WHERE periodo = @periodo
                                        AND ISNULL(eymtra25,0) <> @eymtra25

                                  UPDATE dbo.primas_imss 
                                  SET eymart106I = @eymart106i
                                  WHERE periodo = @periodo
                                        AND ISNULL(eymart106I,0) <> @eymart106i

                                  UPDATE dbo.primas_imss 
                                  SET eymart1062 = @eymart1062
                                  WHERE periodo = @periodo
                                        AND ISNULL(eymart1062,0) <> @eymart1062

                                  UPDATE dbo.primas_imss 
                                  SET eympat1062 = @eympat1062
                                  WHERE periodo = @periodo
                                        AND ISNULL(eympat1062,0) <> @eympat1062 

                                  UPDATE dbo.primas_imss 
                                  SET eymtra1062 = @eymtra1062
                                  WHERE periodo = @periodo
                                        AND ISNULL(eymtra1062,0) <> @eymtra1062

                                  UPDATE dbo.primas_imss 
                                  SET eymart107 = @eymart107
                                  WHERE periodo = @periodo
                                        AND ISNULL(eymart107,0) <> @eymart107

                                  UPDATE dbo.primas_imss 
                                  SET eympat107 = @eympat107
                                  WHERE periodo = @periodo
                                        AND ISNULL(eympat107,0) <> @eympat107

                                  UPDATE dbo.primas_imss 
                                  SET eymtra107 = @eymtra107
                                  WHERE periodo = @periodo
                                        AND ISNULL(eymtra107,0) <> @eymtra107

                                  UPDATE dbo.primas_imss 
                                  SET ivart147 = @ivart147
                                  WHERE periodo = @periodo
                                        AND ISNULL(ivart147,0) <> @ivart147

                                  UPDATE dbo.primas_imss 
                                  SET ivpat147 = @ivpat147
                                  WHERE periodo = @periodo
                                        AND ISNULL(ivpat147,0) <> @ivpat147

                                  UPDATE dbo.primas_imss 
                                  SET ivtra147 = @ivtra147
                                  WHERE periodo = @periodo
                                        AND ISNULL(ivtra147,0) <> @ivtra147 

                                  UPDATE dbo.primas_imss 
                                  SET retiro = @retiro
                                  WHERE periodo = @periodo
                                        AND ISNULL(retiro,0) <> @retiro

                                  UPDATE dbo.primas_imss 
                                  SET cvart168II = @cvart168ii
                                  WHERE periodo = @periodo
                                        AND ISNULL(cvart168II,0) <> @cvart168ii

                                  UPDATE dbo.primas_imss 
                                  SET cvpat168II = @cvpat168ii
                                  WHERE periodo = @periodo
                                        AND ISNULL(cvpat168II,0) <> @cvpat168ii

                                  UPDATE dbo.primas_imss 
                                  SET cvtra168ii = @cvtra168ii
                                  WHERE periodo = @periodo
                                        AND ISNULL(cvtra168ii,0) <> @cvtra168ii

                                  UPDATE dbo.primas_imss 
                                  SET infonavit = @infonavit
                                  WHERE periodo = @periodo
                                        AND ISNULL(infonavit,0) <> @infonavit

                                  UPDATE dbo.primas_imss 
                                  SET art211 = @art211
                                  WHERE periodo = @periodo
                                        AND ISNULL(art211,0) <> @art211

                                  UPDATE dbo.primas_imss 
                                  SET seguroDesempleo = @seguroDesempleo
                                  WHERE periodo = @periodo
                                        AND ISNULL(seguroDesempleo,0) <> @seguroDesempleo
                                    --SET @return = 1
                                END
                    END
--    END
GO

IF OBJECT_ID('dbo.sp_agrega_aviso_historico') IS NOT NULL 
    DROP PROCEDURE dbo.sp_agrega_aviso_historico
GO
CREATE PROCEDURE dbo.sp_agrega_aviso_historico
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @nserial INT ,
    @nmes_operacion INT ,
    @nayo_operacion INT ,
    @dfch_mov DATETIME ,
    @cmov VARCHAR(2) ,
    @nsaldiaint DECIMAL(9, 2) ,
    @nsueldo DECIMAL(9, 2) ,
    @ndiastr INT ,
    @cmot_baja VARCHAR(30) ,
    @nclave_baja INT ,
    @ccaptura CHAR(1) ,
    @sueldoAnterior DECIMAL(12, 2) ,
    @salDiaIntAnterior DECIMAL(12, 2) ,
    @saldiaiv DECIMAL(10, 2) ,
    @campo_07 DATETIME ,
    @fechaEnvio DATETIME ,
    @estatus VARCHAR(25) ,
    @fechaConfirmacion DATETIME ,
    @rpu VARCHAR(3) ,
    @origen VARCHAR(2)
AS 
    DECLARE @nerr_ins_avi INT
    SET @nerr_ins_avi = 0
    
    BEGIN TRANSACTION
    INSERT  INTO dbo.avisos_imss
            ( empresa ,
              codigo ,
              serial ,
              mes_operacion ,
              ayo_operacion ,
              fch_mov ,
              mov ,
              saldiaint ,
              sueldo ,
              diastr ,
              mot_baja ,
              clave_baja ,
              captura ,
              origen ,
              sueldoant ,
              saldiaintant ,
              saldiaiv ,
              campo_07 ,
              fechaEnvio ,
              estatus ,
              fechaConfirmacion ,
              rpu
            )
    VALUES  ( @nempresa ,
              @ncodigo ,
              @nserial ,
              @nmes_operacion ,
              @nayo_operacion ,
              @dfch_mov ,
              @cmov ,
              @nsaldiaint ,
              @nsueldo ,
              @ndiastr ,
              @cmot_baja ,
              @nclave_baja ,
              @ccaptura ,
              @origen ,
              @sueldoAnterior ,
              @salDiaIntAnterior ,
              @saldiaiv ,
              @campo_07 ,
              @fechaEnvio ,
              @estatus ,
              @fechaConfirmacion ,
              @rpu
            )
    SELECT  @nerr_ins_avi = @@error
    IF @nerr_ins_avi <> 0 
        BEGIN
            ROLLBACK TRANSACTION
        END
    ELSE 
        BEGIN
            COMMIT TRANSACTION
        END
GO

IF OBJECT_ID('dbo.sp_agrega_aviso_ms_ri') IS NOT NULL
   DROP PROCEDURE dbo.sp_agrega_aviso_ms_ri
GO

CREATE procedure [dbo].[sp_agrega_aviso_ms_ri]
@nempresa numeric(5,0),
@ncodigo numeric(8,0),
@nserial int,
@nmes_operacion int,
@nayo_operacion int,
@dfch_mov datetime,
@dfch_real datetime,
@cmov varchar(  2),
@nsaldiaint decimal(9,2),
@nsaldiaiv decimal(9,2),
@nsueldo decimal(9,2),
@ndiastr int,
@nincap int,
@nausen decimal(5,2),
@cclase char(2),
@nocupacion int,
@ccentro char(15),
@dfchantigua datetime,
@cfuncion varchar(5),
@copcion varchar(5),
@nfactor decimal(7,4),
@nsdoant decimal(12,2),
@nsdiant decimal(12,2),
@corigen VARCHAR(2),
@cmulti char(1),
@tipoSalario INT,
@rpu varchar(3)

as

declare @nerr_ins_avi int
declare @nerr_upd_emp int
declare @nerr_upd_lla int
set @nerr_ins_avi = 0
set @nerr_upd_emp = 0
set @nerr_upd_lla = 0
begin tran
         insert into avisos_imss
         (empresa, codigo, serial, mes_operacion, ayo_operacion, fch_mov, fch_real, mov, saldiaint, saldiaiv, sueldo, diastr, incap, ausen, sueldoant, saldiaintant, origen, rpu)
         values
         (@nempresa, @ncodigo, @nserial, @nmes_operacion, @nayo_operacion, @dfch_mov, @dfch_real, @cmov, @nsaldiaint, @nsaldiaiv, @nsueldo, @ndiastr, @nincap, @nausen, @nsdoant, @nsdiant, @corigen, @rpu)
         select @nerr_ins_avi = @@error

         update empleados
         set ultmov = @cmov,
             ultfchmov = @dfch_mov,
             sueldo = @nsueldo,
             saldiaint = @nsaldiaint,
             fchantigua = @dfchantigua,
             factorsd = @nfactor,
             multiple = @cmulti,
             tiposal = CASE WHEN @tipoSalario IS NULL THEN tiposal ELSE @tipoSalario END,
             rpu = @rpu
         where empresa = @nempresa and codigo = @ncodigo
         select @nerr_upd_emp = @@error
            if @cmov = 'RI'
           update empleados
           set finikito = 'F'
           where empresa = @nempresa and codigo = @ncodigo

         update llaves
         set clase = @cclase,
             ocupacion = @nocupacion,
             centro = @ccentro
         where empresa = @nempresa and codigo = @ncodigo
         select @nerr_upd_lla = @@error


If @nerr_ins_avi <> 0 or @nerr_upd_emp <> 0 or @nerr_upd_lla <> 0
  begin
       rollback transaction
       insert into estatus (empresa,codigo,grabo,funcion,opcion) values (@nempresa,@ncodigo,'F',@cfuncion,@copcion)
  end
else
  begin
      commit transaction
      insert into estatus (empresa,codigo,grabo,funcion,opcion) values (@nempresa,@ncodigo,'T',@cfuncion,@copcion)
 end
GO

IF OBJECT_ID('dbo.sp_agrega_registro_historico') IS NOT NULL 
    DROP PROCEDURE dbo.sp_agrega_registro_historico
GO
CREATE PROCEDURE [dbo].[sp_agrega_registro_historico]
    @nempresa NUMERIC(5) ,
    @ncodigo NUMERIC(8) ,
    @ccampo VARCHAR(25) ,
    @cvalor_nuevo VARCHAR(50) ,
    @cvalor_original VARCHAR(50) ,
    @cperiodo VARCHAR(06) ,
    @nmes_operacion INT ,
    @nayo_operacion INT ,
    @ccapturo VARCHAR(20) ,
    @dfecha_captura DATETIME ,
    @ddesde DATETIME ,
    @ctipo_motivo VARCHAR(10) ,
    @nnum_motivo INT ,
    @ntiponom INT ,
    @origen VARCHAR(25)
AS 
    DECLARE @nperiodo INT
    DECLARE @cmes CHAR(2)
    DECLARE @cayo CHAR(4)


    SELECT  @nperiodo = dbo.periodos.periodo ,
            @cmes = SUBSTRING(dbo.periodos.mes, 1, 2) ,
            @cayo = SUBSTRING(dbo.periodos.mes, 3, 4)
    FROM    dbo.periodos
    WHERE   dbo.periodos.empresa = @nempresa
            AND dbo.periodos.tiponom = @ntiponom
            AND dbo.periodos.estatus = 'A'
 

    INSERT  INTO dbo.historico
            ( empresa ,
              codigo ,
              campo ,
              valor_nuevo ,
              valor_original ,
              periodo ,
              mes_operacion ,
              ayo_operacion ,
              capturo ,
              fecha_captura ,
              desde ,
              tipo_motivo ,
              num_motivo ,
              origen
            )
    VALUES  ( @nempresa ,
              @ncodigo ,
              @ccampo ,
              @cvalor_nuevo ,
              @cvalor_original ,
              CONVERT(VARCHAR(6), @nperiodo) ,
              CONVERT(INT, @cmes) ,
              CONVERT(INT, @cayo) ,
              @ccapturo ,
              @dfecha_captura ,
              @ddesde ,
              @ctipo_motivo ,
              @nnum_motivo ,
              @origen
            )
GO

IF OBJECT_ID('dbo.sp_avisos_historico') IS NOT NULL
    DROP PROCEDURE dbo.sp_avisos_historico
GO
CREATE PROCEDURE [dbo].[sp_avisos_historico]
    @nempresa INTEGER = 0 ,
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nayo INTEGER = 0
AS
    SET NOCOUNT ON
    
    DECLARE @ayoPeriodoNomina INT
    DECLARE @periodoNomina INT
    DECLARE @tipoNom INT

    SELECT @ayoPeriodoNomina = dbo.Periodos.ayo_operacion,
           @periodoNomina = dbo.Periodos.periodo,
           @tipoNom = dbo.Llaves.tiponom
    FROM dbo.Periodos
    INNER JOIN dbo.Llaves ON dbo.Periodos.empresa = dbo.Llaves.empresa 
                             AND dbo.Periodos.tiponom = dbo.Llaves.tiponom
    WHERE dbo.Periodos.empresa = @nempresa
          AND dbo.Periodos.estatus = 'A'
          AND dbo.Llaves.codigo = @ncodigo
    
    SELECT  dbo.avisos_imss.ayo_operacion,
            dbo.avisos_imss.mes_operacion,
            dbo.avisos_imss.serial,
            dbo.avisos_imss.mov,
            dbo.avisos_imss.fch_mov,
            dbo.avisos_imss.sueldo,
            dbo.avisos_imss.saldiaint,
            dbo.avisos_imss.clave_baja,
            dbo.avisos_imss.mot_baja,
            dbo.avisos_imss.captura,
            dbo.avisos_imss.saldiaiv,
            dbo.avisos_imss.campo_07,
            dbo.avisos_imss.fechaEnvio,
            dbo.avisos_imss.estatus,
            dbo.avisos_imss.fechaConfirmacion,
            dbo.avisos_imss.rpu,
            dbo.avisos_imss.origen,
            dbo.avisos_imss.sueldoant,
            dbo.avisos_imss.saldiaintant,
            CASE WHEN dbo.finiquitos_anual.ayo_operacion IS NOT NULL AND dbo.finiquitos_anual.periodo IS NOT NULL THEN STR(dbo.finiquitos_anual.ayo_operacion, 4) + '/' + RIGHT(STR(100 + dbo.finiquitos_anual.periodo), 2) ELSE CASE WHEN dbo.finiquitos.codigo IS NOT NULL THEN STR(@ayoPeriodoNomina, 4) + '/' + RIGHT(STR(100 + @periodoNomina), 2) ELSE '' END END AS periodoFiniquito,
            dbo.OrigenAvisoImss.descripcion AS descripcionOrigenAviso
    FROM    dbo.avisos_imss
            LEFT JOIN dbo.finiquitos_anual ON dbo.avisos_imss.empresa = dbo.finiquitos_anual.empresa
                                              AND dbo.avisos_imss.codigo = dbo.finiquitos_anual.codigo
                                              AND dbo.avisos_imss.fch_mov = dbo.finiquitos_anual.fchbaja
            LEFT JOIN dbo.finiquitos ON dbo.avisos_imss.empresa = dbo.finiquitos.empresa 
                                        AND dbo.avisos_imss.codigo = dbo.finiquitos.codigo
                                        AND dbo.avisos_imss.fch_mov = dbo.finiquitos.fchbaja
                                        AND dbo.avisos_imss.mov = 'B'
            LEFT JOIN dbo.OrigenAvisoImss ON LTRIM(RTRIM(dbo.avisos_imss.origen)) = LTRIM(RTRIM(dbo.OrigenAvisoImss.origen))
    
    WHERE   dbo.avisos_imss.empresa = @nempresa
            AND dbo.avisos_imss.codigo = @ncodigo
            AND dbo.avisos_imss.ayo_operacion = @nayo
    ORDER BY dbo.avisos_imss.ayo_operacion ,
            dbo.avisos_imss.mes_operacion ,
            dbo.avisos_imss.serial
GO

IF OBJECT_ID('dbo.sp_avisos_imss_fun_d') IS NOT NULL 
    DROP PROCEDURE dbo.sp_avisos_imss_fun_d
GO
CREATE PROCEDURE [dbo].[sp_avisos_imss_fun_d]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @nmes_ini INTEGER = 0 ,
    @nmes_fin INTEGER = 0 ,
    @nayo_ini INTEGER = 0 ,
    @nayo_fin INTEGER = 0
AS 
    SET NOCOUNT ON

    DECLARE @tieneRpu CHAR(1)
    DECLARE @ayoPeriodoNomina INT
    DECLARE @periodoNomina INT
    DECLARE @tipoNom INT

    SET @tieneRpu = ISNULL(( SELECT dbo.empresas.Rpu
                             FROM   dbo.empresas
                             WHERE  dbo.empresas.empresa = @nempresa
                           ), 'N')
                           
    SELECT @ayoPeriodoNomina = dbo.Periodos.ayo_operacion,
           @periodoNomina = dbo.Periodos.periodo,
           @tipoNom = dbo.Llaves.tiponom
    FROM dbo.Periodos
    INNER JOIN dbo.Llaves ON dbo.Periodos.empresa = dbo.Llaves.empresa 
                             AND dbo.Periodos.tiponom = dbo.Llaves.tiponom
    WHERE dbo.Periodos.empresa = @nempresa
          AND dbo.Periodos.estatus = 'A'
          AND dbo.Llaves.codigo = @ncodigo

    SELECT  dbo.avisos_imss.serial ,
            dbo.avisos_imss.mov ,
            dbo.avisos_imss.fch_mov ,
            dbo.avisos_imss.fch_real ,
            dbo.avisos_imss.sueldo ,
            dbo.avisos_imss.saldiaint ,
            dbo.avisos_imss.clave_baja ,
            dbo.avisos_imss.mot_baja ,
            dbo.avisos_imss.sueldoant ,
            dbo.avisos_imss.saldiaintant ,
            dbo.avisos_imss.origen ,
            CASE WHEN @tieneRpu = 'S' THEN dbo.avisos_imss.rpu ELSE NULL END AS rpu ,
            dbo.avisos_imss.lote ,
            CASE WHEN dbo.finiquitos_anual.ayo_operacion IS NOT NULL AND dbo.finiquitos_anual.periodo IS NOT NULL THEN STR(dbo.finiquitos_anual.ayo_operacion, 4) + '/' + RIGHT(STR(100 + dbo.finiquitos_anual.periodo), 2) ELSE CASE WHEN dbo.finiquitos.codigo IS NOT NULL THEN STR(@ayoPeriodoNomina, 4) + '/' + RIGHT(STR(100 + @periodoNomina), 2) ELSE '' END END AS periodoFiniquito,
            dbo.avisos_imss.saldiaiv,
            dbo.avisos_imss.campo_07,
            dbo.avisos_imss.fechaEnvio,
            dbo.avisos_imss.estatus,
            dbo.avisos_imss.fechaConfirmacion,
            dbo.OrigenAvisoImss.descripcion,
            @periodoNomina AS periodoNomina,
            @tipoNom AS tipoNomina,
            Enviar,
            Enviado,
            'FIN' AS FIN -- Este campo simpre se debe dejar al ultimo en caso de agregar mas campos jorge Mtz 27/04/2016
    FROM    dbo.avisos_imss
            LEFT JOIN dbo.finiquitos_anual ON dbo.avisos_imss.empresa = dbo.finiquitos_anual.empresa
                                              AND dbo.avisos_imss.codigo = dbo.finiquitos_anual.codigo
                                              AND dbo.avisos_imss.fch_mov = dbo.finiquitos_anual.fchbaja
            LEFT JOIN dbo.finiquitos ON dbo.avisos_imss.empresa = dbo.finiquitos.empresa 
                                        AND dbo.avisos_imss.codigo = dbo.finiquitos.codigo
                                        AND dbo.avisos_imss.fch_mov = dbo.finiquitos.fchbaja
                                        AND dbo.avisos_imss.mov = 'B'
            LEFT JOIN dbo.OrigenAvisoImss ON LTRIM(RTRIM(dbo.avisos_imss.origen)) = LTRIM(RTRIM(dbo.OrigenAvisoImss.origen))
    WHERE   dbo.avisos_imss.empresa = @nempresa
            AND dbo.avisos_imss.codigo = @ncodigo
            AND ( ( dbo.avisos_imss.ayo_operacion = @nayo_ini
                    AND dbo.avisos_imss.mes_operacion = @nmes_ini
                  )
                  OR ( dbo.avisos_imss.ayo_operacion = @nayo_fin
                       AND dbo.avisos_imss.mes_operacion = @nmes_fin
                     )
                )
    ORDER BY dbo.avisos_imss.ayo_operacion ,
            dbo.avisos_imss.mes_operacion ,
            dbo.avisos_imss.serial
GO

IF OBJECT_ID('dbo.sp_borra_aviso') IS NOT NULL 
    DROP PROCEDURE dbo.sp_borra_aviso
Go
CREATE PROCEDURE dbo.sp_borra_aviso
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @nserial INT ,
    @nmes_operacion INT ,
    @nayo_operacion INT ,
    @nsueldo DECIMAL(9, 2) ,
    @nsaldiaint DECIMAL(9, 2) ,
    @cmov VARCHAR(2) ,
    @dfchmov DATETIME ,
    @cultmov VARCHAR(2)
AS 
    DECLARE @nerr_del_avi INT
    DECLARE @nerr_upd_emp INT
    DECLARE @nerr_upd_emp_b INT
    DECLARE @fechaAntiguedad DATETIME

    SET @nerr_del_avi = 0
    SET @nerr_upd_emp = 0
    SET @nerr_upd_emp_b = 0

    BEGIN TRAN
    DELETE  dbo.avisos_imss
    WHERE   dbo.avisos_imss.empresa = @nempresa
            AND dbo.avisos_imss.codigo = @ncodigo
            AND dbo.avisos_imss.serial = @nserial
            AND dbo.avisos_imss.mes_operacion = @nmes_operacion
            AND dbo.avisos_imss.ayo_operacion = @nayo_operacion
    SELECT  @nerr_del_avi = @@error
    
    UPDATE  dbo.empleados
    SET     dbo.empleados.ultmov = @cmov ,
            dbo.empleados.ultfchmov = @dfchmov ,
            dbo.empleados.sueldo = @nsueldo ,
            dbo.empleados.saldiaint = @nsaldiaint
    WHERE   dbo.empleados.empresa = @nempresa
            AND dbo.empleados.codigo = @ncodigo
    SELECT  @nerr_upd_emp = @@error

    IF @cultmov = 'RI'
       BEGIN
            SELECT TOP 1
                    @fechaAntiguedad = ISNULL(dbo.avisos_imss.campo_07,
                                              dbo.empleados.fchantigua)
            FROM    dbo.avisos_imss
                    INNER JOIN dbo.empleados ON dbo.avisos_imss.empresa = dbo.empleados.empresa
                                                AND dbo.avisos_imss.codigo = dbo.empleados.codigo
            WHERE   dbo.avisos_imss.empresa = @nempresa
                    AND dbo.avisos_imss.codigo = @ncodigo
                    AND dbo.avisos_imss.mov = 'B'
            ORDER BY dbo.avisos_imss.ayo_operacion DESC ,
                    dbo.avisos_imss.mes_operacion DESC
                    
            SELECT @fechaAntiguedad
        
            UPDATE  dbo.empleados
            SET     dbo.empleados.fchantigua = @fechaAntiguedad
            WHERE   dbo.empleados.empresa = @nempresa
                    AND dbo.empleados.codigo = @ncodigo
            SELECT  @nerr_upd_emp_b = @@error
       END

    IF @cultmov = 'B' 
        BEGIN
            UPDATE  dbo.empleados
            SET     dbo.empleados.finikito = 'F'
            WHERE   dbo.empleados.empresa = @nempresa
                    AND dbo.empleados.codigo = @ncodigo
            SELECT  @nerr_upd_emp_b = @@error
        END   
          

    IF @nerr_del_avi <> 0
        OR @nerr_upd_emp <> 0
        OR @nerr_upd_emp_b <> 0 
        ROLLBACK TRANSACTION
    ELSE 
        COMMIT TRANSACTION
GO

IF OBJECT_ID('dbo.sp_borra_incapacidades_fun_a') IS NOT NULL
   DROP PROCEDURE dbo.sp_borra_incapacidades_fun_a
GO
CREATE PROCEDURE dbo.sp_borra_incapacidades_fun_a
@nempresa NUMERIC(5,0),
@ncodigo NUMERIC(8,0),
@nayo_operacion INT,
@nmes_operacion INT,
@nfolio INT,
@periodo INT

AS 

DELETE 
FROM dbo.deducciones 
WHERE empresa = @nempresa 
      AND codigo = @ncodigo 
      AND ayo_operacion = @nayo_operacion 
      AND mes_operacion = @nmes_operacion 
      AND folio = @nfolio
      AND periodo = @periodo


GO

IF OBJECT_ID('dbo.sp_cambia_a_historico') IS NOT NULL 
    DROP PROCEDURE dbo.sp_cambia_a_historico
go


CREATE PROCEDURE dbo.sp_cambia_a_historico
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @dbaja DATETIME ,
    @nmes INT ,
    @nayo INT
AS 
    UPDATE  dbo.empleados
    SET     dbo.empleados.activo = 'N' ,
            dbo.empleados.fch_baja = @dbaja ,
            dbo.empleados.ultmov = 'B' ,
            dbo.empleados.ultfchmov = @dbaja
    WHERE   dbo.empleados.empresa = @nempresa
            AND dbo.empleados.codigo = @ncodigo

    DELETE  dbo.avisos_imss
    WHERE   dbo.avisos_imss.empresa = @nempresa
            AND dbo.avisos_imss.codigo = @ncodigo
            AND RIGHT(dbo.avisos_imss.ayo_operacion, 4) + RIGHT(100
                                                              + dbo.avisos_imss.mes_operacion,
                                                              2) >= RIGHT(@nayo,
                                                              4) + RIGHT(100
                                                              + @nmes, 2)
GO

IF OBJECT_ID('dbo.sp_checa_CURP') IS NOT NULL
    DROP PROCEDURE dbo.sp_checa_CURP
GO
CREATE PROCEDURE [dbo].[sp_checa_CURP]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @curp VARCHAR(18)
AS
    SELECT  dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.empleados.fchalta ,
            dbo.empleados.fchantigua ,
            dbo.empleados.ultmov ,
            dbo.empleados.ultfchmov ,
            dbo.empleados.codigo ,
            dbo.empleados.activo ,
            dbo.empleados.curp
    FROM    dbo.empleados
    WHERE   dbo.empleados.empresa = @nempresa
            AND dbo.empleados.codigo <> @ncodigo
            AND LTRIM(RTRIM(dbo.empleados.curp)) = LTRIM(RTRIM(@curp))
GO

IF OBJECT_ID('dbo.sp_checa_NombreEmpleado') IS NOT NULL
    DROP PROCEDURE dbo.sp_checa_NombreEmpleado
GO
CREATE PROCEDURE [dbo].[sp_checa_NombreEmpleado]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @apellidoPaterno VARCHAR(50) ,
    @apellidoMaterno VARCHAR(50) ,
    @nombre VARCHAR(50)
AS
    SELECT  dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.empleados.fchalta ,
            dbo.empleados.fchantigua ,
            dbo.empleados.ultmov ,
            dbo.empleados.ultfchmov ,
            dbo.empleados.codigo ,
            dbo.empleados.activo
    FROM    dbo.empleados
    WHERE   dbo.empleados.empresa = @nempresa
            AND dbo.empleados.codigo <> @ncodigo
            AND LTRIM(RTRIM(dbo.empleados.ap_paterno)) = LTRIM(RTRIM(@apellidoPaterno))
            AND LTRIM(RTRIM(dbo.empleados.ap_materno)) = LTRIM(RTRIM(@apellidoMaterno))
            AND LTRIM(RTRIM(dbo.empleados.nombre)) = LTRIM(RTRIM(@nombre))
GO

IF OBJECT_ID('dbo.sp_checa_nss') IS NOT NULL
    DROP PROCEDURE dbo.sp_checa_nss
GO
CREATE PROCEDURE [dbo].[sp_checa_nss]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @cafilia CHAR(10) ,
    @cdigvera CHAR(1)
AS
    SELECT  empleados.afiliacion ,
            empleados.digvera ,
            empleados.ap_paterno ,
            empleados.ap_materno ,
            empleados.nombre ,
            empleados.fchalta ,
            empleados.fchantigua ,
            empleados.ultmov ,
            empleados.ultfchmov ,
            empleados.codigo ,
            empleados.activo
    FROM    empleados
    WHERE   empleados.empresa = @nempresa
            AND empleados.codigo <> @ncodigo
            AND afiliacion = @cafilia
            AND digvera = @cdigvera
GO

IF OBJECT_ID('dbo.sp_checa_RFC') IS NOT NULL
    DROP PROCEDURE dbo.sp_checa_RFC
GO
CREATE PROCEDURE [dbo].[sp_checa_RFC]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @rfcAlfa VARCHAR(4) ,
    @rfcNum VARCHAR(6) ,
    @rfcHomo VARCHAR(3)
AS
    SELECT  dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.empleados.fchalta ,
            dbo.empleados.fchantigua ,
            dbo.empleados.ultmov ,
            dbo.empleados.ultfchmov ,
            dbo.empleados.codigo ,
            dbo.empleados.activo ,
            dbo.empleados.rfcalfa ,
            dbo.empleados.rfcnum ,
            dbo.empleados.rfchomo
    FROM    dbo.empleados
    WHERE   dbo.empleados.empresa = @nempresa
            AND dbo.empleados.codigo <> @ncodigo
            AND LTRIM(RTRIM(dbo.empleados.rfcalfa)) = LTRIM(RTRIM(@rfcAlfa))
            AND LTRIM(RTRIM(dbo.empleados.rfcnum)) = LTRIM(RTRIM(@rfcNum))
            AND LTRIM(RTRIM(dbo.empleados.rfchomo)) = LTRIM(RTRIM(@rfcHomo))
GO

IF OBJECT_ID('dbo.sp_datos_captura_fun_d') IS NOT NULL 
    DROP PROCEDURE dbo.sp_datos_captura_fun_d
GO
CREATE PROCEDURE [dbo].[sp_datos_captura_fun_d]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @nmes INTEGER = 0 ,
    @nayo INTEGER = 0
AS 
    DECLARE @fecha DATETIME
    SET @fecha = CONVERT(DATETIME, RIGHT(STR(10000 + @nayo),4) + RIGHT(STR(100) + @nmes,2) + '01')
    
    SELECT  dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.empleados.ap_paterno ,
            dbo.empleados.ap_materno ,
            dbo.empleados.nombre ,
            dbo.empleados.fchalta ,
            dbo.empleados.fchantigua ,
            dbo.llaves.ocupacion ,
            dbo.tabulador.actividad ,
            dbo.llaves.clase ,
            dbo.empleados.tiposal ,
            dbo.llaves.tiponom ,
            dbo.llaves.horario ,
            dbo.llaves.centro ,
            dbo.empleados.sindicato ,
            CASE WHEN dbo.avisos_imss.sueldo IS NULL THEN dbo.empleados.sueldo
                 ELSE dbo.avisos_imss.sueldo
            END AS sueldo ,
            dbo.empleados.varia_imss ,
            dbo.empleados.varia_next ,
            CASE WHEN dbo.avisos_imss.saldiaint IS NULL
                 THEN dbo.empleados.saldiaint
                 ELSE dbo.avisos_imss.saldiaint
            END AS saldiaint ,
            dbo.empleados.tipo_emp ,
            dbo.empleados.art39 ,
            dbo.empleados.sexo ,
            dbo.empleados.edonac ,
            dbo.empleados.fchnac ,
            dbo.empleados.rfcalfa ,
            dbo.empleados.rfcnum ,
            dbo.empleados.rfchomo ,
            dbo.empleados.curp ,
            dbo.datosemps.edocivil ,
            dbo.datosemps.telefono ,
            dbo.empleados.manoobra ,
            dbo.llaves.supervisor ,
            dbo.datosemps.inegi ,
            dbo.datosemps.umf ,
            dbo.datosemps.afore ,
            dbo.datosemps.nacional ,
            dbo.bancos.nombre AS nombreBanco ,
            dbo.empleados.tipo_deposito ,
            dbo.empleados.cta_bco_no ,
            dbo.datosemps.domicilio ,
            dbo.datosemps.colonia ,
            dbo.datosemps.poblacion ,
            dbo.datosemps.codpostal ,
            dbo.horarios_catalogo.turno ,
            dbo.horarios_catalogo.jornada ,
            (SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'CV') AS 'cv' ,
            (SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'IV') AS 'iv' ,
            (SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'S' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'NOIMSS') AS 'imss' ,
            (SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'S' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = '115') AS '115' ,
            'N' AS 'chofer' ,      --(SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'CHOFER') AS 'chofer' ,
            0 AS 'isr_chofer' ,    --(SELECT CASE WHEN dbo.excepciones.excepcion2 IS NULL THEN 0   ELSE dbo.excepciones.excepcion2 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'CHOFER') AS 'isr_chofer' ,
            'N' AS 'ayu_chofer' ,  --(SELECT CASE WHEN dbo.excepciones.excepcion1 IS NULL THEN 'N' ELSE dbo.excepciones.excepcion1 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'ACHOFER') AS 'ayu_chofer' ,
            0 AS 'isr_ayu' ,       --(SELECT CASE WHEN dbo.excepciones.excepcion2 IS NULL THEN 0   ELSE dbo.excepciones.excepcion2 END FROM dbo.excepciones WHERE dbo.excepciones.empresa = dbo.empleados.empresa AND dbo.excepciones.codigo = dbo.empleados.codigo AND dbo.excepciones.excepcion1 = 'ACHOFER') AS 'isr_ayu' ,
            dbo.llaves.banco ,
            dbo.empleados.mcamov ,
            dbo.empleados.sig_bim ,
            dbo.empleados.var_sigmes ,
            dbo.empleados.cotiza_imss ,
            dbo.empleados.pagar_nomina ,
            dbo.empleados.rpu ,
            dbo.empleados.multiple ,
            dbo.empleados.cuenta ,
            ISNULL(dbo.EmpleadoAdicional.discapacitado, 'N') AS discapacitado ,
            ISNULL(dbo.EmpleadoAdicional.clabe,SPACE(20)) AS clabe ,
            ISNULL(dbo.EmpleadoAdicional.tipoRegimen,2) AS tipoRegimen ,
            ISNULL(dbo.EmpleadoAdicional.tipoContrato,1) AS tipoContrato ,
            ISNULL(dbo.datosemps.email,SPACE(40)) AS email ,
            ISNULL(dbo.datosemps.cta_vales,SPACE(20)) AS cta_vales ,
            dbo.datosemps.numeroExterior ,
            dbo.datosemps.numeroInterior ,
            dbo.datosemps.municipio ,
            dbo.datosemps.localidad ,
            dbo.EmpleadoAdicional.claveSat ,
            dbo.EmpleadoAdicional.porcientoSat,
            dbo.EmpleadoAdicional.claveEstado,
            dbo.EmpleadoAdicional.nss,
            CASE WHEN ultimaAlta.ultimaFechaAlta IS NULL THEN dbo.empleados.fchalta ELSE ultimaAlta.ultimaFechaAlta END AS ultimaFechaAlta,
            ultimaBaja.ultimaFechaBaja,
            dbo.centros.nomdepto AS nombreCentro,
			dbo.empleadoAdicional.regimenFiscal
    FROM    dbo.empleados
            LEFT JOIN dbo.llaves ON dbo.empleados.empresa = dbo.llaves.empresa
                                    AND dbo.empleados.codigo = dbo.llaves.codigo
            LEFT JOIN dbo.tabulador ON dbo.empleados.empresa = dbo.tabulador.empresa
                                       AND dbo.llaves.ocupacion = dbo.tabulador.ocupacion
            LEFT JOIN dbo.avisos_imss ON dbo.empleados.empresa = dbo.avisos_imss.empresa
                                         AND dbo.empleados.codigo = dbo.avisos_imss.codigo
                                         AND dbo.avisos_imss.mes_operacion >= @nmes
                                         AND dbo.avisos_imss.ayo_operacion >= @nayo
                                         AND ( dbo.avisos_imss.mov = 'IM'
                                               OR dbo.avisos_imss.mov = 'A'
                                             )
            LEFT JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                       AND dbo.empleados.codigo = dbo.datosemps.codigo
            LEFT JOIN dbo.horarios_catalogo ON dbo.empleados.empresa = dbo.horarios_catalogo.empresa
                                               AND dbo.llaves.horario = dbo.horarios_catalogo.horario
            LEFT JOIN dbo.bancos ON dbo.llaves.banco = dbo.bancos.banco
            LEFT JOIN dbo.EmpleadoAdicional ON dbo.empleados.empresa = dbo.EmpleadoAdicional.empresa 
                                               AND dbo.empleados.codigo = dbo.EmpleadoAdicional.codigo
                                               
            OUTER APPLY (SELECT TOP 1 
                                ultimaAlta.fch_mov AS ultimaFechaAlta
                         FROM dbo.avisos_imss AS ultimaAlta 
                         WHERE dbo.empleados.empresa = ultimaAlta.empresa
                               AND dbo.empleados.codigo = ultimaAlta.codigo
                               AND (ultimaAlta.mov = 'A'
                                    OR ultimaAlta.mov = 'RI')
                         ORDER BY ultimaAlta.fch_mov DESC,
                                  ultimaAlta.serial DESC) AS ultimaAlta        

            OUTER APPLY (SELECT TOP 1 
                                CASE WHEN ultimaBaja.mov = 'B' THEN ultimaBaja.fch_mov ELSE NULL END AS ultimaFechaBaja
                         FROM dbo.avisos_imss AS ultimaBaja 
                         WHERE dbo.empleados.empresa = ultimaBaja.empresa
                               AND dbo.empleados.codigo = ultimaBaja.codigo
                               --AND ultimaBaja.mov = 'B'
                               AND ultimaBaja.fch_mov >= @fecha
                         ORDER BY ultimaBaja.fch_mov DESC,
                                  ultimaBaja.serial DESC) AS ultimaBaja

            LEFT JOIN dbo.centros ON dbo.Llaves.empresa = dbo.centros.empresa
                                     AND LTRIM(RTRIM(dbo.Llaves.centro)) = LTRIM(RTRIM(dbo.centros.centro))
                         
    WHERE   dbo.empleados.empresa = @nempresa
            AND dbo.empleados.codigo = @ncodigo
GO

IF OBJECT_ID('dbo.sp_guarda_parte_variable') IS NOT NULL 
    DROP PROCEDURE [dbo].[sp_guarda_parte_variable]
GO
CREATE PROCEDURE [dbo].[sp_guarda_parte_variable]
    @nempresa NUMERIC(5) ,
    @ncodigo NUMERIC(8) ,
    @nmes_operacion INT ,
    @nayo_operacion INT ,
    @nvariable DECIMAL(12, 2) ,
    @ndiastr INT ,
    @nincap INT ,
    @naus INT ,
    @parte_var DECIMAL(12, 2) ,
    @nfactor DECIMAL(7, 4) ,
    @nparte_fija DECIMAL(5, 2) ,
    @nayos_ant INT ,
    @excedente DECIMAL(12, 2) ,
    @incapacitado CHAR(1) ,
    @fechaVariable DATETIME ,
    @fi DATETIME ,
    @ff DATETIME ,
    @ultimoSueldo NUMERIC(12, 2) ,
    @sbc NUMERIC(12, 2) ,
    @rpu CHAR(3) ,
    @origen VARCHAR(5) ,
    @serial INT ,
    @ultimoSBC NUMERIC(12, 2) ,
    @mismoTope INT
AS 
    INSERT  dbo.partes_variables
            ( empresa ,
              codigo ,
              mes_operacion ,
              ayo_operacion ,
              variable ,
              diastr ,
              incap ,
              aus ,
              parte_variable ,
              factor ,
              parte_fija ,
              ayos_antiguedad ,
              excedente
                    
            )
    VALUES  ( @nempresa ,
              @ncodigo ,
              @nmes_operacion ,
              @nayo_operacion ,
              @nvariable ,
              @ndiastr ,
              @nincap ,
              @naus ,
              @parte_var ,
              @nfactor ,
              @nparte_fija ,
              @nayos_ant ,
              @excedente
                    
            )

    -- Si no esta incapacitado aplicar el cambio de salario JCMM 28/05/2013
    IF @incapacitado = ''
        AND ( @mismoTope = 0
              OR @mismoTope = 2
            ) 
        BEGIN
            SELECT CASE WHEN @fechaVariable >= @fi AND @fechaVariable <= @ff THEN @parte_var ELSE 0 END,
                   CASE WHEN @fechaVariable >= @fi AND @fechaVariable <= @ff THEN 'F' ELSE 'T' END,
                   CASE WHEN @fechaVariable > @ff THEN @parte_var ELSE 0 END
        
            UPDATE  empleado
            SET     empleado.varia_imss = CASE WHEN @fechaVariable >= @fi AND @fechaVariable <= @ff THEN @parte_var ELSE 0 END ,
                    empleado.var_sigmes = CASE WHEN @fechaVariable >= @fi AND @fechaVariable <= @ff THEN 'F' ELSE 'T' END ,
                    empleado.varia_next = CASE WHEN @fechaVariable > @ff THEN @parte_var ELSE 0 END ,
                    empleado.ultmov = 'MS' ,
                    empleado.ultfchmov = @fechaVariable ,
                    empleado.sueldo = @ultimoSueldo ,
                    empleado.saldiaint = @sbc
            FROM    dbo.empleados AS empleado
            WHERE   empleado.codigo = @ncodigo
                    AND empleado.empresa = @nempresa
        
            SET @serial = @serial + 1
        
            INSERT  dbo.avisos_imss
                    ( empresa ,
                      codigo ,
                      serial ,
                      fch_mov ,
                      mov ,
                      saldiaint ,
                      sueldo ,
                      sueldoant ,
                      saldiaintant ,
                      mes_operacion ,
                      ayo_operacion ,
                      origen ,
                      rpu
				
                    )
            VALUES  ( @nempresa ,
                      @ncodigo ,
                      @serial ,
                      @fechaVariable ,
                      'MS' ,
                      @sbc ,
                      @ultimoSueldo ,
                      @ultimoSueldo ,
                      @ultimoSBC ,
                      MONTH(@fechaVariable) ,
                      YEAR(@fechaVariable) ,
                      @origen ,
                      @rpu
                    )
           -- Si esta incapacitado solo guardar la parte variable JCMM 28/05/2013
        END
    ELSE 
        UPDATE  empleado
        SET     empleado.varia_imss = CASE WHEN @fechaVariable >= @fi AND @fechaVariable <= @ff THEN @parte_var ELSE 0 END ,
                empleado.var_sigmes = CASE WHEN @fechaVariable >= @fi AND @fechaVariable <= @ff THEN 'F' ELSE 'T' END ,
                empleado.varia_next = CASE WHEN @fechaVariable > @ff THEN @parte_var ELSE 0 END 
        FROM    dbo.empleados AS empleado
        WHERE   empleado.codigo = @ncodigo
                AND empleado.empresa = @nempresa
GO

IF OBJECT_ID('dbo.sp_info_empleado_fun_d') IS NOT NULL 
    DROP PROCEDURE dbo.sp_info_empleado_fun_d
GO
CREATE PROCEDURE [dbo].[sp_info_empleado_fun_d]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0
AS 
    SELECT  ( RTRIM(dbo.empleados.ap_paterno) + ' '
              + RTRIM(dbo.empleados.ap_materno) + ' '
              + RTRIM(dbo.empleados.nombre) ) AS 'Nombre' ,
            dbo.empleados.fchalta ,
            dbo.empleados.fchantigua ,
            dbo.empleados.borrado ,
            dbo.Llaves.clase ,
            dbo.Llaves.tiponom ,
            dbo.tabulador.actividad ,
            dbo.periodos.inicio ,
            dbo.periodos.cierre ,
            dbo.periodos.pago ,
            dbo.nominas.nomina ,
            dbo.Llaves.centro ,
            dbo.centros.nomdepto ,
            dbo.empleados.activo ,
            dbo.empleados.fch_baja ,
            dbo.Llaves.horario ,
            dbo.datosemps.foto ,
            dbo.empleados.afiliacion ,
            dbo.empleados.digvera ,
            dbo.tabulador.ocupacion ,
            dbo.empleados.fchnac ,
            dbo.empleados.rfcalfa ,
            dbo.empleados.rfcnum ,
            dbo.empleados.rfchomo ,
            dbo.empleados.curp ,
            dbo.periodos.periodo,
            ISNULL(dbo.infonavit.numcredito, 0) AS numeroCredito
            --EmpleadoAdicional.enviarApsiReloj,
            --EmpleadoAdicional.enviosApsiReloj,
            --EmpleadoAdicional.ultimaFechaEnvioApsiReloj,
            --EmpleadoAdicional.ultimoMovimientoEnvioApsiReloj,
    FROM    dbo.empleados
            LEFT JOIN dbo.Llaves ON dbo.empleados.empresa = dbo.Llaves.empresa
                                    AND dbo.empleados.codigo = dbo.Llaves.codigo
            LEFT JOIN dbo.datosemps ON dbo.empleados.empresa = dbo.datosemps.empresa
                                       AND dbo.empleados.codigo = dbo.datosemps.codigo
            LEFT JOIN dbo.tabulador ON dbo.Llaves.empresa = dbo.tabulador.empresa
                                       AND dbo.Llaves.ocupacion = dbo.tabulador.ocupacion
            LEFT JOIN dbo.periodos ON dbo.Llaves.empresa = dbo.periodos.empresa
                                      AND dbo.Llaves.tiponom = dbo.periodos.tiponom
                                      AND dbo.periodos.estatus = 'A'
            LEFT JOIN dbo.nominas ON dbo.Llaves.empresa = dbo.nominas.empresa
                                     AND dbo.Llaves.tiponom = dbo.nominas.tiponom
            LEFT JOIN dbo.centros ON dbo.Llaves.empresa = dbo.centros.empresa
                                     AND dbo.Llaves.centro = dbo.centros.centro
            LEFT JOIN dbo.infonavit ON dbo.empleados.empresa = dbo.infonavit.empresa
                                       AND dbo.empleados.codigo = dbo.infonavit.codigo
            --LEFT JOIN dbo.EmpleadoAdicional AS EmpleadoAdicional ON dbo.empleados.codigo = EmpleadoAdicional.codigo
            --                                                        AND dbo.empleados.empresa = EmpleadoAdicional.empresa
    WHERE   ( dbo.empleados.codigo = @ncodigo
              AND dbo.empleados.empresa = @nempresa
            )
GO

IF OBJECT_ID('dbo.sp_inicializa_parte_variable') IS NOT NULL
    DROP PROCEDURE dbo.sp_inicializa_parte_variable
GO
CREATE PROCEDURE [dbo].[sp_inicializa_parte_variable]
    @nempresa INTEGER = 0 ,
    @ncodigo NUMERIC(8, 0) = 0
AS
    DECLARE @cvar_sigmes CHAR(1)

    SELECT  @cvar_sigmes = var_sigmes
    FROM    empleados
    WHERE   empresa = @nempresa
            AND codigo = @ncodigo

    IF @cvar_sigmes = NULL
        OR @cvar_sigmes = 'F'
        UPDATE  empleados
        SET     varia_imss = 0
        WHERE   empresa = @nempresa
                AND codigo = @ncodigo
    ELSE
        UPDATE  empleados
        SET     varia_imss = varia_next ,
                varia_next = 0 ,
                var_sigmes = 'F'
        WHERE   empresa = @nempresa
                AND codigo = @ncodigo
GO

IF OBJECT_ID('dbo.sp_inserta_aviso_imss_fun_a') IS NOT NULL
    DROP PROCEDURE dbo.sp_inserta_aviso_imss_fun_a
GO
CREATE PROCEDURE [dbo].[sp_inserta_aviso_imss_fun_a]
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @nserial INT ,
    @nmes_operacion INT ,
    @nayo_operacion INT ,
    @dfch_mov DATETIME ,
    @dfch_real DATETIME ,
    @cmov VARCHAR(2) ,
    @nsaldiaint DECIMAL(9, 2) ,
    @nsaldiaiv DECIMAL(9, 2) ,
    @nsueldo DECIMAL(9, 2) ,
    @ndiastr INT ,
    @nincap INT ,
    @nausen DECIMAL(5, 2) ,
    @ncvebaja INT ,
    @cmotbaja VARCHAR(30) ,
    @nsdoant DECIMAL(9, 2) ,
    @nsdiant DECIMAL(9, 2) ,
    @corigen CHAR(2) ,
    @salDiaIv DECIMAL(10, 2) ,
    @campo_07 DATETIME ,
    @fechaEnvio DATETIME ,
    @estatus VARCHAR(25) ,
    @fechaConfirmacion DATETIME ,
    @lote VARCHAR(25),
    @rpu VARCHAR(3)
AS
    INSERT  dbo.avisos_imss
            ( empresa ,
              codigo ,
              serial ,
              mes_operacion ,
              ayo_operacion ,
              fch_mov ,
              fch_real ,
              mov ,
              saldiaint ,
              --saldiaiv ,
              sueldo ,
              diastr ,
              incap ,
              ausen ,
              clave_baja ,
              mot_baja ,
              sueldoant ,
              saldiaintant ,
              origen ,
              saldiaiv ,
              campo_07 ,
              fechaEnvio ,
              estatus ,
              fechaConfirmacion ,
              lote,
              rpu
            )
    VALUES  ( @nempresa ,
              @ncodigo ,
              @nserial ,
              @nmes_operacion ,
              @nayo_operacion ,
              @dfch_mov ,
              @dfch_real ,
              @cmov ,
              @nsaldiaint ,
              --@nsaldiaiv ,
              @nsueldo ,
              @ndiastr ,
              @nincap ,
              @nausen ,
              @ncvebaja ,
              @cmotbaja ,
              @nsdoant ,
              @nsdiant ,
              @corigen ,
              @salDiaIv ,
              @campo_07 ,
              @fechaEnvio ,
              @estatus ,
              @fechaConfirmacion ,
              @lote,
              @rpu
            )
GO

IF OBJECT_ID('dbo.sp_marca_como_borrado') IS NOT NULL 
    DROP PROCEDURE dbo.sp_marca_como_borrado
go


CREATE PROCEDURE dbo.sp_marca_como_borrado
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @nmes INT ,
    @nayo INT
AS 
    UPDATE  dbo.empleados
    SET     dbo.empleados.activo = 'N' ,
            dbo.empleados.borrado = 'S' ,
            dbo.empleados.fch_baja = NULL ,
            dbo.empleados.ultmov = ' ' ,
            dbo.empleados.ultfchmov = ' '
    WHERE   dbo.empleados.empresa = @nempresa
            AND dbo.empleados.codigo = @ncodigo

    DELETE  dbo.avisos_imss
    WHERE   dbo.avisos_imss.empresa = @nempresa
            AND dbo.avisos_imss.codigo = @ncodigo
            AND RIGHT(dbo.avisos_imss.ayo_operacion, 4) + RIGHT(100
                                                              + dbo.avisos_imss.mes_operacion,
                                                              2) >= RIGHT(@nayo,
                                                              4) + RIGHT(100
                                                              + @nmes, 2)
go

IF OBJECT_ID('dbo.sp_saca_ausencias_fun_a') IS NOT NULL 
    DROP PROCEDURE dbo.sp_saca_ausencias_fun_a
GO

CREATE PROCEDURE [dbo].[sp_saca_ausencias_fun_a]
    @nempresa NUMERIC(5, 0) ,
    @ncodigo NUMERIC(8, 0) ,
    @dsig_mes DATETIME
AS 
   DECLARE @folioMax INT
   DECLARE @fechaOperacion DATETIME
   
   SELECT @fechaOperacion = CONVERT (DATETIME, STR(empresa.ayo_operacion) + RIGHT(100 + empresa.mes_operacion,2) + '01', 112)
   FROM dbo.empresas AS empresa
   WHERE empresa.empresa = @nempresa

   
   SELECT @folioMax = MAX(dbo.deducciones.folio) 
   FROM dbo.deducciones
   WHERE dbo.deducciones.empresa = @nempresa
         AND dbo.deducciones.codigo = @ncodigo
         AND dbo.deducciones.fchinicio >= @fechaOperacion --@dsig_mes
   
   --SET @folioMax = CASE WHEN @folioMax IS NULL THEN 0 ELSE @folioMax END

   SELECT  dbo.deducciones.folio ,
           dbo.deducciones.num_conc ,
           dbo.deducciones.tiponom ,
           dbo.deducciones.tipoinc ,
           dbo.deducciones.dias ,
           dbo.deducciones.numeroinc ,
           dbo.deducciones.fchinicio ,
           dbo.deducciones.inicsubs ,
           dbo.deducciones.descuento ,
           dbo.deducciones.periodo ,
           dbo.deducciones.fch_pago ,
           dbo.deducciones.justificar ,
           dbo.deducciones.empresa ,
           dbo.deducciones.codigo,
           dbo.deducciones.ayo_operacion,
           dbo.deducciones.mes_operacion,
           CASE WHEN @folioMax IS NULL THEN dbo.deducciones.folio ELSE @folioMax END AS folioMax --@folioMax AS folioMax
   FROM    dbo.deducciones
   WHERE   dbo.deducciones.empresa >= CASE WHEN @nempresa = 0 THEN 1
                                           ELSE @nempresa
                                      END
           AND dbo.deducciones.empresa <= CASE WHEN @nempresa = 0 THEN 9999
                                               ELSE @nempresa
                                          END
           AND dbo.deducciones.codigo >= CASE WHEN @ncodigo = 0 THEN 1
                                              ELSE @ncodigo
                                         END
           AND dbo.deducciones.codigo <= CASE WHEN @ncodigo = 0 THEN 99999999
                                              ELSE @ncodigo
                                         END
           AND dbo.deducciones.fchinicio + dias - 1 >= @dsig_mes
           AND dbo.deducciones.num_conc BETWEEN 108 AND 111
   ORDER BY dbo.deducciones.empresa ,
            dbo.deducciones.codigo ,
            dbo.deducciones.fchinicio
GO

IF OBJECT_ID('dbo.sp_saca_ausencias_fun_d') IS NOT NULL 
    DROP PROCEDURE dbo.sp_saca_ausencias_fun_d
GO

CREATE PROCEDURE [dbo].[sp_saca_ausencias_fun_d]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @nmes_ini INTEGER = 0 ,
    @nmes_fin INTEGER = 0 ,
    @nayo_ini INTEGER = 0 ,
    @nayo_fin INTEGER = 0
AS 
    DECLARE @fechaInicio DATETIME
    DECLARE @fechaFin DATETIME
    
    SET @fechaInicio = CONVERT(DATETIME, RIGHT(STR(@nayo_ini),4) + RIGHT(STR(100 + @nmes_ini),2) + '01')
    SET @fechaFin = CONVERT(DATETIME, RIGHT(STR(@nayo_fin),4) + RIGHT(STR(100 + @nmes_fin),2) + '01')

    SELECT  deducciones.num_conc ,
            CASE WHEN deducciones.fchinicio < @fechaInicio THEN DATEDIFF(dd, @fechaInicio, deducciones.fchtermino) + 1 ELSE deducciones.dias END AS dias,
            CASE WHEN deducciones.fchinicio <= @fechaInicio THEN @fechaInicio ELSE deducciones.fchinicio END AS fchinicio,
            deducciones.numeroinc ,
            deducciones.inicsubs ,
            deducciones.varia1 ,
            deducciones.varia2 ,
            deducciones.folio ,
            conceptos.concepto,
			[dbo].[NOM_FUN_ObtieneDescripcionIncidencia](deducciones.empresa, deducciones.num_conc, deducciones.justificar, deducciones.inicsubs, deducciones.clase, deducciones.centro) AS nombreConcepto
    FROM    dbo.deducciones AS deducciones
            INNER JOIN conceptos ON conceptos.empresa = deducciones.empresa
                                    AND conceptos.num_conc = deducciones.num_conc
                                    AND dbo.conceptos.clase = ' '
                                    AND dbo.conceptos.centro = ' '
    WHERE   deducciones.empresa = @nempresa
            AND deducciones.codigo = @ncodigo
            AND deducciones.fchtermino >= @fechaInicio
            --AND ( ( deducciones.fchinicio <= @fechaInicio
            --        AND deducciones.fchtermino >= @fechaInicio
            --        AND deducciones.fchinicio <= @fechaFin
            --      )
            --      OR ( deducciones.fchinicio >= @fechaInicio
            --           AND deducciones.fchtermino <= @fechaFin
            --         )
            --      OR ( deducciones.fchinicio >= @fechaInicio
            --           AND deducciones.fchinicio <= @fechaFin
            --           AND deducciones.fchtermino >= @fechaFin
            --         )
            --      OR ( deducciones.fchinicio <= @fechaInicio
            --           AND deducciones.fchtermino >= @fechaFin
            --         )
            --    )   
            AND deducciones.num_conc >= 108
            AND deducciones.num_conc <= 111
    ORDER BY --deducciones.ayo_operacion ,
            --deducciones.mes_operacion ,
            deducciones.fchinicio,
            deducciones.folio
GO

IF OBJECT_ID('dbo.sp_saca_casos_rt') IS NOT NULL
    DROP PROCEDURE dbo.sp_saca_casos_rt
GO
CREATE PROCEDURE dbo.sp_saca_casos_rt
    @nempresa NUMERIC(5, 0) ,
    @dfchbaja DATETIME ,
    @nayo INT
AS
    SELECT  empleados.codigo ,
            RTRIM(empleados.ap_paterno) + ' ' + RTRIM(ap_materno) + ' '
            + RTRIM(empleados.nombre) ,
            casos_rt.caso ,
            empleados.afiliacion ,
            empleados.digvera ,
            llaves.centro
    FROM    empleados
            LEFT JOIN casos_rt ON casos_rt.empresa = empleados.empresa
                                  AND casos_rt.codigo = empleados.codigo
                                  AND casos_rt.ayo_operacion = @nayo
            INNER JOIN llaves ON llaves.codigo = empleados.codigo
                                 AND llaves.empresa = empleados.empresa
    WHERE   empleados.empresa = @nempresa
            AND ( empleados.activo = 'S'
                  OR ( empleados.activo = 'N'
                       AND empleados.fch_baja >= @dfchbaja
                     )
                )
    ORDER BY empleados.codigo
GO

IF OBJECT_ID('dbo.sp_saca_trabajadores_mes_operacion') IS NOT NULL 
    DROP PROCEDURE dbo.sp_saca_trabajadores_mes_operacion
GO

CREATE PROCEDURE [dbo].[sp_saca_trabajadores_mes_operacion]
    @nempresa NUMERIC(5, 0) ,
    @nmes_ini INT ,
    @nmes_fin INT ,
    @nayo_ini INT ,
    @nayo_fin INT
AS 
    SELECT  empleados.codigo ,
            RTRIM(empleados.ap_paterno) + ' ' + RTRIM(empleados.ap_materno)
            + ' ' + RTRIM(empleados.nombre) AS nombre ,
            empleados.fchalta ,
            empleados.fchantigua ,
            empleados.var_sigmes ,
            empleados.varia_imss ,
            empleados.varia_next ,
            --( SELECT TOP 1
            --            dbo.avisos_imss.mov
            --  FROM      dbo.avisos_imss
            --  WHERE     dbo.avisos_imss.empresa = empleados.empresa
            --            AND dbo.avisos_imss.codigo = empleados.codigo
            --            AND dbo.avisos_imss.fch_mov >= avisoEmpleado.fch_mov
            --  ORDER BY  dbo.avisos_imss.fch_mov DESC ,
            --            dbo.avisos_imss.serial DESC
            --) AS mov ,   --dbo.avisos_imss.mov ,
            ultimoAviso.mov,
            --( SELECT TOP 1
            --            dbo.avisos_imss.fch_mov
            --  FROM      dbo.avisos_imss
            --  WHERE     dbo.avisos_imss.empresa = empleados.empresa
            --            AND dbo.avisos_imss.codigo = empleados.codigo
            --            AND dbo.avisos_imss.fch_mov >= avisoEmpleado.fch_mov
            --  ORDER BY  dbo.avisos_imss.fch_mov DESC ,
            --            dbo.avisos_imss.serial DESC
            --) AS fch_mov ,    --dbo.avisos_imss.fch_mov ,
            ultimoAviso.fch_mov,
            --( SELECT TOP 1
            --            dbo.avisos_imss.sueldo
            --  FROM      dbo.avisos_imss
            --  WHERE     dbo.avisos_imss.empresa = empleados.empresa
            --            AND dbo.avisos_imss.codigo = empleados.codigo
            --            AND dbo.avisos_imss.fch_mov >= avisoEmpleado.fch_mov
            --  ORDER BY  dbo.avisos_imss.fch_mov DESC ,
            --            dbo.avisos_imss.serial DESC
            --) AS sueldo ,   --dbo.avisos_imss.sueldo ,
            ultimoAviso.sueldo,
            --( SELECT TOP 1
            --            dbo.avisos_imss.saldiaint
            --  FROM      dbo.avisos_imss
            --  WHERE     dbo.avisos_imss.empresa = empleados.empresa
            --            AND dbo.avisos_imss.codigo = empleados.codigo
            --            AND dbo.avisos_imss.fch_mov >= avisoEmpleado.fch_mov
            --  ORDER BY  dbo.avisos_imss.fch_mov DESC ,
            --            dbo.avisos_imss.serial DESC
            --) AS saldiaint ,  --dbo.avisos_imss.saldiaint ,
            ultimoAviso.saldiaint,
            llaves.clase ,
            llaves.centro ,
            llaves.horario ,
            llaves.tiponom ,
            llaves.ocupacion ,
            empleados.jornada ,
            empleados.tiposal ,
            empleados.multiple ,
            empleados.rpu ,
            --( SELECT TOP 1
            --            salarioMinimo.zona_a
            --  FROM      dbo.avisos_imss AS avisoImss
            --            LEFT JOIN dbo.salarios_minimos AS salarioMinimo ON CASE WHEN avisoImss.mov = 'IM'
            --                                                                         AND MONTH(avisoImss.fch_mov) = 1
            --                                                                         AND DAY(avisoImss.fch_mov) = 1
            --                                                                    THEN avisoImss.fch_mov - 1
            --                                                                    ELSE avisoImss.fch_mov
            --                                                               END >= salarioMinimo.fecha_ini 
            --                                                                      AND CASE WHEN avisoImss.mov = 'IM'
            --                                                                                    AND MONTH(avisoImss.fch_mov) = 1
            --                                                                                    AND DAY(avisoImss.fch_mov) = 1
            --                                                                               THEN avisoImss.fch_mov - 1
            --                                                                               ELSE avisoImss.fch_mov
            --                                                                          END <= salarioMinimo.fecha_fin
            --  WHERE     avisoImss.fch_mov >= avisoEmpleado.fch_mov
            --            AND avisoImss.codigo = avisoEmpleado.codigo
            --            AND avisoImss.empresa = avisoEmpleado.empresa
            --  ORDER BY  avisoImss.fch_mov DESC ,
            --            avisoImss.serial DESC
            --) AS salarioMinimoDfUltimoAviso ,
            salarioMinimo.salarioGeneral AS salarioMinimoDfUltimoAviso ,
            --( SELECT TOP 1
            --            CASE WHEN empresa.zona_geografica = 'A'
            --                 THEN salarioMinimo.zona_a
            --                 WHEN empresa.zona_geografica = 'B'
            --                 THEN salarioMinimo.zona_b
            --                 WHEN empresa.zona_geografica = 'C'
            --                 THEN salarioMinimo.zona_c
            --                 ELSE 0
            --            END
            --  FROM      dbo.avisos_imss AS avisoImss
            --            LEFT JOIN dbo.salarios_minimos AS salarioMinimo ON CASE WHEN avisoImss.mov = 'IM'
            --                                                                         AND MONTH(avisoImss.fch_mov) = 1
            --                                                                         AND DAY(avisoImss.fch_mov) = 1
            --                                                                    THEN avisoImss.fch_mov - 1
            --                                                                    ELSE avisoImss.fch_mov
            --                                                                END >= salarioMinimo.fecha_ini 
            --                                                                       AND CASE WHEN avisoImss.mov = 'IM'
            --                                                                                     AND MONTH(avisoImss.fch_mov) = 1
            --                                                                                     AND DAY(avisoImss.fch_mov) = 1
            --                                                                                THEN avisoImss.fch_mov - 1
            --                                                                                ELSE avisoImss.fch_mov
            --                                                                           END <= salarioMinimo.fecha_fin
            --            INNER JOIN dbo.empresas AS empresa ON avisoImss.empresa = empresa.empresa
            --  WHERE     avisoImss.fch_mov >= avisoEmpleado.fch_mov
            --            AND avisoImss.codigo = avisoEmpleado.codigo
            --            AND avisoImss.empresa = avisoEmpleado.empresa
            --  ORDER BY  avisoImss.fch_mov DESC ,
            --            avisoImss.serial DESC
            --) AS salarioMinimoRegionUltimoAviso,
            salarioMinimo.salarioGeneral AS salarioMinimoRegionUltimoAviso,
            empleados.afiliacion,
            empleados.digvera,
            ISNULL(ultimoAviso.serial,0) AS serial,
            ISNULL(ultimoAviso.sueldo,0) AS ultimoSueldo,
            ISNULL(ultimoAviso.saldiaint,0) AS ultimoSaldiaint
    FROM    dbo.empleados AS empleados
            INNER JOIN llaves ON llaves.empresa = empleados.empresa
                                 AND llaves.codigo = empleados.codigo
            /*
            INNER JOIN ( SELECT dbo.avisos_imss.empresa ,
                                dbo.avisos_imss.codigo ,
                                MAX(dbo.avisos_imss.fch_mov) AS fch_mov
                         FROM   dbo.avisos_imss
                         WHERE  dbo.avisos_imss.empresa = @nempresa
                                AND RIGHT(10000
                                          + dbo.avisos_imss.ayo_operacion, 4)
                                + RIGHT(100 + dbo.avisos_imss.mes_operacion, 2) >= RIGHT(10000
                                                              + @nayo_ini, 4)
                                + RIGHT(100 + @nmes_ini, 2)
                                AND RIGHT(10000
                                          + dbo.avisos_imss.ayo_operacion, 4)
                                + RIGHT(100 + dbo.avisos_imss.mes_operacion, 2) <= RIGHT(10000
                                                              + @nayo_fin, 4)
                                + RIGHT(100 + @nmes_fin, 2)
                         GROUP BY dbo.avisos_imss.empresa ,
                                dbo.avisos_imss.codigo
                       ) AS avisoEmpleado ON empleados.empresa = avisoEmpleado.empresa
                                             AND empleados.codigo = avisoEmpleado.codigo
            */                                             
            CROSS APPLY (SELECT TOP 1
                                ultimoAviso.empresa,
                                ultimoAviso.codigo,
                                ultimoAviso.mov,
                                ultimoAviso.fch_mov,
                                ultimoAviso.serial,
                                ultimoAviso.sueldo,
                                ultimoAviso.saldiaint
                         FROM dbo.avisos_imss AS ultimoAviso
                                    WHERE ultimoAviso.empresa = empleados.empresa
                                          AND ultimoAviso.codigo = empleados.codigo
                                          --AND ultimoAviso.fch_mov <= CASE WHEN @fechaFinMes = @fechaFinMesOperacion THEN DATEADD(MM,1, @fechaFinMes) ELSE @fechaFinMes END
                                          AND RIGHT(10000 + ultimoAviso.ayo_operacion, 4) + RIGHT(100 + ultimoAviso.mes_operacion, 2) >= RIGHT(10000 + @nayo_ini, 4) + RIGHT(100 + @nmes_ini, 2)
                                          AND RIGHT(10000 + ultimoAviso.ayo_operacion, 4) + RIGHT(100 + ultimoAviso.mes_operacion, 2) <= RIGHT(10000 + @nayo_fin, 4) + RIGHT(100 + @nmes_fin, 2)
                                          
                                    ORDER BY ultimoAviso.fch_mov DESC ,
                                             ultimoAviso.serial DESC) AS ultimoAviso
            CROSS APPLY (SELECT TOP 1 salarioMinimo.zona_a AS salarioGeneral
                         FROM dbo.salarios_minimos AS salarioMinimo
                         WHERE salarioMinimo.fecha_ini <= ultimoAviso.fch_mov
                         ORDER BY salarioMinimo.fecha_ini DESC) AS salarioMinimo
    WHERE   empleados.empresa = @nempresa
            AND empleados.borrado = 'N'
            AND empleados.activo = 'S'
GO

IF OBJECT_ID('dbo.sp_suma_variables') IS NOT NULL
    DROP PROCEDURE dbo.sp_suma_variables
GO
CREATE PROCEDURE [dbo].[sp_suma_variables]
    @ncodigo NUMERIC(8, 0) = 0 ,
    @nempresa INTEGER = 0 ,
    @nmes_ini INTEGER = 0 ,
    @nmes_fin INTEGER = 0 ,
    @nayo_ini INTEGER = 0 ,
    @nayo_fin INTEGER = 0
AS
    SELECT  SUM(ISNULL(dbo.percepciones.varia_imss,0))
    FROM    dbo.percepciones
    WHERE   dbo.percepciones.empresa = @nempresa
            AND dbo.percepciones.codigo = @ncodigo
            AND dbo.percepciones.ayo_operacion = @nayo_ini
            AND dbo.percepciones.mes_operacion IN ( @nmes_ini, @nmes_fin )
GO

IF OBJECT_ID('dbo.TieneDeduccionesFuncionD') IS NOT NULL
   DROP PROCEDURE dbo.TieneDeduccionesFuncionD
GO   
CREATE PROCEDURE dbo.TieneDeduccionesFuncionD
@empresa INT
, @codigo INT
, @ayo_operacion INT
, @periodo INT

AS

  SET NOCOUNT ON

  SELECT TOP 1
         1 AS existe
  FROM dbo.deducciones AS d
  WHERE d.empresa = @empresa  
        AND d.codigo = @codigo
		AND d.ayo_operacion = @ayo_operacion
		AND d.periodo = @periodo
		AND (d.num_conc < 108 OR d.num_conc > 111)
GO

IF OBJECT_ID('dbo.TienePercepcionesFuncionD') IS NOT NULL
   DROP PROCEDURE dbo.TienePercepcionesFuncionD
GO   
CREATE PROCEDURE dbo.TienePercepcionesFuncionD
@empresa INT
, @codigo INT
, @ayo_operacion INT
, @periodo INT

AS

  SET NOCOUNT ON

  SELECT TOP 1
         1 AS existe
  FROM dbo.percepciones AS p
  WHERE p.empresa = @empresa
        AND p.codigo = @codigo
	    AND p.ayo_operacion = @ayo_operacion
        AND p.periodo = @periodo
GO

/**************************************************************************************************
 * Name          : ValidaApliacionSalariosVariables
 * Project       : APSI Nomina
 * Description   : Revisa si el contenido de la tabla corresponde al bimestre que se va a aplicar
 * Table name    : tmp_vras
 * Return        : 
 * Copyright     : (c) Apsi 2009 - 2014. All rights reserved
 * Company       : Apsi. (http://www.Apsi.com/)
 * Author        : Jorge Mtz (jorge.martinez@apsi.com.mx)
 * Creation date : Jueves, Septiembre 23, 2010
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    sysobjects
            WHERE   type = 'P'
                    AND name = 'ValidaApliacionSalariosVariables' ) 
    BEGIN
        DROP  PROCEDURE [dbo].[ValidaApliacionSalariosVariables]
    END
GO


CREATE PROCEDURE [dbo].[ValidaApliacionSalariosVariables]
    @empresa INT ,
    @fecha DATETIME
AS 

DECLARE @valor INT
DECLARE @fechaVariable DATETIME

    IF EXISTS ( SELECT  dbo.tmp_vars.codigo
                FROM    dbo.tmp_vars
                WHERE   dbo.tmp_vars.empresa = @empresa
                        AND CONVERT(DATETIME, '20' + dbo.tmp_vars.ano
                        + dbo.tmp_vars.mes + dbo.tmp_vars.dia) = @fecha ) 
       BEGIN
        SET @valor = 1
       END
    ELSE 
       BEGIN
        SET @valor = 0
        
        SELECT TOP 1 @fechaVariable = CONVERT(DATETIME, '20' + dbo.tmp_vars.ano + dbo.tmp_vars.mes + dbo.tmp_vars.dia)
        FROM dbo.tmp_vars
        WHERE dbo.tmp_vars.empresa = @empresa AND CONVERT(DATETIME, '20' + dbo.tmp_vars.ano
                        + dbo.tmp_vars.mes + dbo.tmp_vars.dia) <> @fecha
       END
       
       SELECT @valor AS valor, @fechaVariable AS fechaVariable
        
GO

IF OBJECT_ID('dbo.VerificaPrimaRt') IS NOT NULL
   DROP PROCEDURE dbo.VerificaPrimaRt
GO
CREATE PROCEDURE dbo.VerificaPrimaRt
@empresa INT ,
@fecha DATETIME
AS
DECLARE @ayoEmpresa INT
DECLARE @mesEmpresa INT
DECLARE @fechaEmpresa DATETIME

SELECT  @ayoEmpresa = empresa.ayo_operacion ,
        @mesEmpresa = empresa.mes_operacion
FROM    dbo.empresas AS empresa
WHERE   empresa.empresa = @empresa

SET @fechaEmpresa = RIGHT(10000 + @ayoEmpresa, 4) + RIGHT(100 + @mesEmpresa, 2) + '01'

IF @fecha = @fechaEmpresa 
    BEGIN
        DELETE  primasRt
        FROM    dbo.primas_rt AS primasRt
        WHERE   primasRt.prima_rt = 0
                AND primasRt.empresa = @empresa

        DELETE  primasRt
        FROM    dbo.primas_rt AS primasRt
        WHERE   primasRt.fecha_inicial > @fecha
                AND primasRt.empresa = @empresa
                
        IF NOT EXISTS (SELECT primaRt.empresa
                       FROM dbo.primas_rt AS primaRt
                       WHERE primaRt.fecha_inicial = @fecha
                             AND primaRt.empresa = @empresa)
           BEGIN
               INSERT  dbo.primas_rt
                     ( empresa ,
                       fecha_inicial ,
                       fecha_final ,
                       prima_rt ,
                       prima_omitida ,
                       sw_omitida
                     )
                     SELECT TOP 1
                            primaRt.empresa ,
                            @fecha ,
                            primaRt.fecha_final ,
                            primaRt.prima_rt ,
                            primaRt.prima_omitida ,
                            primaRt.sw_omitida
                     FROM    dbo.primas_rt AS primaRt
                     WHERE   primaRt.empresa = @empresa
                     ORDER BY primaRt.fecha_inicial DESC
           END
                
        UPDATE  primaRt
        SET     primaRt.fecha_final = ISNULL(( SELECT TOP 1
                                                        primaRt1.fecha_inicial
                                                        - 1
                                               FROM     dbo.primas_rt AS primaRt1
                                               WHERE    primaRt1.fecha_inicial > primaRt.fecha_inicial
                                                        AND primaRt1.empresa = primaRt.empresa
                                             ), '29991231')
        FROM    dbo.primas_rt AS primaRt
        WHERE   primaRt.empresa = @empresa 
        
    END
GO

PRINT 'GO'
GO